@@ -51,6 +51,7 @@
 
 //---------------------------------------------------------
 #include <wx/stdpaths.h>
+#include <wx/app.h>
 
 #include "api_core.h"
 #include "grid.h"
@@ -64,14 +65,65 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#if defined(_SAGA_MSW)
-	#define CONSOLE_STDIO      printf(        CSG_String::Format
-	#define CONSOLE_STDERR    fprintf(stderr, CSG_String::Format
+#ifdef _SAGA_MSW
+static bool gSG_UI_Console_bUTF8 = false;
 #else
-	#define CONSOLE_STDIO   SG_Printf(        CSG_String::Format
-	#define CONSOLE_STDERR SG_FPrintf(stderr, CSG_String::Format
+static bool gSG_UI_Console_bUTF8 = true;
 #endif
 
+void	SG_UI_Console_Set_UTF8(bool bOn) {          gSG_UI_Console_bUTF8 = bOn; }
+bool	SG_UI_Console_Get_UTF8(void)     {	return( gSG_UI_Console_bUTF8 );     }
+
+//---------------------------------------------------------
+void	SG_UI_Console_Print_StdOut(const char       *Text, SG_Char End, bool bFlush) { SG_UI_Console_Print_StdOut(CSG_String(Text), End, bFlush); }
+void	SG_UI_Console_Print_StdOut(const wchar_t    *Text, SG_Char End, bool bFlush) { SG_UI_Console_Print_StdOut(CSG_String(Text), End, bFlush); }
+void	SG_UI_Console_Print_StdOut(const CSG_String &Text, SG_Char End, bool bFlush)
+{
+	if( gSG_UI_Console_bUTF8 )
+	{
+		printf("%s", Text.to_UTF8 ().Get_Data());
+	}
+	else
+	{
+		printf("%s", Text.to_ASCII().Get_Data());
+	}
+
+	if( End )
+	{
+		printf("%c", End);
+	}
+
+	if( bFlush )
+	{
+		fflush(stdout);
+	}
+}
+
+//---------------------------------------------------------
+void	SG_UI_Console_Print_StdErr(const char       *Text, SG_Char End, bool bFlush) { SG_UI_Console_Print_StdErr(CSG_String(Text), End, bFlush); }
+void	SG_UI_Console_Print_StdErr(const wchar_t    *Text, SG_Char End, bool bFlush) { SG_UI_Console_Print_StdErr(CSG_String(Text), End, bFlush); }
+void	SG_UI_Console_Print_StdErr(const CSG_String &Text, SG_Char End, bool bFlush)
+{
+	if( gSG_UI_Console_bUTF8 )
+	{
+		fprintf(stderr, "%s", Text.to_UTF8 ().Get_Data());
+	}
+	else
+	{
+		fprintf(stderr, "%s", Text.to_ASCII().Get_Data());
+	}
+
+	if( End )
+	{
+		printf("%c", End);
+	}
+
+	if( bFlush )
+	{
+		fflush(stderr);
+	}
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -136,6 +188,12 @@ int			SG_UI_Progress_Lock(bool bOn)
 	return( gSG_UI_Progress_Lock );
 }
 
+//---------------------------------------------------------
+bool		SG_UI_Progress_is_Locked(void)
+{
+	return( gSG_UI_Progress_Lock != 0 );
+}
+
 //---------------------------------------------------------
 int			SG_UI_Progress_Reset(void)
 {
@@ -158,13 +216,11 @@ bool		SG_UI_Process_Get_Okay(bool bBlink)
 
 	if( gSG_UI_Progress_Lock == 0 && bBlink )
 	{
-		static const SG_Char	Buisy[4]	= {	'|', '/', '-', '\\'	};
+		static int iBuisy = 0; static const SG_Char Buisy[4] = { '|', '/', '-', '\\' };
 
-		static int	iBuisy	= 0;
+		SG_UI_Console_Print_StdOut(CSG_String::Format("\r%c", Buisy[iBuisy++]), '\0', true);
 
-		CONSOLE_STDIO("\r%c   ", Buisy[iBuisy++]));
-
-		iBuisy	%= 4;
+		iBuisy %= 4;
 	}
 
 	return( true );
@@ -224,22 +280,22 @@ bool		SG_UI_Process_Set_Progress(double Position, double Range)
 	}
 
 	//-----------------------------------------------------
-	static int	iPercent	= -1;
+	static int Progress = -1;
 
-	int	i	= Position < 0.0 ? -1 : Range > 0.0 ? 1 + (int)(100.0 * Position / Range) : 100;
+	int i = Position < 0. ? -1 : Range > 0. ? 1 + (int)(100. * Position / Range) : 100;
 
-	if( iPercent != i )
+	if( Progress != i )
 	{
-		if( iPercent < 0 || i < iPercent )
+		if( Progress < 0 || i < Progress )
 		{
-			CONSOLE_STDIO("\n"));
+			SG_UI_Console_Print_StdOut("", '\n', true);
 		}
 
-		iPercent	= i;
+		Progress = i;
 
-		if( iPercent >= 0 )
+		if( Progress >= 0 )
 		{
-			CONSOLE_STDIO("\r%3d%%", iPercent > 100 ? 100 : iPercent));
+			SG_UI_Console_Print_StdOut(CSG_String::Format("\r%3d%%", Progress > 100 ? 100 : Progress), '\0', true);
 		}
 	}
 
@@ -277,7 +333,7 @@ void		SG_UI_Process_Set_Text(const CSG_String &Text)
 		}
 		else
 		{
-			CONSOLE_STDIO("%s\n", Text.c_str()));
+			SG_UI_Console_Print_StdOut(Text, '\n', true);
 		}
 	}
 }
@@ -322,7 +378,7 @@ void		SG_UI_Dlg_Message(const CSG_String &Message, const CSG_String &Caption)
 		}
 		else
 		{
-			CONSOLE_STDIO("%s: %s\n", Caption.c_str(), Message.c_str()));
+			SG_UI_Console_Print_StdOut(CSG_String::Format("%s: %s", Caption.c_str(), Message.c_str()), '\n', true);
 		}
 	}
 }
@@ -377,7 +433,7 @@ void		SG_UI_Dlg_Info(const CSG_String &Message, const CSG_String &Caption)
 		}
 		else
 		{
-			CONSOLE_STDIO("%s: %s\n", Caption.c_str(), Message.c_str()));
+			SG_UI_Console_Print_StdOut(CSG_String::Format("%s: %s", Caption.c_str(), Message.c_str()), '\n', true);
 		}
 	}
 }
@@ -427,6 +483,12 @@ int			SG_UI_Msg_Lock(bool bOn)
 	return( gSG_UI_Msg_Lock );
 }
 
+//---------------------------------------------------------
+bool		SG_UI_Msg_is_Locked(void)
+{
+	return( gSG_UI_Msg_Lock != 0 );
+}
+
 //---------------------------------------------------------
 int			SG_UI_Msg_Reset(void)
 {
@@ -438,66 +500,76 @@ int			SG_UI_Msg_Reset(void)
 }
 
 //---------------------------------------------------------
+void		SG_UI_Msg_Add(const char       *Message, bool bNewLine, TSG_UI_MSG_STYLE Style) { SG_UI_Msg_Add(CSG_String(Message), bNewLine, Style); }
+void		SG_UI_Msg_Add(const wchar_t    *Message, bool bNewLine, TSG_UI_MSG_STYLE Style) { SG_UI_Msg_Add(CSG_String(Message), bNewLine, Style); }
 void		SG_UI_Msg_Add(const CSG_String &Message, bool bNewLine, TSG_UI_MSG_STYLE Style)
 {
-	if( gSG_UI_Msg_Lock )
-		return;
-
-	if( gSG_UI_Callback )
+	if( !gSG_UI_Msg_Lock )
 	{
-		int		Parameters[2];
+		if( gSG_UI_Callback )
+		{
+			int Flags[2]; Flags[0] = bNewLine ? 1 : 0; Flags[1] = Style;
 
-		Parameters[0]	= bNewLine ? 1 : 0;
-		Parameters[1]	= Style;
+			CSG_UI_Parameter p1(Message), p2(Flags);
 
-		CSG_UI_Parameter p1(Message), p2(Parameters);
+			gSG_UI_Callback(CALLBACK_MESSAGE_ADD, p1, p2);
+		}
+		else
+		{
+			if( bNewLine )
+			{
+				SG_UI_Console_Print_StdOut("");
+			}
 
-		gSG_UI_Callback(CALLBACK_MESSAGE_ADD, p1, p2);
-	}
-	else
-	{
-		CONSOLE_STDIO("%s\n", Message.c_str()));
-	}
-}
-
-//---------------------------------------------------------
-void		SG_UI_Msg_Add_Error(const CSG_String &Message)
-{
-	if( gSG_UI_Msg_Lock )
-		return;
-
-	if( gSG_UI_Callback )
-	{
-		CSG_UI_Parameter p1(Message), p2;
-
-		gSG_UI_Callback(CALLBACK_MESSAGE_ADD_ERROR, p1, p2);
-	}
-	else
-	{
-		CONSOLE_STDERR("%s: %s\n", _TL("Error"), Message.c_str()));
+			SG_UI_Console_Print_StdOut(Message, '\0', true);
+		}
 	}
 }
 
 //---------------------------------------------------------
+void		SG_UI_Msg_Add_Execution(const char       *Message, bool bNewLine, TSG_UI_MSG_STYLE Style) { SG_UI_Msg_Add_Execution(CSG_String(Message), bNewLine, Style); }
+void		SG_UI_Msg_Add_Execution(const wchar_t    *Message, bool bNewLine, TSG_UI_MSG_STYLE Style) { SG_UI_Msg_Add_Execution(CSG_String(Message), bNewLine, Style); }
 void		SG_UI_Msg_Add_Execution(const CSG_String &Message, bool bNewLine, TSG_UI_MSG_STYLE Style)
 {
-	if( gSG_UI_Msg_Lock )
-		return;
-
-	if( gSG_UI_Callback )
+	if( !gSG_UI_Msg_Lock )
 	{
-		int		Parameters[2];
+		if( gSG_UI_Callback )
+		{
+			int Flags[2]; Flags[0] = bNewLine ? 1 : 0; Flags[1] = Style;
 
-		Parameters[0]	= bNewLine ? 1 : 0;
-		Parameters[1]	= Style;
+			CSG_UI_Parameter p1(Message), p2(Flags);
 
-		CSG_UI_Parameter p1(Message), p2(Parameters);
+			gSG_UI_Callback(CALLBACK_MESSAGE_ADD_EXECUTION, p1, p2);
+		}
+		else
+		{
+			if( bNewLine )
+			{
+				SG_UI_Console_Print_StdOut("");
+			}
 
-		gSG_UI_Callback(CALLBACK_MESSAGE_ADD_EXECUTION, p1, p2);
+			SG_UI_Console_Print_StdOut(Message, '\0', true);
+		}
 	}
-	else
+}
+
+//---------------------------------------------------------
+void		SG_UI_Msg_Add_Error(const char       *Message) { SG_UI_Msg_Add_Error(CSG_String(Message)); }
+void		SG_UI_Msg_Add_Error(const wchar_t    *Message) { SG_UI_Msg_Add_Error(CSG_String(Message)); }
+void		SG_UI_Msg_Add_Error(const CSG_String &Message)
+{
+	if( !gSG_UI_Msg_Lock )
 	{
-		CONSOLE_STDIO("%s\n", Message.c_str()));
+		if( gSG_UI_Callback )
+		{
+			CSG_UI_Parameter p1(Message), p2;
+
+			gSG_UI_Callback(CALLBACK_MESSAGE_ADD_ERROR, p1, p2);
+		}
+		else
+		{
+			SG_UI_Console_Print_StdErr(CSG_String::Format("\n[%s] %s", _TL("Error"), Message.c_str()), '\0', true);
+		}
 	}
 }
 
@@ -540,7 +612,7 @@ bool		SG_UI_DataObject_Add(CSG_Data_Object *pDataObject, int Show)
 {
 	if( gSG_UI_Callback && pDataObject )
 	{
-		CSG_UI_Parameter p1(pDataObject), p2(Show ? true : false);
+		CSG_UI_Parameter p1(pDataObject), p2(Show);
 
 		return( gSG_UI_Callback(CALLBACK_DATAOBJECT_ADD, p1, p2) != 0 );
 	}
@@ -726,7 +798,7 @@ void *		SG_UI_Get_Window_Main		(void)
 //---------------------------------------------------------
 CSG_String	SG_UI_Get_Application_Path	(bool bPathOnly)
 {
-	CSG_String	App_Path(wxStandardPaths::Get().GetExecutablePath().wc_str());
+	CSG_String App_Path(wxStandardPaths::Get().GetExecutablePath().wc_str());
 
 	if( bPathOnly )
 	{
@@ -736,6 +808,13 @@ CSG_String	SG_UI_Get_Application_Path	(bool bPathOnly)
 	return( SG_File_Get_Path_Absolute(App_Path) );
 }
 
+//---------------------------------------------------------
+CSG_String	SG_UI_Get_Application_Name	(void)
+{
+	return( wxApp::GetInstance()->GetAppName().wc_str() );
+//	return( SG_File_Get_Name(SG_UI_Get_Application_Path(false), false) );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
