@@ -155,8 +155,8 @@
 #endif	// _TYPEDEF_WORD
 
 //---------------------------------------------------------
-	typedef   signed long long	sLong;
-	typedef unsigned long long	uLong;
+typedef   signed long long		sLong;
+typedef unsigned long long		uLong;
 
 //---------------------------------------------------------
 #if defined(_SAGA_MSW)
@@ -391,7 +391,9 @@ public:
 	bool				Add				(void *Value);
 	bool				Add				(const CSG_Array_Pointer &Array);
 	bool				Set				(sLong Index, void *Value)              {	if( !m_Array.Get_Entry(Index) ) return( false ); *((void **)m_Array.Get_Entry(Index)) = Value; return( true );	}
+#ifndef SWIG
 	void *&				Get				(sLong Index)                           {	return( *((void **)m_Array.Get_Entry(Index)) );	}
+#endif
 	void *				Get				(sLong Index)                  const    {	return( *((void **)m_Array.Get_Entry(Index)) );	}
 	bool				Del				(sLong Index);
 	sLong				Del				(void *Value);
@@ -444,7 +446,9 @@ public:
 	bool				Add				(int Value);
 	bool				Add				(const CSG_Array_Int &Array);
 	bool				Set				(sLong Index, int Value)                {	if( !m_Array.Get_Entry(Index) ) return( false ); *((int *)m_Array.Get_Entry(Index)) = Value; return( true );	}
+#ifndef SWIG
 	int &				Get				(sLong Index)                           {	return( *((int *)m_Array.Get_Entry(Index)) );	}
+#endif
 	int	 				Get				(sLong Index)                  const    {	return( *((int *)m_Array.Get_Entry(Index)) );	}
 
 	bool				Assign			(int Value);
@@ -498,7 +502,9 @@ public:
 	bool				Add				(sLong Value);
 	bool				Add				(const CSG_Array_sLong &Array);
 	bool				Set				(sLong Index, sLong Value)              {	if( !m_Array.Get_Entry(Index) ) return( false ); *((sLong *)m_Array.Get_Entry(Index)) = Value; return( true );	}
+#ifndef SWIG
 	sLong &				Get				(sLong Index)                           {	return( *((sLong *)m_Array.Get_Entry(Index)) );	}
+#endif
 	sLong	 			Get				(sLong Index)                  const    {	return( *((sLong *)m_Array.Get_Entry(Index)) );	}
 
 	bool				Assign			(sLong Value);
@@ -529,8 +535,8 @@ private:
 //---------------------------------------------------------
 #define SG_Char				wchar_t
 #define SG_T(s)				L ## s
-#define SG_PRINTF			SG_Printf
-#define SG_FPRINTF			SG_FPrintf
+#define SG_PRINTF			wprintf
+#define SG_FPRINTF			fwprintf
 #define SG_SSCANF			swscanf
 #define SG_STR_CPY			wcscpy
 #define SG_STR_LEN			wcslen
@@ -780,14 +786,6 @@ SAGA_API_DLL_EXPORT CSG_Strings		SG_String_Tokenize				(const CSG_String &String
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT bool			SG_is_Character_Numeric			(int Character);
 
-SAGA_API_DLL_EXPORT int				SG_Printf						(const CSG_String &String);
-SAGA_API_DLL_EXPORT int				SG_Printf						(const  char   *Format, ...);
-SAGA_API_DLL_EXPORT int				SG_Printf						(const wchar_t *Format, ...);
-
-SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE *Stream, const CSG_String &String);
-SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE *Stream, const  char   *Format, ...);
-SAGA_API_DLL_EXPORT int				SG_FPrintf						(FILE *Stream, const wchar_t *Format, ...);
-
 SAGA_API_DLL_EXPORT CSG_String		SG_Get_CurrentTimeStr			(bool bWithDate = true);
 
 SAGA_API_DLL_EXPORT double			SG_Degree_To_Double				(const CSG_String &String);
@@ -800,6 +798,8 @@ SAGA_API_DLL_EXPORT void			SG_Flip_Decimal_Separators		(CSG_String &String);
 SAGA_API_DLL_EXPORT CSG_String		SG_Get_String					(double Value, int Precision = -99);
 SAGA_API_DLL_EXPORT CSG_String		SG_Get_String					(int    Value, int Precision = 0);
 
+SAGA_API_DLL_EXPORT CSG_String		SG_HTML_Tag_Replacer			(const CSG_String &Text);
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -1010,6 +1010,31 @@ typedef enum
 }
 TSG_Data_Type;
 
+//---------------------------------------------------------
+#define SG_DATATYPES_Undefined 0x0000
+#define SG_DATATYPES_Bit       0x0001
+#define SG_DATATYPES_Byte      0x0002
+#define SG_DATATYPES_Char      0x0004
+#define SG_DATATYPES_Word      0x0008
+#define SG_DATATYPES_Short     0x0010
+#define SG_DATATYPES_DWord     0x0020
+#define SG_DATATYPES_Int       0x0040
+#define SG_DATATYPES_ULong     0x0080
+#define SG_DATATYPES_Long      0x0100
+#define SG_DATATYPES_Float     0x0200
+#define SG_DATATYPES_Double    0x0400
+#define SG_DATATYPES_String    0x0800
+#define SG_DATATYPES_Date      0x1000
+#define SG_DATATYPES_Color     0x2000
+#define SG_DATATYPES_Binary    0x4000
+#define SG_DATATYPES_Standard  0xFFFF // all flags set
+#define SG_DATATYPES_SInteger  (SG_DATATYPES_Char|SG_DATATYPES_Short|SG_DATATYPES_Int  |SG_DATATYPES_Long)
+#define SG_DATATYPES_UInteger  (SG_DATATYPES_Byte|SG_DATATYPES_Word |SG_DATATYPES_DWord|SG_DATATYPES_ULong)
+#define SG_DATATYPES_Integer   (SG_DATATYPES_SInteger|SG_DATATYPES_UInteger)
+#define SG_DATATYPES_Real      (SG_DATATYPES_Float|SG_DATATYPES_Double)
+#define SG_DATATYPES_Numeric   (SG_DATATYPES_Integer|SG_DATATYPES_Real)
+#define SG_DATATYPES_Table     (SG_DATATYPES_String|SG_DATATYPES_Date|SG_DATATYPES_Color|SG_DATATYPES_Numeric|SG_DATATYPES_Binary)
+
 //---------------------------------------------------------
 const char	gSG_Data_Type_Identifier[][32]	=
 {
@@ -1059,6 +1084,7 @@ inline size_t	SG_Data_Type_Get_Size	(TSG_Data_Type Type)
 SAGA_API_DLL_EXPORT CSG_String		SG_Data_Type_Get_Name		(TSG_Data_Type Type, bool bShort = false);
 SAGA_API_DLL_EXPORT CSG_String		SG_Data_Type_Get_Identifier	(TSG_Data_Type Type);
 SAGA_API_DLL_EXPORT TSG_Data_Type	SG_Data_Type_Get_Type		(const CSG_String &Identifier);
+SAGA_API_DLL_EXPORT int				SG_Data_Type_Get_Flag		(TSG_Data_Type Type);
 SAGA_API_DLL_EXPORT bool			SG_Data_Type_is_Numeric		(TSG_Data_Type Type);
 SAGA_API_DLL_EXPORT bool			SG_Data_Type_Range_Check	(TSG_Data_Type Type, double &Value);
 
@@ -1198,7 +1224,7 @@ protected:
 
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT bool			SG_Dir_Exists				(const CSG_String &Directory);
-SAGA_API_DLL_EXPORT bool			SG_Dir_Create				(const CSG_String &Directory);
+SAGA_API_DLL_EXPORT bool			SG_Dir_Create				(const CSG_String &Directory, bool bFullPath = false);
 SAGA_API_DLL_EXPORT bool			SG_Dir_Delete				(const CSG_String &Directory, bool bRecursive = false);
 SAGA_API_DLL_EXPORT CSG_String		SG_Dir_Get_Current			(void);
 SAGA_API_DLL_EXPORT CSG_String		SG_Dir_Get_Temp				(void);
@@ -1595,8 +1621,20 @@ typedef int (* TSG_PFNC_UI_Callback) (TSG_UI_Callback_ID ID, CSG_UI_Parameter &P
 SAGA_API_DLL_EXPORT bool					SG_Set_UI_Callback			(TSG_PFNC_UI_Callback Function);
 SAGA_API_DLL_EXPORT TSG_PFNC_UI_Callback	SG_Get_UI_Callback			(void);
 
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Set_UTF8		(bool bOn);
+SAGA_API_DLL_EXPORT bool					SG_UI_Console_Get_UTF8		(void);
+
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Print_StdOut	(const char       *Text, SG_Char End = '\n', bool bFlush = true);
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Print_StdOut	(const wchar_t    *Text, SG_Char End = '\n', bool bFlush = true);
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Print_StdOut	(const CSG_String &Text, SG_Char End = '\n', bool bFlush = true);
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Print_StdErr	(const char       *Text, SG_Char End = '\n', bool bFlush = true);
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Print_StdErr	(const wchar_t    *Text, SG_Char End = '\n', bool bFlush = true);
+SAGA_API_DLL_EXPORT void					SG_UI_Console_Print_StdErr	(const CSG_String &Text, SG_Char End = '\n', bool bFlush = true);
+
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT int						SG_UI_Progress_Lock			(bool bOn);
+SAGA_API_DLL_EXPORT bool					SG_UI_Progress_is_Locked	(void);
 SAGA_API_DLL_EXPORT int						SG_UI_Progress_Reset		(void);
 SAGA_API_DLL_EXPORT bool					SG_UI_Process_Get_Okay		(bool bBlink = false);
 SAGA_API_DLL_EXPORT bool					SG_UI_Process_Set_Okay		(bool bOkay = true);
@@ -1616,10 +1654,17 @@ SAGA_API_DLL_EXPORT void					SG_UI_Dlg_Info				(const CSG_String &Message, const
 SAGA_API_DLL_EXPORT bool					SG_UI_Dlg_Parameters		(class CSG_Parameters *pParameters, const CSG_String &Caption);
 
 SAGA_API_DLL_EXPORT int						SG_UI_Msg_Lock				(bool bOn);
+SAGA_API_DLL_EXPORT bool					SG_UI_Msg_is_Locked			(void);
 SAGA_API_DLL_EXPORT int						SG_UI_Msg_Reset				(void);
-SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add				(const CSG_String &Message, bool bNewLine, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add				(const char       *Message, bool bNewLine = true, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add				(const wchar_t    *Message, bool bNewLine = true, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add				(const CSG_String &Message, bool bNewLine = true, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Execution		(const char       *Message, bool bNewLine = true, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Execution		(const wchar_t    *Message, bool bNewLine = true, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Execution		(const CSG_String &Message, bool bNewLine = true, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Error			(const char       *Message);
+SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Error			(const wchar_t    *Message);
 SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Error			(const CSG_String &Message);
-SAGA_API_DLL_EXPORT void					SG_UI_Msg_Add_Execution		(const CSG_String &Message, bool bNewLine, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
 SAGA_API_DLL_EXPORT void					SG_UI_Msg_Flush				(void);
 
 SAGA_API_DLL_EXPORT void					SG_UI_ProgressAndMsg_Lock	(bool bOn);
@@ -1645,6 +1690,7 @@ SAGA_API_DLL_EXPORT int						SG_UI_Window_Arrange		(int Arrange);
 
 SAGA_API_DLL_EXPORT void *					SG_UI_Get_Window_Main		(void);
 SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Path	(bool bPathOnly = false);
+SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Name	(void);
 
 
 ///////////////////////////////////////////////////////////
