@@ -1174,65 +1174,6 @@ bool SG_is_Character_Numeric(int Character)
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-int				SG_Printf(const CSG_String &Format)
-{
-	return( SG_Printf(Format.c_str()) );
-}
-
-int				SG_Printf(const char *Format, ...)
-{
-#ifdef _SAGA_LINUX
-	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
-	va_list	argptr; va_start(argptr, _Format); int ret = wxVprintf(_Format, argptr); va_end(argptr); return( ret );
-#else
-	va_list	argptr; va_start(argptr,  Format); int ret = wxVprintf( Format, argptr); va_end(argptr); return( ret );
-#endif
-}
-
-int				SG_Printf(const wchar_t *Format, ...)
-{
-#ifdef _SAGA_LINUX
-	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
-	va_list	argptr; va_start(argptr, _Format); int ret = wxVprintf(_Format, argptr); va_end(argptr); return( ret );
-#else
-	va_list	argptr; va_start(argptr,  Format); int ret = wxVprintf( Format, argptr); va_end(argptr); return( ret );
-#endif
-}
-
-//---------------------------------------------------------
-int				SG_FPrintf(FILE *Stream, const CSG_String &String)
-{
-	return( SG_FPrintf(Stream, String.c_str()) );
-}
-
-int				SG_FPrintf(FILE *Stream, const char *Format, ...)
-{
-#ifdef _SAGA_LINUX
-	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
-	va_list	argptr; va_start(argptr, _Format); int ret = wxVfprintf(Stream, _Format, argptr); va_end(argptr); return( ret );
-#else
-	va_list	argptr; va_start(argptr,  Format); int ret = wxVfprintf(Stream,  Format, argptr); va_end(argptr); return( ret );
-#endif
-}
-
-int				SG_FPrintf(FILE *Stream, const wchar_t *Format, ...)
-{
-#ifdef _SAGA_LINUX
-	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
-	va_list	argptr; va_start(argptr, _Format); int ret = wxVfprintf(Stream, _Format, argptr); va_end(argptr); return( ret );
-#else
-	va_list	argptr; va_start(argptr,  Format); int ret = wxVfprintf(Stream,  Format, argptr); va_end(argptr); return( ret );
-#endif
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -1459,6 +1400,72 @@ CSG_String		SG_Get_String(int Value, int Precision)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_String SG_HTML_Tag_Replacer(const CSG_String &Text)
+{
+	const CSG_String Tags[][3] =
+	{
+		{ "table", "\n============\n", "============\n" },
+		{ "tr"   , ""                , "\n" },
+		{ "th"   , ""                , "\t" },
+		{ "td"   , ""                , "\t" },
+		{ "a"    , ""                , ""   },
+		{ "b"    , "["               , "]"  },
+		{ "i"    , "'"               , "'"  },
+		{ "br"   , "\n"              , ""   },
+		{ "p"    , ""                , "\n" },
+		{ "hr"   , "\n____________\n", "\n" },
+		{ "h1"   , "\n############\n", "\n" },
+		{ "h2"   , "\n============\n", "\n" },
+		{ "h3"   , "\n------------\n", "\n" },
+		{ "h4"   , "\n"              , "\n" },
+		{ "ol"   , "\n"              , "\n" },
+		{ "ul"   , "\n"              , "\n" },
+		{ "li"   , "(-) "            , "\n" },
+		{ "", "", ""   }
+	};
+
+	CSG_String _Text(Text);
+
+	for(int i=0, n; !Tags[i][0].is_Empty(); i++)
+	{
+		_Text.Replace("<"  + Tags[i][0] + ">", Tags[i][1]);
+
+		while( (n = _Text.Find("<" + Tags[i][0])) >= 0 )
+		{
+			CSG_String Left(_Text.Left(n)), Right(_Text.Right(_Text.Length() - (n + 1 + Tags[i][0].Length())));
+
+			if( Tags[i][0].Cmp("a") == 0 && (n = Right.BeforeFirst('>').Find("href=\"")) >= 0 )
+			{
+				CSG_String href(Right.Right(Right.Length() - n).BeforeFirst('>').AfterFirst('\"').BeforeFirst('\"'));
+
+				if( !href.is_Empty() && (n = Right.Find("</a>")) >= 0 )
+				{
+					CSG_String text(Right.Left(n).AfterFirst('>'));
+
+					if( !text.is_Empty() )
+					{
+						_Text = Left + "[" + text + "](" + href + ")" + Right.Right(Right.Length() - n);
+
+						continue;
+					}
+				}
+			}
+
+			_Text = Left + Tags[i][1] + Right.AfterFirst('>');
+		}
+
+		_Text.Replace("</" + Tags[i][0] + ">", Tags[i][2]);
+	}
+
+	return( _Text );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
