@@ -72,13 +72,13 @@ CSG_String	SG_Get_DataObject_Identifier(TSG_Data_Object_Type Type)
 {
 	switch( Type )
 	{
-	default                           : return( "UNDEFINED" );
 	case SG_DATAOBJECT_TYPE_Grid      : return( "GRID"      );
 	case SG_DATAOBJECT_TYPE_Grids     : return( "GRIDS"     );
 	case SG_DATAOBJECT_TYPE_Table     : return( "TABLE"     );
 	case SG_DATAOBJECT_TYPE_Shapes    : return( "SHAPES"    );
 	case SG_DATAOBJECT_TYPE_TIN       : return( "TIN"       );
 	case SG_DATAOBJECT_TYPE_PointCloud: return( "POINTS"    );
+	default                           : return( "UNDEFINED" );
 	}
 }
 
@@ -87,13 +87,28 @@ CSG_String	SG_Get_DataObject_Name(TSG_Data_Object_Type Type)
 {
 	switch( Type )
 	{
-	default                           : return( _TL("Undefined"  ) );
 	case SG_DATAOBJECT_TYPE_Grid      : return( _TL("Grid"       ) );
 	case SG_DATAOBJECT_TYPE_Grids     : return( _TL("Grids"      ) );
 	case SG_DATAOBJECT_TYPE_Table     : return( _TL("Table"      ) );
 	case SG_DATAOBJECT_TYPE_Shapes    : return( _TL("Shapes"     ) );
 	case SG_DATAOBJECT_TYPE_TIN       : return( _TL("TIN"        ) );
 	case SG_DATAOBJECT_TYPE_PointCloud: return( _TL("Point Cloud") );
+	default                           : return( _TL("Undefined"  ) );
+	}
+}
+
+//---------------------------------------------------------
+CSG_String	SG_Get_DataObject_Class_Name(TSG_Data_Object_Type Type)
+{
+	switch( Type )
+	{
+	case SG_DATAOBJECT_TYPE_Grid      : return( "CSG_Grid"       );
+	case SG_DATAOBJECT_TYPE_Grids     : return( "CSG_Grids"      );
+	case SG_DATAOBJECT_TYPE_Table     : return( "CSG_Table"      );
+	case SG_DATAOBJECT_TYPE_Shapes    : return( "CSG_Shapes"     );
+	case SG_DATAOBJECT_TYPE_TIN       : return( "CSG_TIN"        );
+	case SG_DATAOBJECT_TYPE_PointCloud: return( "CSG_PointCloud" );
+	default                           : return( "CSG_DataObject" );
 	}
 }
 
@@ -160,6 +175,26 @@ int		SG_Get_History_Ignore_Lists		(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool		SG_Data_Object_Delete		(CSG_Data_Object *pObject)
+{
+	if( pObject && !pObject->Get_Managed() )
+	{
+		delete(pObject);
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -169,34 +204,73 @@ int		SG_Get_History_Ignore_Lists		(void)
 //---------------------------------------------------------
 CSG_Data_Object::CSG_Data_Object(void)
 {
+	static int RefCount = 0;
+
+	#pragma omp critical
+	{
+		m_RefID       = ++RefCount;
+	}
+
+	m_pOwner          = NULL;
+
+	m_File_bNative    = false;
+	m_File_Type       = 0;
+
+	m_NoData_Value[0] = -99999.;
+	m_NoData_Value[1] = -99999.;
+
+	m_Max_Samples     = gSG_DataObject_Max_Samples;
+	m_bModified       = true;
+	m_bUpdate         = false;
+
 	m_MetaData.Set_Name("SAGA_METADATA");
 
-	m_pMD_Database		= m_MetaData.Add_Child(SG_META_DATABASE);
-	m_pMD_Source		= m_MetaData.Add_Child(SG_META_SOURCE  );
-	m_pMD_History		= m_MetaData.Add_Child(SG_META_HISTORY );
+	m_pMD_Database    = m_MetaData.Add_Child(SG_META_DATABASE);
+	m_pMD_Source      = m_MetaData.Add_Child(SG_META_SOURCE  );
+	m_pMD_History     = m_MetaData.Add_Child(SG_META_HISTORY );
 
-	//-----------------------------------------------------
-	m_File_bNative		= false;
-	m_File_Type			= 0;
-	m_bModified			= true;
+	#ifdef WITH_LIFETIME_TRACKER
+	#pragma omp critical
+	{
+		++m_Track_nObjects;
 
-	m_NoData_Value[0]	= -99999.;
-	m_NoData_Value[1]	= -99999.;
-
-	m_Max_Samples		= gSG_DataObject_Max_Samples;
-
-	m_Name				.Clear();
-	m_Description		.Clear();
-
-	m_bUpdate			= false;
-
-	m_pOwner			= NULL;
+		if( m_Track )
+		{
+			SG_UI_Console_Print_StdOut(CSG_String::Format("data object (refid=%04d) constructed, new object count is %d", m_RefID, m_Track_nObjects - m_Track_Offset));
+		}
+	}
+	#endif // WITH_LIFETIME_TRACKER
 }
 
 //---------------------------------------------------------
 CSG_Data_Object::~CSG_Data_Object(void)
 {
 	Destroy();
+
+	#ifdef WITH_LIFETIME_TRACKER
+	#pragma omp critical
+	{
+		--m_Track_nObjects;
+
+		if( m_Track )
+		{
+			SG_UI_Console_Print_StdOut(CSG_String::Format("data object (refid=%04d) destructed,  new object count is %d", m_RefID, m_Track_nObjects - m_Track_Offset));
+		}
+	}
+	#endif // WITH_LIFETIME_TRACKER
+}
+
+//---------------------------------------------------------
+bool CSG_Data_Object::m_Track = false; int CSG_Data_Object::m_Track_nObjects = 0; int CSG_Data_Object::m_Track_Offset = 0;
+
+//---------------------------------------------------------
+void CSG_Data_Object::Track(bool Track, bool Offset)
+{
+	m_Track = Track; m_Track_Offset = Offset ? m_Track_nObjects : 0;
+
+	SG_UI_Console_Print_StdOut(CSG_String::Format("data object construction/destruction tracker, state=%s, offset=%s, current object count is %d",
+		m_Track ? SG_T("ON") : SG_T("OFF"), m_Track_Offset ? SG_T("ON") : SG_T("OFF"), m_Track_nObjects
+	));
 }
 
 //---------------------------------------------------------
@@ -221,20 +295,18 @@ void CSG_Data_Object::Set_Name(const CSG_String &Name)
 {
 	if( Name.is_Empty() )
 	{
-		m_Name	= _TL("Data");
+		m_Name = _TL("Data");
 	}
 	else
 	{
-		m_Name	= Name;
+		m_Name = Name;
 	}
 }
 
 //---------------------------------------------------------
 void CSG_Data_Object::Fmt_Name(const char *Format, ...)
 {
-	wxString	_s;
-
-	va_list	argptr;
+	wxString _s; va_list argptr;
 	
 #ifdef _SAGA_LINUX
 	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
@@ -251,9 +323,7 @@ void CSG_Data_Object::Fmt_Name(const char *Format, ...)
 //---------------------------------------------------------
 void CSG_Data_Object::Fmt_Name(const wchar_t *Format, ...)
 {
-	wxString	_s;
-
-	va_list	argptr;
+	wxString _s; va_list argptr;
 	
 #ifdef _SAGA_LINUX
 	// workaround as we only use wide characters
@@ -266,8 +336,6 @@ void CSG_Data_Object::Fmt_Name(const wchar_t *Format, ...)
 
 	va_end(argptr);
 
-	CSG_String	s(&_s);
-
 	Set_Name(CSG_String(&_s));
 }
 
@@ -280,7 +348,7 @@ const SG_Char * CSG_Data_Object::Get_Name(void) const
 //---------------------------------------------------------
 void CSG_Data_Object::Set_Description(const CSG_String &Description)
 {
-	m_Description	= Description;
+	m_Description = Description;
 }
 
 const SG_Char * CSG_Data_Object::Get_Description(void) const
@@ -342,12 +410,23 @@ int CSG_Data_Object::Get_File_Type(void)	const
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+/*
+* If the data object has a file asssociation, this function
+* can be used to reload its content.
+*/
 //---------------------------------------------------------
 bool CSG_Data_Object::Reload(void)
 {
 	return( SG_File_Exists(m_FileName) && On_Reload() );
 }
 
+//---------------------------------------------------------
+/*
+* If the data object is stored in a native SAGA format,
+* this function can be used to delete all files asssociated
+* with it.
+*/
 //---------------------------------------------------------
 bool CSG_Data_Object::Delete(void)
 {
@@ -387,6 +466,98 @@ bool CSG_Data_Object::Delete(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+/*
+* Type cast function. Returns NULL if object is not exactly
+* of class type CSG_Table with bPolymorph = false or of
+* one of its derivatives (CSG_Shapes, CSG_PointCloud,
+* CSG_TIN) with bPolymorph = true.
+*/
+//---------------------------------------------------------
+CSG_Table * CSG_Data_Object::asTable(bool bPolymorph) const
+{
+	if( bPolymorph )
+	{
+		return( Get_ObjectType() == SG_DATAOBJECT_TYPE_Table
+			||  Get_ObjectType() == SG_DATAOBJECT_TYPE_Shapes
+			||  Get_ObjectType() == SG_DATAOBJECT_TYPE_PointCloud
+			||  Get_ObjectType() == SG_DATAOBJECT_TYPE_TIN
+			? (CSG_Table *)this : NULL
+		);
+	}
+
+	return( Get_ObjectType() == SG_DATAOBJECT_TYPE_Table ? (CSG_Table *)this : NULL );
+}
+
+//---------------------------------------------------------
+/*
+* Type cast function. Returns NULL if object is not exactly
+* of class type CSG_Shapes with bPolymorph = false or of
+* one of its derivatives (CSG_PointCloud) with bPolymorph = true.
+*/
+//---------------------------------------------------------
+CSG_Shapes * CSG_Data_Object::asShapes(bool bPolymorph) const
+{
+	if( bPolymorph )
+	{
+		return( Get_ObjectType() == SG_DATAOBJECT_TYPE_Shapes
+			||  Get_ObjectType() == SG_DATAOBJECT_TYPE_PointCloud
+			? (CSG_Shapes *)this : NULL
+			);
+	}
+
+	return( Get_ObjectType() == SG_DATAOBJECT_TYPE_Shapes ? (CSG_Shapes *)this : NULL );
+}
+
+//---------------------------------------------------------
+/*
+* Type cast function. Returns NULL if object is not exactly
+* of class type CSG_TIN. The bPolymorph flag has no effect.
+*/
+//---------------------------------------------------------
+CSG_TIN * CSG_Data_Object::asTIN(bool bPolymorph) const
+{
+	return( Get_ObjectType() == SG_DATAOBJECT_TYPE_TIN ? (CSG_TIN *)this : NULL );
+}
+
+//---------------------------------------------------------
+/*
+* Type cast function. Returns NULL if object is not exactly
+* of class type CSG_PointCloud. The bPolymorph flag has no effect.
+*/
+//---------------------------------------------------------
+CSG_PointCloud * CSG_Data_Object::asPointCloud(bool bPolymorph) const
+{
+	return( Get_ObjectType() == SG_DATAOBJECT_TYPE_PointCloud ? (CSG_PointCloud *)this : NULL );
+}
+
+//---------------------------------------------------------
+/*
+* Type cast function. Returns NULL if object is not exactly
+* of class type CSG_Grid. The bPolymorph flag has no effect.
+*/
+//---------------------------------------------------------
+CSG_Grid * CSG_Data_Object::asGrid(bool bPolymorph) const
+{
+	return( Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid ? (CSG_Grid *)this : NULL );
+}
+
+//---------------------------------------------------------
+/*
+* Type cast function. Returns NULL if object is not exactly
+* of class type CSG_Grids. The bPolymorph flag has no effect.
+*/
+//---------------------------------------------------------
+CSG_Grids * CSG_Data_Object::asGrids(bool bPolymorph) const
+{
+	return( Get_ObjectType() == SG_DATAOBJECT_TYPE_Grids ? (CSG_Grids *)this : NULL );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -615,6 +786,18 @@ bool CSG_Data_Object::Update(bool bForce)
 //---------------------------------------------------------
 bool CSG_Data_Object::Assign(CSG_Data_Object *pObject)
 {
+	if( pObject )// && pObject->is_Valid() )
+	{
+		Destroy();
+
+		m_Name = pObject->Get_Name();
+
+		Get_MetaData() = pObject->Get_MetaData();
+	//	Get_History () = pObject->Get_History ();
+
+		return( true );
+	}
+
 	return( false );
 }
 
