@@ -84,6 +84,8 @@ CSG_Grids * SG_Create_Grids(const CSG_Grids *_pGrids, bool bCopyData)
 }
 
 //---------------------------------------------------------
+CSG_Grids * SG_Create_Grids(const char       *FileName, bool bLoadData) { return( SG_Create_Grids(CSG_String(FileName), bLoadData) ); }
+CSG_Grids * SG_Create_Grids(const wchar_t    *FileName, bool bLoadData) { return( SG_Create_Grids(CSG_String(FileName), bLoadData) ); }
 CSG_Grids * SG_Create_Grids(const CSG_String &FileName, bool bLoadData)
 {
 	CSG_Grids	*pGrids	= new CSG_Grids(FileName, bLoadData);
@@ -175,12 +177,9 @@ CSG_Grids::CSG_Grids(const CSG_Grids *pGrids, bool bCopyData)
   * Create a grid collection from file.
 */
 //---------------------------------------------------------
-CSG_Grids::CSG_Grids(const CSG_String &FileName, bool bLoadData)
-{
-	_On_Construction();
-
-	Create(FileName, bLoadData);
-}
+CSG_Grids::CSG_Grids(const char       *FileName, bool bLoadData) { _On_Construction(); Create(FileName, bLoadData); }
+CSG_Grids::CSG_Grids(const wchar_t    *FileName, bool bLoadData) { _On_Construction(); Create(FileName, bLoadData); }
+CSG_Grids::CSG_Grids(const CSG_String &FileName, bool bLoadData) { _On_Construction(); Create(FileName, bLoadData); }
 
 //---------------------------------------------------------
 /**
@@ -305,10 +304,9 @@ bool CSG_Grids::Create(const CSG_Grids *pGrids, bool bCopyData)
 }
 
 //---------------------------------------------------------
-bool CSG_Grids::Create(const CSG_String &FileName, bool bLoadData)
-{
-	return( Load(FileName, bLoadData) );
-}
+bool CSG_Grids::Create(const char       *FileName, bool bLoadData) { return( Load(CSG_String(FileName), bLoadData) ); }
+bool CSG_Grids::Create(const wchar_t    *FileName, bool bLoadData) { return( Load(CSG_String(FileName), bLoadData) ); }
+bool CSG_Grids::Create(const CSG_String &FileName, bool bLoadData) { return( Load(           FileName , bLoadData) ); }
 
 //---------------------------------------------------------
 bool CSG_Grids::Create(const CSG_Grid_System &System, int NZ, double zMin, TSG_Data_Type Type)
@@ -473,9 +471,42 @@ bool CSG_Grids::is_Compatible(int NX, int NY, double Cellsize, double xMin, doub
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_Grids::Add_Attribute(const CSG_String &Name, TSG_Data_Type Type, int i)
+bool CSG_Grids::Set_Z_Attribute(int i)
 {
-	return( m_Attributes.Add_Field(Name, Type, i) );
+	if( i >= 0 && i < m_Attributes.Get_Field_Count() )
+	{
+		m_Z_Attribute = i;
+
+		return( Update_Z_Order() );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_Grids::Set_Z_Name_Field(int i)
+{
+	if( i >= 0 && i < m_Attributes.Get_Field_Count() )
+	{
+		m_Z_Name = i;
+
+		return( true );
+	}
+
+	return( false );
+}
+
+int CSG_Grids::Get_Z_Name_Field(void)	const
+{
+	return( m_Z_Name >= 0 && m_Z_Name < m_Attributes.Get_Field_Count() ? m_Z_Name : m_Z_Attribute );
+}
+
+//---------------------------------------------------------
+bool CSG_Grids::Add_Attribute(const char       *Name, TSG_Data_Type Type, int Insert) { return( Add_Attribute(CSG_String(Name), Type, Insert) ); }
+bool CSG_Grids::Add_Attribute(const wchar_t    *Name, TSG_Data_Type Type, int Insert) { return( Add_Attribute(CSG_String(Name), Type, Insert) ); }
+bool CSG_Grids::Add_Attribute(const CSG_String &Name, TSG_Data_Type Type, int Insert)
+{
+	return( m_Attributes.Add_Field(Name, Type, Insert) );
 }
 
 //---------------------------------------------------------
@@ -504,34 +535,21 @@ bool CSG_Grids::Del_Attribute(int i)
 }
 
 //---------------------------------------------------------
-bool CSG_Grids::Set_Z_Attribute(int i)
+bool CSG_Grids::Set_Attribute(int i, const char       *Field, const char       *Value) { return( Set_Attribute(i, m_Attributes.Get_Field(Field), CSG_String(Value)) ); }
+bool CSG_Grids::Set_Attribute(int i, const wchar_t    *Field, const wchar_t    *Value) { return( Set_Attribute(i, m_Attributes.Get_Field(Field), CSG_String(Value)) ); }
+bool CSG_Grids::Set_Attribute(int i, const CSG_String &Field, const CSG_String &Value) { return( Set_Attribute(i, m_Attributes.Get_Field(Field),            Value ) ); }
+bool CSG_Grids::Set_Attribute(int i, int               Field, const CSG_String &Value)
 {
-	if( i >= 0 && i < m_Attributes.Get_Field_Count() )
-	{
-		m_Z_Attribute	= i;
-
-		return( Update_Z_Order() );
-	}
-
-	return( false );
+	return( i >= 0 && i < (int)m_Attributes.Get_Count() && m_Attributes[i].Set_Value(Field, Value) );
 }
 
 //---------------------------------------------------------
-bool CSG_Grids::Set_Z_Name_Field(int i)
+bool CSG_Grids::Set_Attribute(int i, const char       *Field, double Value) { return( Set_Attribute(i, m_Attributes.Get_Field(Field), Value) ); }
+bool CSG_Grids::Set_Attribute(int i, const wchar_t    *Field, double Value) { return( Set_Attribute(i, m_Attributes.Get_Field(Field), Value) ); }
+bool CSG_Grids::Set_Attribute(int i, const CSG_String &Field, double Value) { return( Set_Attribute(i, m_Attributes.Get_Field(Field), Value) ); }
+bool CSG_Grids::Set_Attribute(int i, int               Field, double Value)
 {
-	if( i >= 0 && i < m_Attributes.Get_Field_Count() )
-	{
-		m_Z_Name	= i;
-
-		return( true );
-	}
-
-	return( false );
-}
-
-int CSG_Grids::Get_Z_Name_Field(void)	const
-{
-	return( m_Z_Name >= 0 && m_Z_Name < m_Attributes.Get_Field_Count() ? m_Z_Name : m_Z_Attribute );
+	return( i >= 0 && i < (int)m_Attributes.Get_Count() && m_Attributes[i].Set_Value(Field, Value) );
 }
 
 //---------------------------------------------------------
@@ -1776,21 +1794,19 @@ bool CSG_Grids::Save(const CSG_String &FileName, int Format)
 //---------------------------------------------------------
 bool CSG_Grids::_Load_External(const CSG_String &FileName)
 {
-	bool	bResult	= false;
+	bool bResult = false; CSG_Data_Manager Manager;
 
-	CSG_Data_Manager	Data;
-
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 0);	// import raster
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 0);	// import raster
 
 	SG_UI_Msg_Lock(true);
 
-	if(	pTool && pTool->On_Before_Execution() && pTool->Settings_Push(&Data)
+	if(	pTool && pTool->On_Before_Execution() && pTool->Settings_Push(&Manager)
 	&&  pTool->Set_Parameter("FILES"   , FileName)
 	&&	pTool->Set_Parameter("MULTIPLE", 1       )	// output as grid collection
 	&&	pTool->Execute()
-	&&  Data.Grid_System_Count() > 0 && Data.Get_Grid_System(0)->Count() > 0 && Data.Get_Grid_System(0)->Get(0)->is_Valid() )
+	&&  Manager.Grids().Count() && Manager.Grids(0).is_Valid() )
 	{
-		CSG_Grids *pGrids = (CSG_Grids *)Data.Get_Grid_System(0)->Get(0);
+		CSG_Grids *pGrids = Manager.Grids(0).asGrids();
 
 		m_Attributes.Create(&pGrids->m_Attributes);
 
@@ -1821,41 +1837,40 @@ bool CSG_Grids::_Load_External(const CSG_String &FileName)
 //---------------------------------------------------------
 bool CSG_Grids::_Load_PGSQL(const CSG_String &FileName)
 {
-	bool	bResult	= false;
+	bool bResult = false;
 
 	if( FileName.BeforeFirst(':').Cmp("PGSQL") == 0 )	// database source
 	{
-		CSG_String	s(FileName);
+		CSG_String s(FileName);
 
-		s	= s.AfterFirst(':');	CSG_String	Host  (s.BeforeFirst(':'));
-		s	= s.AfterFirst(':');	CSG_String	Port  (s.BeforeFirst(':'));
-		s	= s.AfterFirst(':');	CSG_String	DBName(s.BeforeFirst(':'));
-		s	= s.AfterFirst(':');	CSG_String	Table (s.BeforeFirst(':'));
-		s	= s.AfterFirst(':');	CSG_String	rid   (s.BeforeFirst(':').AfterFirst('='));
+		s = s.AfterFirst(':'); CSG_String Host  (s.BeforeFirst(':'));
+		s = s.AfterFirst(':'); CSG_String Port  (s.BeforeFirst(':'));
+		s = s.AfterFirst(':'); CSG_String DBName(s.BeforeFirst(':'));
+		s = s.AfterFirst(':'); CSG_String Table (s.BeforeFirst(':'));
+		s = s.AfterFirst(':'); CSG_String rid   (s.BeforeFirst(':').AfterFirst('='));
 
 		//-------------------------------------------------
-		CSG_String_Tokenizer	rids(rid, ",");	rid.Clear();
+		CSG_String_Tokenizer rids(rid, ","); rid.Clear();
 
 		while( rids.Has_More_Tokens() )
 		{
 			if( !rid.is_Empty() )
 			{
-				rid	+= " OR ";
+				rid += " OR ";
 			}
 
-			rid	+= "rid=\'" + rids.Get_Next_Token() + "\'";
+			rid += "rid=\'" + rids.Get_Next_Token() + "\'";
 		}
 
 		//-------------------------------------------------
-		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", 0, true);	// CGet_Connections
+		CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", 0, true);	// CGet_Connections
 
 		if(	pTool != NULL )
 		{
 			SG_UI_ProgressAndMsg_Lock(true);
 
 			//---------------------------------------------
-			CSG_Table	Connections;
-			CSG_String	Connection	= DBName + " [" + Host + ":" + Port + "]";
+			CSG_Table Connections; CSG_String Connection = DBName + " [" + Host + ":" + Port + "]";
 
 			pTool->Set_Manager(NULL);
 			pTool->On_Before_Execution();
@@ -1866,7 +1881,7 @@ bool CSG_Grids::_Load_PGSQL(const CSG_String &FileName)
 				{
 					if( !Connection.Cmp(Connections[i].asString(0)) )
 					{
-						bResult	= true;
+						bResult = true;
 					}
 				}
 			}
@@ -1876,23 +1891,23 @@ bool CSG_Grids::_Load_PGSQL(const CSG_String &FileName)
 			//---------------------------------------------
 			if( bResult && (bResult = (pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", 30, true)) != NULL) == true )	// CPGIS_Raster_Load
 			{
-				CSG_Data_Manager	Grids;
+				CSG_Data_Manager Manager;
 
 				pTool->On_Before_Execution();
-				pTool->Settings_Push(&Grids);
+				pTool->Settings_Push(&Manager);
 
-				bResult	=  SG_TOOL_PARAMETER_SET("CONNECTION", Connection)
-						&& SG_TOOL_PARAMETER_SET("TABLES"    , Table)
-						&& SG_TOOL_PARAMETER_SET("MULTIPLE"  , 1)	// grid collection
-						&& SG_TOOL_PARAMETER_SET("WHERE"     , rid)
-						&& pTool->Execute();
+				bResult = SG_TOOL_PARAMETER_SET("CONNECTION", Connection)
+				       && SG_TOOL_PARAMETER_SET("TABLES"    , Table)
+				       && SG_TOOL_PARAMETER_SET("MULTIPLE"  , 1) // grid collection
+				       && SG_TOOL_PARAMETER_SET("WHERE"     , rid)
+				       && pTool->Execute();
 
 				SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
 				//-----------------------------------------
-				if( Grids.Grid_System_Count() > 0 && Grids.Get_Grid_System(0)->Get(0) && Grids.Get_Grid_System(0)->Get(0)->is_Valid() )
+				if( Manager.Grids().Count() && Manager.Grids(0).is_Valid() )
 				{
-					CSG_Grids	*pGrids	= (CSG_Grids *)Grids.Get_Grid_System(0)->Get(0);
+					CSG_Grids *pGrids = Manager.Grids(0).asGrids();
 
 					Set_File_Name(FileName);
 
