@@ -380,7 +380,9 @@ public:
 	CSG_String					to_String			(int Width = -1, int Precision = -1, bool bScientific = false, const SG_Char *Separator = NULL)	const;
 	bool						from_String			(const CSG_String &String);
 
+	bool						is_Null				(void)						const;
 	bool						is_Equal			(const CSG_Vector &Vector)	const;
+	bool						is_Collinear		(const CSG_Vector &Vector)	const;
 
 	bool						Assign				(double Scalar);
 	bool						Assign				(const CSG_Vector &Vector);
@@ -389,10 +391,12 @@ public:
 	bool						Subtract			(const CSG_Vector &Vector);
 	bool						Multiply			(double Scalar);
 	bool						Multiply			(const CSG_Vector &Vector);
+	bool						Multiply_Cross		(const CSG_Vector &Vector);
 	double						Multiply_Scalar		(const CSG_Vector &Vector)	const;
 	bool						Multiply			(const class CSG_Matrix &Matrix);
 
-	bool						operator ==			(const CSG_Vector &Vector)	const;
+	bool						operator ==			(const CSG_Vector &Vector)	const { return(  is_Equal(Vector) ); }
+	bool						operator !=			(const CSG_Vector &Vector)	const { return( !is_Equal(Vector) ); }
 	CSG_Vector &				operator =			(double Scalar);
 	CSG_Vector &				operator =			(const CSG_Vector &Vector);
 	CSG_Vector &				operator +=			(double Scalar);
@@ -417,6 +421,8 @@ public:
 	bool						Sort				(bool bAscending = true);
 
 	double						Get_Length			(void)						const;
+	CSG_Vector					Get_Scalar_Product	(const CSG_Vector &Vector)	const;
+	CSG_Vector					Get_Cross_Product	(const CSG_Vector &Vector)	const;
 	double						Get_Angle			(const CSG_Vector &Vector)	const;
 	CSG_Vector					Get_Unity			(void)						const;
 
@@ -1135,13 +1141,13 @@ public:
 	bool					Destroy				(void);
 
 	bool					Add_Element			(void);
-	bool					Set_Feature			(int iElement, int iFeature, double Value);
+	bool					Set_Feature			(sLong iElement, int iFeature, double Value);
 
-	int						Get_Cluster			(int iElement)	const	{	return( iElement >= 0 && iElement < Get_nElements() ? m_Clusters[iElement] : -1 );	}
+	sLong					Get_Cluster			(sLong iElement) const	{	return( iElement >= 0 && iElement < Get_nElements() ? m_Clusters[iElement] : -1 );	}
 
 	bool					Execute				(int Method, int nClusters, int nMaxIterations = 0, int Initialization = 0);
 
-	int						Get_nElements		(void)	const	{	return( (int)m_Features.Get_Size() );	}
+	sLong					Get_nElements		(void)	const	{	return(      m_Features.Get_Size() );	}
 	int						Get_nFeatures		(void)	const	{	return(      m_nFeatures           );	}
 	int						Get_nClusters		(void)	const	{	return( (int)m_nMembers.Get_Size() );	}
 
