@@ -247,6 +247,7 @@ bool CSG_Parameter::is_Option(void)	const
 		case PARAMETER_TYPE_Degree      :
 		case PARAMETER_TYPE_Date        :
 		case PARAMETER_TYPE_Range       :
+		case PARAMETER_TYPE_Data_Type   :
 		case PARAMETER_TYPE_Choice      :
 		case PARAMETER_TYPE_Choices     :
 		case PARAMETER_TYPE_String      :
@@ -339,6 +340,7 @@ bool CSG_Parameter::is_Compatible(CSG_Parameter *pParameter)	const
 		switch( Get_Type() )
 		{
 		//-------------------------------------------------
+		case PARAMETER_TYPE_Data_Type        :
 		case PARAMETER_TYPE_Choice           :
 			{
 				bool	bResult	= pParameter->asChoice()->Get_Count() == asChoice()->Get_Count();
@@ -401,6 +403,7 @@ bool CSG_Parameter::is_Value_Equal(CSG_Parameter *pParameter)	const
 		//-------------------------------------------------
 		case PARAMETER_TYPE_Bool             :	return( pParameter->asBool  () == asBool  () );
 		case PARAMETER_TYPE_Table_Field      :
+		case PARAMETER_TYPE_Data_Type        :
 		case PARAMETER_TYPE_Choice           :
 		case PARAMETER_TYPE_Color            :
 		case PARAMETER_TYPE_Int              :	return( pParameter->asInt   () == asInt   () );
@@ -551,6 +554,29 @@ bool CSG_Parameter::Cmp_Identifier(const CSG_String &Identifier)	const
 	return( !m_Identifier.Cmp(Identifier) || !m_Identifier.Cmp(Identifier + ".Default") );
 }
 
+//---------------------------------------------------------
+/**
+* Constructs a command line parser conform identifier.
+*/
+//---------------------------------------------------------
+CSG_String CSG_Parameter::Get_CmdID(void)	const
+{
+	CSG_String ID(Get_Parameters()->Get_Identifier());
+
+	if( ID.Length() > 0 )
+	{
+		ID += "_";
+	}
+
+	ID += Get_Identifier();
+
+	ID.Replace(".", "_");
+	ID.Replace("|", "_");
+	ID.Replace(" ", "_");
+
+	return( ID );
+}
+
 //---------------------------------------------------------
 bool CSG_Parameter::Set_Name(const CSG_String &Name)
 {
@@ -583,25 +609,22 @@ CSG_String CSG_Parameter::Get_Description(int Flags)	const
 	return( Get_Description(Flags, SG_T("\n")) );
 }
 
-//---------------------------------------------------------
-#define SEPARATE	if( bSeparate )	s.Append(Separator);	bSeparate	= true;
-
 //---------------------------------------------------------
 CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	const
 {
+	#define SEPARATE if( !s.is_Empty() ) { s.Append(Separator); }
+
 	if( !Separator || !Separator[0] )
 	{
 		return( Get_Description(Flags) );
 	}
 
-	bool		bSeparate	= false;
-	int			i;
-	CSG_String	s;
+	CSG_String s;
 
 	//-----------------------------------------------------
 	if( (Flags & PARAMETER_DESCRIPTION_NAME) != 0 )
 	{
-		SEPARATE;	s	+= CSG_String::Format("%s", Get_Name());
+		SEPARATE; s += CSG_String::Format("%s", Get_Name());
 	}
 
 	//-----------------------------------------------------
@@ -611,33 +634,33 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 
 		if( is_DataObject() && Get_Type() == PARAMETER_TYPE_DataObject_Output )
 		{
-			s	+= CSG_String::Format("%s %s", Get_Type_Name().c_str(), SG_Get_DataObject_Name(Get_DataObject_Type()).c_str());
+			s += CSG_String::Format("%s %s", Get_Type_Name().c_str(), SG_Get_DataObject_Name(Get_DataObject_Type()).c_str());
 		}
 		else
 		{
-			s	+= CSG_String::Format("%s", Get_Type_Name().c_str());
+			s += CSG_String::Format("%s", Get_Type_Name().c_str());
 		}
 
 		if( is_DataObject() || is_DataObject_List() )
 		{
-			s	+= CSG_String::Format(", %s", is_Input() ? _TL("input") : _TL("output"));
+			s += CSG_String::Format(", %s", is_Input() ? _TL("input") : _TL("output"));
 
 			if( is_Optional() )
 			{
-				s	+= CSG_String::Format(", %s", _TL("optional"));
+				s += CSG_String::Format(", %s", _TL("optional"));
 			}
 		}
 
 		if( do_UseInGUI() != do_UseInCMD() )
 		{
-			s	+= CSG_String::Format(", %s", do_UseInGUI() ? SG_T("GUI") : SG_T("CMD"));
+			s += CSG_String::Format(", %s", do_UseInGUI() ? SG_T("GUI") : SG_T("CMD"));
 		}
 	}
 
 	//-----------------------------------------------------
 	if( (Flags & PARAMETER_DESCRIPTION_OPTIONAL) != 0 && is_Optional() )
 	{
-		SEPARATE;	s	+= CSG_String::Format("%s", _TL("optional"));
+		SEPARATE; s += CSG_String::Format("%s", _TL("optional"));
 	}
 
 	//-----------------------------------------------------
@@ -648,33 +671,34 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 		default:
 			break;
 
+		case PARAMETER_TYPE_Data_Type:
 		case PARAMETER_TYPE_Choice:
-			SEPARATE;	s	+= CSG_String::Format("%s:", _TL("Available Choices"));
+			SEPARATE; s += CSG_String::Format("%s:", _TL("Available Choices"));
 
-			for(i=0; i<asChoice()->Get_Count(); i++)
+			for(int i=0; i<asChoice()->Get_Count(); i++)
 			{
-				s	+= CSG_String::Format("%s[%d] %s", Separator, i, asChoice()->Get_Item(i));
+				s += CSG_String::Format("%s[%d] %s", Separator, i, asChoice()->Get_Item(i));
 			}
 			break;
 
 		case PARAMETER_TYPE_Choices:
-			SEPARATE;	s	+= CSG_String::Format("%s:", _TL("Available Choices"));
+			SEPARATE; s += CSG_String::Format("%s:", _TL("Available Choices"));
 
-			for(i=0; i<asChoices()->Get_Item_Count(); i++)
+			for(int i=0; i<asChoices()->Get_Item_Count(); i++)
 			{
-				s	+= CSG_String::Format("%s[%d] %s", Separator, i, asChoices()->Get_Item(i).c_str());
+				s += CSG_String::Format("%s[%d] %s", Separator, i, asChoices()->Get_Item(i).c_str());
 			}
 			break;
 
 		case PARAMETER_TYPE_Int:
 			if( asValue()->has_Minimum() )
 			{
-				SEPARATE;	s	+= CSG_String::Format("%s: %d", _TL("Minimum"), (int)asValue()->Get_Minimum());
+				SEPARATE; s += CSG_String::Format("%s: %d", _TL("Minimum"), (int)asValue()->Get_Minimum());
 			}
 
 			if( asValue()->has_Maximum() )
 			{
-				SEPARATE;	s	+= CSG_String::Format("%s: %d", _TL("Maximum"), (int)asValue()->Get_Maximum());
+				SEPARATE; s += CSG_String::Format("%s: %d", _TL("Maximum"), (int)asValue()->Get_Maximum());
 			}
 			break;
 
@@ -683,49 +707,49 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 //		case PARAMETER_TYPE_Range:
 			if( asValue()->has_Minimum() )
 			{
-				SEPARATE;	s	+= CSG_String::Format("%s: %f", _TL("Minimum"), asValue()->Get_Minimum());
+				SEPARATE; s += CSG_String::Format("%s: %f", _TL("Minimum"), asValue()->Get_Minimum());
 			}
 
 			if( asValue()->has_Maximum() )
 			{
-				SEPARATE;	s	+= CSG_String::Format("%s: %f", _TL("Maximum"), asValue()->Get_Maximum());
+				SEPARATE; s += CSG_String::Format("%s: %f", _TL("Maximum"), asValue()->Get_Maximum());
 			}
 			break;
 
 		case PARAMETER_TYPE_FixedTable:
 			SEPARATE;	s	+= CSG_String::Format("%d %s:%s", asTable()->Get_Field_Count(), _TL("Fields"), Separator);
 
-			for(i=0; i<asTable()->Get_Field_Count(); i++)
+			for(int i=0; i<asTable()->Get_Field_Count(); i++)
 			{
-				s	+= CSG_String::Format("- %d. [%s] %s%s", i + 1, SG_Data_Type_Get_Name(asTable()->Get_Field_Type(i)).c_str(), asTable()->Get_Field_Name(i), Separator);
+				s += CSG_String::Format("- %d. [%s] %s%s", i + 1, SG_Data_Type_Get_Name(asTable()->Get_Field_Type(i)).c_str(), asTable()->Get_Field_Name(i), Separator);
 			}
 			break;
 
 		case PARAMETER_TYPE_Parameters:
-			SEPARATE;	s	+= CSG_String::Format("%d %s:%s", asParameters()->Get_Count(), _TL("Parameters"), Separator);
+			SEPARATE; s += CSG_String::Format("%d %s:%s", asParameters()->Get_Count(), _TL("Parameters"), Separator);
 
-			for(i=0; i<asParameters()->Get_Count(); i++)
+			for(int i=0; i<asParameters()->Get_Count(); i++)
 			{
-				s	+= CSG_String::Format("- %d. %s%s", i + 1, asParameters()->Get_Parameter(i)->Get_Description(Flags, Separator).c_str(), Separator);
+				s += CSG_String::Format("- %d. %s%s", i + 1, asParameters()->Get_Parameter(i)->Get_Description(Flags, Separator).c_str(), Separator);
 			}
 			break;
 		}
 
 		if( !m_Default.is_Empty() )
 		{
-			SEPARATE;	s	+= CSG_String::Format("%s: %s", _TL("Default"), m_Default.c_str());
+			SEPARATE; s += CSG_String::Format("%s: %s", _TL("Default"), m_Default.c_str());
 		}
 	}
 
 	//-----------------------------------------------------
 	if( (Flags & PARAMETER_DESCRIPTION_TEXT) != 0 && m_Description.Length() > 0 )
 	{
-		SEPARATE;
-
-		s	+= m_Description;
+		SEPARATE; s += m_Description;
 	}
 
 	//-----------------------------------------------------
+	#undef SEPARATE
+
 	return( s );
 }
 
@@ -812,6 +836,7 @@ bool CSG_Parameter::Set_Value(CSG_Parameter *Value)
 		default:
 			break;
 
+		case PARAMETER_TYPE_Data_Type:
 		case PARAMETER_TYPE_Choice:
 			return( Set_Value(Value->asInt()) );
 		}
@@ -864,17 +889,23 @@ bool CSG_Parameter::Set_Default(double Value)
 //---------------------------------------------------------
 bool CSG_Parameter::Set_Default(const CSG_String &Value)
 {
-	m_Default	= Value;
+	m_Default = Value;
 
 	return( true );
 }
 
 //---------------------------------------------------------
-const CSG_String & CSG_Parameter::Get_Default(void)	const
+const CSG_String & CSG_Parameter::Get_Default(void) const
 {
 	return( m_Default );
 }
 
+//---------------------------------------------------------
+bool CSG_Parameter::is_Default(void) const
+{
+	return( m_Default.Cmp(asString()) == 0 );
+}
+
 //---------------------------------------------------------
 bool CSG_Parameter::Restore_Default(void)
 {
@@ -897,9 +928,24 @@ bool CSG_Parameter::Check(bool bSilent)
 	//-----------------------------------------------------
 	if( Get_Type() == PARAMETER_TYPE_Grid_System )
 	{
-		if( m_pParameters->Get_Manager() && !m_pParameters->Get_Manager()->Exists(*asGrid_System()) )
+		if( m_pParameters->Get_Manager() )
 		{
-			Set_Value((void *)NULL);
+			bool bExists = false; CSG_Data_Manager &Manager = *m_pParameters->Get_Manager();
+
+			for(size_t i=0; !bExists && i<Manager.Grid ().Count(); i++)
+			{
+				bExists = Manager.Grid (i).Get_System() == *asGrid_System();
+			}
+
+			for(size_t i=0; !bExists && i<Manager.Grids().Count(); i++)
+			{
+				bExists = Manager.Grids(i).Get_System() == *asGrid_System();
+			}
+
+			if( bExists == false )
+			{
+				Set_Value((void *)NULL);
+			}
 		}
 
 		return( true );	// ( false );
@@ -924,7 +970,7 @@ bool CSG_Parameter::Check(bool bSilent)
 	{
 		for(int j=asList()->Get_Item_Count()-1; j>=0; j--)
 		{
-			CSG_Data_Object	*pDataObject	= asList()->Get_Item(j);
+			CSG_Data_Object *pDataObject = asList()->Get_Item(j);
 
 			if( !pDataObject || (m_pParameters->Get_Manager() && !m_pParameters->Get_Manager()->Exists(pDataObject)) )
 			{
@@ -1026,7 +1072,9 @@ CSG_Parameter_Value           * CSG_Parameter::asValue         (void) const
 }
 
 CSG_Parameter_Date            * CSG_Parameter::asDate          (void) const {	return( Get_Type() != PARAMETER_TYPE_Date            ? NULL : (CSG_Parameter_Date            *)this );	}
-CSG_Parameter_Choice          * CSG_Parameter::asChoice        (void) const {	return( Get_Type() != PARAMETER_TYPE_Choice          ? NULL : (CSG_Parameter_Choice          *)this );	}
+CSG_Parameter_Data_Type       * CSG_Parameter::asDataType      (void) const {	return( Get_Type() != PARAMETER_TYPE_Data_Type       ? NULL : (CSG_Parameter_Data_Type       *)this );	}
+CSG_Parameter_Choice          * CSG_Parameter::asChoice        (void) const {	return( Get_Type() != PARAMETER_TYPE_Choice
+                                                                                     && Get_Type() != PARAMETER_TYPE_Data_Type       ? NULL : (CSG_Parameter_Choice          *)this );	}
 CSG_Parameter_Choices         * CSG_Parameter::asChoices       (void) const {	return( Get_Type() != PARAMETER_TYPE_Choices         ? NULL : (CSG_Parameter_Choices         *)this );	}
 CSG_Parameter_Range           * CSG_Parameter::asRange         (void) const {	return( Get_Type() != PARAMETER_TYPE_Range           ? NULL : (CSG_Parameter_Range           *)this );	}
 CSG_Parameter_File_Name       * CSG_Parameter::asFilePath      (void) const {	return( Get_Type() != PARAMETER_TYPE_FilePath        ? NULL : (CSG_Parameter_File_Name       *)this );	}
@@ -1134,7 +1182,7 @@ bool CSG_Parameter::_Serialize(CSG_MetaData &Entry, bool bSave)
 //---------------------------------------------------------
 CSG_Parameters_Grid_Target::CSG_Parameters_Grid_Target(void)
 {
-	m_pParameters	= NULL;
+	m_pParameters = NULL;
 }
 
 //---------------------------------------------------------
@@ -1150,11 +1198,11 @@ bool CSG_Parameters_Grid_Target::Create(CSG_Parameters *pParameters, bool bAddDe
 		return( false );
 	}
 
-	m_pParameters	= pParameters;
-	m_Prefix		= Prefix;
+	m_pParameters = pParameters;
+	m_Prefix      = Prefix;
 
 	//-----------------------------------------------------
-	CSG_String	TargetID(m_Prefix + "DEFINITION");
+	CSG_String TargetID(m_Prefix + "DEFINITION");
 
 	m_pParameters->Add_Choice(
 		ParentID, TargetID, _TL("Target Grid System"),
@@ -1204,7 +1252,7 @@ bool CSG_Parameters_Grid_Target::Create(CSG_Parameters *pParameters, bool bAddDe
 //---------------------------------------------------------
 bool CSG_Parameters_Grid_Target::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	return( pParameter && pParameters && m_pParameters && m_pParameters->Get_Identifier().Cmp(pParameters->Get_Identifier()) == 0
+	return( pParameter && pParameters && m_pParameters && m_pParameters->Cmp_Identifier(pParameters->Get_Identifier())
 		&& On_Parameter_Changed(pParameters, pParameter, m_Prefix)
 	);
 }
@@ -1212,11 +1260,23 @@ bool CSG_Parameters_Grid_Target::On_Parameter_Changed(CSG_Parameters *pParameter
 //---------------------------------------------------------
 bool CSG_Parameters_Grid_Target::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, const CSG_String Prefix)
 {
-	if( !pParameter || !pParameters )
+	if( !pParameters || !pParameter )
 	{
 		return( false );
 	}
 
+	if( !pParameter->Cmp_Identifier(Prefix + "USER_SIZE")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_XMIN")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_XMAX")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_YMIN")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_YMAX")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_ROWS")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_COLS")
+	&&  !pParameter->Cmp_Identifier(Prefix + "USER_FITS") )
+	{
+		return( true );
+	}
+
 	CSG_Parameter *pSize = (*pParameters)(Prefix + "USER_SIZE");
 	CSG_Parameter *pXMin = (*pParameters)(Prefix + "USER_XMIN");
 	CSG_Parameter *pXMax = (*pParameters)(Prefix + "USER_XMAX");
@@ -1317,7 +1377,7 @@ bool CSG_Parameters_Grid_Target::On_Parameter_Changed(CSG_Parameters *pParameter
 
 		bChanged = true;
 
-		if(      pParameter->Cmp_Identifier(pZSize->Get_Identifier()) && zSize > 0. )
+		if     ( pParameter->Cmp_Identifier(pZSize->Get_Identifier()) && zSize > 0. )
 		{
 			zMax = zMin + zSize * (int)(0.5 + (zMax - zMin) / zSize);
 		}
@@ -1479,13 +1539,13 @@ bool CSG_Parameters_Grid_Target::Set_User_Defined(CSG_Parameters *pParameters, C
 		return( false );
 	}
 
-	CSG_Rect	r	= pPoints->Get_Extent();
+	CSG_Rect r(pPoints->Get_Extent());
 
-	double	Size	= sqrt(r.Get_Area() / pPoints->Get_Count()) / (Scale > 1 ? Scale : 1);	// edge length of a square given as average area per point (cell size)
+	double Size = sqrt(r.Get_Area() / pPoints->Get_Count()) / (Scale > 1 ? Scale : 1);	// edge length of a square given as average area per point (cell size)
 
 	if( Rounding > 0 )
 	{
-		Size	= SG_Get_Rounded_To_SignificantFigures(Size, Rounding);
+		Size   = SG_Get_Rounded_To_SignificantFigures(Size, Rounding);
 
 		r.xMin = Size * floor(r.xMin / Size);
 		r.xMax = Size * ceil (r.xMax / Size);
@@ -1493,7 +1553,7 @@ bool CSG_Parameters_Grid_Target::Set_User_Defined(CSG_Parameters *pParameters, C
 		r.yMax = Size * ceil (r.yMax / Size);
 	}
 
-	int		Rows	= 1 + (int)(0.5 + r.Get_YRange() / Size);
+	int Rows = 1 + (int)(0.5 + r.Get_YRange() / Size);
 
 	return( Set_User_Defined(pParameters, r, Rows, 0) );
 }
@@ -1545,26 +1605,26 @@ bool CSG_Parameters_Grid_Target::Set_User_Defined_ZLevels(CSG_Parameters *pParam
 
 	if( zMax - zMin <= 0. )
 	{
-		zMin	-= 0.5 * nLevels;
-		zMax	+= 0.5 * nLevels;	// assume cellsize = 1.
+		zMin -= 0.5 * nLevels;
+		zMax += 0.5 * nLevels;	// assume cellsize = 1.
 	}
 
 	//-----------------------------------------------------
-	double	Size	= (zMax - zMin) / (nLevels - 1.);
+	double Size = (zMax - zMin) / (nLevels - 1.);
 
 	if( Rounding > 0 )
 	{
-		Size	= SG_Get_Rounded_To_SignificantFigures(Size, Rounding);
+		Size = SG_Get_Rounded_To_SignificantFigures(Size, Rounding);
 
-		zMin	= Size * floor(zMin / Size);
-		zMax	= Size * ceil (zMax / Size);
+		zMin = Size * floor(zMin / Size);
+		zMax = Size * ceil (zMax / Size);
 	}
 
 	//-----------------------------------------------------
 	if( (*pParameters)(m_Prefix + "USER_FITS")->asInt() == 1 )
 	{
-		zMin	-= 0.5 * Size;
-		zMax	+= 0.5 * Size;
+		zMin -= 0.5 * Size;
+		zMax += 0.5 * Size;
 	}
 
 	bool	bCallback	= pParameters->Set_Callback(false);
@@ -1592,26 +1652,26 @@ bool CSG_Parameters_Grid_Target::Add_Grid(const CSG_String &Identifier, const CS
 		return( false );
 	}
 
-	CSG_Parameter	*pTarget	= (*m_pParameters)(m_Prefix + "DEFINITION");
-	CSG_Parameter	*pSystem	= NULL;
+	CSG_Parameter *pTarget = (*m_pParameters)(m_Prefix + "DEFINITION");
+	CSG_Parameter *pSystem = NULL;
 
 	for(int i=0; i<pTarget->Get_Children_Count() && !pSystem; i++)
 	{
 		if( pTarget->Get_Child(i)->Get_Type() == PARAMETER_TYPE_Grid_System )
 		{
-			pSystem	= pTarget->Get_Child(i);
+			pSystem = pTarget->Get_Child(i);
 		}
 	}
 
-	m_pParameters->Add_Grid (pSystem ? pSystem->Get_Identifier() : SG_T(""), Identifier, Name, _TL(""), bOptional ? PARAMETER_OUTPUT_OPTIONAL : PARAMETER_OUTPUT, false);
+	m_pParameters->Add_Grid(pSystem ? pSystem->Get_Identifier() : SG_T(""), Identifier, Name, _TL(""), bOptional ? PARAMETER_OUTPUT_OPTIONAL : PARAMETER_OUTPUT, false);
 
 	if( bOptional && m_pParameters->Get_Tool()->has_GUI() )
 	{
-		CSG_Parameter	*pNode	= (*m_pParameters)(m_Prefix + "USER_OPTS");
+		CSG_Parameter *pNode = (*m_pParameters)(m_Prefix + "USER_OPTS");
 
 		if( !pNode )
 		{
-			pNode	= m_pParameters->Add_Node(pTarget->Get_Identifier(), m_Prefix + "USER_OPTS", _TL("Optional Target Grids"), _TL(""));
+			pNode = m_pParameters->Add_Node(pTarget->Get_Identifier(), m_Prefix + "USER_OPTS", _TL("Optional Target Grids"), _TL(""));
 		}
 
 		m_pParameters->Add_Bool(pNode->Get_Identifier(), Identifier + "_CREATE", Name, _TL(""), false);
@@ -1628,14 +1688,14 @@ bool CSG_Parameters_Grid_Target::Add_Grids(const CSG_String &Identifier, const C
 		return( false );
 	}
 
-	CSG_Parameter	*pTarget	= (*m_pParameters)(m_Prefix + "DEFINITION");
-	CSG_Parameter	*pSystem	= NULL;
+	CSG_Parameter *pTarget = (*m_pParameters)(m_Prefix + "DEFINITION");
+	CSG_Parameter *pSystem = NULL;
 
 	for(int i=0; i<pTarget->Get_Children_Count() && !pSystem; i++)
 	{
 		if( pTarget->Get_Child(i)->Get_Type() == PARAMETER_TYPE_Grid_System )
 		{
-			pSystem	= pTarget->Get_Child(i);
+			pSystem = pTarget->Get_Child(i);
 		}
 	}
 
@@ -1643,11 +1703,11 @@ bool CSG_Parameters_Grid_Target::Add_Grids(const CSG_String &Identifier, const C
 
 	if( bOptional && m_pParameters->Get_Tool()->has_GUI() )
 	{
-		CSG_Parameter	*pNode	= (*m_pParameters)(m_Prefix + "USER_OPTS");
+		CSG_Parameter *pNode = (*m_pParameters)(m_Prefix + "USER_OPTS");
 
 		if( !pNode )
 		{
-			pNode	= m_pParameters->Add_Node(pTarget->Get_Identifier(), m_Prefix + "USER_OPTS", _TL("Optional Target Grids"), _TL(""));
+			pNode = m_pParameters->Add_Node(pTarget->Get_Identifier(), m_Prefix + "USER_OPTS", _TL("Optional Target Grids"), _TL(""));
 		}
 
 		m_pParameters->Add_Bool(pNode->Get_Identifier(), Identifier + "_CREATE", Name, _TL(""), false);
@@ -1655,7 +1715,7 @@ bool CSG_Parameters_Grid_Target::Add_Grids(const CSG_String &Identifier, const C
 
 	if( bZLevels )
 	{
-		pTarget	= m_pParameters->Add_Node(pTarget, "USER_Z", _TL("Z Levels"), _TL(""));
+		pTarget = m_pParameters->Add_Node(pTarget, "USER_Z", _TL("Z Levels"), _TL(""));
 
 		m_pParameters->Add_Double(pTarget, m_Prefix + "USER_ZSIZE", _TL("Cellsize"), _TL(""), 1., 0., true);
 		m_pParameters->Add_Double(pTarget, m_Prefix + "USER_ZMIN" , _TL("Bottom"  ), _TL(""),   0.);
@@ -1674,15 +1734,15 @@ bool CSG_Parameters_Grid_Target::Add_Grids(const CSG_String &Identifier, const C
 //---------------------------------------------------------
 CSG_Grid_System CSG_Parameters_Grid_Target::Get_System(void)
 {
-	CSG_Grid_System	System;
+	CSG_Grid_System System;
 
 	if( m_pParameters )
 	{
 		if( (*m_pParameters)(m_Prefix + "DEFINITION")->asInt() == 0 )	// user defined
 		{
-			double	Size	= (*m_pParameters)(m_Prefix + "USER_SIZE")->asDouble();
+			double Size = (*m_pParameters)(m_Prefix + "USER_SIZE")->asDouble();
 
-			CSG_Rect	r(
+			CSG_Rect r(
 				(*m_pParameters)(m_Prefix + "USER_XMIN")->asDouble(),
 				(*m_pParameters)(m_Prefix + "USER_YMIN")->asDouble(),
 				(*m_pParameters)(m_Prefix + "USER_XMAX")->asDouble(),
@@ -1698,7 +1758,7 @@ CSG_Grid_System CSG_Parameters_Grid_Target::Get_System(void)
 		}
 		else
 		{
-			CSG_Parameter	*pParameter	= (*m_pParameters)(m_Prefix + "SYSTEM");
+			CSG_Parameter *pParameter = (*m_pParameters)(m_Prefix + "SYSTEM");
 
 			if( pParameter->asGrid_System() )
 			{
@@ -1718,48 +1778,48 @@ CSG_Grid * CSG_Parameters_Grid_Target::Get_Grid(const CSG_String &Identifier, TS
 		return( NULL );
 	}
 
-	CSG_Parameter	*pParameter	= (*m_pParameters)(Identifier);
+	CSG_Parameter *pParameter = (*m_pParameters)(Identifier);
 
 	if( !pParameter || pParameter->Get_Type() != PARAMETER_TYPE_Grid )
 	{
 		return( NULL );
 	}
 
-	CSG_Grid_System	System(Get_System());
+	CSG_Grid_System System(Get_System());
 
 	if( !System.is_Valid() )
 	{
 		return( NULL );
 	}
 
-	CSG_Parameter	*pSystem	= (*m_pParameters)(m_Prefix + "SYSTEM");
+//	CSG_Parameter *pSystem = (*m_pParameters)(m_Prefix + "SYSTEM");
+//
+//	if( pSystem->asGrid_System() && !pSystem->asGrid_System()->is_Equal(System) )
+//	{
+//		pSystem->asGrid_System()->Assign(System);
+//	}
 
-	if( pSystem->asGrid_System() && !pSystem->asGrid_System()->is_Equal(System) )
-	{
-		pSystem->asGrid_System()->Assign(System);
-	}
-
-	CSG_Grid	*pGrid	= NULL;
+	CSG_Grid *pGrid = NULL;
 
 	if( (*m_pParameters)(m_Prefix + "DEFINITION")->asInt() == 0 && m_pParameters->Get_Tool()->has_GUI() )
 	{
 		if( (*m_pParameters)(Identifier + "_CREATE") == NULL
 		||  (*m_pParameters)(Identifier + "_CREATE")->asBool() )
 		{
-			pGrid	= SG_Create_Grid(System, Type);
+			pGrid = SG_Create_Grid(System, Type);
 		}
 	}
 	else
 	{
-		pGrid	= pParameter->asGrid();
+		pGrid = pParameter->asGrid();
 
-		if( pParameter->asPointer() == DATAOBJECT_CREATE || (!pGrid && !pParameter->is_Optional()) )
+		if( pParameter->asDataObject() == DATAOBJECT_CREATE || (!pGrid && !pParameter->is_Optional()) )
 		{
-			pGrid	= SG_Create_Grid(System, Type);
+			pGrid = SG_Create_Grid(System, Type);
 		}
-		else if( pGrid && pGrid->Get_Type() != Type )
+		else if( pGrid && (pGrid->Get_Type() != Type || !pGrid->Get_System().is_Equal(System)) )
 		{
-			pGrid->Create(pGrid->Get_System(), Type);
+			pGrid->Create(System, Type);
 		}
 	}
 
@@ -1790,37 +1850,37 @@ CSG_Grids * CSG_Parameters_Grid_Target::Get_Grids(const CSG_String &Identifier,
 		return( NULL );
 	}
 
-	CSG_Parameter	*pParameter	= (*m_pParameters)(Identifier);
+	CSG_Parameter *pParameter = (*m_pParameters)(Identifier);
 
 	if( !pParameter || pParameter->Get_Type() != PARAMETER_TYPE_Grids )
 	{
 		return( NULL );
 	}
 
-	CSG_Grid_System	System(Get_System());
+	CSG_Grid_System System(Get_System());
 
 	if( !System.is_Valid() )
 	{
 		return( NULL );
 	}
 
-	CSG_Grids	*pGrids	= NULL;
+	CSG_Grids *pGrids = NULL;
 
 	if( (*m_pParameters)(m_Prefix + "DEFINITION")->asInt() == 0
 	&&  (*m_pParameters)(Identifier + "_CREATE") )
 	{
 		if( (*m_pParameters)(Identifier + "_CREATE")->asBool() )
 		{
-			pGrids	= SG_Create_Grids(System, 0, 0., Type);
+			pGrids = SG_Create_Grids(System, 0, 0., Type);
 		}
 	}
 	else
 	{
-		pGrids	= pParameter->asGrids();
+		pGrids = pParameter->asGrids();
 
 		if( pParameter->asPointer() == DATAOBJECT_CREATE || (!pGrids && !pParameter->is_Optional()) )
 		{
-			pGrids	= SG_Create_Grids(System, 0, 0., Type);
+			pGrids = SG_Create_Grids(System, 0, 0., Type);
 		}
 	}
 
@@ -1834,9 +1894,9 @@ CSG_Grids * CSG_Parameters_Grid_Target::Get_Grids(const CSG_String &Identifier,
 	&&  (*m_pParameters)(m_Prefix + "USER_ZMIN" )
 	&&  (*m_pParameters)(m_Prefix + "USER_ZNUM" ) )
 	{
-		int		nz	= (*m_pParameters)(m_Prefix + "USER_ZNUM" )->asInt   ();
-		double	z	= (*m_pParameters)(m_Prefix + "USER_ZMIN" )->asDouble();
-		double	dz	= (*m_pParameters)(m_Prefix + "USER_ZSIZE")->asDouble();
+		int    nz = (*m_pParameters)(m_Prefix + "USER_ZNUM" )->asInt   ();
+		double  z = (*m_pParameters)(m_Prefix + "USER_ZMIN" )->asDouble();
+		double dz = (*m_pParameters)(m_Prefix + "USER_ZSIZE")->asDouble();
 
 		pGrids->Del_Grids();
 
