@@ -65,47 +65,48 @@ CSG_String SG_Parameter_Type_Get_Name(TSG_Parameter_Type Type)
 {
 	switch( Type )
 	{
-	default                              :	return( _TL("Parameter"       ) );
+	default                              :	return( _TL("parameter"            ) );
 
-	case PARAMETER_TYPE_Node             :	return( _TL("Node"            ) );
+	case PARAMETER_TYPE_Node             :	return( _TL("node"                 ) );
 
-	case PARAMETER_TYPE_Bool             :	return( _TL("Boolean"         ) );
-	case PARAMETER_TYPE_Int              :	return( _TL("Integer"         ) );
-	case PARAMETER_TYPE_Double           :	return( _TL("Floating point"  ) );
-	case PARAMETER_TYPE_Degree           :	return( _TL("Degree"          ) );
-	case PARAMETER_TYPE_Date             :	return( _TL("Date"            ) );
-	case PARAMETER_TYPE_Range            :	return( _TL("Value range"     ) );
-	case PARAMETER_TYPE_Choice           :	return( _TL("Choice"          ) );
-	case PARAMETER_TYPE_Choices          :	return( _TL("Choices"         ) );
+	case PARAMETER_TYPE_Bool             :	return( _TL("boolean"              ) );
+	case PARAMETER_TYPE_Int              :	return( _TL("integer number"       ) );
+	case PARAMETER_TYPE_Double           :	return( _TL("floating point number") );
+	case PARAMETER_TYPE_Degree           :	return( _TL("degree"               ) );
+	case PARAMETER_TYPE_Date             :	return( _TL("date"                 ) );
+	case PARAMETER_TYPE_Range            :	return( _TL("value range"          ) );
+	case PARAMETER_TYPE_Data_Type        :	return( _TL("data type"            ) );
+	case PARAMETER_TYPE_Choice           :	return( _TL("choice"               ) );
+	case PARAMETER_TYPE_Choices          :	return( _TL("choices"              ) );
 
-	case PARAMETER_TYPE_String           :	return( _TL("Text"            ) );
-	case PARAMETER_TYPE_Text             :	return( _TL("Long text"       ) );
-	case PARAMETER_TYPE_FilePath         :	return( _TL("File path"       ) );
+	case PARAMETER_TYPE_String           :	return( _TL("text"                 ) );
+	case PARAMETER_TYPE_Text             :	return( _TL("long text"            ) );
+	case PARAMETER_TYPE_FilePath         :	return( _TL("file path"            ) );
 
-	case PARAMETER_TYPE_Font             :	return( _TL("Font"            ) );
-	case PARAMETER_TYPE_Color            :	return( _TL("Color"           ) );
-	case PARAMETER_TYPE_Colors           :	return( _TL("Colors"          ) );
-	case PARAMETER_TYPE_FixedTable       :	return( _TL("Static table"    ) );
-	case PARAMETER_TYPE_Grid_System      :	return( _TL("Grid system"     ) );
-	case PARAMETER_TYPE_Table_Field      :	return( _TL("Table field"     ) );
-	case PARAMETER_TYPE_Table_Fields     :	return( _TL("Table fields"    ) );
+	case PARAMETER_TYPE_Font             :	return( _TL("font"                 ) );
+	case PARAMETER_TYPE_Color            :	return( _TL("color"                ) );
+	case PARAMETER_TYPE_Colors           :	return( _TL("colors"               ) );
+	case PARAMETER_TYPE_FixedTable       :	return( _TL("static table"         ) );
+	case PARAMETER_TYPE_Grid_System      :	return( _TL("grid system"          ) );
+	case PARAMETER_TYPE_Table_Field      :	return( _TL("table field"          ) );
+	case PARAMETER_TYPE_Table_Fields     :	return( _TL("table fields"         ) );
 
-	case PARAMETER_TYPE_DataObject_Output:	return( _TL("Data Object"     ) );
-	case PARAMETER_TYPE_Grid             :	return( _TL("Grid"            ) );
-	case PARAMETER_TYPE_Grids            :	return( _TL("Grids"           ) );
-	case PARAMETER_TYPE_Table            :	return( _TL("Table"           ) );
-	case PARAMETER_TYPE_Shapes           :	return( _TL("Shapes"          ) );
-	case PARAMETER_TYPE_TIN              :	return( _TL("TIN"             ) );
-	case PARAMETER_TYPE_PointCloud       :	return( _TL("Point Cloud"     ) );
+	case PARAMETER_TYPE_DataObject_Output:	return( _TL("data object"          ) );
+	case PARAMETER_TYPE_Grid             :	return( _TL("grid"                 ) );
+	case PARAMETER_TYPE_Grids            :	return( _TL("grid collection"      ) );
+	case PARAMETER_TYPE_Table            :	return( _TL("table"                ) );
+	case PARAMETER_TYPE_Shapes           :	return( _TL("shapes"               ) );
+	case PARAMETER_TYPE_TIN              :	return( _TL("TIN"                  ) );
+	case PARAMETER_TYPE_PointCloud       :	return( _TL("point cloud"          ) );
 
-	case PARAMETER_TYPE_Grid_List        :	return( _TL("Grid list"       ) );
-	case PARAMETER_TYPE_Grids_List       :	return( _TL("Grids list"      ) );
-	case PARAMETER_TYPE_Table_List       :	return( _TL("Table list"      ) );
-	case PARAMETER_TYPE_Shapes_List      :	return( _TL("Shapes list"     ) );
-	case PARAMETER_TYPE_TIN_List         :	return( _TL("TIN list"        ) );
-	case PARAMETER_TYPE_PointCloud_List  :	return( _TL("Point Cloud list") );
+	case PARAMETER_TYPE_Grid_List        :	return( _TL("grid list"            ) );
+	case PARAMETER_TYPE_Grids_List       :	return( _TL("grid collection list" ) );
+	case PARAMETER_TYPE_Table_List       :	return( _TL("table list"           ) );
+	case PARAMETER_TYPE_Shapes_List      :	return( _TL("shapes list"          ) );
+	case PARAMETER_TYPE_TIN_List         :	return( _TL("TIN list"             ) );
+	case PARAMETER_TYPE_PointCloud_List  :	return( _TL("point cloud list"     ) );
 
-	case PARAMETER_TYPE_Parameters       :	return( _TL("Parameters"      ) );
+	case PARAMETER_TYPE_Parameters       :	return( _TL("parameters"           ) );
 	}
 }
 
@@ -124,6 +125,7 @@ CSG_String SG_Parameter_Type_Get_Identifier(TSG_Parameter_Type Type)
 	case PARAMETER_TYPE_Degree           :	return( "degree"       );
 	case PARAMETER_TYPE_Date             :	return( "date"         );
 	case PARAMETER_TYPE_Range            :	return( "range"        );
+	case PARAMETER_TYPE_Data_Type        :	return( "datatype"     );
 	case PARAMETER_TYPE_Choice           :	return( "choice"       );
 	case PARAMETER_TYPE_Choices          :	return( "choices"      );
 
@@ -168,6 +170,7 @@ TSG_Parameter_Type SG_Parameter_Type_Get_Type(const CSG_String &Identifier)
 	if( !Identifier.Cmp("degree"      ) )	{	return( PARAMETER_TYPE_Degree           );	}
 	if( !Identifier.Cmp("date"        ) )	{	return( PARAMETER_TYPE_Date             );	}
 	if( !Identifier.Cmp("range"       ) )	{	return( PARAMETER_TYPE_Range            );	}
+	if( !Identifier.Cmp("datatype"    ) )	{	return( PARAMETER_TYPE_Data_Type        );	}
 	if( !Identifier.Cmp("choice"      ) )	{	return( PARAMETER_TYPE_Choice           );	}
 	if( !Identifier.Cmp("choices"     ) )	{	return( PARAMETER_TYPE_Choices          );	}
 
@@ -231,6 +234,12 @@ CSG_Parameter_Bool::CSG_Parameter_Bool(CSG_Parameters *pOwner, CSG_Parameter *pP
 	m_Value	= false;
 }
 
+//---------------------------------------------------------
+bool CSG_Parameter_Bool::is_Default(void) const
+{
+	return( m_Value == (Get_Default().asInt() != 0) );
+}
+
 //---------------------------------------------------------
 bool CSG_Parameter_Bool::Toggle_Value(void)
 {
@@ -240,11 +249,11 @@ bool CSG_Parameter_Bool::Toggle_Value(void)
 //---------------------------------------------------------
 int CSG_Parameter_Bool::_Set_Value(int Value)
 {
-	bool	bValue = Value != 0;
+	bool bValue = Value != 0;
 
 	if( m_Value != bValue )
 	{
-		m_Value	= bValue;
+		m_Value = bValue;
 
 		return( SG_PARAMETER_DATA_SET_CHANGED );
 	}
@@ -259,17 +268,17 @@ int CSG_Parameter_Bool::_Set_Value(double Value)
 
 int CSG_Parameter_Bool::_Set_Value(const CSG_String &Value)
 {
-	if( !Value.CmpNoCase("true") || !Value.CmpNoCase("yes") )
+	if( !Value.CmpNoCase(_TL("true" )) || !Value.CmpNoCase(_TL("yes")) )
 	{
 		return( _Set_Value(1) );
 	}
 
-	if( !Value.CmpNoCase("false") || !Value.CmpNoCase("no") )
+	if( !Value.CmpNoCase(_TL("false")) || !Value.CmpNoCase(_TL("no" )) )
 	{
 		return( _Set_Value(0) );
 	}
 
-	int		i;
+	int i;
 
 	if( Value.asInt(i) )
 	{
@@ -282,13 +291,13 @@ int CSG_Parameter_Bool::_Set_Value(const CSG_String &Value)
 //---------------------------------------------------------
 void CSG_Parameter_Bool::_Set_String(void)
 {
-	m_String	= m_Value ? _TL("true") : _TL("false");
+	m_String = m_Value ? _TL("true") : _TL("false");
 }
 
 //---------------------------------------------------------
 bool CSG_Parameter_Bool::_Assign(CSG_Parameter *pSource)
 {
-	m_Value		= pSource->asBool();
+	m_Value = pSource->asBool();
 
 	return( true );
 }
@@ -302,7 +311,7 @@ bool CSG_Parameter_Bool::_Serialize(CSG_MetaData &Entry, bool bSave)
 	}
 	else
 	{
-		m_Value	= Entry.Cmp_Content("true", true);
+		m_Value = Entry.Cmp_Content("true", true);
 	}
 
 	return( true );
@@ -421,7 +430,13 @@ bool CSG_Parameter_Value::_Assign(CSG_Parameter *pSource)
 CSG_Parameter_Int::CSG_Parameter_Int(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 	: CSG_Parameter_Value(pOwner, pParent, ID, Name, Description, Constraint)
 {
-	m_Value		= 0;
+	m_Value = 0;
+}
+
+//---------------------------------------------------------
+bool CSG_Parameter_Int::is_Default(void) const
+{
+	return( m_Value == Get_Default().asInt() );
 }
 
 //---------------------------------------------------------
@@ -454,7 +469,7 @@ int CSG_Parameter_Int::_Set_Value(double Value)
 
 int CSG_Parameter_Int::_Set_Value(const CSG_String &Value)
 {
-	int		i;
+	int i;
 
 	if( Value.asInt(i) )
 	{
@@ -504,7 +519,13 @@ bool CSG_Parameter_Int::_Serialize(CSG_MetaData &Entry, bool bSave)
 CSG_Parameter_Double::CSG_Parameter_Double(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 	: CSG_Parameter_Value(pOwner, pParent, ID, Name, Description, Constraint)
 {
-	m_Value		= 0.;
+	m_Value = 0.;
+}
+
+//---------------------------------------------------------
+bool CSG_Parameter_Double::is_Default(void) const
+{
+	return( m_Value == Get_Default().asDouble() );
 }
 
 //---------------------------------------------------------
@@ -725,17 +746,17 @@ bool CSG_Parameter_Date::_Serialize(CSG_MetaData &Entry, bool bSave)
 CSG_Parameter_Range::CSG_Parameter_Range(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 	: CSG_Parameter(pOwner, pParent, ID, Name, Description, Constraint)
 {
-	m_pRange	= new CSG_Parameters;
+	m_pRange = new CSG_Parameters;
 
 	if( is_Information() )
 	{
-		m_pMin	= (CSG_Parameter_Double *)m_pRange->Add_Info_Value(ID, "MIN", "Minimum", Description, PARAMETER_TYPE_Double);
-		m_pMax	= (CSG_Parameter_Double *)m_pRange->Add_Info_Value(ID, "MAX", "Maximum", Description, PARAMETER_TYPE_Double);
+		m_pMin = (CSG_Parameter_Double *)m_pRange->Add_Info_Value(ID, "MIN", "Minimum", Description, PARAMETER_TYPE_Double);
+		m_pMax = (CSG_Parameter_Double *)m_pRange->Add_Info_Value(ID, "MAX", "Maximum", Description, PARAMETER_TYPE_Double);
 	}
 	else
 	{
-		m_pMin	= (CSG_Parameter_Double *)m_pRange->Add_Double    (ID, "MIN", "Minimum", Description);
-		m_pMax	= (CSG_Parameter_Double *)m_pRange->Add_Double    (ID, "MAX", "Maximum", Description);
+		m_pMin = (CSG_Parameter_Double *)m_pRange->Add_Double    (ID, "MIN", "Minimum", Description);
+		m_pMax = (CSG_Parameter_Double *)m_pRange->Add_Double    (ID, "MAX", "Maximum", Description);
 	}
 }
 
@@ -761,17 +782,17 @@ int CSG_Parameter_Range::_Set_Value(const CSG_String &Value)
 
 bool CSG_Parameter_Range::Set_Range(double Min, double Max)
 {
-	bool	bResult;
+	bool bResult;
 
 	if( Min > Max )
 	{
-		bResult	 = m_pMin->Set_Value(Max);
-		bResult	|= m_pMax->Set_Value(Min);
+		bResult  = m_pMin->Set_Value(Max);
+		bResult |= m_pMax->Set_Value(Min);
 	}
 	else
 	{
-		bResult	 = m_pMin->Set_Value(Min);
-		bResult	|= m_pMax->Set_Value(Max);
+		bResult  = m_pMin->Set_Value(Min);
+		bResult |= m_pMax->Set_Value(Max);
 	}
 
 	return( bResult );
@@ -813,6 +834,12 @@ double CSG_Parameter_Range::Get_Max(void)	const
 	return( m_pMax->asDouble() );
 }
 
+//---------------------------------------------------------
+bool CSG_Parameter_Range::is_Default(void) const
+{
+	return( m_pMin->is_Default() && m_pMax->is_Default() );
+}
+
 //---------------------------------------------------------
 bool CSG_Parameter_Range::Restore_Default(void)
 {
@@ -864,7 +891,13 @@ bool CSG_Parameter_Range::_Serialize(CSG_MetaData &Entry, bool bSave)
 CSG_Parameter_Choice::CSG_Parameter_Choice(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 	: CSG_Parameter(pOwner, pParent, ID, Name, Description, Constraint)
 {
-	m_Value	= -1;
+	m_Value = -1;
+}
+
+//---------------------------------------------------------
+bool CSG_Parameter_Choice::is_Default(void) const
+{
+	return( m_Value == Get_Default().asInt() );
 }
 
 //---------------------------------------------------------
@@ -1032,22 +1065,21 @@ int CSG_Parameter_Choice::_Set_Value(const CSG_String &Value)
 {
 	if( !Value.is_Empty() )
 	{
-		int Index; // first test, if value string is an integer specifying the index position
+		for(int i=0; i<m_Items.Get_Count(); i++)
+		{
+			if( !Value.Cmp(Get_Item_Data(i)) || !Value.Cmp(Get_Item(i)) )
+			{
+				return( _Set_Value(i) );
+			}
+		}
+
+		int Index; // choice not found? then test, if value string is an integer specifying the index position
 
 		if( Value.asInt(Index) && Index >= 0 && Index < m_Items.Get_Count() )
 		{
 			return( _Set_Value(Index) );
 		}
 
-		CSG_String _Value(Value[0] == '\"' ? Value.AfterFirst('\"').BeforeFirst('\"') : Value); // quotations can be used to enforce comparison with item's data/name (overpassing index based selection)
-
-		for(int i=0; i<m_Items.Get_Count(); i++)
-		{
-			if( !_Value.Cmp(Get_Item_Data(i)) || !_Value.Cmp(Get_Item(i)) )
-			{
-				return( _Set_Value(i) );
-			}
-		}
 	}
 
 	return( SG_PARAMETER_DATA_SET_FALSE );
@@ -1093,7 +1125,139 @@ bool CSG_Parameter_Choice::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//						Choice							 //
+//						Data Type						 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Parameter_Data_Type::CSG_Parameter_Data_Type(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
+	: CSG_Parameter_Choice(pOwner, pParent, ID, Name, Description, Constraint)
+{
+	// nop
+}
+
+//---------------------------------------------------------
+/**
+* This function initializes the data types available for
+* selection. The Data_Types argument expects a combination
+* of data type flags as defined in <api_core.h>, e.g.
+* SG_DATATYPES_Integer or SG_DATATYPES_Numeric. You can add
+* an additional choice with the User argument, e.g. to offer
+* a type related to an selected input data set.
+*/
+//---------------------------------------------------------
+bool CSG_Parameter_Data_Type::Set_Data_Types(int Data_Types, TSG_Data_Type Default, const CSG_String &User)
+{
+	if( Data_Types <= SG_DATATYPES_Undefined )
+	{
+		Data_Types = SG_DATATYPES_Standard;
+	}
+
+	if( Default == SG_DATATYPE_Undefined && User.is_Empty() )
+	{
+		switch( Data_Types )
+		{
+		case (SG_DATATYPES_Integer                 ): Default = SG_DATATYPE_Int   ; break;
+		case (SG_DATATYPES_Integer|SG_DATATYPES_Bit): Default = SG_DATATYPE_Int   ; break;
+		case (SG_DATATYPES_Numeric                 ): Default = SG_DATATYPE_Float ; break;
+		case (SG_DATATYPES_Numeric|SG_DATATYPES_Bit): Default = SG_DATATYPE_Float ; break;
+		case (SG_DATATYPES_Table                   ): Default = SG_DATATYPE_String; break;
+		case (SG_DATATYPES_Standard                ): Default = SG_DATATYPE_String; break;
+		}
+	}
+
+	#define ADD_TYPE(type) if( (Data_Types & SG_Data_Type_Get_Flag(type)) != 0 ) {  if( Default == type ) { _Default = Get_Count(); } Add_Item(SG_Data_Type_Get_Name(type), SG_Data_Type_Get_Identifier(type)); }
+
+	int _Default = -1;
+
+	ADD_TYPE(SG_DATATYPE_String); // data types are added in this order to the choice item list
+	ADD_TYPE(SG_DATATYPE_Date  );
+	ADD_TYPE(SG_DATATYPE_Color );
+	ADD_TYPE(SG_DATATYPE_Bit   );
+	ADD_TYPE(SG_DATATYPE_Byte  );
+	ADD_TYPE(SG_DATATYPE_Char  );
+	ADD_TYPE(SG_DATATYPE_Word  );
+	ADD_TYPE(SG_DATATYPE_Short );
+	ADD_TYPE(SG_DATATYPE_DWord );
+	ADD_TYPE(SG_DATATYPE_Int   );
+	ADD_TYPE(SG_DATATYPE_ULong );
+	ADD_TYPE(SG_DATATYPE_Long  );
+	ADD_TYPE(SG_DATATYPE_Float );
+	ADD_TYPE(SG_DATATYPE_Double);
+	ADD_TYPE(SG_DATATYPE_Binary);
+
+	if( !User.is_Empty() )
+	{
+		if( _Default < 0 )
+		{
+			_Default = Get_Count();
+		}
+
+		Add_Item(User, SG_Data_Type_Get_Identifier(SG_DATATYPE_Undefined));
+	}
+	else if( _Default < 0 )
+	{
+		_Default = 0;
+	}
+
+	Set_Default(_Default); Set_Value(_Default);
+
+	return( true );
+}
+
+//---------------------------------------------------------
+/**
+* Select a data type from the choices list after it has been
+* initialized. Useful e.g. when adjusting a default data type
+* in CSG_Tool::On_Parameters_Changed() to a changed input data
+* selection.
+*/
+//---------------------------------------------------------
+bool CSG_Parameter_Data_Type::Set_Data_Type(TSG_Data_Type Value)
+{
+	for(int i=0; i<Get_Count(); i++)
+	{
+		if( Value == SG_Data_Type_Get_Type(Get_Item_Data(i)) )
+		{
+			return( Set_Value(i) );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+/**
+* This function returns the selected data type. If an additional
+* 'user' option has been added and is selected, the data type
+* returned is the one given as 'Default' argument. This is useful
+* e.g. if you want to return a data type that comes from an input
+* data set.
+*/
+//---------------------------------------------------------
+TSG_Data_Type CSG_Parameter_Data_Type::Get_Data_Type(TSG_Data_Type Default)	const
+{
+	TSG_Data_Type Type = SG_Data_Type_Get_Type(Get_Data());
+
+	return( Type == SG_DATATYPE_Undefined ? Default : Type );
+}
+
+//---------------------------------------------------------
+bool CSG_Parameter_Data_Type::_Assign(CSG_Parameter *pSource)
+{
+	return( CSG_Parameter_Choice::_Assign(pSource) );
+}
+
+//---------------------------------------------------------
+bool CSG_Parameter_Data_Type::_Serialize(CSG_MetaData &Entry, bool bSave)
+{
+	return( CSG_Parameter_Choice::_Serialize(Entry, bSave) );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//						Choices							 //
 //														 //
 ///////////////////////////////////////////////////////////
 
@@ -1827,7 +1991,7 @@ CSG_Parameter_Grid_System::CSG_Parameter_Grid_System(CSG_Parameters *pOwner, CSG
 //---------------------------------------------------------
 int CSG_Parameter_Grid_System::_Set_Value(void *Value)
 {
-	CSG_Grid_System	System;
+	CSG_Grid_System System;
 
 	if( Value != NULL )
 	{
@@ -1839,41 +2003,44 @@ int CSG_Parameter_Grid_System::_Set_Value(void *Value)
 		return( SG_PARAMETER_DATA_SET_TRUE );
 	}
 
-	m_System	= System;
+	m_System = System;
 
 	//-----------------------------------------------------
-	CSG_Data_Manager *pManager    = Get_Manager();
+	bool bCallback = Get_Parameters()->Set_Callback(false); // only update grid parameter objects in 1st loop...
 
 	for(int i=0; i<Get_Children_Count(); i++)
 	{
-		CSG_Parameter	*pParameter	= Get_Child(i);
+		CSG_Parameter *pParameter = Get_Child(i);
 
 		if( pParameter->is_DataObject() )
 		{
-			CSG_Data_Object	*pObject	= pParameter->asDataObject();
+			CSG_Data_Object *pObject = pParameter->asDataObject();
 
-			bool	bInvalid	= !m_System.is_Valid() || !(pManager && pManager->Exists(pObject));
-
-			if( !bInvalid && pObject != DATAOBJECT_NOTSET && pObject != DATAOBJECT_CREATE )
+			if( pObject != DATAOBJECT_NOTSET && pObject != DATAOBJECT_CREATE )
 			{
-				switch( pObject->Get_ObjectType() )
+				bool bInvalid = !m_System.is_Valid() || !(Get_Manager() && Get_Manager()->Exists(pObject));
+
+				if( !bInvalid )
 				{
-				case SG_DATAOBJECT_TYPE_Grid : bInvalid = !m_System.is_Equal(((CSG_Grid  *)pObject)->Get_System()); break;
-				case SG_DATAOBJECT_TYPE_Grids: bInvalid = !m_System.is_Equal(((CSG_Grids *)pObject)->Get_System()); break;
-				default: break;
+					switch( pObject->Get_ObjectType() )
+					{
+					case SG_DATAOBJECT_TYPE_Grid : bInvalid = !m_System.is_Equal(((CSG_Grid  *)pObject)->Get_System()); break;
+					case SG_DATAOBJECT_TYPE_Grids: bInvalid = !m_System.is_Equal(((CSG_Grids *)pObject)->Get_System()); break;
+					default: break;
+					}
 				}
-			}
 
-			if( bInvalid && pObject != DATAOBJECT_CREATE )
-			{
-				pParameter->Set_Value(DATAOBJECT_NOTSET);
+				if( bInvalid )
+				{
+					pParameter->Set_Value(DATAOBJECT_NOTSET);
+				}
 			}
 		}
 
 		//-------------------------------------------------
 		else if( pParameter->is_DataObject_List() )
 		{
-			CSG_Parameter_List	*pList	= pParameter->asList();
+			CSG_Parameter_List *pList = pParameter->asList();
 
 			if( !m_System.is_Valid() )
 			{
@@ -1881,9 +2048,9 @@ int CSG_Parameter_Grid_System::_Set_Value(void *Value)
 			}
 			else for(int j=pList->Get_Item_Count()-1; j>=0; j--)
 			{
-				CSG_Data_Object	*pObject	= pList->Get_Item(j);
+				CSG_Data_Object *pObject = pList->Get_Item(j);
 
-				bool	bInvalid	= !(pManager && pManager->Exists(pObject));
+				bool bInvalid = !(Get_Manager() && Get_Manager()->Exists(pObject));
 
 				if( !bInvalid && pObject != DATAOBJECT_NOTSET && pObject != DATAOBJECT_CREATE )
 				{
@@ -1900,8 +2067,21 @@ int CSG_Parameter_Grid_System::_Set_Value(void *Value)
 					pList->Del_Item(j);
 				}
 			}
+		}
+	}
 
-			pParameter->has_Changed();
+	Get_Parameters()->Set_Callback(bCallback);
+
+	if( bCallback ) // ...process On_Parameter_Changed()/On_Parameters_Enable() in a 2nd loop!
+	{
+		for(int i=0; i<Get_Children_Count(); i++)
+		{
+			CSG_Parameter *pParameter = Get_Child(i);
+
+			if( pParameter->is_DataObject() || pParameter->is_DataObject_List() )
+			{
+				pParameter->has_Changed();
+			}
 		}
 	}
 
@@ -1912,7 +2092,7 @@ int CSG_Parameter_Grid_System::_Set_Value(void *Value)
 //---------------------------------------------------------
 void CSG_Parameter_Grid_System::_Set_String(void)
 {
-	m_String	= m_System.Get_Name();
+	m_String = m_System.Get_Name();
 }
 
 //---------------------------------------------------------
@@ -1924,7 +2104,7 @@ void * CSG_Parameter_Grid_System::_asPointer(void)	const
 //---------------------------------------------------------
 bool CSG_Parameter_Grid_System::_Assign(CSG_Parameter *pSource)
 {
-	m_System	= ((CSG_Parameter_Grid_System *)pSource)->m_System;
+	m_System = ((CSG_Parameter_Grid_System *)pSource)->m_System;
 
 	return( true );
 }
@@ -1936,22 +2116,19 @@ bool CSG_Parameter_Grid_System::_Serialize(CSG_MetaData &Entry, bool bSave)
 	{
 		Entry.Add_Child("CELLSIZE", m_System.Get_Cellsize());
 		Entry.Add_Child("XMIN"    , m_System.Get_Extent().Get_XMin());
-		Entry.Add_Child("XMAX"    , m_System.Get_Extent().Get_XMax());
 		Entry.Add_Child("YMIN"    , m_System.Get_Extent().Get_YMin());
+		Entry.Add_Child("XMAX"    , m_System.Get_Extent().Get_XMax());
 		Entry.Add_Child("YMAX"    , m_System.Get_Extent().Get_YMax());
 	}
 	else
 	{
-		double		Cellsize;
-		TSG_Rect	Extent;
-
-		Cellsize	= Entry("CELLSIZE")->Get_Content().asDouble();
-		Extent.xMin	= Entry("XMIN"    )->Get_Content().asDouble();
-		Extent.xMax	= Entry("XMAX"    )->Get_Content().asDouble();
-		Extent.yMin	= Entry("YMIN"    )->Get_Content().asDouble();
-		Extent.yMax	= Entry("YMAX"    )->Get_Content().asDouble();
-
-		m_System.Assign(Cellsize, CSG_Rect(Extent));
+		m_System.Create(
+			Entry("CELLSIZE")->Get_Content().asDouble(),
+			Entry("XMIN"    )->Get_Content().asDouble(),
+			Entry("YMIN"    )->Get_Content().asDouble(),
+			Entry("XMAX"    )->Get_Content().asDouble(),
+			Entry("YMAX"    )->Get_Content().asDouble()
+		);
 	}
 
 	return( true );
@@ -2076,7 +2253,7 @@ void CSG_Parameter_Table_Field::_Set_String(void)
 //---------------------------------------------------------
 double CSG_Parameter_Table_Field::_asDouble(void) const
 {
-	return( Get_Child(m_Default) ? Get_Child(m_Default)->asDouble() : CSG_Parameter_Int::asDouble() );
+	return( Get_Child(m_Default) ? Get_Child(m_Default)->asDouble() : 0. );
 }
 
 //---------------------------------------------------------
@@ -2493,26 +2670,19 @@ bool CSG_Parameter_Data_Object_Output::Set_DataObject_Type(TSG_Data_Object_Type
 CSG_Parameter_Grid::CSG_Parameter_Grid(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 	: CSG_Parameter_Data_Object(pOwner, pParent, ID, Name, Description, Constraint)
 {
-	m_Type		= SG_DATATYPE_Undefined;
-
-	m_Default	= -1;
+	m_Type = SG_DATATYPE_Undefined; m_Default = -1;
 }
 
 //---------------------------------------------------------
 void CSG_Parameter_Grid::Set_Preferred_Type(TSG_Data_Type Type)
 {
-	m_Type	= Type;
+	m_Type = Type;
 }
 
 //---------------------------------------------------------
 CSG_Grid_System * CSG_Parameter_Grid::Get_System(void)	const
 {
-	if( Get_Parent() && Get_Parent()->Get_Type() == PARAMETER_TYPE_Grid_System )
-	{
-		return( Get_Parent()->asGrid_System() );
-	}
-
-	return( NULL );
+	return( Get_Parent() ? Get_Parent()->asGrid_System() : NULL );
 }
 
 //---------------------------------------------------------
@@ -2520,7 +2690,7 @@ bool CSG_Parameter_Grid::Add_Default(double Value, double Minimum, bool bMinimum
 {
 	if( m_Default < 0 && is_Input() && is_Optional() )
 	{
-		m_Default	= Get_Children_Count();
+		m_Default = Get_Children_Count();
 
 		Get_Parameters()->Add_Double(Get_Identifier(), CSG_String::Format("%s_DEFAULT", Get_Identifier()),
 			_TL("Default"), _TL("default value if no grid has been selected"),
@@ -2534,41 +2704,57 @@ bool CSG_Parameter_Grid::Add_Default(double Value, double Minimum, bool bMinimum
 //---------------------------------------------------------
 int CSG_Parameter_Grid::_Set_Value(void *Value)
 {
-	if( Value == m_pDataObject )	// nothing to do
+	if( Value == m_pDataObject ) // nothing to do
 	{
 		return( SG_PARAMETER_DATA_SET_TRUE );
 	}
 
 	//-----------------------------------------------------
-	if( Value != DATAOBJECT_NOTSET && Value != DATAOBJECT_CREATE && Get_System() )// && Get_Manager()
+	if( Value != DATAOBJECT_NOTSET && Value != DATAOBJECT_CREATE && Get_System() ) // check grid system compatibility
 	{
-		CSG_Grid_System	System	= Get_Type() == PARAMETER_TYPE_Grid
+		CSG_Grid_System System = Get_Type() == PARAMETER_TYPE_Grid
 			? ((CSG_Grid  *)Value)->Get_System()
 			: ((CSG_Grids *)Value)->Get_System();
 
-		if( !Get_System()->is_Equal(System) )
+		if( System.is_Valid() == false )
 		{
-			for(int i=0; i<Get_Parent()->Get_Children_Count(); i++)
+			if( is_Input() )
 			{
-				CSG_Parameter	*pChild	= Get_Parent()->Get_Child(i);
-
-				if( pChild->Get_Type() == PARAMETER_TYPE_Grid
-				||  pChild->Get_Type() == PARAMETER_TYPE_Grids )
+				return( SG_PARAMETER_DATA_SET_FALSE );
+			}
+		}
+		else if( !Get_System()->is_Equal(System) )
+		{
+			if( Get_System()->is_Valid() )
+			{
+				for(int i=0; i<Get_Parent()->Get_Children_Count(); i++)
 				{
-					if( pChild->asDataObject() != DATAOBJECT_NOTSET
-					&&  pChild->asDataObject() != DATAOBJECT_CREATE
-					&&  pChild->asDataObject() != m_pDataObject )
+					CSG_Parameter *pChild = Get_Parent()->Get_Child(i);
+
+					if( pChild->is_Output() && !Get_Parameters()->has_GUI() )
 					{
-						return( false );
+						continue;
 					}
-				}
 
-				if( pChild->is_DataObject_List() && pChild->asList()->Get_Item_Count() > 0 )
-				{
-					if( (pChild->Get_Type() == PARAMETER_TYPE_Grid_List  && pChild->asGridList ()->Get_System())
-					||  (pChild->Get_Type() == PARAMETER_TYPE_Grids_List && pChild->asGridsList()->Get_System()) )
+					if( pChild->Get_Type() == PARAMETER_TYPE_Grid
+					||  pChild->Get_Type() == PARAMETER_TYPE_Grids )
 					{
-						return( false );
+						if( pChild->asDataObject() != DATAOBJECT_NOTSET
+						&&  pChild->asDataObject() != DATAOBJECT_CREATE
+						&&  pChild->asDataObject() != m_pDataObject
+						&&  pChild->asDataObject() != Value )
+						{
+							return( SG_PARAMETER_DATA_SET_FALSE );
+						}
+					}
+
+					if( pChild->is_DataObject_List() && pChild->asList()->Get_Item_Count() > 0 )
+					{
+						if( (pChild->Get_Type() == PARAMETER_TYPE_Grid_List  && pChild->asGridList ()->Get_System())
+						||  (pChild->Get_Type() == PARAMETER_TYPE_Grids_List && pChild->asGridsList()->Get_System()) )
+						{
+							return( SG_PARAMETER_DATA_SET_FALSE );
+						}
 					}
 				}
 			}
@@ -2578,7 +2764,7 @@ int CSG_Parameter_Grid::_Set_Value(void *Value)
 	}
 
 	//-----------------------------------------------------
-	m_pDataObject	= (CSG_Data_Object *)Value;
+	m_pDataObject = (CSG_Data_Object *)Value;
 
 	if( Get_Child(m_Default) )
 	{
@@ -2603,8 +2789,8 @@ double CSG_Parameter_Grid::_asDouble(void) const
 //---------------------------------------------------------
 bool CSG_Parameter_Grid::_Assign(CSG_Parameter *pSource)
 {
-	m_Type		= ((CSG_Parameter_Grid *)pSource)->m_Type;
-	m_Default	= ((CSG_Parameter_Grid *)pSource)->m_Default;
+	m_Type    = ((CSG_Parameter_Grid *)pSource)->m_Type;
+	m_Default = ((CSG_Parameter_Grid *)pSource)->m_Default;
 
 	return( _Set_Value(pSource->asPointer()) != 0 );
 }
@@ -2645,11 +2831,11 @@ int CSG_Parameter_Table::_Set_Value(void *Value)
 		return( SG_PARAMETER_DATA_SET_TRUE );
 	}
 
-	m_pDataObject	= (CSG_Data_Object *)Value;
+	m_pDataObject = (CSG_Data_Object *)Value;
 
 	for(int i=0; i<Get_Children_Count(); i++)
 	{
-		CSG_Parameter	*pChild	= Get_Child(i);
+		CSG_Parameter *pChild = Get_Child(i);
 
 		if( pChild->Get_Type() == PARAMETER_TYPE_Table_Field )
 		{
@@ -2675,13 +2861,13 @@ int CSG_Parameter_Table::_Set_Value(void *Value)
 CSG_Parameter_Shapes::CSG_Parameter_Shapes(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 	: CSG_Parameter_Data_Object(pOwner, pParent, ID, Name, Description, Constraint)
 {
-	m_Type	= SHAPE_TYPE_Undefined;
+	m_Type = SHAPE_TYPE_Undefined;
 }
 
 //---------------------------------------------------------
 int CSG_Parameter_Shapes::_Set_Value(void *Value)
 {
-	if(	Value != DATAOBJECT_NOTSET && Value != DATAOBJECT_CREATE
+	if( (is_Input() || Get_Parameters()->has_GUI()) && Value != DATAOBJECT_NOTSET && Value != DATAOBJECT_CREATE
 	&&	m_Type != SHAPE_TYPE_Undefined && m_Type != ((CSG_Shapes *)Value)->Get_Type() )
 	{
 		return( SG_PARAMETER_DATA_SET_FALSE );
@@ -2692,11 +2878,11 @@ int CSG_Parameter_Shapes::_Set_Value(void *Value)
 		return( SG_PARAMETER_DATA_SET_TRUE );
 	}
 
-	m_pDataObject	= (CSG_Data_Object *)Value;
+	m_pDataObject = (CSG_Data_Object *)Value;
 
 	for(int i=0; i<Get_Children_Count(); i++)
 	{
-		CSG_Parameter	*pChild	= Get_Child(i);
+		CSG_Parameter *pChild = Get_Child(i);
 
 		if(	pChild->Get_Type() == PARAMETER_TYPE_Table_Field )
 		{
@@ -2714,13 +2900,13 @@ int CSG_Parameter_Shapes::_Set_Value(void *Value)
 //---------------------------------------------------------
 void CSG_Parameter_Shapes::Set_Shape_Type(TSG_Shape_Type Type)
 {
-	m_Type	= Type;
+	m_Type = Type;
 }
 
 //---------------------------------------------------------
 bool CSG_Parameter_Shapes::_Assign(CSG_Parameter *pSource)
 {
-	m_Type	= ((CSG_Parameter_Shapes *)pSource)->m_Type;
+	m_Type = ((CSG_Parameter_Shapes *)pSource)->m_Type;
 
 	return( CSG_Parameter_Data_Object::_Assign(pSource) );
 }
@@ -2747,11 +2933,11 @@ int CSG_Parameter_TIN::_Set_Value(void *Value)
 		return( SG_PARAMETER_DATA_SET_TRUE );
 	}
 
-	m_pDataObject	= (CSG_Data_Object *)Value;
+	m_pDataObject = (CSG_Data_Object *)Value;
 
 	for(int i=0; i<Get_Children_Count(); i++)
 	{
-		CSG_Parameter	*pChild	= Get_Child(i);
+		CSG_Parameter *pChild = Get_Child(i);
 
 		if( pChild->Get_Type() == PARAMETER_TYPE_Table_Field )
 		{
@@ -2788,11 +2974,11 @@ int CSG_Parameter_PointCloud::_Set_Value(void *Value)
 		return( SG_PARAMETER_DATA_SET_TRUE );
 	}
 
-	m_pDataObject	= (CSG_Data_Object *)Value;
+	m_pDataObject = (CSG_Data_Object *)Value;
 
 	for(int i=0; i<Get_Children_Count(); i++)
 	{
-		CSG_Parameter	*pChild	= Get_Child(i);
+		CSG_Parameter *pChild = Get_Child(i);
 
 		if( pChild->Get_Type() == PARAMETER_TYPE_Table_Field )
 		{
@@ -3004,23 +3190,26 @@ bool CSG_Parameter_Grid_List::Add_Item(CSG_Data_Object *pObject)
 	}
 
 	//-----------------------------------------------------
-	CSG_Grid_System *pSystem = Get_System();
-
-	if( pSystem )	// check grid system compatibility
+	if( Get_System() ) // check grid system compatibility
 	{
 		CSG_Grid_System System = pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid
 			? ((CSG_Grid  *)pObject)->Get_System()
 			: ((CSG_Grids *)pObject)->Get_System();
 
-		if( !pSystem->is_Valid() )
+		if( System.is_Valid() == false && is_Input() )
+		{
+			return( false );
+		}
+
+		if( !Get_System()->is_Valid() )
 		{
 			Get_Parent()->Set_Value((void *)&System);
 		}
-		else if( !pSystem->is_Equal(System) )
+		else if( !Get_System()->is_Equal(System) )
 		{
 			for(int i=0; i<Get_Parent()->Get_Children_Count(); i++)
 			{
-				CSG_Parameter	*pChild	= Get_Parent()->Get_Child(i);
+				CSG_Parameter *pChild = Get_Parent()->Get_Child(i);
 
 				if( pChild->Get_Type() == PARAMETER_TYPE_Grid
 				||  pChild->Get_Type() == PARAMETER_TYPE_Grids )
