@@ -105,17 +105,19 @@ CSG_Parameters::~CSG_Parameters(void)
 //---------------------------------------------------------
 void CSG_Parameters::_On_Construction(void)
 {
-	m_pOwner		= NULL;
-	m_pTool			= NULL;
-	m_pManager		= &SG_Get_Data_Manager();
+	m_pOwner       = NULL;
+	m_pTool        = NULL;
+	m_pManager     = &SG_Get_Data_Manager();
 
-	m_Parameters	= NULL;
-	m_nParameters	= 0;
+	m_Callback     = NULL;
+	m_bCallback    = true;
 
-	m_Callback		= NULL;
-	m_bCallback		= true;
+	m_Parameters   = NULL;
+	m_nParameters  = 0;
 
-	m_pGrid_System	= NULL;
+	m_pGrid_System = NULL;
+
+	m_pStack       = NULL;
 }
 
 //---------------------------------------------------------
@@ -123,18 +125,17 @@ bool CSG_Parameters::Create(const CSG_Parameters &Parameters)
 {
 	Destroy();
 
-	m_pOwner		= Parameters.m_pOwner;
-	m_pTool			= Parameters.m_pTool;
-	m_pManager		= Parameters.m_pManager;
+	Set_Identifier (Parameters.Get_Identifier ());
+	Set_Name       (Parameters.Get_Name       ());
+	Set_Description(Parameters.Get_Description());
 
-	m_Callback		= Parameters.m_Callback;
-	m_bCallback		= Parameters.m_bCallback;
+	m_pOwner       = Parameters.m_pOwner;
+	m_pTool        = Parameters.m_pTool;
+	m_pManager     = Parameters.m_pManager;
 
-	Set_Identifier	(Parameters.Get_Identifier ());
-	Set_Name		(Parameters.Get_Name       ());
-	Set_Description	(Parameters.Get_Description());
+	m_Callback     = Parameters.m_Callback;
+	m_bCallback    = Parameters.m_bCallback;
 
-	//-----------------------------------------------------
 	for(int i=0; i<Parameters.m_nParameters; i++)
 	{
 		_Add(Parameters.m_Parameters[i]);
@@ -142,7 +143,7 @@ bool CSG_Parameters::Create(const CSG_Parameters &Parameters)
 
 	if( Parameters.m_pGrid_System )
 	{
-		m_pGrid_System	= Get_Parameter(Parameters.m_pGrid_System->Get_Identifier());
+		m_pGrid_System = Get_Parameter(Parameters.m_pGrid_System->Get_Identifier());
 	}
 
 	return( m_nParameters == Parameters.m_nParameters );
@@ -170,7 +171,7 @@ bool CSG_Parameters::Create(void *pOwner, const SG_Char *Name, const SG_Char *De
 {
 	if( Create(Name, Description, Identifier, bGrid_System) )
 	{
-		m_pOwner	= pOwner;
+		m_pOwner = pOwner;
 
 		return( true );
 	}
@@ -181,6 +182,8 @@ bool CSG_Parameters::Create(void *pOwner, const SG_Char *Name, const SG_Char *De
 //---------------------------------------------------------
 void CSG_Parameters::Destroy(void)
 {
+	Pop();
+
 	m_pOwner       = NULL;
 	m_pTool        = NULL;
 	m_pGrid_System = NULL;
@@ -195,6 +198,12 @@ void CSG_Parameters::Destroy(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+void CSG_Parameters::Set_Tool(CSG_Tool *pTool)
+{
+	m_pTool = pTool;
+}
+
 //---------------------------------------------------------
 /**
   * Set the responsible data manager for this parameter list.
@@ -205,7 +214,7 @@ void CSG_Parameters::Destroy(void)
 //---------------------------------------------------------
 void CSG_Parameters::Set_Manager(CSG_Data_Manager *pManager)
 {
-	m_pManager		= pManager;
+	m_pManager = pManager;
 
 	for(int i=0; i<Get_Count(); i++)
 	{
@@ -233,6 +242,58 @@ bool CSG_Parameters::Use_Grid_System(void)
 	return( false );
 }
 
+
+//---------------------------------------------------------
+/**
+* Stores the current parameter settings including the data
+* manager to an internal CSG_Parameters copy.
+* Settings and data manager can be restored by a subsequent
+* call to Pop().
+*/
+//---------------------------------------------------------
+bool CSG_Parameters::Push(CSG_Data_Manager *pManager, bool bRestoreDefaults)
+{
+	CSG_Parameters *pStack = m_pStack;
+
+	m_pStack = new CSG_Parameters(*this);
+
+	m_pStack->m_pStack = pStack;
+
+	m_pManager = pManager;
+
+	if( bRestoreDefaults )
+	{
+		Restore_Defaults(true);
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+/**
+* Restores previously pushed parameter settings and data manager.
+*/
+//---------------------------------------------------------
+bool CSG_Parameters::Pop(void)
+{
+	if( m_pStack )
+	{
+		m_pManager = m_pStack->m_pManager;
+
+		Assign_Values(m_pStack);
+
+		CSG_Parameters *pStack = m_pStack->m_pStack;
+
+		delete( m_pStack );
+
+		m_pStack = pStack;
+
+		return( true );
+	}
+
+	return( false );
+}
+
 //---------------------------------------------------------
 /**
 * If parameters are owned by a tool the function returns the
@@ -291,9 +352,7 @@ void CSG_Parameters::Set_Description(const CSG_String &Description)
 //---------------------------------------------------------
 void CSG_Parameters::Add_Reference(const CSG_String &Authors, const CSG_String &Year, const CSG_String &Title, const CSG_String &Where, const SG_Char *Link, const SG_Char *Link_Text)
 {
-	CSG_String	Reference	= Authors;
-
-	Reference.Printf("<b>%s (%s):</b> %s. %s", Authors.c_str(), Year.c_str(), Title.c_str(), Where.c_str());
+	CSG_String Reference("<b>" + Authors + " (" + Year + "):</b> " + Title  + ". " + Where);
 
 	if( Link && *Link )
 	{
@@ -441,6 +500,27 @@ CSG_Parameter * CSG_Parameters::Add_Info_Range(const CSG_String &ParentID, const
 	return( _Add_Range(ParentID, ID, Name, Description,  true, Range_Min, Range_Max, 0.0, false, 0.0, false) );
 }
 
+//---------------------------------------------------------
+/**
+* Add a parameter for selecting a data type from a list of
+* choices. The Data_Types argument expects a combination
+* of data type flags as defined in <api_core.h>, e.g.
+* SG_DATATYPES_Integer or SG_DATATYPES_Numeric. You can add
+* an additional choice with the User argument, e.g. to offer
+* a type related to an selected input data set.
+*/
+//---------------------------------------------------------
+CSG_Parameter * CSG_Parameters::Add_Data_Type(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Data_Types, TSG_Data_Type Default, const CSG_String &User)
+{
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Data_Type, 0);
+
+	bool bCallback = Set_Callback(false);
+	pParameter->asDataType()->Set_Data_Types(Data_Types, Default, User);
+	Set_Callback(bCallback);
+
+	return( pParameter );
+}
+
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Choice(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items, int Default)
 {
@@ -448,7 +528,7 @@ CSG_Parameter * CSG_Parameters::Add_Choice(const CSG_String &ParentID, const CSG
 
 	pParameter->asChoice()->Set_Items(Items);
 
-	bool	bCallback	= Set_Callback(false);
+	bool bCallback = Set_Callback(false);
 	pParameter->Set_Value  (Default);
 	pParameter->Set_Default(Default);
 	Set_Callback(bCallback);
@@ -1026,63 +1106,70 @@ CSG_Parameter * CSG_Parameters::_Add_String(const CSG_String &ParentID, const CS
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
+#ifdef _DEBUG
 #include <wx/debug.h>
+#include <wx/string.h>
+#endif
 
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::_Add(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, TSG_Parameter_Type Type, int Constraint)
 {
-	wxASSERT_MSG(!ID.is_Empty(), "CSG_Parameter::Add: ID is empty");
+#ifdef _DEBUG
+	wxASSERT_MSG(!ID.is_Empty()    , wxString::Format("CSG_Parameter::_Add(): Parameter ID is empty!"));
+	wxASSERT_MSG(!Get_Parameter(ID), wxString::Format("CSG_Parameter::_Add(): Parameter ID \"%s\" is already in use!", ID.c_str()));
+#endif
 
-	CSG_Parameter	*pParameter;
+	CSG_Parameter *pParameter;
 
 	switch( Type )
 	{
 	default:
 		return( NULL );
 
-	case PARAMETER_TYPE_Node             : pParameter	= new CSG_Parameter_Node              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Node             : pParameter = new CSG_Parameter_Node              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 
-	case PARAMETER_TYPE_Bool             : pParameter	= new CSG_Parameter_Bool              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Int              : pParameter	= new CSG_Parameter_Int               (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Double           : pParameter	= new CSG_Parameter_Double            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Degree           : pParameter	= new CSG_Parameter_Degree            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Date             : pParameter	= new CSG_Parameter_Date              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Range            : pParameter	= new CSG_Parameter_Range             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Choice           : pParameter	= new CSG_Parameter_Choice            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Choices          : pParameter	= new CSG_Parameter_Choices           (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Bool             : pParameter = new CSG_Parameter_Bool              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Int              : pParameter = new CSG_Parameter_Int               (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Double           : pParameter = new CSG_Parameter_Double            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Degree           : pParameter = new CSG_Parameter_Degree            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Date             : pParameter = new CSG_Parameter_Date              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Range            : pParameter = new CSG_Parameter_Range             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Data_Type        : pParameter = new CSG_Parameter_Data_Type         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Choice           : pParameter = new CSG_Parameter_Choice            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Choices          : pParameter = new CSG_Parameter_Choices           (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 
-	case PARAMETER_TYPE_String           : pParameter	= new CSG_Parameter_String            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Text             : pParameter	= new CSG_Parameter_Text              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_FilePath         : pParameter	= new CSG_Parameter_File_Name         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_String           : pParameter = new CSG_Parameter_String            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Text             : pParameter = new CSG_Parameter_Text              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_FilePath         : pParameter = new CSG_Parameter_File_Name         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 
-	case PARAMETER_TYPE_Font             : pParameter	= new CSG_Parameter_Font              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Color            : pParameter	= new CSG_Parameter_Color             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Colors           : pParameter	= new CSG_Parameter_Colors            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_FixedTable       : pParameter	= new CSG_Parameter_Fixed_Table       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Grid_System      : pParameter	= new CSG_Parameter_Grid_System       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Table_Field      : pParameter	= new CSG_Parameter_Table_Field       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Table_Fields     : pParameter	= new CSG_Parameter_Table_Fields      (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Font             : pParameter = new CSG_Parameter_Font              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Color            : pParameter = new CSG_Parameter_Color             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Colors           : pParameter = new CSG_Parameter_Colors            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_FixedTable       : pParameter = new CSG_Parameter_Fixed_Table       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Grid_System      : pParameter = new CSG_Parameter_Grid_System       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Table_Field      : pParameter = new CSG_Parameter_Table_Field       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Table_Fields     : pParameter = new CSG_Parameter_Table_Fields      (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 
-	case PARAMETER_TYPE_DataObject_Output: pParameter	= new CSG_Parameter_Data_Object_Output(this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Grid             : pParameter	= new CSG_Parameter_Grid              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Grids            : pParameter	= new CSG_Parameter_Grids             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Table            : pParameter	= new CSG_Parameter_Table             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Shapes           : pParameter	= new CSG_Parameter_Shapes            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_TIN              : pParameter	= new CSG_Parameter_TIN               (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_PointCloud       : pParameter	= new CSG_Parameter_PointCloud        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_DataObject_Output: pParameter = new CSG_Parameter_Data_Object_Output(this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Grid             : pParameter = new CSG_Parameter_Grid              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Grids            : pParameter = new CSG_Parameter_Grids             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Table            : pParameter = new CSG_Parameter_Table             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Shapes           : pParameter = new CSG_Parameter_Shapes            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_TIN              : pParameter = new CSG_Parameter_TIN               (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_PointCloud       : pParameter = new CSG_Parameter_PointCloud        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 
-	case PARAMETER_TYPE_Grid_List        : pParameter	= new CSG_Parameter_Grid_List         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Grids_List       : pParameter	= new CSG_Parameter_Grids_List        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Table_List       : pParameter	= new CSG_Parameter_Table_List        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_Shapes_List      : pParameter	= new CSG_Parameter_Shapes_List       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_TIN_List         : pParameter	= new CSG_Parameter_TIN_List          (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
-	case PARAMETER_TYPE_PointCloud_List  : pParameter	= new CSG_Parameter_PointCloud_List   (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Grid_List        : pParameter = new CSG_Parameter_Grid_List         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Grids_List       : pParameter = new CSG_Parameter_Grids_List        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Table_List       : pParameter = new CSG_Parameter_Table_List        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_Shapes_List      : pParameter = new CSG_Parameter_Shapes_List       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_TIN_List         : pParameter = new CSG_Parameter_TIN_List          (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
+	case PARAMETER_TYPE_PointCloud_List  : pParameter = new CSG_Parameter_PointCloud_List   (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 
-	case PARAMETER_TYPE_Parameters       : pParameter	= new CSG_Parameter_Parameters        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Parameters       : pParameter = new CSG_Parameter_Parameters        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint); break;
 	}
 
-	m_Parameters	= (CSG_Parameter **)SG_Realloc(m_Parameters, (m_nParameters + 1) * sizeof(CSG_Parameter *));
-	m_Parameters[m_nParameters++]	= pParameter;
+	m_Parameters = (CSG_Parameter **)SG_Realloc(m_Parameters, (m_nParameters + 1) * sizeof(CSG_Parameter *));
+	m_Parameters[m_nParameters++] = pParameter;
 
 	pParameter->_Set_String();
 
@@ -1092,7 +1179,7 @@ CSG_Parameter * CSG_Parameters::_Add(const CSG_String &ParentID, const CSG_Strin
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::_Add(CSG_Parameter *pSource)
 {
-	CSG_Parameter	*pParameter	= !pSource ? NULL : _Add(
+	CSG_Parameter *pParameter = !pSource ? NULL : _Add(
 		pSource->Get_Parent() ? pSource->Get_Parent()->Get_Identifier() : SG_T(""),
 		pSource->Get_Identifier (),
 		pSource->Get_Name       (),
@@ -1279,9 +1366,9 @@ TSG_PFNC_Parameter_Changed CSG_Parameters::Set_Callback_On_Parameter_Changed(TSG
 // Return value is the previous state.
 bool CSG_Parameters::Set_Callback(bool bActive)
 {
-	bool	bPrevious	= m_bCallback;
+	bool bPrevious = m_bCallback;
 
-	m_bCallback	= bActive;
+	m_bCallback = bActive;
 
 	for(int i=0; i<m_nParameters; i++)
 	{
@@ -1299,7 +1386,7 @@ bool CSG_Parameters::_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 {
 	if( m_Callback && m_bCallback )
 	{
-		bool	bCallback	= Set_Callback(false);
+		bool bCallback = Set_Callback(false);
 
 		m_Callback(pParameter, Flags);
 
@@ -1485,16 +1572,14 @@ bool CSG_Parameters::Assign_Parameters(CSG_Parameters *pSource)
 //---------------------------------------------------------
 bool CSG_Parameters::DataObjects_Check(bool bSilent)
 {
-	bool		bResult	= true;
-
-	CSG_String	sError;
+	bool bResult = true; CSG_String sError;
 
 	//-----------------------------------------------------
 	for(int i=0; i<Get_Count(); i++)
 	{
 		if( m_Parameters[i]->Check(bSilent) == false )
 		{
-			bResult	= false;
+			bResult = false;
 
 			sError.Append(CSG_String::Format("\n%s: %s", m_Parameters[i]->Get_Type_Name().c_str(), m_Parameters[i]->Get_Name()));
 		}
@@ -1512,120 +1597,147 @@ bool CSG_Parameters::DataObjects_Check(bool bSilent)
 //---------------------------------------------------------
 bool CSG_Parameters::DataObjects_Create(void)
 {
-	bool	bResult	= true;
+	bool bResult = true;
 
-	for(int i=0; i<Get_Count() && bResult; i++)
+	for(int i=0; bResult && i<Get_Count(); i++)
 	{
-		CSG_Parameter	*p	= m_Parameters[i];
+		CSG_Parameter &P = *m_Parameters[i];
 
 		//-------------------------------------------------
-		if( p->Get_Type() == PARAMETER_TYPE_Parameters )
+		if( P.Get_Type() == PARAMETER_TYPE_Parameters )
 		{
-			bResult	= p->asParameters()->DataObjects_Create();
-		}
-		else if( p->Get_Type() == PARAMETER_TYPE_DataObject_Output )
-		{
-			if( m_pManager || p->asDataObject() == DATAOBJECT_CREATE )
+			if( !P.asParameters()->DataObjects_Create() )
 			{
-				p->Set_Value(DATAOBJECT_NOTSET);
+				bResult = false;
 			}
 		}
-		else if( p->is_Input() )
+		else if( P.is_Input() )
 		{
-			bResult	= !p->is_Enabled() || p->Check(true);
+			if( P.is_Enabled() && P.Check(true) == false )
+			{
+				bResult = false;
+
+				SG_UI_Dlg_Message(CSG_String::Format("%s\n[%s]\n%s", _TL("Input Error"), P.Get_Identifier(), P.Get_Name()), Get_Name());
+			}
 		}
 
 		//-------------------------------------------------
-		else if( p->is_DataObject_List() )
+		else if( P.is_DataObject_List() )
 		{
-			for(int j=p->asList()->Get_Item_Count()-1; j>=0; j--)
+			for(int j=P.asList()->Get_Item_Count()-1; j>=0; j--)
 			{
-				if( m_pManager && !m_pManager->Exists(p->asList()->Get_Item(j)) )
+				if( m_pManager && !m_pManager->Exists(P.asList()->Get_Item(j)) )
 				{
-					p->asList()->Del_Item(j);
+					P.asList()->Del_Item(j);
 				}
 			}
 		}
 
 		//-------------------------------------------------
-		else if( p->is_DataObject() && p->is_Enabled() == false )
+		else if( P.is_DataObject() && P.is_Enabled() == false && has_GUI() )
 		{
-			if( p->asDataObject() != DATAOBJECT_CREATE && (!m_pManager || !m_pManager->Exists(p->asDataObject())) )
+			if( P.asDataObject() != DATAOBJECT_CREATE && (m_pManager && !m_pManager->Exists(P.asDataObject())) )
 			{
-				p->Set_Value(DATAOBJECT_NOTSET);
+				P.Set_Value(DATAOBJECT_NOTSET);
 			}
 		}
 
-		else if( p->is_DataObject() )
+		else if( P.is_DataObject() )
 		{
-			CSG_Data_Object	*pDataObject	= p->asDataObject();
+			CSG_Data_Object *pObject = P.asDataObject();
 
-			if(	(pDataObject == DATAOBJECT_CREATE)
-			||	(pDataObject == DATAOBJECT_NOTSET && !p->is_Optional())
-			||	(pDataObject != DATAOBJECT_NOTSET && m_pManager && !m_pManager->Exists(pDataObject)) )
+			if( pObject != DATAOBJECT_CREATE )
 			{
-				pDataObject	= NULL;
-
-				switch( p->Get_Type() )
+				if( P.Get_Type() == PARAMETER_TYPE_DataObject_Output && has_GUI() )
 				{
-				case PARAMETER_TYPE_Table     :	pDataObject	= SG_Create_Table     ();	break;
-				case PARAMETER_TYPE_TIN       :	pDataObject	= SG_Create_TIN       ();	break;
-				case PARAMETER_TYPE_PointCloud:	pDataObject	= SG_Create_PointCloud();	break;
-				case PARAMETER_TYPE_Shapes    :	pDataObject	= SG_Create_Shapes(
-						((CSG_Parameter_Shapes *)p)->Get_Shape_Type()
-					);
-					break;
+					pObject = (CSG_Data_Object *)DATAOBJECT_CREATE;
+				}
+				else if( m_pManager && !m_pManager->Exists(pObject) )
+				{
+					pObject = (CSG_Data_Object *)DATAOBJECT_NOTSET;
+				}
 
-				case PARAMETER_TYPE_Grid      :
-				case PARAMETER_TYPE_Grids     :
-					if(	p->Get_Parent() && p->Get_Parent()->Get_Type() == PARAMETER_TYPE_Grid_System 
-					&&	p->Get_Parent()->asGrid_System() && p->Get_Parent()->asGrid_System()->is_Valid() )
+				if( pObject == DATAOBJECT_NOTSET && !P.is_Optional() )
+				{
+					pObject = (CSG_Data_Object *)DATAOBJECT_CREATE;
+				}
+			}
+
+			if( pObject == DATAOBJECT_CREATE )
+			{
+				switch( P.Get_DataObject_Type() )
+				{
+				case SG_DATAOBJECT_TYPE_Table     : pObject = SG_Create_Table     (); break;
+				case SG_DATAOBJECT_TYPE_Shapes    : pObject = SG_Create_Shapes    (); break;
+				case SG_DATAOBJECT_TYPE_PointCloud: pObject = SG_Create_PointCloud(); break;
+				case SG_DATAOBJECT_TYPE_TIN       : pObject = SG_Create_TIN       (); break;
+				case SG_DATAOBJECT_TYPE_Grid      : pObject = SG_Create_Grid      (); break;
+				case SG_DATAOBJECT_TYPE_Grids     : pObject = SG_Create_Grids     (); break;
+				default                           : pObject = NULL                  ; break;
+				}
+			}
+
+			if( pObject )
+			{
+				if( P.Get_Type() == PARAMETER_TYPE_Shapes
+				&&  ((CSG_Parameter_Shapes *)&P)->Get_Shape_Type() != SHAPE_TYPE_Undefined
+				&&  ((CSG_Parameter_Shapes *)&P)->Get_Shape_Type() != pObject->asShapes()->Get_Type() )
+				{
+					if( has_GUI() && pObject->asShapes()->Get_Type() != SHAPE_TYPE_Undefined )
 					{
-						if( p->Get_Type() == PARAMETER_TYPE_Grid )
+						pObject	= SG_Create_Shapes (((CSG_Parameter_Shapes *)&P)->Get_Shape_Type());
+					}
+					else
+					{
+						pObject->asShapes()->Create(((CSG_Parameter_Shapes *)&P)->Get_Shape_Type());
+					}
+				}
+
+				if( (P.Get_Type() == PARAMETER_TYPE_Grid || P.Get_Type() == PARAMETER_TYPE_Grids) )
+				{
+					if(	P.Get_Parent() && P.Get_Parent()->asGrid_System() && P.Get_Parent()->asGrid_System()->is_Valid() )
+					{
+						CSG_Grid_System System(*P.Get_Parent()->asGrid_System());
+
+						if( P.Get_Type() == PARAMETER_TYPE_Grid  && !System.is_Equal(pObject->asGrid ()->Get_System()) )
 						{
-							pDataObject	= SG_Create_Grid(*p->Get_Parent()->asGrid_System(), ((CSG_Parameter_Grid *)p)->Get_Preferred_Type());
+							pObject->asGrid ()->Create(System       , ((CSG_Parameter_Grid  *)&P)->Get_Preferred_Type());
 						}
-						else
+
+						if( P.Get_Type() == PARAMETER_TYPE_Grids && !System.is_Equal(pObject->asGrids()->Get_System()) )
 						{
-							pDataObject	= SG_Create_Grids(*p->Get_Parent()->asGrid_System(), 0, 0.0, ((CSG_Parameter_Grids *)p)->Get_Preferred_Type());
+							pObject->asGrids()->Create(System, 0, 0., ((CSG_Parameter_Grids *)&P)->Get_Preferred_Type());
 						}
 					}
-					break;
-
-				default:
-					break;
 				}
-			}
-			else if( p->Get_Type() == PARAMETER_TYPE_Shapes && p->asShapes() )
-			{
-				if( ((CSG_Parameter_Shapes *)p)->Get_Shape_Type() != SHAPE_TYPE_Undefined
-				&&	((CSG_Parameter_Shapes *)p)->Get_Shape_Type() != p->asShapes()->Get_Type() )
-				{
-					pDataObject	= SG_Create_Shapes(((CSG_Parameter_Shapes *)p)->Get_Shape_Type());
-				}
-			}
 
-			if( pDataObject )
-			{
-				if( p->Set_Value(pDataObject) )
+				if( P.Set_Value(pObject) )
 				{
-					pDataObject->Set_Name(p->Get_Name());
+					pObject->Set_Name(P.Get_Name());
+					pObject->Get_MetaData().Del_Children();
 
 					if( m_pManager )
 					{
-						m_pManager->Add(pDataObject);
+						m_pManager->Add(pObject);
 					}
 				}
 				else
 				{
-					delete(pDataObject);
+					delete(pObject);
 
-					bResult	= false;
+					bResult = false;
+
+					SG_UI_Dlg_Message(CSG_String::Format("%s\n[%s]\n%s", _TL("Output Error"), P.Get_Identifier(), P.Get_Name()), Get_Name());
 				}
 			}
-			else
+			else // if( pObject == NULL )
 			{
-				bResult	= p->is_Optional();
+				if( !P.is_Optional() )
+				{
+					bResult = false;
+
+					SG_UI_Dlg_Message(CSG_String::Format("%s\n[%s]\n%s", _TL("Output Error"), P.Get_Identifier(), P.Get_Name()), Get_Name());
+				}
 			}
 		}
 	}
@@ -1638,23 +1750,23 @@ bool CSG_Parameters::DataObjects_Synchronize(void)
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
-		CSG_Parameter	*p	= m_Parameters[i];
+		CSG_Parameter &P = *m_Parameters[i];
 
-		if( p->Get_Type() == PARAMETER_TYPE_Parameters )
+		if( P.Get_Type() == PARAMETER_TYPE_Parameters )
 		{
-			p->asParameters()->DataObjects_Synchronize();
+			P.asParameters()->DataObjects_Synchronize();
 		}
 
 		//-------------------------------------------------
-		else if( p->is_Output() )
+		else if( P.is_Output() )
 		{
-			if( p->is_DataObject() )
+			if( P.is_DataObject() )
 			{
-				CSG_Data_Object	*pObject	= p->asDataObject();
+				CSG_Data_Object *pObject = P.asDataObject();
 
 				if( pObject == DATAOBJECT_CREATE )
 				{
-					p->Set_Value(DATAOBJECT_NOTSET);
+					P.Set_Value(DATAOBJECT_NOTSET);
 				}
 				else if( pObject != DATAOBJECT_NOTSET )
 				{
@@ -1666,33 +1778,43 @@ bool CSG_Parameters::DataObjects_Synchronize(void)
 							delete(pObject);
 						}
 
-						p->Set_Value(DATAOBJECT_NOTSET);
+						P.Set_Value(DATAOBJECT_NOTSET);
 					}
 					else
 					{
-						if( m_pManager && !m_pManager->Exists(pObject) )
+						if( m_pManager )
 						{
 							m_pManager->Add(pObject);
+
+							if( m_pManager == &SG_Get_Data_Manager() )
+							{
+								SG_UI_DataObject_Add(pObject, 0);
+							}
 						}
 
-						SG_UI_DataObject_Update(pObject, SG_UI_DATAOBJECT_UPDATE_ONLY, NULL);
+						SG_UI_DataObject_Update(pObject, SG_UI_DATAOBJECT_UPDATE, NULL);
 					}
 				}
 			}
 
 			//---------------------------------------------
-			else if( p->is_DataObject_List() )
+			else if( P.is_DataObject_List() )
 			{
-				for(int j=0; j<p->asList()->Get_Item_Count(); j++)
+				for(int j=0; j<P.asList()->Get_Item_Count(); j++)
 				{
-					CSG_Data_Object	*pObject	= p->asList()->Get_Item(j);
+					CSG_Data_Object *pObject = P.asList()->Get_Item(j);
 
-					if( m_pManager && !m_pManager->Exists(pObject) )
+					if( m_pManager )
 					{
 						m_pManager->Add(pObject);
+
+						if( m_pManager == &SG_Get_Data_Manager() )
+						{
+							SG_UI_DataObject_Add(pObject, 0);
+						}
 					}
 
-					SG_UI_DataObject_Update(pObject, SG_UI_DATAOBJECT_UPDATE_ONLY, NULL);
+					SG_UI_DataObject_Update(pObject, SG_UI_DATAOBJECT_UPDATE, NULL);
 				}
 			}
 		}
