@@ -128,6 +128,7 @@ typedef enum
 	PARAMETER_TYPE_Degree,
 	PARAMETER_TYPE_Date,
 	PARAMETER_TYPE_Range,
+	PARAMETER_TYPE_Data_Type,
 	PARAMETER_TYPE_Choice,
 	PARAMETER_TYPE_Choices,
 	PARAMETER_TYPE_String,
@@ -216,6 +217,7 @@ public:	///////////////////////////////////////////////////
 
 	const SG_Char *					Get_Identifier			(void)	const;
 	bool							Cmp_Identifier			(const CSG_String &Identifier)	const;
+	CSG_String						Get_CmdID				(void)	const;
 	bool							Set_Name				(const CSG_String &Name);
 	const SG_Char *					Get_Name				(void)	const;
 	const SG_Char *					Get_Description			(void)	const;
@@ -269,6 +271,7 @@ public:	///////////////////////////////////////////////////
 	bool							Set_Default				(double            Value);
 	bool							Set_Default				(const CSG_String &Value);
 	const CSG_String &				Get_Default				(void)	const;
+	virtual bool					is_Default				(void)	const;
 	virtual bool					Restore_Default			(void);
 
 	bool							Check					(bool bSilent = true);
@@ -297,6 +300,7 @@ public:	///////////////////////////////////////////////////
 	//-----------------------------------------------------
 	class CSG_Parameter_Value           *	asValue			(void)	const;
 	class CSG_Parameter_Date            *	asDate			(void)	const;
+	class CSG_Parameter_Data_Type       *	asDataType		(void)	const;
 	class CSG_Parameter_Choice          *	asChoice		(void)	const;
 	class CSG_Parameter_Choices         *	asChoices		(void)	const;
 	class CSG_Parameter_Range           *	asRange			(void)	const;
@@ -394,6 +398,8 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Bool );	}
 
+	virtual bool				is_Default				(void)	const;
+
 	virtual bool				Toggle_Value			(void);
 
 
@@ -467,6 +473,8 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Int );		}
 
+	virtual bool				is_Default				(void)	const;
+
 
 protected:
 
@@ -503,6 +511,8 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Double );	}
 
+	virtual bool				is_Default				(void)	const;
+
 
 protected:
 
@@ -614,6 +624,8 @@ public:
 	double						Get_Max					(void)	const;
 	CSG_Parameter_Double *		Get_Max_Parameter		(void)	const	{	return( m_pMax );	}
 
+	virtual bool				is_Default				(void)	const;
+
 	virtual bool				Restore_Default			(void);
 
 
@@ -650,6 +662,8 @@ public:
 
 	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Choice );	}
 
+	virtual bool				is_Default				(void)	const;
+
 	virtual bool				Toggle_Value			(void);
 
 	bool						Del_Items				(void);
@@ -695,6 +709,36 @@ protected:
 };
 
 
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_Parameter_Data_Type : public CSG_Parameter_Choice
+{
+public:
+
+	virtual TSG_Parameter_Type	Get_Type				(void)	const	{	return( PARAMETER_TYPE_Data_Type );	}
+
+	bool						Set_Data_Types			(int Data_Types, TSG_Data_Type Default = SG_DATATYPE_Undefined, const CSG_String &User = "");
+
+	bool						Set_Data_Type			(TSG_Data_Type Value);
+	TSG_Data_Type				Get_Data_Type			(TSG_Data_Type Default = SG_DATATYPE_Undefined)	const;
+
+
+protected:
+
+	CSG_Parameter_Data_Type(CSG_Parameters *pOwner, CSG_Parameter *pParent, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint);
+
+
+	virtual bool				_Assign					(CSG_Parameter *pSource);
+	virtual bool				_Serialize				(CSG_MetaData &Entry, bool bSave);
+
+
+	friend class CSG_Parameters;
+};
+
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
@@ -1056,6 +1100,8 @@ public:
 	int							Get_Count				(void)	const	{	return( m_nFields );	}
 	int							Get_Index				(int i)	const	{	return( i >= 0 && i < m_nFields ? m_Fields[i] : -1 );	}
 
+	int							operator []				(int i)	const	{	return( i >= 0 && i < m_nFields ? m_Fields[i] : -1 );	}
+
 	CSG_Table *					Get_Table				(void)	const;
 
 
@@ -1627,10 +1673,14 @@ public:
 	void *						Get_Owner				(void)	const	{	return( m_pOwner      );	}
 
 	class CSG_Tool *			Get_Tool				(void)	const	{	return( m_pTool       );	}
+	void						Set_Tool				(class CSG_Tool *pTool);
 
 	class CSG_Data_Manager *	Get_Manager				(void)	const	{	return( m_pManager    );	}
 	void						Set_Manager				(class CSG_Data_Manager *pManager);
 
+	bool						Push					(class CSG_Data_Manager *pManager = NULL, bool bRestoreDefaults = true);
+	bool						Pop						(void);
+
 	bool						Use_Grid_System			(void);
 
 	bool						has_GUI					(void)	const;
@@ -1699,6 +1749,8 @@ public:
 	CSG_Parameter *				Add_Range				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, double Range_Min = 0.0, double Range_Max = 0.0, double Minimum = 0.0, bool bMinimum = false, double Maximum = 0.0, bool bMaximum = false);
 	CSG_Parameter *				Add_Info_Range			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, double Range_Min = 0.0, double Range_Max = 0.0);
 
+	CSG_Parameter *				Add_Data_Type			(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Data_Types, TSG_Data_Type Default = SG_DATATYPE_Undefined, const CSG_String &User = "");
+
 	CSG_Parameter *				Add_Choice				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items, int Default = 0);
 	CSG_Parameter *				Add_Choices				(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items);
 
@@ -1822,6 +1874,8 @@ private:
 
 	CSG_Parameter				**m_Parameters, *m_pGrid_System;
 
+	CSG_Parameters				*m_pStack;
+
 	TSG_PFNC_Parameter_Changed	m_Callback;
 
 
