@@ -361,10 +361,10 @@ bool CSG_Shape_Polygon_Part::is_Neighbour(CSG_Shape_Polygon_Part *pPart, bool bS
 		return( false );
 	}
 
-	int iPoint;	bool	bNeighbour	= false;
+	bool bNeighbour = false;
 
 	//---------------------------------------------------------
-	for(iPoint=0; iPoint<pPart->Get_Count(); iPoint++)
+	for(int iPoint=0; iPoint<pPart->Get_Count(); iPoint++)
 	{
 		switch( Get_Point_Relation(pPart->Get_Point(iPoint)) )
 		{
@@ -378,7 +378,7 @@ bool CSG_Shape_Polygon_Part::is_Neighbour(CSG_Shape_Polygon_Part *pPart, bool bS
 	}
 
 	//---------------------------------------------------------
-	for(iPoint=0; iPoint<Get_Count(); iPoint++)
+	for(int iPoint=0; iPoint<Get_Count(); iPoint++)
 	{
 		switch( pPart->Get_Point_Relation(Get_Point(iPoint)) )
 		{
@@ -395,6 +395,202 @@ bool CSG_Shape_Polygon_Part::is_Neighbour(CSG_Shape_Polygon_Part *pPart, bool bS
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CSG_Shape_Polygon_Part::_Add_Edge_Points(CSG_Shape_Polygon_Part *pPart, const CSG_Point &P0, const CSG_Point &P1, CSG_Points &Part, double Epsilon)
+{
+	CSG_Points Points;
+
+	for(int i=0; i<pPart->Get_Count(); i++)
+	{
+		CSG_Point P = pPart->Get_Point(i);
+
+		if( P != P0 && P != P1 && SG_Is_Point_On_Line(P, P0, P1, true, Epsilon) )
+		{
+			Points.Add(P);
+		}
+	}
+
+	if( Points.Get_Count() == 1 )
+	{
+		Part.Add(Points[0]);
+	}
+	else if( Points.Get_Count() > 1 )
+	{
+		double *Distances = new double[Points.Get_Count()];
+
+		for(sLong i=0; i<Points.Get_Count(); i++)
+		{
+			Distances[i] = SG_Get_Distance(P0, Points[i]);
+		}
+
+		CSG_Index Index(Points.Get_Count(), Distances); delete[](Distances);
+
+		for(sLong i=0; i<Points.Get_Count(); i++)
+		{
+			Part.Add(Points[Index[i]]);
+		}
+	}
+}
+
+//---------------------------------------------------------
+bool CSG_Shape_Polygon_Part::_is_OnEdge(CSG_Shape_Polygon_Part *pPart, const CSG_Point &P, bool bVertex, double Epsilon)
+{
+	CSG_Point P1 = pPart->Get_Point(0, false); // close the ring, starting with last point!
+
+	if( !bVertex && P == P1 )
+	{
+		return( false );
+	}
+
+	for(int i=0; i<pPart->Get_Count(); i++)
+	{
+		CSG_Point P0 = P1; P1 = pPart->Get_Point(i);
+
+		if( !bVertex && P == P1 )
+		{
+			return( false );
+		}
+
+		if( SG_Is_Point_On_Line(P, P0, P1, true, Epsilon) )
+		{
+			return( true );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+/**
+* Returns all edge segments shared by this polygon part and
+* the one provide by pPart argument as CSG_Lines object.
+* If bVertexCheck is true vertices lying on edged segments
+* of the other polygon part will be recognized. If not only
+* vertices are taken into respect that are shared by both
+* polygon parts. Due to precision issues the tolerance factor
+* specified with Epsilon should be slightly greater than zero
+* when using the bVertexCheck option.
+*/
+//---------------------------------------------------------
+CSG_Lines CSG_Shape_Polygon_Part::Get_Shared_Edges(CSG_Shape_Polygon_Part *pPart, bool bVertexCheck, double Epsilon)
+{
+	CSG_Lines Edges;
+
+	if( Get_Extent().Intersects(pPart->Get_Extent()) )
+	{
+		if( bVertexCheck == false )
+		{
+			bool bOnEdge = is_OnEdge(pPart->Get_Point(0, false)); // close the ring, starting with last point!
+
+			if( bOnEdge )
+			{
+				Edges.Add().Add(pPart->Get_Point(0, false));
+			}
+
+			for(int i=0; i<pPart->Get_Count(); i++)
+			{
+				CSG_Point Point = pPart->Get_Point(i);
+
+				if( is_OnEdge(Point) )
+				{
+					if( !bOnEdge ) // start a new edge segment
+					{
+						Edges.Add().Add(Point);
+					}
+					else // continue edge segment
+					{
+						Edges[Edges.Get_Count() - 1].Add(Point);
+					}
+
+					bOnEdge = true;
+				}
+				else
+				{
+					bOnEdge = false;
+				}
+			}
+		}
+		else
+		{
+			CSG_Points Part; CSG_Point P1 = Get_Point(0, false); // close the ring, starting with last point!
+
+			if( _is_OnEdge(pPart, P1, true, Epsilon) ) { Part.Add(P1); }
+
+			for(int i=0; i<Get_Count(); i++)
+			{
+				CSG_Point P0 = P1; P1 = Get_Point(i);
+
+				_Add_Edge_Points(pPart, P0, P1, Part, Epsilon);
+
+				if( _is_OnEdge(pPart, P1, true, Epsilon) ) { Part.Add(P1); }
+			}
+
+			//---------------------------------------------
+			if( Part.Get_Count() > 1 )
+			{
+				P1 = Part[0]; bool bOnEdge = false;
+				CSG_Point C0 = P1;
+
+				for(sLong i=1, n=-1; i<Part.Get_Count(); i++)
+				{
+					CSG_Point C1, P0 = P1; P1 = Part[i];
+
+					C1.x = P0.x + 0.5 * (P1.x - P0.x);
+					C1.y = P0.y + 0.5 * (P1.y - P0.y);
+
+					if( C0 == C1 )
+					{
+						continue; // do not add the same edge twice (in different directions)
+					}
+
+					if( _is_OnEdge(this, C1, true, Epsilon) && _is_OnEdge(pPart, C1, true, Epsilon) )
+					{
+						if( !bOnEdge ) // start a new edge segment
+						{
+							n = Edges.Get_Count(); Edges.Add();
+							Edges[n].Add(P0);
+							Edges[n].Add(P1);
+						}
+						else // continue edge segment
+						{
+							Edges[n].Add(P1);
+						}
+
+						bOnEdge = true;
+					}
+					else
+					{
+						bOnEdge = false;
+					}
+
+					C0 = C1;
+				}
+			}
+		}
+	}
+
+	return( Edges );
+}
+
+//---------------------------------------------------------
+/**
+* This function requests the edges shared by this polygon part
+* and the one provided by the pPart argument and returns
+* the total length. See Get_Shared_Edges() for more details.
+*/
+//---------------------------------------------------------
+double CSG_Shape_Polygon_Part::Get_Shared_Length(CSG_Shape_Polygon_Part *pPart, bool bVertexCheck, double Epsilon)
+{
+	CSG_Lines Edges(Get_Shared_Edges(pPart, bVertexCheck, Epsilon));
+
+	return( Edges.Get_Length() );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -934,10 +1130,10 @@ bool CSG_Shape_Polygon::is_Neighbour(CSG_Shape_Polygon *pPolygon, bool bSimpleCh
 		return( false );
 	}
 
-	int iPoint;	bool	bNeighbour	= false;
+	bool bNeighbour = false;
 
 	//---------------------------------------------------------
-	for(iPoint=0; iPoint<pPolygon->Get_Point_Count(); iPoint++)
+	for(int iPoint=0; iPoint<pPolygon->Get_Point_Count(); iPoint++)
 	{
 		switch( Get_Point_Relation(pPolygon->Get_Point(iPoint)) )
 		{
@@ -951,7 +1147,7 @@ bool CSG_Shape_Polygon::is_Neighbour(CSG_Shape_Polygon *pPolygon, bool bSimpleCh
 	}
 
 	//---------------------------------------------------------
-	for(iPoint=0; iPoint<Get_Point_Count(); iPoint++)
+	for(int iPoint=0; iPoint<Get_Point_Count(); iPoint++)
 	{
 		switch( pPolygon->Get_Point_Relation(Get_Point(iPoint)) )
 		{
@@ -968,6 +1164,55 @@ bool CSG_Shape_Polygon::is_Neighbour(CSG_Shape_Polygon *pPolygon, bool bSimpleCh
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+/**
+* Returns all edge segments shared by this polygon and the
+* one provide by the pPolygon argument as CSG_Lines object.
+* If bVertexCheck is true vertices lying on edged segments
+* of the other polygon will be recognized. If not only
+* vertices are taken into respect that are shared by both
+* polygons. Due to precision issues the tolerance factor
+* specified with Epsilon argument should be slightly greater
+* than zero when using the bVertexCheck option.
+*/
+//---------------------------------------------------------
+CSG_Lines CSG_Shape_Polygon::Get_Shared_Edges(CSG_Shape_Polygon *pPolygon, bool bVertexCheck, double Epsilon)
+{
+	CSG_Lines Edges;
+
+	if( Get_Extent().Intersects(pPolygon->Get_Extent()) )
+	{
+		for(int i=0; i<Get_Part_Count(); i++)
+		{
+			for(int j=0; j<pPolygon->Get_Part_Count(); j++)
+			{
+				Edges.Add(Get_Polygon_Part(i)->Get_Shared_Edges(pPolygon->Get_Polygon_Part(j), bVertexCheck, Epsilon));
+			}
+		}
+	}
+
+	return( Edges );
+}
+
+//---------------------------------------------------------
+/**
+* This function requests the edges shared by this polygon
+* and the one provided by the pPolygon argument and returns
+* the total length. See Get_Shared_Edges() for more details.
+*/
+//---------------------------------------------------------
+double CSG_Shape_Polygon::Get_Shared_Length(CSG_Shape_Polygon *pPolygon, bool bVertexCheck, double Epsilon)
+{
+	CSG_Lines Edges(Get_Shared_Edges(pPolygon, bVertexCheck, Epsilon));
+
+	return( Edges.Get_Length() );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -975,7 +1220,7 @@ bool CSG_Shape_Polygon::is_Neighbour(CSG_Shape_Polygon *pPolygon, bool bSimpleCh
 //---------------------------------------------------------
 double CSG_Shape_Polygon::Get_Distance(TSG_Point Point, TSG_Point &Next, int iPart)	const
 {
-	CSG_Shape_Polygon_Part	*pPart	= Get_Polygon_Part(iPart);
+	CSG_Shape_Polygon_Part *pPart = Get_Polygon_Part(iPart);
 
 	return(	pPart ? pPart->Get_Distance(Point, Next) : -1. );
 }
