@@ -346,7 +346,14 @@ CSG_Shapes::~CSG_Shapes(void)
 //---------------------------------------------------------
 bool CSG_Shapes::Destroy(void)
 {
-	return( CSG_Table::Destroy() );
+	if( CSG_Table::Destroy() )
+	{
+		m_Type = SHAPE_TYPE_Undefined;
+
+		return( true );
+	}
+
+	return( false );
 }
 
 
@@ -359,14 +366,12 @@ bool CSG_Shapes::Destroy(void)
 //---------------------------------------------------------
 bool CSG_Shapes::Assign(CSG_Data_Object *pObject)
 {
-	if(	pObject && pObject->is_Valid() && (pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Shapes || pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_PointCloud) )
+	if( CSG_Data_Object::Assign(pObject) && pObject->asShapes(true) )
 	{
-		CSG_Shapes	*pShapes	= (CSG_Shapes *)pObject;
+		CSG_Shapes *pShapes = pObject->asShapes(true);
 
 		Create(pShapes->Get_Type(), pShapes->Get_Name(), pShapes, pShapes->Get_Vertex_Type());
 
-		Get_History()	= pShapes->Get_History();
-
 		Get_Projection().Create(pShapes->Get_Projection());
 
 		for(sLong iShape=0; iShape<pShapes->Get_Count() && SG_UI_Process_Get_Okay(); iShape++)
@@ -381,98 +386,6 @@ bool CSG_Shapes::Assign(CSG_Data_Object *pObject)
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-static TSG_Shape_File_Format	gSG_Shape_File_Format_Default	= SHAPE_FILE_FORMAT_ESRI;
-
-//---------------------------------------------------------
-bool					SG_Shapes_Set_File_Format_Default	(int Format)
-{
-	switch( Format )
-	{
-	case SHAPE_FILE_FORMAT_ESRI      :
-	case SHAPE_FILE_FORMAT_GeoPackage:
-	case SHAPE_FILE_FORMAT_GeoJSON   :
-		gSG_Shape_File_Format_Default	= (TSG_Shape_File_Format)Format;
-		return( true );
-	}
-
-	return( false );
-}
-
-//---------------------------------------------------------
-TSG_Shape_File_Format	SG_Shapes_Get_File_Format_Default	(void)
-{
-	return( gSG_Shape_File_Format_Default );
-}
-
-//---------------------------------------------------------
-CSG_String				SG_Shapes_Get_File_Extension_Default	(void)
-{
-	switch( gSG_Shape_File_Format_Default )
-	{
-	default:
-	case SHAPE_FILE_FORMAT_ESRI      :	return( "shp"     );
-	case SHAPE_FILE_FORMAT_GeoPackage:	return( "gpkg"    );
-	case SHAPE_FILE_FORMAT_GeoJSON   :	return( "geojson" );
-	}
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-bool CSG_Shapes::Save(const CSG_String &File, int Format)
-{
-	SG_UI_Msg_Add(CSG_String::Format("%s %s: %s...", _TL("Saving"), _TL("shapes"), File.c_str()), true);
-
-	//-----------------------------------------------------
-	if( Format == SHAPE_FILE_FORMAT_Undefined )
-	{
-		Format	= gSG_Shape_File_Format_Default;
-
-		if( SG_File_Cmp_Extension(File, "shp"    ) )	Format	= SHAPE_FILE_FORMAT_ESRI      ;
-		if( SG_File_Cmp_Extension(File, "gpkg"   ) )	Format	= SHAPE_FILE_FORMAT_GeoPackage;
-		if( SG_File_Cmp_Extension(File, "geojson") )	Format	= SHAPE_FILE_FORMAT_GeoJSON   ;
-	}
-
-	//-----------------------------------------------------
-	bool	bResult	= false;
-
-	switch( Format )
-	{
-	case SHAPE_FILE_FORMAT_ESRI      : bResult = _Save_ESRI(File           ); break;
-	case SHAPE_FILE_FORMAT_GeoPackage: bResult = _Save_GDAL(File, "GPKG"   ); break;
-	case SHAPE_FILE_FORMAT_GeoJSON   : bResult = _Save_GDAL(File, "GeoJSON"); break;
-	}
-
-	//-----------------------------------------------------
-	if( bResult )
-	{
-		Set_Modified(false);
-
-		Set_File_Name(File, true);
-
-		SG_UI_Process_Set_Ready();
-		SG_UI_Msg_Add(_TL("okay"), false, SG_UI_MSG_STYLE_SUCCESS);
-
-		return( true );
-	}
-
-	SG_UI_Process_Set_Ready();
-	SG_UI_Msg_Add(_TL("failed"), false, SG_UI_MSG_STYLE_FAILURE);
-
-	return( false );
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
