@@ -165,10 +165,10 @@ public:
 	virtual int					Get_Point_Count		(int iPart) const = 0;
 	virtual int					Get_Part_Count		(void)      const = 0;
 
-	virtual int					Add_Part			(class CSG_Shape_Part *pPart) {	return( -1   );	}
-	virtual CSG_Shape_Part *	Get_Part			(int iPart) const             {	return( NULL );	}
-	virtual int					Del_Part			(int iPart)                   {	return( -1   );	}
-	virtual int					Del_Parts			(void)                        {	return( -1   );	}
+	virtual int					Add_Part			(class CSG_Shape_Part *pPart, bool bRevert = false) { return( -1   ); }
+	virtual CSG_Shape_Part *	Get_Part			(int iPart) const                                   { return( NULL ); }
+	virtual int					Del_Part			(int iPart)                                         { return( -1   ); }
+	virtual int					Del_Parts			(void)                                              { return( -1   ); }
 
 	virtual int					Add_Point			(double x, double y,                    int iPart = 0) = 0;
 	virtual int					Add_Point			(const CSG_Point    &p,                 int iPart = 0) = 0;
@@ -444,6 +444,8 @@ public:
 		return( Point );
 	}
 
+	bool						Add_Points			(CSG_Shape_Part *pPoints, bool bAscending = true);
+
 	bool						Revert_Points		(void);
 
 
@@ -495,7 +497,7 @@ public:
 	virtual int					Get_Point_Count		(int iPart)	const	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart]->Get_Count() : 0 );	}
 	virtual int					Get_Part_Count		(void)		const	{	return( m_nParts );		}
 
-	virtual int					Add_Part			(class CSG_Shape_Part *pPart);
+	virtual int					Add_Part			(class CSG_Shape_Part *pPart, bool bRevert = false);
 	virtual CSG_Shape_Part *	Get_Part			(int iPart)	const	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart] : NULL );	}
 	virtual int					Del_Part			(int iPart);
 	virtual int					Del_Parts			(void);
@@ -666,6 +668,9 @@ public:
 
 	bool						is_Neighbour		(CSG_Shape_Polygon_Part *pPart, bool bSimpleCheck = true);
 
+	CSG_Lines					Get_Shared_Edges	(CSG_Shape_Polygon_Part *pPart, bool bVertexCheck, double Epsilon = 0.);
+	double						Get_Shared_Length	(CSG_Shape_Polygon_Part *pPart, bool bVertexCheck, double Epsilon = 0.);
+
 	double						Get_Distance		(TSG_Point Point, TSG_Point &Next);
 
 
@@ -686,6 +691,9 @@ protected:
 
 	void						_Update_Area		(void);
 
+	void						_Add_Edge_Points	(CSG_Shape_Polygon_Part *pPart, const CSG_Point &P0, const CSG_Point &P1, CSG_Points &Part, double Epsilon);
+	bool						_is_OnEdge			(CSG_Shape_Polygon_Part *pPart, const CSG_Point &P, bool bVertex                          , double Epsilon);
+
 };
 
 //---------------------------------------------------------
@@ -731,6 +739,9 @@ public:
 
 	bool						is_Neighbour		(CSG_Shape_Polygon *pPolygon, bool bSimpleCheck = true);
 
+	CSG_Lines					Get_Shared_Edges	(CSG_Shape_Polygon *pPolygon, bool bVertexCheck, double Epsilon = 0.);
+	double						Get_Shared_Length	(CSG_Shape_Polygon *pPolygon, bool bVertexCheck, double Epsilon = 0.);
+
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next, int iPart)	const;
 
 
@@ -1233,7 +1244,7 @@ protected:
 
 	void						*m_pKDTree;
 
-	CSG_Array_Int				m_Indices;
+	CSG_Array_sLong				m_Indices;
 
 	CSG_Vector					m_Distances;
 
@@ -1273,23 +1284,23 @@ public:
 	virtual double				Get_Point_Value		(size_t i)	const	{	return( m_Points[i][2] );	}
 
 	virtual size_t				Get_Nearest_Points	(double Coordinate[2], size_t Count, double Radius);
-	virtual size_t				Get_Nearest_Points	(double Coordinate[2], size_t Count, double Radius, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Nearest_Points	(double Coordinate[2], size_t Count, double Radius, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Nearest_Points	(double Coordinate[2], size_t Count, size_t *Indices, double *Distances);
 	virtual bool				Get_Nearest_Point	(double Coordinate[2], size_t &Index, double &Distance);
 	virtual bool				Get_Nearest_Point	(double Coordinate[2], size_t &Index);
 	virtual bool				Get_Nearest_Value	(double Coordinate[2], double &Value);
 	virtual CSG_Shape *			Get_Nearest_Shape	(double Coordinate[2]);
-	virtual size_t				Get_Duplicates		(double Coordinate[2], CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Duplicates		(double Coordinate[2], CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Duplicates		(double Coordinate[2]);
 
 	virtual size_t				Get_Nearest_Points	(double x, double y, size_t Count, double Radius);
-	virtual size_t				Get_Nearest_Points	(double x, double y, size_t Count, double Radius, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Nearest_Points	(double x, double y, size_t Count, double Radius, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Nearest_Points	(double x, double y, size_t Count, size_t *Indices, double *Distances);
 	virtual bool				Get_Nearest_Point	(double x, double y, size_t &Index, double &Distance);
 	virtual bool				Get_Nearest_Point	(double x, double y, size_t &Index);
 	virtual bool				Get_Nearest_Value	(double x, double y, double &Value);
 	virtual CSG_Shape *			Get_Nearest_Shape	(double x, double y);
-	virtual size_t				Get_Duplicates		(double x, double y, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Duplicates		(double x, double y, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Duplicates		(double x, double y);
 
 };
@@ -1325,22 +1336,22 @@ public:
 	virtual size_t				Get_Nearest_Points	(double Coordinate[3], size_t Count, double Radius);
 
 	virtual size_t				Get_Nearest_Points	(double Coordinate[3], size_t Count, size_t *Indices, double *Distances);
-	virtual size_t				Get_Nearest_Points	(double Coordinate[3], size_t Count, double Radius, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Nearest_Points	(double Coordinate[3], size_t Count, double Radius, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual bool				Get_Nearest_Point	(double Coordinate[3], size_t &Index, double &Distance);
 	virtual bool				Get_Nearest_Point	(double Coordinate[3], size_t &Index);
 	virtual bool				Get_Nearest_Value	(double Coordinate[3], double &Value);
 	virtual CSG_Shape *			Get_Nearest_Shape	(double Coordinate[3]);
-	virtual size_t				Get_Duplicates		(double Coordinate[3], CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Duplicates		(double Coordinate[3], CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Duplicates		(double Coordinate[3]);
 
 	virtual size_t				Get_Nearest_Points	(double x, double y, double z, size_t Count, double Radius);
-	virtual size_t				Get_Nearest_Points	(double x, double y, double z, size_t Count, double Radius, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Nearest_Points	(double x, double y, double z, size_t Count, double Radius, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Nearest_Points	(double x, double y, double z, size_t Count, size_t *Indices, double *Distances);
 	virtual bool				Get_Nearest_Point	(double x, double y, double z, size_t &Index, double &Distance);
 	virtual bool				Get_Nearest_Point	(double x, double y, double z, size_t &Index);
 	virtual bool				Get_Nearest_Value	(double x, double y, double z, double &Value);
 	virtual CSG_Shape *			Get_Nearest_Shape	(double x, double y, double z);
-	virtual size_t				Get_Duplicates		(double x, double y, double z, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	virtual size_t				Get_Duplicates		(double x, double y, double z, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 	virtual size_t				Get_Duplicates		(double x, double y, double z);
 
 };
@@ -1402,11 +1413,11 @@ public:
 	bool						Get_Points				(double x, double y, CSG_Points_3D &Points);
 	bool						Get_Points				(const CSG_Point &p, CSG_Points_3D &Points);
 
-	bool						Get_Points				(double x, double y, CSG_Array_Int &Indices);
-	bool						Get_Points				(const CSG_Point &p, CSG_Array_Int &Indices);
+	bool						Get_Points				(double x, double y, CSG_Array_sLong &Indices);
+	bool						Get_Points				(const CSG_Point &p, CSG_Array_sLong &Indices);
 
-	bool						Get_Points				(double x, double y, CSG_Array_Int &Indices, CSG_Vector &Distances);
-	bool						Get_Points				(const CSG_Point &p, CSG_Array_Int &Indices, CSG_Vector &Distances);
+	bool						Get_Points				(double x, double y, CSG_Array_sLong &Indices, CSG_Vector &Distances);
+	bool						Get_Points				(const CSG_Point &p, CSG_Array_sLong &Indices, CSG_Vector &Distances);
 
 
 private:
