@@ -88,7 +88,7 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum ESG_Summary_Format
+typedef enum
 {
 	SG_SUMMARY_FMT_FLAT		= 0,
 	SG_SUMMARY_FMT_HTML,
@@ -97,7 +97,7 @@ typedef enum ESG_Summary_Format
 TSG_Summary_Format;
 
 //---------------------------------------------------------
-typedef enum ESG_Tool_Type
+typedef enum
 {
 	TOOL_TYPE_Base			= 0,
 	TOOL_TYPE_Interactive,
@@ -108,7 +108,7 @@ typedef enum ESG_Tool_Type
 TSG_Tool_Type;
 
 //---------------------------------------------------------
-typedef enum ESG_Tool_Error
+typedef enum
 {
 	TOOL_ERROR_Unknown		= 0,
 	TOOL_ERROR_Calculation
@@ -116,12 +116,18 @@ typedef enum ESG_Tool_Error
 TSG_Tool_Error;
 
 //---------------------------------------------------------
-typedef enum ESG_Tool_Script_Type
+typedef enum
 {
 	TOOL_SCRIPT_CMD_SHELL	= 0,
 	TOOL_SCRIPT_CMD_BATCH,
+	TOOL_SCRIPT_CMD_USAGE,
+	TOOL_SCRIPT_CHAIN,
 	TOOL_SCRIPT_PYTHON,
-	TOOL_SCRIPT_CHAIN
+	TOOL_SCRIPT_PYTHON_WRAP_NAME,
+	TOOL_SCRIPT_PYTHON_WRAP_NAME_CALL,
+	TOOL_SCRIPT_PYTHON_WRAP_NAME_CALL_FULL,
+	TOOL_SCRIPT_PYTHON_WRAP_ID,
+	TOOL_SCRIPT_PYTHON_WRAP_ID_CALL
 }
 TSG_Tool_Script_Type;
 
@@ -171,10 +177,12 @@ public:
 	virtual CSG_String			Get_MenuPath				(void)	{	return( SG_T("") );	}
 	virtual CSG_String			Get_MenuPath				(bool bSolved);
 
-	int							Get_Parameters_Count		(void)	{	return( m_npParameters );	}
 	CSG_Parameters *			Get_Parameters				(void)	{	return( &Parameters );	}
-	CSG_Parameters *			Get_Parameters				(int i)	{	return( i >= 0 && i < m_npParameters ? m_pParameters[i] : NULL );	}
-	CSG_Parameters *			Get_Parameters				(const CSG_String &Identifier);
+
+	int							Get_Parameters_Count		(void)  const { return( (int)m_pParameters.Get_Size() ); }
+	CSG_Parameters *			Get_Parameters				(int i) const { return( i >= 0 && i < Get_Parameters_Count() ? (CSG_Parameters *)m_pParameters[i] : NULL ); }
+	CSG_Parameters *			Get_Parameters				(int i)       { return( i >= 0 && i < Get_Parameters_Count() ? (CSG_Parameters *)m_pParameters[i] : NULL ); }
+	CSG_Parameters *			Get_Parameters				(const CSG_String &Identifier) const;
 
 	CSG_Parameter *				Get_Parameter				(const CSG_String &ID)	const	{	return( Parameters(ID) );	}
 	CSG_Parameter *				Get_Parameter				(const char       *ID)	const	{	return( Parameters(ID) );	}
@@ -211,6 +219,8 @@ public:
 
 	bool						Set_Manager					(class CSG_Data_Manager *pManager);
 	class CSG_Data_Manager *	Get_Manager					(void)	const;
+	class CSG_Data_Manager *	Create_Manager				(void);
+	bool						Delete_Manager				(bool bDetachData = false, bool bReset = true);
 
 	bool						Set_Grid_System				(const CSG_Grid_System &System);
 	CSG_Grid_System *			Get_Grid_System				(void)	const;
@@ -222,6 +232,7 @@ public:
 
 	virtual bool				needs_GUI					(void)	const	{	return( false );	}
 	bool						has_GUI						(void)	const;
+	bool						has_CMD						(void)	const;
 
 	virtual bool				is_Grid						(void)	const	{	return( false );	}
 	virtual bool				is_Interactive				(void)	const	{	return( false );	}
@@ -237,7 +248,7 @@ public:
 
 	const SG_Char *				Get_Execution_Info			(void)	const	{	return( m_Execution_Info );	}
 
-	CSG_String					Get_Script					(TSG_Tool_Script_Type Type, bool bHeader, bool bAllParameters = false);
+	CSG_String					Get_Script					(TSG_Tool_Script_Type Type, bool bHeader = true, bool bAllParameters = false);
 
 
 protected:
@@ -266,12 +277,15 @@ protected:
 
 	//-----------------------------------------------------
 	CSG_Parameters *			Add_Parameters				(const CSG_String &Identifier, const CSG_String &Name, const CSG_String &Description);
-	bool						Dlg_Parameters				(const CSG_String &Identifier);
-	bool						Dlg_Parameters				(CSG_Parameters *pParameters, const CSG_String &Caption);
+	bool						Dlg_Parameters				(const CSG_String &Identifier); // deprecated
+
+	bool						Dlg_Parameters				(CSG_Parameters *pParameters, const CSG_String &Caption = "");
+	bool						Dlg_Parameters				(CSG_Parameters  &Parameters, const CSG_String &Caption = "");
 
 	//-----------------------------------------------------
-	virtual bool				Set_Progress				(double Percent)				const;
-	virtual bool				Set_Progress				(double Position, double Range)	const;
+	virtual bool				Set_Progress				(int    Position, int    Range     )	const;
+	virtual bool				Set_Progress				(sLong  Position, sLong  Range     )	const;
+	virtual bool				Set_Progress				(double Position, double Range = 1.)	const;
 
 	bool						Stop_Execution				(bool bDialog = true);
 
@@ -304,8 +318,8 @@ public:	// static functions...
 	static void					Process_Set_Text			(const char    *Format, ...);
 	static void					Process_Set_Text			(const wchar_t *Format, ...);
 
-	static bool					DataObject_Update			(CSG_Data_Object *pDataObject                                , int Show = SG_UI_DATAOBJECT_UPDATE_ONLY);
-	static bool					DataObject_Update			(CSG_Data_Object *pDataObject, double Minimum, double Maximum, int Show = SG_UI_DATAOBJECT_UPDATE_ONLY);
+	static bool					DataObject_Update			(CSG_Data_Object *pDataObject                                , int Show = SG_UI_DATAOBJECT_UPDATE);
+	static bool					DataObject_Update			(CSG_Data_Object *pDataObject, double Minimum, double Maximum, int Show = SG_UI_DATAOBJECT_UPDATE);
 
 	static bool					DataObject_Get_Colors		(CSG_Data_Object *pDataObject, CSG_Colors &Colors);
 	static bool					DataObject_Set_Colors		(CSG_Data_Object *pDataObject, const CSG_Colors &Colors);
@@ -324,16 +338,14 @@ public:	// static functions...
 	static bool					DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, const SG_Char *Value);
 	static bool					DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, double loVal, double hiVal);	// Range Parameter
 
+	static int					_On_Parameter_Changed		(CSG_Parameter *pParameter, int Flags);
+
 
 private:
 
-	bool						m_bExecutes, m_bError_Ignore, m_bShow_Progress, m_bWithGUI;
+	bool						m_bExecutes, m_bError_Ignore, m_bShow_Progress, m_bGUI, m_bCMD;
 
-	int							m_npParameters;
-
-	CSG_Array					m_Settings_Stack;
-
-	CSG_Parameters				**m_pParameters;
+	CSG_Array_Pointer			m_pParameters;
 
 	CSG_String					m_ID, m_Library, m_Library_Menu, m_File_Name, m_Author, m_Version, m_Execution_Info;
 
@@ -341,18 +353,22 @@ private:
 	bool						_Synchronize_DataObjects	(void);
 
 	CSG_String					_Get_Script_CMD				(bool bHeader, bool bAllParameters, TSG_Tool_Script_Type Type);
-	void						_Get_Script_CMD				(CSG_String &Script, CSG_Parameters *pParameters, bool bAllParameters);
+	void						_Get_Script_CMD				(CSG_String &Script, CSG_Parameters *pParameters, bool bAllParameters, TSG_Tool_Script_Type Type);
+
+	CSG_String					_Get_Script_CMD_Usage		(void);
+	void						_Get_Script_CMD_Usage		(CSG_Parameters *pParameters, class wxCmdLineParser &Parser);
 
 	CSG_String					_Get_Script_Python			(bool bHeader, bool bAllParameters);
 	void						_Get_Script_Python			(CSG_String &Script, CSG_Parameters *pParameters, bool bAllParameters, const CSG_String &Prefix = "");
 
+	CSG_String					_Get_Script_Python_Wrap		(bool bHeader, bool bName, bool bCall, bool bOnlyNonDefaults);
+	bool						_Get_Script_Python_Wrap		(const CSG_Parameter &Parameter, int Constraint, CSG_String &Arguments, CSG_String &Description, CSG_String &Code, bool bCall, bool bOnlyNonDefaults, const CSG_String &Prefix = "");
+
 	CSG_MetaData				_Get_Output_History			(void);
 	void						_Set_Output_History			(void);
 
 	void						_Update_Parameter_States	(CSG_Parameters *pParameters);
 
-	static int					_On_Parameter_Changed		(CSG_Parameter *pParameter, int Flags);
-
 };
 
 
@@ -383,9 +399,8 @@ public:
 
 protected:
 
-	virtual bool				Set_Progress_NCells		(sLong iCell)					const;
-	virtual bool				Set_Progress			(int    iRow)					const;
-	virtual bool				Set_Progress			(double Position, double Range)	const;
+	virtual bool				Set_Progress_Cells		(sLong Cell)					const;
+	virtual bool				Set_Progress_Rows		(int    Row)					const;
 
 	//-----------------------------------------------------
 	int							Get_NX					(void)						const	{	return( Get_System().Get_NX      () );	}
@@ -438,7 +453,7 @@ private:
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum ESG_Tool_Interactive_Mode
+typedef enum
 {
 	TOOL_INTERACTIVE_UNDEFINED		= 0,
 	TOOL_INTERACTIVE_LDOWN,
@@ -458,7 +473,7 @@ typedef enum ESG_Tool_Interactive_Mode
 TSG_Tool_Interactive_Mode;
 
 //---------------------------------------------------------
-typedef enum ESG_Tool_Interactive_DragMode
+typedef enum
 {
 	TOOL_INTERACTIVE_DRAG_NONE		= 0,
 	TOOL_INTERACTIVE_DRAG_LINE,
@@ -506,13 +521,13 @@ protected:
 	virtual bool				On_Execute_Keyboard		(int Character);
 	virtual bool				On_Execute_Finish		(void);
 
-	const CSG_Point &			Get_Position			(void)	const	{	return( m_Point              );	}
-	double						Get_xPosition			(void)	const	{	return( m_Point     .Get_X() );	}
-	double						Get_yPosition			(void)	const	{	return( m_Point     .Get_Y() );	}
+	const CSG_Point &			Get_Position			(void)	const	{	return( m_Point        );	}
+	double						Get_xPosition			(void)	const	{	return( m_Point     .x );	}
+	double						Get_yPosition			(void)	const	{	return( m_Point     .y );	}
 
-	const CSG_Point &			Get_Position_Last		(void)	const	{	return( m_Point_Last         );	}
-	double						Get_xPosition_Last		(void)	const	{	return( m_Point_Last.Get_X() );	}
-	double						Get_yPosition_Last		(void)	const	{	return( m_Point_Last.Get_Y() );	}
+	const CSG_Point &			Get_Position_Last		(void)	const	{	return( m_Point_Last   );	}
+	double						Get_xPosition_Last		(void)	const	{	return( m_Point_Last.x );	}
+	double						Get_yPosition_Last		(void)	const	{	return( m_Point_Last.y );	}
 
 	bool						is_Shift				(void)	const	{	return( (m_Keys & TOOL_INTERACTIVE_KEY_SHIFT) != 0 );	}
 	bool						is_Alt					(void)	const	{	return( (m_Keys & TOOL_INTERACTIVE_KEY_ALT  ) != 0 );	}
@@ -601,7 +616,7 @@ protected:
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum ESG_TLB_Info
+typedef enum
 {
 	TLB_INFO_Name	= 0,
 	TLB_INFO_Description,
