@@ -67,27 +67,27 @@
 //---------------------------------------------------------
 CSG_Tool_Library::CSG_Tool_Library(void)
 {
-	m_pInterface	= NULL;
-	m_pLibrary		= NULL;
+	m_pInterface = NULL;
+	m_pLibrary   = NULL;
 }
 
 //---------------------------------------------------------
 CSG_Tool_Library::CSG_Tool_Library(const CSG_String &File)
 {
-	m_pLibrary	= new wxDynamicLibrary(SG_File_Get_Path_Absolute(File).c_str(), wxDL_DEFAULT|wxDL_QUIET);
+	m_pLibrary = new wxDynamicLibrary(SG_File_Get_Path_Absolute(File).c_str(), wxDL_DEFAULT|wxDL_QUIET);
 
 	if(	m_pLibrary->IsLoaded()
-	&&	m_pLibrary->HasSymbol(SYMBOL_TLB_Get_Interface)
-	&&	m_pLibrary->HasSymbol(SYMBOL_TLB_Initialize)
-	&&	m_pLibrary->HasSymbol(SYMBOL_TLB_Finalize)
-	&&	((TSG_PFNC_TLB_Initialize)m_pLibrary->GetSymbol(SYMBOL_TLB_Initialize))(File) )
+	&&  m_pLibrary->HasSymbol(SYMBOL_TLB_Get_Interface)
+	&&  m_pLibrary->HasSymbol(SYMBOL_TLB_Initialize)
+	&&  m_pLibrary->HasSymbol(SYMBOL_TLB_Finalize)
+	&&  ((TSG_PFNC_TLB_Initialize)m_pLibrary->GetSymbol(SYMBOL_TLB_Initialize))(File) )
 	{
-		m_pInterface	= ((TSG_PFNC_TLB_Get_Interface)m_pLibrary->GetSymbol(SYMBOL_TLB_Get_Interface))();
+		m_pInterface = ((TSG_PFNC_TLB_Get_Interface)m_pLibrary->GetSymbol(SYMBOL_TLB_Get_Interface))();
 
 		if( m_pInterface->Get_Count() > 0 )
 		{
-			m_File_Name		= m_pInterface->Get_Info(TLB_INFO_File   );
-			m_Library_Name	= m_pInterface->Get_Info(TLB_INFO_Library);
+			m_File_Name    = m_pInterface->Get_Info(TLB_INFO_File   );
+			m_Library_Name = m_pInterface->Get_Info(TLB_INFO_Library);
 
 			return;	// success
 		}
@@ -337,7 +337,6 @@ int CSG_Tool_Library_Manager::Get_Tool_Count(void)	const
 //---------------------------------------------------------
 CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const CSG_String &File)
 {
-	//-----------------------------------------------------
 	if( !SG_File_Cmp_Extension(File, "mlb"  )
 	&&	!SG_File_Cmp_Extension(File, "dll"  )
 	&&	!SG_File_Cmp_Extension(File, "so"   )
@@ -349,7 +348,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const CSG_String &File)
 	//-----------------------------------------------------
 	SG_UI_Msg_Add(CSG_String::Format("%s: %s...", _TL("Loading library"), File.c_str()), true);
 
-	wxFileName	fn(File.c_str());
+	wxFileName fn(File.c_str());
 
 	for(int i=0; i<Get_Count(); i++)
 	{
@@ -362,12 +361,12 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const CSG_String &File)
 	}
 
 	//-----------------------------------------------------
-	CSG_Tool_Library	*pLibrary	= new CSG_Tool_Library(File);
+	CSG_Tool_Library *pLibrary = new CSG_Tool_Library(File);
 
 	if( pLibrary->is_Valid() )
 	{
-		m_pLibraries	= (CSG_Tool_Library **)SG_Realloc(m_pLibraries, (m_nLibraries + 1) * sizeof(CSG_Tool_Library *));
-		m_pLibraries[m_nLibraries++]	= pLibrary;
+		m_pLibraries = (CSG_Tool_Library **)SG_Realloc(m_pLibraries, (m_nLibraries + 1) * sizeof(CSG_Tool_Library *));
+		m_pLibraries[m_nLibraries++] = pLibrary;
 
 		SG_UI_Msg_Add(_TL("okay"), false, SG_UI_MSG_STYLE_SUCCESS);
 
@@ -394,12 +393,11 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const wchar_t    *File)
 //---------------------------------------------------------
 int CSG_Tool_Library_Manager::Add_Directory(const CSG_String &Directory, bool bOnlySubDirectories)
 {
-	int		nOpened	= 0;
-	wxDir	Dir;
+	int nOpened = 0; wxDir Dir;
 
 	if( Dir.Open(Directory.c_str()) )
 	{
-		wxString	FileName, DirName(Dir.GetName());
+		wxString FileName, DirName(Dir.GetName());
 
 		if( !bOnlySubDirectories && Dir.GetFirst(&FileName, wxEmptyString, wxDIR_FILES) )
 		{
@@ -447,19 +445,18 @@ int CSG_Tool_Library_Manager::Add_Directory(const wchar_t    *Directory, bool bO
 //---------------------------------------------------------
 CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const CSG_String &File)
 {
-	//-----------------------------------------------------
 	if( !SG_File_Cmp_Extension(File, "xml") )
 	{
 		return( NULL );
 	}
 
 	//-----------------------------------------------------
-	CSG_Tool_Chains	*pLibrary	= NULL;
-	CSG_Tool_Chain	*pTool		= NULL;
+	CSG_Tool_Chains *pLibrary = NULL;
+	CSG_Tool_Chain     *pTool = NULL;
 
 	//-----------------------------------------------------
 	{	// is tool chain already loaded ?
-		wxFileName	fn(File.c_str());
+		wxFileName fn(File.c_str());
 
 		for(int iLibrary=0; !pTool && iLibrary<Get_Count(); iLibrary++)
 		{
@@ -469,8 +466,8 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const CSG_String &F
 				{
 					if( fn == ((CSG_Tool_Chain *)Get_Library(iLibrary)->Get_Tool(iTool))->Get_File_Name().c_str() )
 					{
-						pLibrary	= (CSG_Tool_Chains *)Get_Library(iLibrary);
-						pTool		= (CSG_Tool_Chain  *)Get_Library(iLibrary)->Get_Tool(iTool);
+						pLibrary = (CSG_Tool_Chains *)Get_Library(iLibrary);
+						pTool    = (CSG_Tool_Chain  *)Get_Library(iLibrary)->Get_Tool(iTool);
 					}
 				}
 			}
@@ -492,7 +489,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const CSG_String &F
 	}
 
 	//-----------------------------------------------------
-	pTool	= new CSG_Tool_Chain(File);
+	pTool = new CSG_Tool_Chain(File);
 
 	if( !pTool || !pTool->is_Okay() )
 	{
@@ -505,21 +502,21 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const CSG_String &F
 	}
 
 	//-----------------------------------------------------
-	CSG_String	Library	= pTool->Get_Library();
+	CSG_String Library = pTool->Get_Library();
 
 	for(int iLibrary=0; !pLibrary && iLibrary<Get_Count(); iLibrary++)
 	{
 		if( Get_Library(iLibrary)->Get_Type() == TOOL_CHAINS
 		&&  Get_Library(iLibrary)->Get_Library_Name().Cmp(Library) == 0 )
 		{
-			pLibrary	= (CSG_Tool_Chains *)Get_Library(iLibrary);
+			pLibrary = (CSG_Tool_Chains *)Get_Library(iLibrary);
 		}
 	}
 
 	if( !pLibrary && (pLibrary = new CSG_Tool_Chains(pTool->Get_Library(), SG_File_Get_Path(File))) != NULL )
 	{
-		m_pLibraries	= (CSG_Tool_Library **)SG_Realloc(m_pLibraries, (m_nLibraries + 1) * sizeof(CSG_Tool_Library *));
-		m_pLibraries[m_nLibraries++]	= pLibrary;
+		m_pLibraries = (CSG_Tool_Library **)SG_Realloc(m_pLibraries, (m_nLibraries + 1) * sizeof(CSG_Tool_Library *));
+		m_pLibraries[m_nLibraries++] = pLibrary;
 	}
 
 	if( !pLibrary )	// this should never happen, but who knows...
@@ -561,8 +558,8 @@ bool CSG_Tool_Library_Manager::Destroy(void)
 
 		SG_Free(m_pLibraries);
 
-		m_pLibraries	= NULL;
-		m_nLibraries	= 0;
+		m_pLibraries = NULL;
+		m_nLibraries = 0;
 	}
 
 	return( true );
@@ -617,7 +614,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Get_Library(const CSG_String &Name,
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
-		CSG_Tool_Library	*pLibrary	= Get_Library(i);
+		CSG_Tool_Library *pLibrary = Get_Library(i);
 
 		if( !Name.Cmp(bLibrary ? pLibrary->Get_Library_Name() : pLibrary->Get_Name()) )
 		{
@@ -708,11 +705,11 @@ CSG_Tool * CSG_Tool_Library_Manager::Create_Tool(const CSG_String &Library, cons
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
-		CSG_Tool_Library	*pLibrary	= Get_Library(i);
+		CSG_Tool_Library *pLibrary = Get_Library(i);
 
 		if( pLibrary->Get_Library_Name().Cmp(Library) == 0 )
 		{
-			CSG_Tool	*pTool	= pLibrary->Create_Tool(Name, bWithGUI);
+			CSG_Tool *pTool = pLibrary->Create_Tool(Name, bWithGUI);
 
 			if( pTool )
 			{
@@ -739,6 +736,159 @@ bool CSG_Tool_Library_Manager::Delete_Tool(CSG_Tool *pTool) const
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Tool_Library_Manager::Create_Python_ToolBox(const CSG_String &Destination, bool bClean, bool bName, bool bSingleFile) const
+{
+	const char *Header =
+		"#! /usr/bin/env python\n\n"
+		"'''\n"
+		"Python Interface to SAGA Tools Library\n"
+		"----------\n"
+		"- Category : %s\n"
+		"- Name     : %s\n"
+		"- ID       : %s\n\n"
+		"Description\n"
+		"----------\n%s\n"
+		"'''\n\n"
+		"from PySAGA.helper import Tool_Wrapper\n\n";
+
+	CSG_File Stream;
+
+	if( bSingleFile )
+	{
+		if( SG_File_Exists(Destination) )
+		{
+			SG_File_Delete(Destination);
+		}
+
+		if( !Stream.Open(Destination, SG_FILE_W, false, SG_FILE_ENCODING_UTF8) )
+		{
+			SG_UI_Msg_Add_Error(CSG_String::Format("%s: %s", _TL("failed to create destination file"), Destination.c_str()));
+
+			return( false );
+		}
+
+		Stream.Write("#! /usr/bin/env python\n\n'''\n");
+		Stream.Write("Python Interface to SAGA Tools\n");
+		Stream.Write("----------\n'''\n\n");
+		Stream.Write("from PySAGA.helper import Tool_Wrapper\n\n");
+	}
+	else
+	{
+		if( !SG_Dir_Exists(Destination) && !SG_Dir_Create(Destination, true) )
+		{
+			SG_UI_Msg_Add_Error(CSG_String::Format("%s: %s", _TL("failed to create destination folder"), Destination.c_str()));
+
+			return( false );
+		}
+
+		if( bClean )
+		{
+			CSG_Strings Files;
+
+			SG_Dir_List_Files(Files, Destination);
+
+			for(int i=0; i<Files.Get_Count(); i++)
+			{
+				SG_File_Delete(Files[i]);
+			}
+		}
+	}
+
+	//-----------------------------------------------------
+	for(int iLibrary=0; iLibrary<Get_Count() && SG_UI_Process_Set_Progress(iLibrary, Get_Count()); iLibrary++)
+	{
+		CSG_Tool_Library *pLibrary = Get_Library(iLibrary);
+
+		if( !pLibrary->Get_Category    ().Cmp("SAGA Development" ) // generally exclude certain categories/libraries
+		||  !pLibrary->Get_Category    ().Cmp("Garden"           )
+		||  !pLibrary->Get_Library_Name().Cmp("vis_3d_viewer"    )
+		||  !pLibrary->Get_Library_Name().Cmp("grid_calculus_bsl")
+		||   pLibrary->Get_Type() == TOOL_CHAINS                 ) // exclude tool chains in 1st run
+		{
+			continue;
+		}
+
+		SG_UI_Process_Set_Text(CSG_String::Format("%s: %s", SG_T("Library"), pLibrary->Get_Library_Name().c_str()));
+
+		if( !bSingleFile )
+		{
+			if( !Stream.Open(SG_File_Make_Path(Destination, pLibrary->Get_Library_Name(), "py"), SG_FILE_W, false, SG_FILE_ENCODING_UTF8) )
+			{
+				continue;
+			}
+
+			Stream.Printf(Header, pLibrary->Get_Category().c_str(), pLibrary->Get_Name().c_str(), pLibrary->Get_Library_Name().c_str(), SG_HTML_Tag_Replacer(pLibrary->Get_Description()).c_str());
+		}
+
+		for(int iTool=0; iTool<pLibrary->Get_Count(); iTool++)
+		{
+			CSG_Tool *pTool = pLibrary->Get_Tool(iTool);
+
+			if( pTool && pTool != TLB_INTERFACE_SKIP_TOOL && !pTool->needs_GUI() && !pTool->is_Interactive() && pTool->Get_Parameters_Count() == 0 )
+			{
+				Stream.Write(pTool->Get_Script(bName ? TOOL_SCRIPT_PYTHON_WRAP_NAME : TOOL_SCRIPT_PYTHON_WRAP_ID, false));
+			}
+		}
+	}
+
+	//-----------------------------------------------------
+	for(int iLibrary=0; iLibrary<Get_Count() && SG_UI_Process_Set_Progress(iLibrary, Get_Count()); iLibrary++)
+	{
+		CSG_Tool_Library *pLibrary = Get_Library(iLibrary);
+
+		if( !pLibrary->Get_Category().Cmp("SAGA Development" ) // generally exclude certain categories
+		||  !pLibrary->Get_Category().Cmp("Garden"           )
+		||   pLibrary->Get_Type() != TOOL_CHAINS             ) // process tool chains in 2nd run
+		{
+			continue;
+		}
+
+		SG_UI_Process_Set_Text(CSG_String::Format("%s: %s", SG_T("Library"), pLibrary->Get_Library_Name().c_str()));
+
+		if( !bSingleFile )
+		{
+			CSG_String File(SG_File_Make_Path(Destination, pLibrary->Get_Library_Name(), "py"));
+
+			if( SG_File_Exists(File) )
+			{
+				if( !Stream.Open(File, SG_FILE_RW, false, SG_FILE_ENCODING_UTF8) )
+				{
+					continue;
+				}
+
+				Stream.Seek_End();
+			}
+			else
+			{
+				if( !Stream.Open(File, SG_FILE_W, false, SG_FILE_ENCODING_UTF8) )
+				{
+					continue;
+				}
+
+				Stream.Printf(Header, pLibrary->Get_Category().c_str(), pLibrary->Get_Name().c_str(), pLibrary->Get_Library_Name().c_str(), SG_HTML_Tag_Replacer(pLibrary->Get_Description()).c_str());
+			}
+		}
+
+		for(int iTool=0; iTool<pLibrary->Get_Count(); iTool++)
+		{
+			CSG_Tool *pTool = pLibrary->Get_Tool(iTool);
+
+			if( pTool && pTool != TLB_INTERFACE_SKIP_TOOL && !pTool->needs_GUI() && !pTool->is_Interactive() && pTool->Get_Parameters_Count() == 0 )
+			{
+				Stream.Write(pTool->Get_Script(bName ? TOOL_SCRIPT_PYTHON_WRAP_NAME : TOOL_SCRIPT_PYTHON_WRAP_ID, false));
+			}
+		}
+	}
+
+	return( true );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
