@@ -233,7 +233,7 @@ bool		Execute(int argc, char *argv[])
 	//-----------------------------------------------------
 	if( argc == 3 && CMD_Get_XML() )
 	{	// Just output tool synopsis as XML-tagged text, then return.
-		SG_Printf(pTool->Get_Summary(true, "", "", SG_SUMMARY_FMT_XML).c_str());
+		CMD_Print(pTool->Get_Summary(true, "", "", SG_SUMMARY_FMT_XML));
 
 		return( true );
 	}
@@ -382,6 +382,11 @@ bool		Execute_Script(const CSG_String &Script)
 	{
 		Command.Trim(true);
 
+		if( !Command.CmpNoCase("exit") )
+		{
+			return( true );
+		}
+
 		if( Command.Length() > 0 && Command[Command.Length() - 1] == CONTINUE_LINE )
 		{
 			CSG_String Line;
@@ -452,11 +457,16 @@ bool		Check_First		(const CSG_String &Argument, int argc, char *argv[])
 {
 	if( !Argument.Cmp("-h") || !Argument.Cmp("--help") )
 	{
+		while( argc > 0 && Check_Flags(argv[0]) )
+		{
+			argc--;	argv++;
+		}
+
 		switch( argc )
 		{
-		default:	Print_Help(                );	break;
-		case  1:	Print_Help(argv[0]         );	break;
-		case  2:	Print_Help(argv[0], argv[1]);	break;
+		default: Print_Help(                ); break;
+		case  1: Print_Help(argv[0]         ); break;
+		case  2: Print_Help(argv[0], argv[1]); break;
 		}
 
 		return( true );
@@ -516,8 +526,8 @@ bool		Check_Flags		(const CSG_String &Argument)
 
 		if( s.Find('l') >= 0 )	// l: load translation dictionary
 		{
-			SG_Printf(CSG_String::Format("\n%s:", _TL("loading translation dictionary")));
-			SG_Printf(CSG_String::Format("\n%s.\n",
+			CMD_Print(CSG_String::Format("\n%s:", _TL("loading translation dictionary")));
+			CMD_Print(CSG_String::Format("\n%s.\n",
 				SG_Get_Translator().Create(SG_File_Make_Path(Path_Shared, SG_T("saga"), SG_T("lng")), false)
 				? _TL("success") : _TL("failed")
 			));
@@ -560,6 +570,16 @@ bool		Check_Flags		(const CSG_String &Argument)
 		return( true );
 	}
 
+	//-----------------------------------------------------
+	else if( !s.Cmp("-u") || !s.Cmp("--utf8") )
+	{
+		int	On; if( !CSG_String(Argument).AfterFirst('=').asInt(On) ) { On = 1; } // let's switch it on by default!
+
+		SG_UI_Console_Set_UTF8(On);
+
+		return( true );
+	}
+
 	//-----------------------------------------------------
 	return( false );
 }
@@ -578,7 +598,7 @@ void		Print_Libraries	(void)
 	{
 		if( CMD_Get_XML() )
 		{
-			SG_Printf(SG_Get_Tool_Library_Manager().Get_Summary(SG_SUMMARY_FMT_XML).c_str());
+			CMD_Print(SG_Get_Tool_Library_Manager().Get_Summary(SG_SUMMARY_FMT_XML));
 		}
 		else
 		{
@@ -600,11 +620,11 @@ void		Print_Tools		(const CSG_String &Library)
 		{
 			for(int i=0; i<SG_Get_Tool_Library_Manager().Get_Count(); i++)
 			{
-				CSG_Tool_Library	*pLibrary	= SG_Get_Tool_Library_Manager().Get_Library(i);
+				CSG_Tool_Library *pLibrary = SG_Get_Tool_Library_Manager().Get_Library(i);
 
 				if( !pLibrary->Get_Library_Name().Cmp(Library) )
 				{
-					SG_Printf(pLibrary->Get_Summary(SG_SUMMARY_FMT_XML , false).c_str());
+					CMD_Print(pLibrary->Get_Summary(SG_SUMMARY_FMT_XML , false));
 				}
 			}
 		}
@@ -612,7 +632,7 @@ void		Print_Tools		(const CSG_String &Library)
 		{
 			for(int i=0; i<SG_Get_Tool_Library_Manager().Get_Count(); i++)
 			{
-				CSG_Tool_Library	*pLibrary	= SG_Get_Tool_Library_Manager().Get_Library(i);
+				CSG_Tool_Library *pLibrary = SG_Get_Tool_Library_Manager().Get_Library(i);
 
 				if( !pLibrary->Get_Library_Name().Cmp(Library) )
 				{
@@ -634,29 +654,26 @@ void		Print_Execution	(CSG_Tool *pTool)
 	{
 		if( CMD_Get_XML() )
 		{
-			#define SG_XML_LIBRARY		SG_T("library")
-			#define SG_XML_LIBRARY_PATH	SG_T("path")
-			#define SG_XML_LIBRARY_NAME	SG_T("name")
-
-			SG_Printf("<?xml version='1.0' encoding='UTF-8' standalone='yes' ?>\n");
-			SG_Printf("<%s>\n", SG_XML_LIBRARY);
-			SG_Printf("\t<%s>%s</%s>\n", SG_XML_LIBRARY_PATH, pTool->Get_File_Name().c_str(), SG_XML_LIBRARY_PATH);
-			SG_Printf("\t<%s>%s</%s>\n", SG_XML_LIBRARY_NAME, pTool->Get_Library  ().c_str(), SG_XML_LIBRARY_NAME);
-			SG_Printf("</%s>\n", SG_XML_LIBRARY);
+			CMD_Print("<?xml version='1.0' encoding='UTF-8' standalone='yes' ?>\n");
+			CMD_Print("<library>");
+			CMD_Print(pTool->Get_File_Name(), "path");
+			CMD_Print(pTool->Get_Library  (), "name");
+			CMD_Print("</library>");
 		}
 		else
 		{
-			SG_Printf("____________________________\n");
-			SG_Printf("%s: %s\n", _TL("library path"), SG_File_Get_Path(pTool->Get_File_Name()       ).c_str());
-			SG_Printf("%s: %s\n", _TL("library name"), SG_File_Get_Name(pTool->Get_File_Name(), false).c_str());
-			SG_Printf("%s: %s\n", _TL("library     "), pTool->Get_Library().c_str());
-			SG_Printf("%s: %s\n", _TL("tool        "), pTool->Get_Name   ().c_str());
-			SG_Printf("%s: %s\n", _TL("identifier  "), pTool->Get_ID     ().c_str());
-			SG_Printf("%s: %s\n", _TL("author      "), pTool->Get_Author ().c_str());
+			CMD_Print("____________________________");
+			CMD_Print(CSG_String::Format("%s: %s", _TL("library path"), SG_File_Get_Path(pTool->Get_File_Name()       ).c_str()));
+			CMD_Print(CSG_String::Format("%s: %s", _TL("library path"), SG_File_Get_Path(pTool->Get_File_Name()       ).c_str()));
+			CMD_Print(CSG_String::Format("%s: %s", _TL("library name"), SG_File_Get_Name(pTool->Get_File_Name(), false).c_str()));
+			CMD_Print(CSG_String::Format("%s: %s", _TL("library     "), pTool->Get_Library().c_str()));
+			CMD_Print(CSG_String::Format("%s: %s", _TL("tool        "), pTool->Get_Name   ().c_str()));
+			CMD_Print(CSG_String::Format("%s: %s", _TL("identifier  "), pTool->Get_ID     ().c_str()));
+			CMD_Print(CSG_String::Format("%s: %s", _TL("author      "), pTool->Get_Author ().c_str()));
 		#ifdef _OPENMP
-			SG_Printf("%s: %d [%d]\n", _TL("processors  "), SG_OMP_Get_Max_Num_Threads(), SG_OMP_Get_Max_Num_Procs());
+			CMD_Print(CSG_String::Format("%s: %d [%d]", _TL("processors  "), SG_OMP_Get_Max_Num_Threads(), SG_OMP_Get_Max_Num_Procs()));
 		#endif // _OPENMP
-			SG_Printf("____________________________\n\n");
+			CMD_Print("____________________________\n");
 		}
 	}
 }
@@ -705,8 +722,7 @@ void		Print_Get_Help	(void)
 {
 	if( CMD_Get_Show_Messages() )
 	{
-		CMD_Print(_TL("type -h or --help for further information"));
-		CMD_Print("");
+		CMD_Print(CSG_String::Format("\n%s\n", _TL("type -h or --help for further information")));
 	}
 }
 
@@ -740,6 +756,11 @@ void		Print_Help		(void)
 		"[-v], [--version]: version information\n"
 		"[-s], [--story]  : maximum data history depth (default is unlimited)\n"
 		"[-C], [--config] : configuration file (default is 'saga_cmd.ini')\n"
+#ifdef _SAGA_MSW
+		"[-u], [--utf8]   : print UTF-8 (=1) or ANSI (=0) (default is 0)\n"
+#else
+		"[-u], [--utf8]   : print UTF-8 (=1) or ANSI (=0) (default is 1)\n"
+#endif
 #ifdef _OPENMP
 		"[-c], [--cores]  : number of physical processors to use for computation\n"
 #endif
@@ -781,7 +802,7 @@ void		Print_Help		(void)
 		"\n"
 		"A more convenient way to set various saga_cmd options is to edit a\n"
 		"configuration file. The default configuration file \'saga_cmd.ini\' will be\n"
-		"loaded automatically, if present. You can specify a different configuration "
+		"loaded automatically, if present. You can specify a different configuration\n"
 		"file with the \'-C\' or \'--config\' option. Use \'--create-config\' to\n"
 		"generate such a file with default options and edit it to fit your purposes.\n"
 		"\n"
@@ -811,7 +832,7 @@ void		Print_Help		(const CSG_String &Library)
 {
 	Print_Logo();
 
-	CSG_Tool_Library	*pLibrary;
+	CSG_Tool_Library *pLibrary;
 
 	if( !Load_Libraries() || !(pLibrary = SG_Get_Tool_Library_Manager().Get_Library(Library, true)) )
 	{
@@ -819,7 +840,7 @@ void		Print_Help		(const CSG_String &Library)
 	}
 	else
 	{
-		CMD_Print(pLibrary->Get_Description());
+		CMD_Print(SG_HTML_Tag_Replacer(pLibrary->Get_Description()));
 		CMD_Print(pLibrary->Get_Summary(SG_SUMMARY_FMT_FLAT, false));
 	}
 }
@@ -835,7 +856,7 @@ void		Print_Help		(const CSG_String &Library, const CSG_String &Tool)
 	}
 	else
 	{
-		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Get_Tool(Library, Tool);
+		CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Get_Tool(Library, Tool);
 
 		if( !pTool )
 		{
