@@ -90,22 +90,7 @@ bool CCMD_Tool::Create(CSG_Tool *pTool)
 
 	if( (m_pTool = pTool) != NULL )
 	{
-		wxCmdLineParser Parser; Parser.SetSwitchChars("-");
-
-		_Set_Parser(m_pTool->Get_Parameters(), Parser);
-
-		for(int i=0; i<m_pTool->Get_Parameters_Count(); i++)
-		{
-			_Set_Parser(m_pTool->Get_Parameters(i), Parser);
-		}
-
-		wxString Usage = wxString::Format("\nUsage: saga_cmd %s %s %s",
-			m_pTool->Get_Library().c_str(),
-			m_pTool->Get_ID     ().c_str(),
-			Parser.GetUsageString().AfterFirst(' ').AfterFirst(' ')
-		);
-
-		m_Usage.Create(&Usage);
+		m_Usage = m_pTool->Get_Script(TOOL_SCRIPT_CMD_USAGE);
 
 		return( true );
 	}
@@ -184,7 +169,7 @@ bool CCMD_Tool::Execute(int argc, char *argv[])
 			_Save_Output(m_pTool->Get_Parameters(i));
 		}
 
-		SG_Get_Data_Manager().Delete_Unsaved();	// remove temporary data to save memory resources
+		SG_Get_Data_Manager().Delete();	// remove temporary data to save memory resources
 	}
 	else
 	{
@@ -197,28 +182,6 @@ bool CCMD_Tool::Execute(int argc, char *argv[])
 }
 
 
-///////////////////////////////////////////////////////////
-//                                                       //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-CSG_String CCMD_Tool::_Get_ID(CSG_Parameter *pParameter)
-{
-	CSG_String ID(pParameter->Get_Parameters()->Get_Identifier());
-
-	if( ID.Length() > 0 )
-	{
-		ID += "_";
-	}
-
-	ID += pParameter->Get_Identifier();
-
-	ID.Replace(".", "_");
-
-	return( ID );
-}
-
-
 ///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
@@ -363,130 +326,6 @@ bool CCMD_Tool::_Found(const CSG_String &Name, CSG_DateTime &Value)
 }
 
 
-///////////////////////////////////////////////////////////
-//                                                       //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-bool CCMD_Tool::_Set_Parser(CSG_Parameters *pParameters, wxCmdLineParser &Parser)
-{
-	if( !pParameters )
-	{
-		return( false );
-	}
-
-	//-----------------------------------------------------
-	for(int i=0; i<pParameters->Get_Count(); i++)
-	{
-		CSG_Parameter *pParameter = pParameters->Get_Parameter(i);
-
-		//-------------------------------------------------
-		if( pParameter->is_DataObject() )	// reset data object parameters, avoids problems when tool is called more than once without un-/reloading
-		{
-			pParameter->Set_Value(DATAOBJECT_NOTSET);
-		}
-		else if( pParameter->is_DataObject_List() )
-		{
-			pParameter->asList()->Del_Items();
-		}
-
-		//-------------------------------------------------
-		if( pParameter->do_UseInCMD() == false )
-		{
-			continue;
-		}
-
-		wxString Description = pParameter->Get_Description(
-			PARAMETER_DESCRIPTION_NAME|PARAMETER_DESCRIPTION_TYPE|PARAMETER_DESCRIPTION_PROPERTIES, SG_T("\n\t")
-		).c_str();
-
-		Description.Replace("\xb", "");	// unicode problem: quick'n'dirty bug fix, to be replaced
-
-		wxString ID(_Get_ID(pParameter).c_str());
-
-		if( pParameter->is_Input() || pParameter->is_Output() )
-		{
-			Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_NEEDS_SEPARATOR|wxCMD_LINE_PARAM_OPTIONAL);
-		}
-
-		//-------------------------------------------------
-		else if( pParameter->is_Option() && !pParameter->is_Information() )
-		{
-			switch( pParameter->Get_Type() )
-			{
-			case PARAMETER_TYPE_Parameters  :
-				_Set_Parser(pParameter->asParameters(), Parser);
-				break;
-
-			case PARAMETER_TYPE_Bool        :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Int         :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_NUMBER, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Choice      :
-			case PARAMETER_TYPE_Choices     :
-			case PARAMETER_TYPE_Table_Field :
-			case PARAMETER_TYPE_Table_Fields:
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Double      :
-			case PARAMETER_TYPE_Degree      :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_DOUBLE, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Date        :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_DATE  , wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Range       :
-				Parser.AddOption(ID + "_MIN", wxEmptyString, Description, wxCMD_LINE_VAL_DOUBLE, wxCMD_LINE_PARAM_OPTIONAL);
-				Parser.AddOption(ID + "_MAX", wxEmptyString, Description, wxCMD_LINE_VAL_DOUBLE, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Color       :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Colors      :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_String      :
-			case PARAMETER_TYPE_Text        :
-			case PARAMETER_TYPE_FilePath    :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_FixedTable  :
-				Parser.AddOption(ID, wxEmptyString, Description, wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				break;
-
-			case PARAMETER_TYPE_Grid_System :
-				if( pParameter->Get_Children_Count() == 0 )
-				{
-					Parser.AddOption(ID + "_D"   , wxEmptyString, _TL("Cell Size"                          ), wxCMD_LINE_VAL_DOUBLE, wxCMD_LINE_PARAM_OPTIONAL);
-					Parser.AddOption(ID + "_X"   , wxEmptyString, _TL("Lower Left Center Cell X-Coordinate"), wxCMD_LINE_VAL_DOUBLE, wxCMD_LINE_PARAM_OPTIONAL);
-					Parser.AddOption(ID + "_Y"   , wxEmptyString, _TL("Lower Left Center Cell Y-Coordinate"), wxCMD_LINE_VAL_DOUBLE, wxCMD_LINE_PARAM_OPTIONAL);
-					Parser.AddOption(ID + "_NX"  , wxEmptyString, _TL("Number of Columns"                  ), wxCMD_LINE_VAL_NUMBER, wxCMD_LINE_PARAM_OPTIONAL);
-					Parser.AddOption(ID + "_NY"  , wxEmptyString, _TL("Number of Rows"                     ), wxCMD_LINE_VAL_NUMBER, wxCMD_LINE_PARAM_OPTIONAL);
-					Parser.AddOption(ID + "_FILE", wxEmptyString, _TL("Grid File"                          ), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
-				}
-				break;
-
-			default:
-				break;
-			}
-		}
-	}
-
-	return( true );
-}
-
-
 ///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
@@ -516,7 +355,7 @@ bool CCMD_Tool::_Get_Options(CSG_Parameters *pParameters, bool bInitialize)
 {
 	for(int i=0; i<pParameters->Get_Count(); i++)
 	{
-		CSG_Parameter *pParameter = pParameters->Get_Parameter(i); CSG_String ID(_Get_ID(pParameter));
+		CSG_Parameter *pParameter = pParameters->Get_Parameter(i); CSG_String ID(pParameter->Get_CmdID());
 
 		if( pParameter->do_UseInCMD() == false )
 		{
@@ -580,6 +419,7 @@ bool CCMD_Tool::_Get_Options(CSG_Parameters *pParameters, bool bInitialize)
 				}
 				break;
 
+			case PARAMETER_TYPE_Data_Type:
 			case PARAMETER_TYPE_Choice:
 				if( _Found(ID, valString) )
 				{
@@ -761,7 +601,7 @@ bool CCMD_Tool::_Get_Input(CSG_Parameters *pParameters)
 				break;
 
 			case PARAMETER_TYPE_Table_Field: { CSG_String valString; int valInt;
-				if( _Found(_Get_ID(pParameter), valString) )
+				if( _Found(pParameter->Get_CmdID(), valString) )
 				{
 					if( valString.asInt(valInt) )
 					{
@@ -775,7 +615,7 @@ bool CCMD_Tool::_Get_Input(CSG_Parameters *pParameters)
 				break; }
 
 			case PARAMETER_TYPE_Table_Fields: { CSG_String valString;
-				if( _Found(_Get_ID(pParameter), valString) )
+				if( _Found(pParameter->Get_CmdID(), valString) )
 				{
 					pParameter->Set_Value(valString);
 				}
@@ -803,11 +643,11 @@ bool CCMD_Tool::_Load_Input(CSG_Parameter *pParameter)
 
 	CSG_String FileName;
 
-	if( !_Found(_Get_ID(pParameter), FileName) )
+	if( !_Found(pParameter->Get_CmdID(), FileName) )
 	{
 		if( !pParameter->is_Optional() )
 		{
-			CSG_String ID(_Get_ID(pParameter));
+			CSG_String ID(pParameter->Get_CmdID());
 
 			CMD_Print_Error(CSG_String::Format("%s: %s", ID.c_str(), _TL("Provide a value for non-optional argument!")));
 
@@ -900,7 +740,7 @@ bool CCMD_Tool::_Save_Output(CSG_Parameters *pParameters)
 		}
 
 		//-------------------------------------------------
-		else if( pParameter->is_Output() && _Found(_Get_ID(pParameter), FileName) && FileName.Length() > 0 )
+		else if( pParameter->is_Output() && _Found(pParameter->Get_CmdID(), FileName) && FileName.Length() > 0 )
 		{
 			if( pParameter->is_DataObject() )
 			{
