@@ -113,6 +113,14 @@ void CSG_3DView_Canvas::Set_Image(BYTE *pRGB, int NX, int NY)
 	m_Projector.Set_Screen(m_Image_NX, m_Image_NY);
 }
 
+//---------------------------------------------------------
+bool CSG_3DView_Canvas::Set_Drape(CSG_Grid *pDrape)
+{
+	m_pDrape = pDrape;
+
+	return( m_pDrape != NULL );
+}
+
 //---------------------------------------------------------
 bool CSG_3DView_Canvas::Draw(void)
 {
@@ -698,10 +706,37 @@ int CSG_3DView_Canvas::_Dim_Color(int Color, double Dim)
 	return( 0 );
 }
 
+//---------------------------------------------------------
+double CSG_3DView_Canvas::Get_Dim(double x0, double y0, double z0, double x1, double y1, double z1, double x2, double y2, double z2, const CSG_Vector &LightSource, int Shading, double zScale)
+{
+	CSG_Vector n(3), v(3);
+
+	n[0] = x2 - x0; n[1] = y2 - y0; n[2] = (z2 - z0) * zScale;
+	v[0] = x1 - x0; v[1] = y1 - y0; v[2] = (z1 - z0) * zScale;
+
+	double dim = n.Get_Cross_Product(v).Get_Angle(LightSource) / M_PI_090;
+
+	switch( Shading )
+	{
+	case  1: if( dim > 1. ) { dim = 2. - dim; }
+		dim = 0.5 + 0.5 * dim; break;
+
+	case  2:
+		dim = 1.  - 0.8 * dim; break;
+	}
+
+	return( dim );
+}
+
+double CSG_3DView_Canvas::Get_Dim(const CSG_Point_3D &p0, const CSG_Point_3D &p1, const CSG_Point_3D &p2, const CSG_Vector &LightSource, int Shading, double zScale)
+{
+	return( Get_Dim(p0.x, p0.y, p0.z, p1.x, p1.y, p1.z, p2.x, p2.y, p2.z, LightSource, Shading, zScale) );
+}
+
 //---------------------------------------------------------
 inline void CSG_3DView_Canvas::_Draw_Pixel(int x, int y, double z, int color)
 {
-	if( x >= 0 && x < m_Image_NX && y >= 0 && y < m_Image_NY && z < m_Image_zMax[y][x] )
+	if( x >= 0 && x < m_Image_NX && y >= 0 && y < m_Image_NY && z >= 0. && z < m_Image_zMax[y][x] )
 	{
 		BYTE *RGB = m_Image_pRGB + 3 * (y * m_Image_NX + x);
 
@@ -773,8 +808,8 @@ void CSG_3DView_Canvas::Draw_Point(int x, int y, double z, int Color, int Size)
 //---------------------------------------------------------
 void CSG_3DView_Canvas::Draw_Line(double ax, double ay, double az, double bx, double by, double bz, int aColor, int bColor)
 {
-	if(	(ax < 0 && bx < 0) || (ax >= m_Image_NX && bx >= m_Image_NX)
-	||	(ay < 0 && by < 0) || (ay >= m_Image_NY && by >= m_Image_NY) )
+	if(	(ax < 0. && bx < 0.) || ((int)ax >= m_Image_NX && (int)bx >= m_Image_NX)
+	||	(ay < 0. && by < 0.) || ((int)ay >= m_Image_NY && (int)by >= m_Image_NY) )
 	{
 		return; // completely out of area
 	}
@@ -784,30 +819,58 @@ void CSG_3DView_Canvas::Draw_Line(double ax, double ay, double az, double bx, do
 		return; // completely in front of screen
 	}
 
-	double n, dx = bx - ax, dy = by - ay, dz = bz - az;
+	double dx = bx - ax, dy = by - ay;
 
-	if( fabs(dx) > fabs(dy) && fabs(dx) > 0. )
+	if( fabs(dx) < 1. && fabs(dy) < 1. ) // both end points fall into the same pixel
 	{
-		n = fabs(dx); dx = dx < 0. ? -1. : 1.; dy /= n; dz /= n;
-	}
-	else if( fabs(dy) > 0. )
-	{
-		n = fabs(dy); dy = dy < 0. ? -1. : 1.; dx /= n; dz /= n;
+		_Draw_Pixel((int)ax, (int)ay, az < bz ? az : bz, az < bz ? aColor : bColor);
 	}
 	else
 	{
-		_Draw_Pixel((int)ax, (int)ay, az, aColor);
-		_Draw_Pixel((int)bx, (int)by, bz, bColor);
+		double dz = bz - az, ac = 0., dc = 1.; CSG_Colors Colors(2); Colors[0] = aColor; Colors[1] = bColor;
 
-		return;
-	}
+		if( fabs(dx) > fabs(dy) )
+		{
+			if( dx < 0. ) // ax < bx
+			{
+				double d = ax;
+				ax = bx; dx = -dx; bx = d;
+				ay = by; dy = -dy;
+				az = bz; dz = -dz;
+				ac = 1.; dc = -1.;
+			}
 
-	//-----------------------------------------------------
-	CSG_Colors Colors(2); Colors[0] = aColor; Colors[1] = bColor;
+			dy /= fabs(dx); dz /= fabs(dx); dc /= fabs(dx);
 
-	for(double i=0.; i<=n; i++, ax+=dx, ay+=dy, az+=dz)
-	{
-		_Draw_Pixel((int)ax, (int)ay, az, Colors.Get_Interpolated(i / n));
+			if( ax < 0. ) { ay -= dy * ax; az -= dz * ax; ac -= dc * ax; ax = 0.; }
+			if( bx >= m_Image_NX ) { bx = m_Image_NX - 1; }
+
+			for(int ix=(int)ax; ix<=(int)bx; ix++, ay+=dy, az+=dz, ac+=dc)
+			{
+				_Draw_Pixel(ix, (int)ay, az, Colors.Get_Interpolated(ac));
+			}
+		}
+		else
+		{
+			if( dy < 0. ) // ax < bx
+			{
+				double d = ay;
+				ay = by; dy = -dy; by = d;
+				ax = bx; dx = -dx;
+				az = bz; dz = -dz;
+				ac = 1.; dc = -1.;
+			}
+
+			dx /= fabs(dy); dz /= fabs(dy); dc /= fabs(dy);
+
+			if( ay < 0. ) { ax -= dx * ay; az -= dz * ay; ac -= dc * ay; ay = 0.; }
+			if( by >= m_Image_NY ) { by = m_Image_NY - 1; }
+
+			for(int iy=(int)ay; iy<=(int)by; iy++, ax+=dx, az+=dz, ac+=dc)
+			{
+				_Draw_Pixel((int)ax, iy, az, Colors.Get_Interpolated(ac));
+			}
+		}
 	}
 }
 
@@ -867,30 +930,7 @@ void CSG_3DView_Canvas::Draw_Line(const TSG_Point_3D &a, const TSG_Point_3D &b,
 //---------------------------------------------------------
 void CSG_3DView_Canvas::Draw_Triangle(TSG_Triangle_Node p[3], bool bValueAsColor, const CSG_Vector &LightSource, int Shading, double zScale)
 {
-	CSG_Vector n(3), v(3);
-
-	n[0] = p[2].x - p[0].x; n[1] = p[2].y - p[0].y; n[2] = (p[2].z - p[0].z) * zScale;
-	v[0] = p[1].x - p[0].x; v[1] = p[1].y - p[0].y; v[2] = (p[1].z - p[0].z) * zScale;
-
-	n.Multiply(v); // cross product n x v => normal vector
-
-	double a = n.Get_Angle(LightSource) / M_PI_090;
-
-	switch( Shading )
-	{
-	case  1: if( a > 1. ) { a = 2. - a; }
-		a = 0.5 + 0.5 * a;
-		break;
-
-	case  2:
-		a = 1.  - 0.8 * a;
-		break;
-
-	default:
-		break;
-	}
-
-	Draw_Triangle(p, bValueAsColor, a);
+	Draw_Triangle(p, bValueAsColor, Get_Dim(p[0].x, p[0].y, p[0].z, p[1].x, p[1].y, p[1].z, p[2].x, p[2].y, p[2].z, LightSource, Shading, zScale));
 }
 
 //---------------------------------------------------------
@@ -960,22 +1000,23 @@ void CSG_3DView_Canvas::Draw_Triangle(TSG_Triangle_Node p[3], bool bValueAsColor
 //---------------------------------------------------------
 void CSG_3DView_Canvas::Draw_Triangle(TSG_Triangle_Node Point[3], bool bValueAsColor, double Dim)
 {
-	if( Point[0].z < 0. || Point[1].z < 0. || Point[2].z < 0. )
+	if( Point[0].z < 0. && Point[1].z < 0. && Point[2].z < 0. )
 	{
 		return;	// completely in front of projection plane
 	}
 
-	CSG_Rect r(Point[0].x, Point[0].y, Point[1].x, Point[1].y); r.Union(CSG_Point(Point[2].x, Point[2].y));
+	CSG_Rect r(Point[0].x, Point[0].y, Point[1].x, Point[1].y); r.Union(Point[2].x, Point[2].y);
 
 	if( r.Get_XMax() < 0. || r.Get_XMin() >= m_Image_NX
-	||	r.Get_YMax() < 0. || r.Get_YMin() >= m_Image_NY )
+	||  r.Get_YMax() < 0. || r.Get_YMin() >= m_Image_NY )
 	{
 		return;	// completely off screen
 	}
+
 	if( (r.Get_XMin() < 0. && r.Get_XMax() >= m_Image_NX)
 	||  (r.Get_YMin() < 0. && r.Get_YMax() >= m_Image_NY) )
 	{
-		return;	// completely off screen
+		return;	// completely filling the screen
 	}
 
 	if( r.Get_XRange() <= 0. || r.Get_YRange() <= 0. )
@@ -984,9 +1025,7 @@ void CSG_3DView_Canvas::Draw_Triangle(TSG_Triangle_Node Point[3], bool bValueAsC
 	}
 
 	//-----------------------------------------------------
-	int Mode = m_pDrape ? 1 : bValueAsColor ? 2 : 0;
-
-	int i[3];
+	int i[3], Mode = m_pDrape ? 1 : bValueAsColor ? 2 : 0;
 
 	if     ( Point[0].y < Point[1].y && Point[0].y < Point[2].y )
 	{
@@ -1001,17 +1040,15 @@ void CSG_3DView_Canvas::Draw_Triangle(TSG_Triangle_Node Point[3], bool bValueAsC
 		i[0] = 2; if( Point[0].y < Point[1].y ) { i[1] = 0; i[2] = 1; } else { i[1] = 1; i[2] = 0; }
 	}
 
-	double p[3][6];
+	double p[3][6], tm[6], tb[6], mb[6];
 
 	TRIANGLE_SET_POINT(p[0], Point[i[0]]); // top
 	TRIANGLE_SET_POINT(p[1], Point[i[1]]); // middle
 	TRIANGLE_SET_POINT(p[2], Point[i[2]]); // bottom
 
-	double d[3][6];
-
-	TRIANGLE_GET_GRADIENT(p[0], p[2], d[0]); // top to bottom
-	TRIANGLE_GET_GRADIENT(p[0], p[1], d[1]); // top to middle
-	TRIANGLE_GET_GRADIENT(p[1], p[2], d[2]); // middle to bottom
+	TRIANGLE_GET_GRADIENT(p[0], p[1], tm); // top to middle
+	TRIANGLE_GET_GRADIENT(p[0], p[2], tb); // top to bottom
+	TRIANGLE_GET_GRADIENT(p[1], p[2], mb); // middle to bottom
 
 	int ay = (int)(r.Get_YMin()); if( ay < 0           ) ay = 0; if( ay < r.Get_YMin() ) ay++;
 	int by = (int)(r.Get_YMax()); if( by >= m_Image_NY ) by = m_Image_NY - 1;
@@ -1019,39 +1056,45 @@ void CSG_3DView_Canvas::Draw_Triangle(TSG_Triangle_Node Point[3], bool bValueAsC
 	//-----------------------------------------------------
 	for(int y=ay; y<=by; y++)
 	{
-		if( y <= p[1][1] && d[1][1] > 0. )
+		if( y <= p[1][1] )
 		{
-			double a[6]; TRIANGLE_GET_POINT(p[0], d[0], a); // a = p[0] + d[0] * (y - p[0][1]); // using CSG_Vector is, unluckily, significantly slower!!
-			double b[6]; TRIANGLE_GET_POINT(p[0], d[1], b);
+			if( tm[1] > 0. )
+			{
+				double a[6]; TRIANGLE_GET_POINT(p[0], tb, a); // a = p[0] + tb * (y - p[0][1]); // using CSG_Vector is, unluckily, significantly slower!!
+				double b[6]; TRIANGLE_GET_POINT(p[0], tm, b);
 
-			if( a[0] < b[0] )
-			{
-				_Draw_Triangle_Line(y, a, b, Dim, Mode);
-			}
-			else
-			{
-				_Draw_Triangle_Line(y, b, a, Dim, Mode);
+				if( a[0] < b[0] )
+				{
+					_Draw_Triangle_Line(y, a, b, Dim, Mode);
+				}
+				else
+				{
+					_Draw_Triangle_Line(y, b, a, Dim, Mode);
+				}
 			}
 		}
-		else if( d[2][1] > 0. )
+		else
 		{
-			double a[6]; TRIANGLE_GET_POINT(p[0], d[0], a);
-			double b[6]; TRIANGLE_GET_POINT(p[1], d[2], b);
+			if( mb[1] > 0. )
+			{
+				double a[6]; TRIANGLE_GET_POINT(p[0], tb, a);
+				double b[6]; TRIANGLE_GET_POINT(p[1], mb, b);
 
-			if( a[0] < b[0] )
-			{
-				_Draw_Triangle_Line(y, a, b, Dim, Mode);
-			}
-			else
-			{
-				_Draw_Triangle_Line(y, b, a, Dim, Mode);
+				if( a[0] < b[0] )
+				{
+					_Draw_Triangle_Line(y, a, b, Dim, Mode);
+				}
+				else
+				{
+					_Draw_Triangle_Line(y, b, a, Dim, Mode);
+				}
 			}
 		}
 	}
 }
 
 //---------------------------------------------------------
-inline void CSG_3DView_Canvas::_Draw_Triangle_Line(int y, double a[], double b[], double Dim, int mode)
+inline void CSG_3DView_Canvas::_Draw_Triangle_Line(int y, double a[], double b[], double Dim, int Mode)
 {
 	if( a[0] == b[0] )
 	{
@@ -1068,29 +1111,28 @@ inline void CSG_3DView_Canvas::_Draw_Triangle_Line(int y, double a[], double b[]
 	}
 
 	//-----------------------------------------------------
-	double d[6], dx; int ax, bx;
+	double d[6]; d[0] = b[0] - a[0];
 
-	ax = (int)a[0]; if( ax <  0          ) ax = 0;
-	bx = (int)b[0]; if( bx >= m_Image_NX ) bx = m_Image_NX - 1;
-	dx = ax - a[0];
-
-	switch( mode )
+	switch( Mode )
 	{
 	case 2:
-		d[5] = (b[5] - a[5]) / (b[0] - a[0]);
+		d[5] = (b[5] - a[5]) / d[0];
 	case 1:
-		d[4] = (b[4] - a[4]) / (b[0] - a[0]);
+		d[4] = (b[4] - a[4]) / d[0];
 	default:
-		d[2] = (b[2] - a[2]) / (b[0] - a[0]);
-		d[3] = (b[3] - a[3]) / (b[0] - a[0]);
+		d[3] = (b[3] - a[3]) / d[0];
+		d[2] = (b[2] - a[2]) / d[0];
 	}
 
 	//-----------------------------------------------------
+	int ax = (int)(a[0]); if( ax <  0          ) ax = 0; double dx = ax - a[0];
+	int bx = (int)(b[0]); if( bx >= m_Image_NX ) bx = m_Image_NX - 1;
+
 	for(int x=ax; x<=bx; x++, dx++)
 	{
 		double z = a[2] + dx * d[2];
 
-		switch( mode )
+		switch( Mode )
 		{
 		default: {
 			_Draw_Pixel(x, y, z, _Dim_Color(Get_Color(a[3] + dx * d[3]), Dim));
@@ -1117,6 +1159,90 @@ inline void CSG_3DView_Canvas::_Draw_Triangle_Line(int y, double a[], double b[]
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool Get_Polygon_Plane(const CSG_Shape_Polygon &Polygon, int iPart, CSG_Vector &Normal, double zScale)
+{
+	if( Polygon.is_Valid() )
+	{
+		CSG_Vector v[2]; int n = 0; CSG_Point_3D a = Polygon.Get_Point_Z(0, iPart, false);
+
+		for(int i=0; n<2 && i<Polygon.Get_Point_Count(iPart); i++)
+		{
+			CSG_Point_3D b = a; a = Polygon.Get_Point_Z(i, iPart);
+
+			v[n].Create(3); v[n][0] = a.x - b.x; v[n][1] = a.y - b.y; v[n][2] = (a.z - b.z);// * zScale;
+
+			if( !v[n].is_Null() && (n == 0 || !v[0].is_Collinear(v[1])) )
+			{
+				n++;
+			}
+		}
+
+		if( n == 2 )
+		{
+			Normal = v[0].Get_Cross_Product(v[1]); // cross product v0 x v1 => normal vector
+
+			return( true );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+void CSG_3DView_Canvas::Draw_Polygon(CSG_Shape_Polygon &Polygon, int Color, const CSG_Vector &LightSource, int Shading, double zScale)
+{
+	CSG_Vector Normal; if( !Get_Polygon_Plane(Polygon, 0, Normal, zScale) ) { return; }
+
+	double dim = Normal.Get_Angle(LightSource) / M_PI_090;
+
+	switch( Shading )
+	{
+	case  1: if( dim > 1. ) { dim = 2. - dim; }
+		dim = 0.5 + 0.5 * dim; break;
+
+	case  2:
+		dim = 1.  - 0.8 * dim; break;
+	}
+
+	Draw_Polygon(Polygon, _Dim_Color(Color, dim));
+}
+
+//---------------------------------------------------------
+void CSG_3DView_Canvas::Draw_Polygon(CSG_Shape_Polygon &Polygon, int Color)
+{
+	for(int iPart=0; iPart<Polygon.Get_Part_Count(); iPart++)
+	{
+		CSG_Vector Plane;
+
+		if( Get_Polygon_Plane(Polygon, iPart, Plane, 1) )
+		{
+			CSG_Point_3D p = Polygon.Get_Point_Z(0, iPart), n(Plane[0], Plane[1], Plane[2]);
+
+			CSG_Rect r(0, 0, m_Image_NX, m_Image_NY); r.Intersect(Polygon.Get_Part(iPart)->Get_Extent());
+
+			#pragma omp parallel for
+			for(int y=(int)r.Get_YMin(); y<=(int)r.Get_YMax(); y++)
+			{
+				for(int x=(int)r.Get_XMin(); x<=(int)r.Get_XMax(); x++)
+				{
+					if( Polygon.Contains(x, y, iPart) )
+					{
+						double z = p.z - ((x - p.x) * n.x + (y - p.y) * n.y) / n.z;
+
+						_Draw_Pixel(x, y, z, Color);
+					}
+				}
+			}
+		}
+	}
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
