@@ -267,7 +267,7 @@ void CDLG_Table_Control::On_Selected(wxGridRangeSelectEvent &event)
 	{
 		m_Table.Select();	// clear current selection
 
-		for(int i=0; i<m_Table.Get_Count(); i++)
+		for(sLong i=0; i<m_Table.Get_Count(); i++)
 		{
 			if( IsInSelection(i, 0) )
 			{
@@ -630,7 +630,7 @@ void CDLG_Table_Control::On_Field_Sort(wxCommandEvent &event)
 
 void CDLG_Table_Control::On_Field_Sort_UI(wxUpdateUIEvent &event)
 {
-	event.Enable(m_Table.Get_Field_Count() > 0 && m_Table.Get_Record_Count() > 1);
+	event.Enable(m_Table.Get_Field_Count() > 0 && m_Table.Get_Count() > 1);
 }
 
 
