@@ -414,12 +414,13 @@ bool CParameters_Control::Set_Parameters(CSG_Parameters *pParameters)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define CHECK_LIST_OUTPUT(p)	if( p->is_Output() ) { pRoot = NULL; break; }
+void CParameters_Control::_Add_Properties(CSG_Parameters *pParameters)
+{
+	#define CHECK_LIST_OUTPUT(p) if( p->is_Output() ) { pRoot = NULL; break; }
 
-//---------------------------------------------------------
-#define CHECK_DATA_NODE(pNode, Name, ID)	if( !pNode )\
+	#define CHECK_DATA_NODE(pNode, Name, ID) if( !pNode )\
 	{\
-		pNode	= new wxPropertyCategory(Name, ID);\
+		pNode = new wxPropertyCategory(Name, ID);\
 		\
 		if( !pData )\
 		{\
@@ -429,11 +430,9 @@ bool CParameters_Control::Set_Parameters(CSG_Parameters *pParameters)
 		m_pPG->Insert(pData, -1, pNode);\
 	}\
 	\
-	pRoot	= pNode;
+	pRoot = pNode;
 
-//---------------------------------------------------------
-void CParameters_Control::_Add_Properties(CSG_Parameters *pParameters)
-{
+	//-----------------------------------------------------
 	wxPGProperty *pData        = NULL;
 	wxPGProperty *pGrids       = NULL;
 	wxPGProperty *pShapes      = NULL;
@@ -446,11 +445,11 @@ void CParameters_Control::_Add_Properties(CSG_Parameters *pParameters)
 
 	for(int i=0; i<pParameters->Get_Count(); i++)
 	{
-		CSG_Parameter	*pParameter	= pParameters->Get_Parameter(i);
+		CSG_Parameter *pParameter = pParameters->Get_Parameter(i);
 
 		if(	pParameter->do_UseInGUI() && pParameter->Get_Parent() == NULL )
 		{
-			wxPGProperty	*pRoot	= NULL;
+			wxPGProperty *pRoot = NULL;
 
 			switch( pParameter->Get_Type() )
 			{
@@ -508,7 +507,7 @@ void CParameters_Control::_Add_Properties(CSG_Parameters *pParameters)
 				{
 					m_pPG->Append(pOptions = new wxPropertyCategory(_TL("Options"), "_DATAOBJECT_OPTIONS"));
 				}
-				pRoot	= pOptions;
+				pRoot = pOptions;
 				break;
 			}
 
@@ -525,7 +524,7 @@ void CParameters_Control::_Add_Property(wxPGProperty *pParent, CSG_Parameter *pP
 {
 	if( pParameter->do_UseInGUI() )
 	{
-		wxPGProperty	*pProperty	= _Get_Property(pParent, pParameter);
+		wxPGProperty *pProperty = _Get_Property(pParent, pParameter);
 
 		if( pParameter->Get_Children_Count() > 0 )
 		{
@@ -542,17 +541,15 @@ void CParameters_Control::_Add_Property(wxPGProperty *pParent, CSG_Parameter *pP
 //---------------------------------------------------------
 wxPGProperty * CParameters_Control::_Get_Property(wxPGProperty *pParent, CSG_Parameter *pParameter)
 {
-	#define ADD_PROPERTY(p, limit)	if( pParent ) { m_pPG->Insert(pParent, -1, pProperty = p); } else { m_pPG->Append(pProperty = p); }\
+	#define ADD_PROPERTY(p, limit) if( pParent ) { m_pPG->Insert(pParent, -1, pProperty = p); } else { m_pPG->Append(pProperty = p); }\
 		if( pParameter->is_Information() ) { m_pPG->LimitPropertyEditing(pProperty); m_pPG->EnableProperty(pProperty, false); } else\
-		if( limit ) { m_pPG->LimitPropertyEditing(pProperty); } { CSG_String	s, sDesc;\
-		sDesc	= pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE);\
-		s		= pParameter->Get_Description(PARAMETER_DESCRIPTION_TEXT      ); if( !s.is_Empty() ) { sDesc.Append("\n___\n"); sDesc.Append(s); }\
-		s		= pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES); if( !s.is_Empty() ) { sDesc.Append("\n___\n"); sDesc.Append(s); }\
+		if( limit ) { m_pPG->LimitPropertyEditing(pProperty); } { CSG_String s, sDesc;\
+		sDesc = pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE);\
+		s     = pParameter->Get_Description(PARAMETER_DESCRIPTION_TEXT      ); if( !s.is_Empty() ) { sDesc.Append("\n___\n"); sDesc.Append(s); }\
+		s     = pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES); if( !s.is_Empty() ) { sDesc.Append("\n___\n"); sDesc.Append(s); }\
 		m_pPG->SetPropertyHelpString(pProperty, sDesc.c_str()); }
 
-	wxString	Name(pParameter->Get_Name()), ID(pParameter->Get_Identifier());
-
-	wxPGProperty	*pProperty	= NULL;
+	wxPGProperty *pProperty = NULL; wxString Name(pParameter->Get_Name()), ID(pParameter->Get_Identifier());
 
 	switch( pParameter->Get_Type() )
 	{
@@ -644,6 +641,7 @@ wxPGProperty * CParameters_Control::_Get_Property(wxPGProperty *pParent, CSG_Par
 		}
 		break;
 
+	case PARAMETER_TYPE_Data_Type      :
 	case PARAMETER_TYPE_Choice         :
 	case PARAMETER_TYPE_Table_Field    :
 	case PARAMETER_TYPE_Grid_System    :
@@ -669,14 +667,14 @@ wxPGProperty * CParameters_Control::_Get_Property(wxPGProperty *pParent, CSG_Par
 //---------------------------------------------------------
 wxString CParameters_Control::_Get_Identifier(CSG_Parameter *pParameter)
 {
-	wxString	id;
+	wxString id;
 
 	if( pParameter->Get_Parent() )
 	{
-		id	= _Get_Identifier(pParameter->Get_Parent()) + wxT(".");
+		id = _Get_Identifier(pParameter->Get_Parent()) + ".";
 	}
 
-	id	+= pParameter->Get_Identifier();
+	id += pParameter->Get_Identifier();
 
 	return( id );
 }
@@ -703,11 +701,11 @@ void CParameters_Control::_Set_Parameter(wxPGProperty *pProperty)
 {
 	Freeze();
 
-	CSG_Parameter	*pParameter	=  _Get_Parameter(pProperty);
+	CSG_Parameter *pParameter = _Get_Parameter(pProperty);
 
 	if( pParameter )
 	{
-		m_bModified	= true;
+		m_bModified = true;
 
 		switch( pParameter->Get_Type() )
 		{
@@ -742,7 +740,7 @@ void CParameters_Control::_Set_Parameter(wxPGProperty *pProperty)
 
 		if( pParameter->Get_Type() != PARAMETER_TYPE_Date )
 		{
-			_Update_Parameters();
+			_Update_Parameters(pParameter);
 
 			m_pPG->SelectProperty(pProperty);
 		}
@@ -754,12 +752,12 @@ void CParameters_Control::_Set_Parameter(wxPGProperty *pProperty)
 //---------------------------------------------------------
 void CParameters_Control::_Update_Parameter(CSG_Parameter *pParameter)
 {
-	wxPGProperty	*pProperty	= m_pPG->GetProperty(_Get_Identifier(pParameter));
+	wxPGProperty *pProperty = m_pPG->GetProperty(_Get_Identifier(pParameter));
 
 	if( pProperty )
 	{
-		pProperty->Enable( _Get_Enabled(pParameter));
-		pProperty->Hide  (!_Get_Enabled(pParameter));
+		pProperty->Enable(_Get_Enabled(pParameter));
+		pProperty->Hide (!_Get_Enabled(pParameter));
 
 		switch( pParameter->Get_Type() )
 		{
@@ -804,7 +802,7 @@ void CParameters_Control::_Update_Parameter(CSG_Parameter *pParameter)
 
 		case PARAMETER_TYPE_Date:
 			{
-				wxDateTime	Date(pParameter->asDouble());
+				wxDateTime Date(pParameter->asDouble());
 
 				if( ((wxDateProperty *)pProperty)->GetDateValue() != Date )
 				{
@@ -813,6 +811,15 @@ void CParameters_Control::_Update_Parameter(CSG_Parameter *pParameter)
 			}
 			break;
 
+        case PARAMETER_TYPE_Color:
+            if( ((wxColourProperty *)pProperty)->GetVal().m_colour != pParameter->asColor() )
+            {
+                wxColor c = wxColor(pParameter->asColor());
+                m_pPG->SetPropertyValue(pProperty, c);
+            }
+            break;
+
+		case PARAMETER_TYPE_Data_Type      :
 		case PARAMETER_TYPE_Choice         :
 		case PARAMETER_TYPE_Table_Field    :
 		case PARAMETER_TYPE_Grid_System    :
@@ -851,35 +858,32 @@ bool CParameters_Control::Update_DataObjects(void)
 	{
 		for(int i=0; i<m_pParameters->Get_Count(); i++)
 		{
-			CSG_Parameter	*pParameter	= m_pParameters->Get_Parameter(i);
-			wxPGProperty	*pProperty	= m_pPG->GetProperty(_Get_Identifier(pParameter));
+			wxPGProperty *pProperty = m_pPG->GetProperty(_Get_Identifier((*m_pParameters)(i)));
 
 			if( pProperty  )
 			{
-				switch( pParameter->Get_Type() )
+				switch( (*m_pParameters)(i)->Get_Type() )
 				{
 				default:
 					break;
 
-				case PARAMETER_TYPE_Grid_System:
-				case PARAMETER_TYPE_Grid:
-				case PARAMETER_TYPE_Grids:
-				case PARAMETER_TYPE_Table:
-				case PARAMETER_TYPE_Shapes:
-				case PARAMETER_TYPE_TIN:
-				case PARAMETER_TYPE_PointCloud:
+				case PARAMETER_TYPE_Grid_System    :
+				case PARAMETER_TYPE_Grid           :
+				case PARAMETER_TYPE_Grids          :
+				case PARAMETER_TYPE_Table          :
+				case PARAMETER_TYPE_Shapes         :
+				case PARAMETER_TYPE_TIN            :
+				case PARAMETER_TYPE_PointCloud     :
 					((CParameters_PG_Choice *)pProperty)->Update();
 					break;
 
-				case PARAMETER_TYPE_Grid_List:
-				case PARAMETER_TYPE_Grids_List:
-				case PARAMETER_TYPE_Table_List:
-				case PARAMETER_TYPE_Shapes_List:
-				case PARAMETER_TYPE_TIN_List:
+				case PARAMETER_TYPE_Grid_List      :
+				case PARAMETER_TYPE_Grids_List     :
+				case PARAMETER_TYPE_Table_List     :
+				case PARAMETER_TYPE_Shapes_List    :
+				case PARAMETER_TYPE_TIN_List       :
 				case PARAMETER_TYPE_PointCloud_List:
-					if( pParameter->Check() == false )
-					{
-					}
+					(*m_pParameters)(i)->Check();
 					break;
 				}
 			}
@@ -890,27 +894,7 @@ bool CParameters_Control::Update_DataObjects(void)
 }
 
 //---------------------------------------------------------
-#define UPDATE_DATA_NODE(NODE)	{\
-	wxPGProperty	*pProperty	= m_pPG->GetProperty(NODE);\
-	\
-	if( pProperty )\
-	{\
-		bool	bShow	= false;\
-		\
-		for(size_t i=0; i<pProperty->GetChildCount() && !bShow; i++)\
-		{\
-			if( pProperty->Item(i)->IsEnabled() )\
-			{\
-				bShow	= true;\
-			}\
-		}\
-		\
-		pProperty->Hide(!bShow, wxPG_DONT_RECURSE);\
-	}\
-}
-
-//---------------------------------------------------------
-void CParameters_Control::_Update_Parameters(void)
+void CParameters_Control::_Update_Parameters(CSG_Parameter *pSender)
 {
 	if( m_pParameters )
 	{
@@ -918,16 +902,50 @@ void CParameters_Control::_Update_Parameters(void)
 
 		for(int i=0; i<m_pParameters->Get_Count(); i++)
 		{
-			_Update_Parameter(m_pParameters->Get_Parameter(i));
+			CSG_Parameter *pParameter = m_pParameters->Get_Parameter(i);
+
+			if( pSender )
+			{
+				if( pSender == pParameter )
+				{
+					continue;
+				}
+
+				if( pParameter->asGrid_System() && pParameter == pSender->Get_Parent() )
+				{
+					continue;
+				}
+			}
+
+			_Update_Parameter(pParameter);
 		}
 
-		UPDATE_DATA_NODE("_DATAOBJECT_GRIDS");
-		UPDATE_DATA_NODE("_DATAOBJECT_TABLES");
-		UPDATE_DATA_NODE("_DATAOBJECT_SHAPES");
-		UPDATE_DATA_NODE("_DATAOBJECT_TINS");
-		UPDATE_DATA_NODE("_DATAOBJECT_POINTCLOUDS");
-		UPDATE_DATA_NODE("_DATAOBJECT_OPTIONS");
+		//-------------------------------------------------
+		#define SHOW_DATA_NODE(NODE) { wxPGProperty *pProperty = m_pPG->GetProperty(NODE);\
+			if( pProperty )\
+			{\
+				bool bShow = false;\
+				\
+				for(size_t i=0; i<pProperty->GetChildCount() && !bShow; i++)\
+				{\
+					if( pProperty->Item(i)->IsEnabled() )\
+					{\
+						bShow = true;\
+					}\
+				}\
+				\
+				pProperty->Hide(!bShow, wxPG_DONT_RECURSE);\
+			}\
+		}
 
+		SHOW_DATA_NODE("_DATAOBJECT_GRIDS"      );
+		SHOW_DATA_NODE("_DATAOBJECT_TABLES"     );
+		SHOW_DATA_NODE("_DATAOBJECT_SHAPES"     );
+		SHOW_DATA_NODE("_DATAOBJECT_POINTCLOUDS");
+		SHOW_DATA_NODE("_DATAOBJECT_TINS"       );
+		SHOW_DATA_NODE("_DATAOBJECT_OPTIONS"    );
+
+		//-------------------------------------------------
 		m_pPG->Refresh();
 
 		GetParent()->Thaw();
