@@ -72,7 +72,7 @@
 enum
 {
 	MAP3D_STATUSBAR_ROTATE_X	= 0,
-	MAP3D_STATUSBAR_ROTATE_Y,
+//	MAP3D_STATUSBAR_ROTATE_Y,
 	MAP3D_STATUSBAR_ROTATE_Z,
 	MAP3D_STATUSBAR_SHIFT_X,
 	MAP3D_STATUSBAR_SHIFT_Y,
@@ -118,11 +118,9 @@ CVIEW_Map_3D::CVIEW_Map_3D(CWKSP_Map *pMap)
 	m_pPanel->SetSize(GetClientSize());
 
 	//-----------------------------------------------------
-	Parameters_Create();
-
-	if( DLG_Parameters(&m_Parameters) )
+	if( DLG_Parameters(&m_pPanel->m_Parameters) )
 	{
-		Parameters_Update(false);
+		m_pPanel->Update_Parameters(false);
 
 		Do_Show();
 
@@ -141,6 +139,44 @@ CVIEW_Map_3D::~CVIEW_Map_3D(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CVIEW_Map_3D::Do_Update(void)
+{
+	m_pPanel->Update_View(true);
+}
+
+//---------------------------------------------------------
+void CVIEW_Map_3D::Update_StatusBar(void)
+{
+	SetStatusText(wxString::Format("RX %+.1f", m_pPanel->Get_Projector().Get_xRotation() * M_RAD_TO_DEG), MAP3D_STATUSBAR_ROTATE_X    );
+//	SetStatusText(wxString::Format("RY %+.1f", m_pPanel->Get_Projector().Get_yRotation() * M_RAD_TO_DEG), MAP3D_STATUSBAR_ROTATE_Y    );
+	SetStatusText(wxString::Format("RZ %+.1f", m_pPanel->Get_Projector().Get_zRotation() * M_RAD_TO_DEG), MAP3D_STATUSBAR_ROTATE_Z    );
+
+	SetStatusText(wxString::Format("DX %+.1f", m_pPanel->Get_Projector().Get_xShift   ()               ), MAP3D_STATUSBAR_SHIFT_X     );
+	SetStatusText(wxString::Format("DY %+.1f", m_pPanel->Get_Projector().Get_yShift   ()               ), MAP3D_STATUSBAR_SHIFT_Y     );
+	SetStatusText(wxString::Format("DZ %+.1f", m_pPanel->Get_Projector().Get_zShift   ()               ), MAP3D_STATUSBAR_SHIFT_Z     );
+
+	SetStatusText(wxString::Format("EX %.1f" , m_pPanel->Get_Projector().Get_zScaling ()               ), MAP3D_STATUSBAR_EXAGGERATION);
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CVIEW_Map_3D::On_Size(wxSizeEvent &event)
+{
+	m_pPanel->SetSize(GetClientRect());
+
+	event.Skip();
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -151,13 +187,17 @@ wxMenu * CVIEW_Map_3D::_Create_Menu(void)
 	wxMenu *pMenu = new wxMenu, *pMenu_Sub;
 
 	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_PARAMETERS);
+	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_USAGE);
+	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_SAVE);
+	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_TO_CLIPBOARD);
+
+	pMenu->AppendSeparator();
+	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_EXAGGERATE_LESS);
+	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_EXAGGERATE_MORE);
 
 	pMenu->Append(ID_CMD_MAP3D_FIRST, _TL("Rotation"), pMenu_Sub = new wxMenu());
 	CMD_Menu_Add_Item(pMenu_Sub, false, ID_CMD_MAP3D_ROTATE_X_LESS);
 	CMD_Menu_Add_Item(pMenu_Sub, false, ID_CMD_MAP3D_ROTATE_X_MORE);
-//	pMenu_Sub->AppendSeparator();
-//	CMD_Menu_Add_Item(pMenu_Sub, false, ID_CMD_MAP3D_ROTATE_Y_LESS);
-//	CMD_Menu_Add_Item(pMenu_Sub, false, ID_CMD_MAP3D_ROTATE_Y_MORE);
 	pMenu_Sub->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu_Sub, false, ID_CMD_MAP3D_ROTATE_Z_LESS);
 	CMD_Menu_Add_Item(pMenu_Sub, false, ID_CMD_MAP3D_ROTATE_Z_MORE);
@@ -182,19 +222,9 @@ wxMenu * CVIEW_Map_3D::_Create_Menu(void)
 	CMD_Menu_Add_Item(pMenu_Sub,  true, ID_CMD_MAP3D_SEQ_PLAY_LOOP);
 	CMD_Menu_Add_Item(pMenu_Sub,  true, ID_CMD_MAP3D_SEQ_SAVE);
 
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_EXAGGERATE_LESS);
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_EXAGGERATE_MORE);
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu    ,  true, ID_CMD_MAP3D_CENTRAL);
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_CENTRAL_LESS);
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_CENTRAL_MORE);
-	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu    ,  true, ID_CMD_MAP3D_STEREO);
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_STEREO_LESS);
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_STEREO_MORE);
-	pMenu->AppendSeparator();
-	CMD_Menu_Add_Item(pMenu    ,  true, ID_CMD_MAP3D_INTERPOLATED);
-	CMD_Menu_Add_Item(pMenu    , false, ID_CMD_MAP3D_SAVE);
 
 	return( pMenu );
 }
@@ -205,14 +235,12 @@ wxToolBarBase * CVIEW_Map_3D::_Create_ToolBar(void)
 	wxToolBarBase *pToolBar = CMD_ToolBar_Create(ID_TB_VIEW_MAP_3D);
 
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_PARAMETERS);
+	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_TO_CLIPBOARD);
 	CMD_ToolBar_Add_Separator(pToolBar);
 	CMD_ToolBar_Add_Item(pToolBar,  true, ID_CMD_MAP3D_STEREO);
-	CMD_ToolBar_Add_Item(pToolBar,  true, ID_CMD_MAP3D_INTERPOLATED);
 	CMD_ToolBar_Add_Separator(pToolBar);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_ROTATE_X_LESS);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_ROTATE_X_MORE);
-//	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_ROTATE_Y_LESS);
-//	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_ROTATE_Y_MORE);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_ROTATE_Z_LESS);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_MAP3D_ROTATE_Z_MORE);
 	CMD_ToolBar_Add_Separator(pToolBar);
@@ -235,47 +263,6 @@ wxToolBarBase * CVIEW_Map_3D::_Create_ToolBar(void)
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CVIEW_Map_3D::Do_Update(void)
-{
-	m_pPanel->Update_View(true);
-}
-
-//---------------------------------------------------------
-void CVIEW_Map_3D::Update_StatusBar(void)
-{
-	if( m_pPanel )
-	{
-		SetStatusText(wxString::Format("RX %+.1f", m_pPanel->Get_Projector().Get_xRotation() * M_RAD_TO_DEG), MAP3D_STATUSBAR_ROTATE_X    );
-		SetStatusText(wxString::Format("RY %+.1f", m_pPanel->Get_Projector().Get_yRotation() * M_RAD_TO_DEG), MAP3D_STATUSBAR_ROTATE_Y    );
-		SetStatusText(wxString::Format("RZ %+.1f", m_pPanel->Get_Projector().Get_zRotation() * M_RAD_TO_DEG), MAP3D_STATUSBAR_ROTATE_Z    );
-
-		SetStatusText(wxString::Format("DX %+.1f", m_pPanel->Get_Projector().Get_xShift   ()               ), MAP3D_STATUSBAR_SHIFT_X     );
-		SetStatusText(wxString::Format("DY %+.1f", m_pPanel->Get_Projector().Get_yShift   ()               ), MAP3D_STATUSBAR_SHIFT_Y     );
-		SetStatusText(wxString::Format("DZ %+.1f", m_pPanel->Get_Projector().Get_zShift   ()               ), MAP3D_STATUSBAR_SHIFT_Z     );
-
-		SetStatusText(wxString::Format("EX %.1f" , m_pPanel->Get_Projector().Get_zScaling ()               ), MAP3D_STATUSBAR_EXAGGERATION);
-	}
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CVIEW_Map_3D::On_Size(wxSizeEvent &event)
-{
-	m_pPanel->SetSize(GetClientRect());
-
-	event.Skip();
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -290,14 +277,19 @@ void CVIEW_Map_3D::On_Command(wxCommandEvent &event)
 
 	//-----------------------------------------------------
 	case ID_CMD_MAP3D_PARAMETERS     : {
-		Parameters_Update(true);
+		m_pPanel->Update_Parameters(true);
 
-		if( DLG_Parameters(&m_Parameters) )
+		if( DLG_Parameters(&m_pPanel->m_Parameters) )
 		{
-			Parameters_Update(false);
+			m_pPanel->Update_Parameters(false); m_pPanel->Update_View();
 		}
 		return; }
 
+	//-----------------------------------------------------
+	case ID_CMD_MAP3D_USAGE          : {
+		DLG_Info(_TL("3D View Usage"), m_pPanel->Get_Usage().c_str());
+		return; }
+
 	//-----------------------------------------------------
 	case ID_CMD_MAP3D_SAVE           : { wxString File; int Type;
 		CSG_Parameters P(_TL("Image Resolution"));
@@ -326,6 +318,11 @@ void CVIEW_Map_3D::On_Command(wxCommandEvent &event)
 		}
 		return; }
 
+	//-----------------------------------------------------
+	case ID_CMD_MAP3D_TO_CLIPBOARD:
+		m_pPanel->Save_toClipboard();
+		break;
+
 	//-----------------------------------------------------
 	case ID_CMD_MAP3D_SEQ_POS_EDIT   : {
 		DLG_Table(_TL("Edit 3D-View Sequencer Positions"), m_pPanel->m_Parameters("PLAY")->asTable());
@@ -338,7 +335,6 @@ void CVIEW_Map_3D::On_Command(wxCommandEvent &event)
 	case ID_CMD_MAP3D_SEQ_PLAY       : m_pPanel->Play_Once   (); return;
 	case ID_CMD_MAP3D_SEQ_PLAY_LOOP  : m_pPanel->Play_Loop   (); return;
 	case ID_CMD_MAP3D_SEQ_SAVE       : { wxString File; int Type;
-
 		if( DLG_Image_Save(File, Type) )
 		{
 			m_pPanel->m_Parameters("PLAY_FILE")->Set_Value(File.wc_str());
@@ -361,20 +357,17 @@ void CVIEW_Map_3D::On_Command(wxCommandEvent &event)
 	case ID_CMD_MAP3D_SHIFT_Z_LESS   : m_pPanel->Get_Projector().Inc_zShift(-0.1); break;
 	case ID_CMD_MAP3D_SHIFT_Z_MORE   : m_pPanel->Get_Projector().Inc_zShift( 0.1); break;
 
+	case ID_CMD_MAP3D_EXAGGERATE_LESS: m_pPanel->Get_Projector().Inc_zScaling(-0.5); break;
+	case ID_CMD_MAP3D_EXAGGERATE_MORE: m_pPanel->Get_Projector().Inc_zScaling( 0.5); break;
+
 	case ID_CMD_MAP3D_CENTRAL        : m_pPanel->Get_Projector().do_Central(m_pPanel->Get_Projector().is_Central() == false);	break;
 	case ID_CMD_MAP3D_CENTRAL_LESS   : m_pPanel->Get_Projector().Inc_Central_Distance( 0.1); break;
 	case ID_CMD_MAP3D_CENTRAL_MORE   : m_pPanel->Get_Projector().Inc_Central_Distance(-0.1); break;
 
-	case ID_CMD_MAP3D_EXAGGERATE_LESS: m_pPanel->m_Parameters("Z_SCALE"    )->Set_Value(m_pPanel->m_Parameters("Z_SCALE"    )->asDouble() - 0.5     ); break;
-	case ID_CMD_MAP3D_EXAGGERATE_MORE: m_pPanel->m_Parameters("Z_SCALE"    )->Set_Value(m_pPanel->m_Parameters("Z_SCALE"    )->asDouble() + 0.5     ); break;
-	case ID_CMD_MAP3D_STEREO         : m_pPanel->m_Parameters("STEREO"     )->Set_Value(m_pPanel->m_Parameters("STEREO"     )->asBool() == false    ); break;
-	case ID_CMD_MAP3D_STEREO_LESS    : m_pPanel->m_Parameters("STEREO_DIST")->Set_Value(m_pPanel->m_Parameters("STEREO_DIST")->asDouble() - 2       ); break;
-	case ID_CMD_MAP3D_STEREO_MORE    : m_pPanel->m_Parameters("STEREO_DIST")->Set_Value(m_pPanel->m_Parameters("STEREO_DIST")->asDouble() + 2       ); break;
-	case ID_CMD_MAP3D_INTERPOLATED   : m_pPanel->m_Parameters("DRAPE_MODE" )->Set_Value(m_pPanel->m_Parameters("DRAPE_MODE" )->asInt() == 0 ? 1 : 0 ); break;
-//	case ID_CMD_MAP3D_DRAW_BOX       : m_pPanel->m_Parameters("BOX"        )->Set_Value(m_pPanel->m_Parameters("BOX"        )->asBool() ==  true    ); break;
+	case ID_CMD_MAP3D_STEREO         : m_pPanel->Parameter_Value_Toggle("STEREO"); return;
 	}
 
-	Parameters_Update(true); m_pPanel->Update_View();
+	m_pPanel->Update_Parameters(true); m_pPanel->Update_View();
 }
 
 //---------------------------------------------------------
@@ -382,166 +375,18 @@ void CVIEW_Map_3D::On_Command_UI(wxUpdateUIEvent &event)
 {
 	switch( event.GetId() )
 	{
-	case ID_CMD_MAP3D_CENTRAL:
-		event.Check(m_pPanel->Get_Projector().is_Central());
-		break;
+	case ID_CMD_MAP3D_CENTRAL_LESS :
+	case ID_CMD_MAP3D_CENTRAL_MORE : event.Enable(m_pPanel->Get_Projector().is_Central()); break;
+	case ID_CMD_MAP3D_CENTRAL      : event.Check (m_pPanel->Get_Projector().is_Central()); break;
 
-	case ID_CMD_MAP3D_CENTRAL_LESS:
-	case ID_CMD_MAP3D_CENTRAL_MORE:
-		event.Enable(m_pPanel->Get_Projector().is_Central());
-		break;
-
-	case ID_CMD_MAP3D_INTERPOLATED:
-		event.Check(m_pPanel->m_Parameters("DRAPE_MODE")->asInt() != 0);
-		break;
-
-	case ID_CMD_MAP3D_STEREO:
-		event.Check(m_pPanel->m_Parameters("STEREO")->asBool());
-		break;
-
-	case ID_CMD_MAP3D_SEQ_PLAY:
-		event.Check(m_pPanel->Play_Get_State() == SG_3DVIEW_PLAY_RUN_ONCE);
-		break;
-
-	case ID_CMD_MAP3D_SEQ_PLAY_LOOP:
-		event.Check(m_pPanel->Play_Get_State() == SG_3DVIEW_PLAY_RUN_LOOP);
-		break;
-
-	case ID_CMD_MAP3D_SEQ_SAVE:
-		event.Check(m_pPanel->Play_Get_State() == SG_3DVIEW_PLAY_RUN_SAVE);
-		break;
+	case ID_CMD_MAP3D_STEREO       : event.Check (m_pPanel->m_Parameters("STEREO")->asBool()           ); break;
+	case ID_CMD_MAP3D_SEQ_PLAY     : event.Check (m_pPanel->Play_Get_State() == SG_3DVIEW_PLAY_RUN_ONCE); break;
+	case ID_CMD_MAP3D_SEQ_PLAY_LOOP: event.Check (m_pPanel->Play_Get_State() == SG_3DVIEW_PLAY_RUN_LOOP); break;
+	case ID_CMD_MAP3D_SEQ_SAVE     : event.Check (m_pPanel->Play_Get_State() == SG_3DVIEW_PLAY_RUN_SAVE); break;
 	}
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void CVIEW_Map_3D::Parameters_Update(bool bFromPanel)
-{
-	if( bFromPanel )
-	{
-		m_Parameters("ROTATION_X"  )->Set_Value(m_pPanel->Get_Projector().Get_xRotation() * M_RAD_TO_DEG);
-		m_Parameters("ROTATION_Y"  )->Set_Value(m_pPanel->Get_Projector().Get_yRotation() * M_RAD_TO_DEG);
-		m_Parameters("ROTATION_Z"  )->Set_Value(m_pPanel->Get_Projector().Get_zRotation() * M_RAD_TO_DEG);
-
-		m_Parameters("SHIFT_X"     )->Set_Value(m_pPanel->Get_Projector().Get_xShift());
-		m_Parameters("SHIFT_Y"     )->Set_Value(m_pPanel->Get_Projector().Get_yShift());
-		m_Parameters("SHIFT_Z"     )->Set_Value(m_pPanel->Get_Projector().Get_zShift());
-
-		m_Parameters("CENTRAL"     )->Set_Value(m_pPanel->Get_Projector().is_Central() ? 1 : 0);
-		m_Parameters("CENTRAL_DIST")->Set_Value(m_pPanel->Get_Projector().Get_Central_Distance());
-
-		m_Parameters("BGCOLOR"     )->Set_Value(m_pPanel->m_Parameters("BGCOLOR"    ));
-		m_Parameters("STEREO"      )->Set_Value(m_pPanel->m_Parameters("STEREO"     ));
-		m_Parameters("STEREO_DIST" )->Set_Value(m_pPanel->m_Parameters("STEREO_DIST"));
-		m_Parameters("BOX"         )->Set_Value(m_pPanel->m_Parameters("BOX"        ));
-
-		m_Parameters("LABELS"      )->Set_Value(m_pPanel->m_Parameters("LABELS"     ));
-		m_Parameters("LABEL_RES"   )->Set_Value(m_pPanel->m_Parameters("LABEL_RES"  ));
-		m_Parameters("LABEL_SCALE" )->Set_Value(m_pPanel->m_Parameters("LABEL_SCALE"));
-
-		m_Parameters("Z_SCALE"     )->Set_Value(m_pPanel->m_Parameters("Z_SCALE"    ));
-		m_Parameters("DEM_RES"     )->Set_Value(m_pPanel->Get_DEM_Res());
-		m_Parameters("MAP_RES"     )->Set_Value(m_pPanel->Get_Map_Res());
-	}
-
-	//-----------------------------------------------------
-	else
-	{
-		m_pPanel->Get_Projector().Set_Rotation(
-			m_Parameters("ROTATION_X")->asDouble() * M_DEG_TO_RAD,
-			m_Parameters("ROTATION_Y")->asDouble() * M_DEG_TO_RAD,
-			m_Parameters("ROTATION_Z")->asDouble() * M_DEG_TO_RAD
-		);
-
-		m_pPanel->Get_Projector().Set_Shift(
-			m_Parameters("SHIFT_X")->asDouble(),
-			m_Parameters("SHIFT_Y")->asDouble(),
-			m_Parameters("SHIFT_Z")->asDouble()
-		);
-
-		m_pPanel->Get_Projector().do_Central          (m_Parameters("CENTRAL"     )->asBool  ());
-		m_pPanel->Get_Projector().Set_Central_Distance(m_Parameters("CENTRAL_DIST")->asDouble());
-
-		m_pPanel->m_Parameters("BGCOLOR"    )->Set_Value(m_Parameters("BGCOLOR"    ));
-		m_pPanel->m_Parameters("STEREO"     )->Set_Value(m_Parameters("STEREO"     ));
-		m_pPanel->m_Parameters("STEREO_DIST")->Set_Value(m_Parameters("STEREO_DIST"));
-		m_pPanel->m_Parameters("DRAPE_MODE" )->Set_Value(m_Parameters("DRAPE_MODE" ));
-		m_pPanel->m_Parameters("BOX"        )->Set_Value(m_Parameters("BOX"        ));
-
-		m_pPanel->m_Parameters("LABELS"     )->Set_Value(m_Parameters("LABELS"     ));
-		m_pPanel->m_Parameters("LABEL_RES"  )->Set_Value(m_Parameters("LABEL_RES"  ));
-		m_pPanel->m_Parameters("LABEL_SCALE")->Set_Value(m_Parameters("LABEL_SCALE"));
-
-		m_pPanel->m_Parameters("Z_SCALE"    )->Set_Value(m_Parameters("Z_SCALE"    ));
-
-		//-------------------------------------------------
-		CSG_Grid *pDEM = m_Parameters("DEM")->asGrid();
-
-		if( !m_pPanel->Set_Options(
-			SG_Get_Data_Manager().Exists(pDEM) ? pDEM : NULL,
-			m_Parameters("DEM_RES")->asInt(),
-			m_Parameters("MAP_RES")->asInt()) )
-		{
-			m_pPanel->Update_View();
-		}
-	}
-
-	Update_StatusBar();
-}
-
-//---------------------------------------------------------
-void CVIEW_Map_3D::Parameters_Create(void)
-{
-	m_Parameters.Create(_TL("3D-View"));
-
-	m_Parameters.Add_Grid  (""        , "DEM"         , _TL("Elevation"            ), _TL(""), PARAMETER_INPUT);
-	m_Parameters.Add_Int   ("DEM"     , "DEM_RES"     , _TL("Resolution"           ), _TL(""), 100, 2, true);
-	m_Parameters.Add_Double("DEM"     , "Z_SCALE"     , _TL("Exaggeration"         ), _TL(""), 3.);
-
-	m_Parameters.Add_Node  (""        , "MAP"         , _TL("Map"                  ), _TL(""));
-	m_Parameters.Add_Int   ("MAP"     , "MAP_RES"     , _TL("Resolution"           ), _TL(""), 1000, 2, true);
-	m_Parameters.Add_Choice("MAP"     , "DRAPE_MODE"  , _TL("Interpolation"        ), _TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s",
-			_TL("None"),
-			_TL("Bilinear"),
-			_TL("Inverse Distance"),
-			_TL("Bicubic Spline"),
-			_TL("B-Spline")
-		), 0
-	);
-
-	m_Parameters.Add_Node  (""        , "ROTATION"    , _TL("Rotation"             ), _TL(""));
-	m_Parameters.Add_Double("ROTATION", "ROTATION_X"  , _TL("X"                    ), _TL(""),  55., -360., true, 360., true);
-	m_Parameters.Add_Double("ROTATION", "ROTATION_Y"  , _TL("Y"                    ), _TL(""),   0., -360., true, 360., true);
-	m_Parameters.Add_Double("ROTATION", "ROTATION_Z"  , _TL("Z"                    ), _TL(""), -45., -360., true, 360., true);
-
-	m_Parameters.Add_Node  (""        , "SHIFT"       , _TL("Shift"                ), _TL(""));
-	m_Parameters.Add_Double("SHIFT"   , "SHIFT_X"     , _TL("Left/Right"           ), _TL(""),  0.0);
-	m_Parameters.Add_Double("SHIFT"   , "SHIFT_Y"     , _TL("Up/Down"              ), _TL(""), -0.1);
-	m_Parameters.Add_Double("SHIFT"   , "SHIFT_Z"     , _TL("In/Out"               ), _TL(""), -0.4);
-
-	m_Parameters.Add_Choice(""        , "CENTRAL"     , _TL("Projection"           ), _TL(""), CSG_String::Format("%s|%s", _TL("parallel"), _TL("central")), 1);
-	m_Parameters.Add_Double("CENTRAL" , "CENTRAL_DIST", _TL("Perspectivic Distance"), _TL(""), 1.5, 1, true);
-
-	m_Parameters.Add_Bool  (""        , "STEREO"     , _TL("Anaglyph"              ), _TL(""), false);
-	m_Parameters.Add_Double("STEREO"  , "STEREO_DIST", _TL("Eye Distance [Degree]" ), _TL(""), 1., 0., true, 180., true);
-
-	m_Parameters.Add_Color (""        , "BGCOLOR"    , _TL("Background Color"      ), _TL(""), SG_GET_RGB(255, 255, 255));
-
-	m_Parameters.Add_Bool  (""        , "BOX"        , _TL("Bounding Box"          ), _TL(""), false);
-
-	m_Parameters.Add_Choice(""        , "LABELS"     , _TL("Axis Labeling"         ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("all"), _TL("horizontal"), _TL("none")), 0);
-	m_Parameters.Add_Int   ("LABELS"  , "LABEL_RES"  , _TL("Resolution"            ), _TL(""), 50, 20, true, 1000, true);
-	m_Parameters.Add_Double("LABELS"  , "LABEL_SCALE", _TL("Size"                  ), _TL(""), 1., 0.1, true, 10., true);
-
-	m_Parameters.Add_Bool  (""        , "NORTH"      , _TL("North Arrow"           ), _TL(""), false)->Set_Enabled(false);
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
