@@ -116,13 +116,13 @@ CVIEW_Map_Control::CVIEW_Map_Control(CVIEW_Map *pParent, CWKSP_Map *pMap)
 {
 	SYS_Set_Color_BG_Window(this);
 
-	m_pParent	= (CVIEW_Map *)pParent;
-	m_pMap		= pMap;
+	m_pParent   = (CVIEW_Map *)pParent;
+	m_pMap      = pMap;
 
-	m_Mode		= -1;
+	m_Mode      = -1;
 	Set_Mode(MAP_MODE_ZOOM);
 
-	m_Drag_Mode	= TOOL_INTERACTIVE_DRAG_NONE;
+	m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE;
 
 	m_CrossHair.x = m_CrossHair.y = -1;
 }
@@ -143,22 +143,18 @@ bool CVIEW_Map_Control::Set_Mode(int Mode)
 	{
 		return( false );
 	}
-#
-	if( m_Mode == MAP_MODE_DISTANCE )
-	{
-		m_Measure.Reset();
-	}
+
+	m_Mode_Previous = m_Mode;
 
 	m_Mode = Mode;
 
 	switch( m_Mode )
 	{
-	default:
+	default               :
 	case MAP_MODE_ZOOM    : SetCursor(IMG_Get_Cursor(ID_IMG_CRS_SELECT   )); break;
 	case MAP_MODE_PAN     : SetCursor(IMG_Get_Cursor(ID_IMG_CRS_HAND     )); break;
 	case MAP_MODE_PAN_DOWN: SetCursor(IMG_Get_Cursor(ID_IMG_CRS_HAND_GRAP)); break;
 	case MAP_MODE_SELECT  : SetCursor(IMG_Get_Cursor(ID_IMG_CRS_INFO     )); break;
-	case MAP_MODE_DISTANCE: SetCursor(IMG_Get_Cursor(ID_IMG_CRS_SELECT   )); break;
 	}
 
 	return( true );
@@ -167,15 +163,15 @@ bool CVIEW_Map_Control::Set_Mode(int Mode)
 //---------------------------------------------------------
 inline void CVIEW_Map_Control::_Set_StatusBar(const TSG_Point &Point)
 {
-	static bool	bBuisy	= false;
+	static bool bBuisy = false;
 
 	if( bBuisy == false )
 	{
-		bBuisy	= true;
+		bBuisy = true;
 
 		if( m_pMap->Get_Parameter("GCS_POSITION")->asBool() && m_pMap->Get_Projection().is_Okay() )
 		{
-			CSG_Projection	GCS; GCS.Set_GCS_WGS84(); TSG_Point Position = Point;
+			CSG_Projection GCS; GCS.Set_GCS_WGS84(); TSG_Point Position = Point;
 
 			if( SG_Get_Projected(m_pMap->Get_Projection(), GCS, Position) )
 			{
@@ -189,24 +185,28 @@ inline void CVIEW_Map_Control::_Set_StatusBar(const TSG_Point &Point)
 			STATUSBAR_Set_Text(wxString::Format("Y %f", Point.y), STATUSBAR_VIEW_Y);
 		}
 
-		if( m_Mode == MAP_MODE_DISTANCE )
+		if( m_Mode == MAP_MODE_DISTANCE_GET )
 		{
-			STATUSBAR_Set_Text(wxString::Format("D %f", m_Measure.Get(Point)), STATUSBAR_VIEW_Z);
+			STATUSBAR_Set_Text(m_Measure.Get_Measure(Point), STATUSBAR_VIEW_Z);
+		}
+		else if( m_Mode == MAP_MODE_DISTANCE )
+		{
+		//	STATUSBAR_Set_Text(m_Measure.Get_Measure(     ), STATUSBAR_VIEW_Z);
 		}
 		else if( Get_Active_Layer() )
 		{
 			CWKSP_Layer *pLayer = Get_Active_Layer(); CWKSP_Map_Layer *pMapLayer = m_pMap->Get_Map_Layer(pLayer);
 
-			TSG_Point	p(Point);	double epsilon	= _Get_Client2World(2.); // 2 pixel tolerance...
+			TSG_Point p(Point); double epsilon = _Get_Client2World(2.); // 2 pixel tolerance...
 
 			if( !pMapLayer || pMapLayer->is_Projecting() )
 			{
-				TSG_Point	e(Point); e.x += epsilon; e.y += epsilon;
+				TSG_Point e(Point); e.x += epsilon; e.y += epsilon;
 
 				if( SG_Get_Projected(m_pMap->Get_Projection(), pLayer->Get_Object()->Get_Projection(), p)
 				&&  SG_Get_Projected(m_pMap->Get_Projection(), pLayer->Get_Object()->Get_Projection(), e) )
 				{
-					epsilon	= (fabs(e.x - e.x) + fabs(e.y - e.y)) / 2.;
+					epsilon = (fabs(e.x - e.x) + fabs(e.y - e.y)) / 2.;
 				}
 			}
 
@@ -217,7 +217,7 @@ inline void CVIEW_Map_Control::_Set_StatusBar(const TSG_Point &Point)
 			STATUSBAR_Set_Text("Z", STATUSBAR_VIEW_Z);
 		}
 
-		bBuisy	= false;
+		bBuisy = false;
 	}
 }
 
@@ -258,7 +258,7 @@ inline double CVIEW_Map_Control::_Get_Client2World(double Length, bool bToActive
 
 	if( bToActive && m_pMap->Get_Map_Layer_Active() )
 	{
-		SG_Get_Projected(m_pMap->Get_Projection(), Get_Active_Layer()->Get_Object()->Get_Projection(), rWorld.m_rect);
+		SG_Get_Projected(m_pMap->Get_Projection(), Get_Active_Layer()->Get_Object()->Get_Projection(), rWorld);
 	}
 
 	return( Length * rWorld.Get_XRange() / (double)rClient.GetWidth() );
@@ -349,7 +349,7 @@ bool CVIEW_Map_Control::_Zoom(bool bZoomIn)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CVIEW_Map_Control::_Move(wxPoint &A, const wxPoint &B)
+bool CVIEW_Map_Control::_Move(wxPoint &A, const wxPoint &B, bool bUpdate)
 {
 	if( A != B )
 	{
@@ -361,6 +361,11 @@ bool CVIEW_Map_Control::_Move(wxPoint &A, const wxPoint &B)
 
 		A = B;
 
+		if( bUpdate )
+		{
+			Update(); _Set_StatusBar(_Get_Client2World(m_Mouse_Move));
+		}
+
 		return( true );
 	}
 
@@ -368,11 +373,11 @@ bool CVIEW_Map_Control::_Move(wxPoint &A, const wxPoint &B)
 }
 
 //---------------------------------------------------------
-bool CVIEW_Map_Control::_Move(const wxPoint &Move)
+bool CVIEW_Map_Control::_Move(const wxPoint &Move, bool bUpdate)
 {
 	wxPoint	A(Move), B(0, 0);
 
-	return( _Move(A, B) );
+	return( _Move(A, B, bUpdate) );
 }
 
 
@@ -410,31 +415,34 @@ void CVIEW_Map_Control::_Draw_CrossHair(wxDC &dc)
 //---------------------------------------------------------
 void CVIEW_Map_Control::_Draw_Measure(wxDC &dc)
 {
-	if( m_Measure.Count() > 0 )
+	if( m_Mode != MAP_MODE_PAN_DOWN && (m_Measure.Count() > 1 || (m_Measure.Count() > 0 && m_Mode == MAP_MODE_DISTANCE_GET)) )
 	{
 		wxPen oldPen(dc.GetPen());
 
-		//-------------------------------------------------
-		dc.SetPen(wxPen(*wxWHITE, 4));
-
-		for(int i=0, j=1; j<m_Measure.Count(); i++, j++)
+		for(int Draw=0; Draw<2; Draw++)
 		{
-			dc.DrawLine(_Get_World2Client(m_Measure[i]), _Get_World2Client(m_Measure[j]));
+			dc.SetPen(Draw == 0 ? wxPen(*wxWHITE, 4) : wxPen(*wxBLACK, 2));
+
+			for(int i=0, j=1; j<m_Measure.Count(); i++, j++)
+			{
+				dc.DrawLine(_Get_World2Client(m_Measure[i]), _Get_World2Client(m_Measure[j]));
+			}
+
+			if( m_Mode == MAP_MODE_DISTANCE_GET )
+			{
+				dc.DrawLine(_Get_World2Client(m_Measure[m_Measure.Count() - 1]), m_Mouse_Move);
+
+				if( m_Measure.Get_Type() == 1 )
+				{
+					dc.DrawLine(_Get_World2Client(m_Measure[0]), m_Mouse_Move);
+				}
+			}
+			else if( m_Measure.Get_Type() == 1 )
+			{
+				dc.DrawLine(_Get_World2Client(m_Measure[0]), _Get_World2Client(m_Measure[m_Measure.Count() - 1]));
+			}
 		}
 
-		dc.DrawLine(_Get_World2Client(m_Measure[m_Measure.Count() - 1]), m_Mouse_Move);
-
-		//-------------------------------------------------
-		dc.SetPen(wxPen(*wxBLACK, 2));
-
-		for(int i=0, j=1; j<m_Measure.Count(); i++, j++)
-		{
-			dc.DrawLine(_Get_World2Client(m_Measure[i]), _Get_World2Client(m_Measure[j]));
-		}
-
-		dc.DrawLine(_Get_World2Client(m_Measure[m_Measure.Count() - 1]), m_Mouse_Move);
-
-		//-------------------------------------------------
 		dc.SetPen(oldPen);
 	}
 }
@@ -507,7 +515,7 @@ void CVIEW_Map_Control::_Draw_Edit_Moves(wxDC &dc)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Paint(wxPaintEvent &event)
 {
-	if( m_Bitmap.Ok() )
+	if( _Update_Bitmap_Size() )
 	{
 		wxPaintDC dc(this);
 
@@ -526,15 +534,28 @@ void CVIEW_Map_Control::On_Size(wxSizeEvent &event)
 {
 	if( m_pParent->Do_Updates() )
 	{
-		wxRect	r(GetClientSize());
+		_Update_Bitmap_Size();
+	}
+}
 
+//---------------------------------------------------------
+bool CVIEW_Map_Control::_Update_Bitmap_Size(void)
+{
+	wxRect r(GetClientSize());
+
+	if( r.GetWidth() > 0 && r.GetHeight() > 0 )
+	{
 		if( !m_Bitmap.Ok() || m_Bitmap.GetWidth() != r.GetWidth() || m_Bitmap.GetHeight() != r.GetHeight() )
 		{
 			m_Bitmap.Create(r.GetWidth(), r.GetHeight());
 
 			Refresh_Map();
 		}
+
+		return( m_Bitmap.Ok() );
 	}
+
+	return( false );
 }
 
 //---------------------------------------------------------
@@ -580,19 +601,19 @@ void CVIEW_Map_Control::On_Key_Down(wxKeyEvent &event)
 		break;
 
 	case WXK_LEFT:
-		_Move(wxPoint(-10,   0));
+		_Move(wxPoint(-10,   0), true);
 		break;
 
 	case WXK_RIGHT:
-		_Move(wxPoint( 10,   0));
+		_Move(wxPoint( 10,   0), true);
 		break;
 
 	case WXK_UP:
-		_Move(wxPoint(  0, -10));
+		_Move(wxPoint(  0, -10), true);
 		break;
 
 	case WXK_DOWN:
-		_Move(wxPoint(  0,  10));
+		_Move(wxPoint(  0,  10), true);
 		break;
 
 	case WXK_F2:
@@ -647,9 +668,6 @@ bool CVIEW_Map_Control::_Check_Interactive(bool bProjection)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_LDown(wxMouseEvent &event)
 {
-	m_Mouse_Down = m_Mouse_Move = event.GetPosition();
-
-	//-----------------------------------------------------
 	if( m_Mode != MAP_MODE_SELECT )	// clipboard copy ?
 	{
 		if( event.ControlDown() )
@@ -668,20 +686,31 @@ void CVIEW_Map_Control::On_Mouse_LDown(wxMouseEvent &event)
 	}
 
 	//-----------------------------------------------------
-	bool	bCaptureMouse	= true;
+	SetFocus();
+
+	m_Mouse_Down = m_Mouse_Move = event.GetPosition();
+
+	bool bCaptureMouse = false;
 
 	switch( m_Mode )
 	{
+	default:
+		break;
+
 	//-----------------------------------------------------
 	case MAP_MODE_SELECT:
 		if( _Check_Interactive() )
 		{
 			m_Drag_Mode   = ((CSG_Tool_Interactive *)g_pTool->Get_Tool())->Get_Drag_Mode();
 
-			bCaptureMouse = !g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_LDOWN, GET_KEYS(event));
+			bCaptureMouse = m_Drag_Mode != TOOL_INTERACTIVE_DRAG_NONE;
+
+			g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_LDOWN, GET_KEYS(event));
 		}
 		else if( m_pMap->Get_Map_Layer_Active(false) )
 		{
+			bCaptureMouse = true;
+
 			switch(	Get_Active_Layer()->Get_Type() )
 			{
 			default                  : m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE; break;
@@ -703,23 +732,31 @@ void CVIEW_Map_Control::On_Mouse_LDown(wxMouseEvent &event)
 
 	//-----------------------------------------------------
 	case MAP_MODE_DISTANCE:
-		m_Drag_Mode		= TOOL_INTERACTIVE_DRAG_NONE;
+		m_Mode = MAP_MODE_DISTANCE_GET;
+		m_Measure.Reset();
+
+	case MAP_MODE_DISTANCE_GET:
+		m_Drag_Mode   = TOOL_INTERACTIVE_DRAG_NONE;
+		m_Measure.Add(_Get_Client2World(event.GetPosition()));
+		Refresh(false);
 		break;
 
 	//-----------------------------------------------------
 	case MAP_MODE_ZOOM:
-		m_Drag_Mode		= TOOL_INTERACTIVE_DRAG_BOX;
+		m_Drag_Mode   = TOOL_INTERACTIVE_DRAG_BOX;
+		bCaptureMouse = true;
 		break;
 
 	//-----------------------------------------------------
 	case MAP_MODE_PAN:
-		m_Drag_Mode		= TOOL_INTERACTIVE_DRAG_NONE;
+		m_Drag_Mode   = TOOL_INTERACTIVE_DRAG_NONE;
+		bCaptureMouse = true;
 		Set_Mode(MAP_MODE_PAN_DOWN);
 		break;
 
 	//-----------------------------------------------------
 	case MAP_MODE_PAN_DOWN:
-		m_Drag_Mode		= TOOL_INTERACTIVE_DRAG_NONE;
+		m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE;
 		break;
 	}
 
@@ -728,8 +765,6 @@ void CVIEW_Map_Control::On_Mouse_LDown(wxMouseEvent &event)
 	{
 		CaptureMouse();
 	}
-
-	event.Skip();
 }
 
 //---------------------------------------------------------
@@ -747,10 +782,13 @@ void CVIEW_Map_Control::On_Mouse_LUp(wxMouseEvent &event)
 	}
 
 	//-----------------------------------------------------
-	m_Drag_Mode	= TOOL_INTERACTIVE_DRAG_NONE;
+	m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE;
 
 	switch( m_Mode )
 	{
+	default:
+		break;
+
 	//-----------------------------------------------------
 	case MAP_MODE_SELECT:
 		if( _Check_Interactive() )
@@ -767,29 +805,18 @@ void CVIEW_Map_Control::On_Mouse_LUp(wxMouseEvent &event)
 		}
 		else if( m_pMap->Get_Map_Layer_Active() )	// on-the-fly projected layer !
 		{
-			double	d	= _Get_Client2World(1., true);
+			double d = _Get_Client2World(1., true);
 
 			Get_Active_Layer()->Edit_On_Mouse_Down(_Get_Client2World(m_Mouse_Down       , true), d, GET_KEYS(event));
 			Get_Active_Layer()->Edit_On_Mouse_Up  (_Get_Client2World(event.GetPosition(), true), d, GET_KEYS(event)|TOOL_INTERACTIVE_KEY_LEFT);
 		}
 		break;
 
-	//-----------------------------------------------------
-	case MAP_MODE_DISTANCE:
-		m_Measure.Add(_Get_Client2World(event.GetPosition()));
-
-		Refresh(false);
-		break;
-
 	//-----------------------------------------------------
 	case MAP_MODE_ZOOM:
 		_Zoom(m_Mouse_Down, event.GetPosition(), true);
 		break;
 
-	//-----------------------------------------------------
-	case MAP_MODE_PAN:
-		break;
-
 	//-----------------------------------------------------
 	case MAP_MODE_PAN_DOWN:
 		Set_Mode(MAP_MODE_PAN);
@@ -803,8 +830,13 @@ void CVIEW_Map_Control::On_Mouse_LUp(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_LDClick(wxMouseEvent &event)
 {
+	SetFocus();
+
 	switch( m_Mode )
 	{
+	default:
+		break;
+
 	//-----------------------------------------------------
 	case MAP_MODE_SELECT:
 		if( _Check_Interactive() )
@@ -812,10 +844,6 @@ void CVIEW_Map_Control::On_Mouse_LDClick(wxMouseEvent &event)
 			g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_LDCLICK, GET_KEYS(event));
 		}
 		break;
-
-	//-----------------------------------------------------
-	default:
-		break;
 	}
 }
 
@@ -827,12 +855,14 @@ void CVIEW_Map_Control::On_Mouse_LDClick(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_RDown(wxMouseEvent &event)
 {
-	m_pParent->Activate();
+	SetFocus();
 
 	m_Mouse_Down = m_Mouse_Move = event.GetPosition();
 
 	m_Drag_Mode	= TOOL_INTERACTIVE_DRAG_NONE;
 
+	m_pParent->Activate();
+
 	switch( m_Mode )
 	{
 	//-----------------------------------------------------
@@ -863,50 +893,59 @@ void CVIEW_Map_Control::On_Mouse_RDown(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_RUp(wxMouseEvent &event)
 {
-	wxMenu	*pMenu	= NULL;
+	wxMenu *pMenu = NULL;
 
-	m_Drag_Mode		= TOOL_INTERACTIVE_DRAG_NONE;
+	m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE;
 
 	switch( m_Mode )
 	{
+	default:
+		pMenu = m_pParent->_Create_Menu();
+		break;
+
 	//-----------------------------------------------------
 	case MAP_MODE_SELECT:
 		if( _Check_Interactive() )
 		{
 			g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_RUP, GET_KEYS(event));
 		}
-		else
-		{
-			if( m_pMap->Get_Map_Layer_Active(true) && !Get_Active_Layer()->Edit_On_Mouse_Up(
+		else if( m_pMap->Get_Map_Layer_Active(true) && !Get_Active_Layer()->Edit_On_Mouse_Up(
 				_Get_Client2World(event.GetPosition()), _Get_Client2World(1.), GET_KEYS(event)|TOOL_INTERACTIVE_KEY_RIGHT) )
-			{
-				pMenu	= Get_Active_Layer()->Edit_Get_Menu();
-			}
-			else if( event.AltDown() )	// request coordinate
-			{
-				m_pMap->Show_Coordinate(_Get_Client2World(event.GetPosition()));
-			}
+		{
+			pMenu = Get_Active_Layer()->Edit_Get_Menu();
 		}
 		break;
 
 	//-----------------------------------------------------
 	case MAP_MODE_DISTANCE:
-		if( event.ControlDown() )	// context menu
+		if( event.ControlDown() )
 		{
-			pMenu	= m_pParent->_Create_Menu();
+			if( m_Measure.Dialog() )
+			{
+				STATUSBAR_Set_Text(m_Measure.Get_Measure(), STATUSBAR_VIEW_Z);
+				Refresh(false);
+			}
 		}
-		else	// reset
+		else
 		{
 			m_Measure.Reset();
-
+			STATUSBAR_Set_Text(m_Measure.Get_Measure(), STATUSBAR_VIEW_Z);
 			Refresh(false);
 		}
 		break;
 
+	//-----------------------------------------------------
+	case MAP_MODE_DISTANCE_GET:
+		m_Mode = MAP_MODE_DISTANCE;
+		STATUSBAR_Set_Text(m_Measure.Get_Measure(), STATUSBAR_VIEW_Z);
+		Refresh(false);
+		break;
+
+	//-----------------------------------------------------
 	case MAP_MODE_ZOOM:
 		if( event.ControlDown() )	// context menu
 		{
-			pMenu	= m_pParent->_Create_Menu();
+			pMenu = m_pParent->_Create_Menu();
 		}
 		else if( event.AltDown() )	// request coordinate
 		{
@@ -917,11 +956,6 @@ void CVIEW_Map_Control::On_Mouse_RUp(wxMouseEvent &event)
 			_Zoom(m_Mouse_Down, event.GetPosition(), false);
 		}
 		break;
-
-	//-----------------------------------------------------
-	default:
-		pMenu	= m_pParent->_Create_Menu();
-		break;
 	}
 
 	//-----------------------------------------------------
@@ -938,8 +972,13 @@ void CVIEW_Map_Control::On_Mouse_RUp(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_RDClick(wxMouseEvent &event)
 {
+	SetFocus();
+
 	switch( m_Mode )
 	{
+	default:
+		break;
+
 	//-----------------------------------------------------
 	case MAP_MODE_SELECT:
 		if( _Check_Interactive() )
@@ -947,22 +986,6 @@ void CVIEW_Map_Control::On_Mouse_RDClick(wxMouseEvent &event)
 			g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_RDCLICK, GET_KEYS(event));
 		}
 		break;
-
-	//-----------------------------------------------------
-	case MAP_MODE_DISTANCE:
-		break;
-
-	//-----------------------------------------------------
-	case MAP_MODE_ZOOM:
-		break;
-
-	//-----------------------------------------------------
-	case MAP_MODE_PAN:
-		break;
-
-	//-----------------------------------------------------
-	case MAP_MODE_PAN_DOWN:
-		break;
 	}
 }
 
@@ -974,9 +997,11 @@ void CVIEW_Map_Control::On_Mouse_RDClick(wxMouseEvent &event)
 //---------------------------------------------------------
 void CVIEW_Map_Control::On_Mouse_MDown(wxMouseEvent &event)
 {
-	bool	bCaptureMouse	= true;
+	SetFocus();
 
-	m_Mouse_Down	= m_Mouse_Move	= event.GetPosition();
+	bool bCaptureMouse = true, bPan = true;
+
+	m_Mouse_Down = m_Mouse_Move = event.GetPosition();
 
 	switch( m_Mode )
 	{
@@ -987,20 +1012,24 @@ void CVIEW_Map_Control::On_Mouse_MDown(wxMouseEvent &event)
 	case MAP_MODE_SELECT:
 		if( _Check_Interactive() )
 		{
-			g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_MDOWN, GET_KEYS(event));
+			m_Drag_Mode   = ((CSG_Tool_Interactive *)g_pTool->Get_Tool())->Get_Drag_Mode();
+
+			bCaptureMouse = m_Drag_Mode != TOOL_INTERACTIVE_DRAG_NONE;
+
+			if( g_pTool->Execute(_Get_Client2World(event.GetPosition()), TOOL_INTERACTIVE_MDOWN, GET_KEYS(event)) )
+			{
+				bPan = false;
+			}
 		}
 		break;
+	}
 
 	//-----------------------------------------------------
-	case MAP_MODE_ZOOM:
+	if( bPan )
+	{
 		m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE;
+
 		Set_Mode(MAP_MODE_PAN_DOWN);
-		break;
-
-	//-----------------------------------------------------
-	case MAP_MODE_PAN_DOWN:
-		m_Drag_Mode = TOOL_INTERACTIVE_DRAG_NONE;
-		break;
 	}
 
 	//-----------------------------------------------------
@@ -1008,8 +1037,6 @@ void CVIEW_Map_Control::On_Mouse_MDown(wxMouseEvent &event)
 	{
 		CaptureMouse();
 	}
-
-	event.Skip();
 }
 
 //---------------------------------------------------------
@@ -1029,7 +1056,7 @@ void CVIEW_Map_Control::On_Mouse_MUp(wxMouseEvent &event)
 
 	//-----------------------------------------------------
 	case MAP_MODE_PAN_DOWN:
-		Set_Mode(MAP_MODE_ZOOM);
+		Set_Mode(m_Mode_Previous);
 		_Move(m_Mouse_Down, event.GetPosition());
 		break;
 	}
@@ -1076,7 +1103,7 @@ void CVIEW_Map_Control::On_Mouse_Motion(wxMouseEvent &event)
 		break;
 
 	//-----------------------------------------------------
-	case MAP_MODE_DISTANCE:
+	case MAP_MODE_DISTANCE_GET:
 		if( m_Measure.Count() > 0 )
 		{
 			Refresh(false);
@@ -1130,9 +1157,11 @@ void CVIEW_Map_Control::On_Mouse_Wheel(wxMouseEvent &event)
 
 		m_Mouse_Wheel_Accumulator -= event.GetWheelDelta();
 	}
+
 	if( m_Mouse_Wheel_Accumulator <= -event.GetWheelDelta() )
 	{
 		_Zoom(event.GetPosition(), false);
+
 		m_Mouse_Wheel_Accumulator += event.GetWheelDelta();
 	}
 }
