@@ -1018,15 +1018,7 @@ bool CWKSP_Grid::Edit_On_Mouse_Up(const CSG_Point &Point, double ClientToWorld,
 					for(int x=0; x<nx; x++)
 					{
 						pRecord->Set_Value(0, m_ySel + ny - y);
-
-						if( !Get_Grid()->is_NoData(m_xSel + x, m_ySel + ny - 1 - y) )
-						{
-							pRecord->Set_Value(1 + x, Get_Grid()->asDouble(m_xSel + x, m_ySel + ny - 1 - y));
-						}
-						else
-						{
-							pRecord->Set_NoData(1 + x);
-						}
+						pRecord->Set_Value(1 + x, Get_Grid()->asDouble(m_xSel + x, m_ySel + ny - 1 - y));
 					}
 				}
 			}
@@ -1097,7 +1089,7 @@ bool CWKSP_Grid::_Edit_Clr_Selection(void)
 //---------------------------------------------------------
 bool CWKSP_Grid::_Edit_Del_Selection(void)
 {
-	if( m_Edit_Attributes.Get_Count() > 0 && DLG_Message_Confirm(_TL("Set selected values to no data."), _TL("Delete")) )
+	if( m_Edit_Attributes.Get_Count() > 0 && DLG_Message_Confirm(_TL("Set selected cells to no-data."), _TL("Delete")) )
 	{
 		for(sLong y=0; y<m_Edit_Attributes.Get_Count(); y++)
 		{
