@@ -319,7 +319,7 @@ void CWKSP_Grids::On_Create_Parameters(void)
 	Set_Grid_Choices(&m_Parameters);
 
 	//-----------------------------------------------------
-	m_Fit_Colors	= g_pData->Get_Parameter("GRID_STRETCH_DEFAULT")->asInt();
+	m_Fit_Colors = g_pData->Get_Parameter("STRETCH_DEFAULT")->asInt();
 }
 
 
@@ -523,7 +523,7 @@ void CWKSP_Grids::On_Parameters_Changed(void)
 	//-----------------------------------------------------
 	if( m_Parameters("STRETCH_DEFAULT")->asInt() < 3 )	// not manual, remember last state...
 	{
-		m_Fit_Colors	= m_Parameters("STRETCH_DEFAULT")->asInt();
+		m_Fit_Colors = m_Parameters("STRETCH_DEFAULT")->asInt();
 	}
 }
 
@@ -1147,7 +1147,7 @@ void CWKSP_Grids::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 	{
 	case CLASSIFY_SINGLE   : m_pClassify->Set_Mode(CLASSIFY_SINGLE   ); break;
 	case CLASSIFY_LUT      : m_pClassify->Set_Mode(CLASSIFY_LUT      ); break;
-	case CLASSIFY_DISCRETE   : m_pClassify->Set_Mode(CLASSIFY_DISCRETE   ); break;
+	case CLASSIFY_DISCRETE : m_pClassify->Set_Mode(CLASSIFY_DISCRETE ); break;
 	case CLASSIFY_GRADUATED: m_pClassify->Set_Mode(CLASSIFY_GRADUATED); break;
 	case CLASSIFY_OVERLAY  : m_pClassify->Set_Mode(CLASSIFY_OVERLAY  ); break;
 	}
@@ -1155,12 +1155,11 @@ void CWKSP_Grids::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 	//-----------------------------------------------------
 	TSG_Grid_Resampling	Resampling;
 
-	if( m_pClassify->Get_Mode() == CLASSIFY_SINGLE
-	||  m_pClassify->Get_Mode() == CLASSIFY_LUT )
+	if( m_pClassify->Get_Mode() == CLASSIFY_SINGLE )
 	{
 		Resampling	= GRID_RESAMPLING_NearestNeighbour;
 	}
-	else switch( m_Parameters("DISPLAY_RESAMPLING")->asInt() )
+	else switch( m_Parameters(m_pClassify->Get_Mode() == CLASSIFY_LUT ? "LUT_RESAMPLING" : "DISPLAY_RESAMPLING")->asInt() )
 	{
 	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
 	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
