@@ -714,7 +714,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 		if( pTool && pTool->Set_Manager(NULL)
 			&&  pTool->Set_Parameter("CRS_PROJ4"        , prj_Map.Get_Proj4())
 			&&  pTool->Set_Parameter("RESAMPLING"       , m_pLayer->Get_Parameter("DISPLAY_RESAMPLING")->asInt() ? 3 : 0)
-			&&  pTool->Set_Parameter("KEEP_TYPE"        , true)
+			&&  pTool->Set_Parameter("DATA_TYPE"        , true)
 			&&  pTool->Set_Parameter("TARGET_AREA"      , m_bProject_Area)
 			&&  pTool->Set_Parameter("TARGET_DEFINITION", 1)
 			&&  pTool->Set_Parameter("SOURCE"           , pGrid)
@@ -754,7 +754,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 		if( pTool && pTool->Set_Manager(NULL)
 			&&  pTool->Set_Parameter("CRS_PROJ4"        , prj_Map.Get_Proj4())
 			&&  pTool->Set_Parameter("RESAMPLING"       , m_pLayer->Get_Parameter("DISPLAY_RESAMPLING")->asInt() ? 3 : 0)
-			&&  pTool->Set_Parameter("KEEP_TYPE"        , true)
+		//	&&  SG_TOOL_PARAMETER_SET("DATA_TYPE"       , 10) // "Preserve" => is already default!
 			&&  pTool->Set_Parameter("TARGET_AREA"      , true)
 			&&  pTool->Set_Parameter("TARGET_DEFINITION", 0)
 			&&  pTool->Set_Parameter("TARGET_USER_SIZE" , System.Get_Cellsize())
