@@ -118,15 +118,15 @@ wxString CWKSP_TIN::Get_Description(void)
 		DESC_ADD_STR(_TL("Data Source" ), _TL("memory"));
 	}
 
-	DESC_ADD_STR(_TL("Modified"        ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
-	DESC_ADD_STR(_TL("Projection"      ), m_pObject->Get_Projection().Get_Description().c_str());
-	DESC_ADD_FLT(_TL("West"            ), asTIN()->Get_Extent().Get_XMin());
-	DESC_ADD_FLT(_TL("East"            ), asTIN()->Get_Extent().Get_XMax());
-	DESC_ADD_FLT(_TL("West-East"       ), asTIN()->Get_Extent().Get_XRange());
-	DESC_ADD_FLT(_TL("South"           ), asTIN()->Get_Extent().Get_YMin());
-	DESC_ADD_FLT(_TL("North"           ), asTIN()->Get_Extent().Get_YMax());
-	DESC_ADD_FLT(_TL("South-North"     ), asTIN()->Get_Extent().Get_YRange());
-	DESC_ADD_INT(_TL("Number of Points"), asTIN()->Get_Node_Count());
+	DESC_ADD_STR (_TL("Modified"        ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
+	DESC_ADD_STR (_TL("Projection"      ), m_pObject->Get_Projection().Get_Description().c_str());
+	DESC_ADD_FLT (_TL("West"            ), asTIN()->Get_Extent().Get_XMin());
+	DESC_ADD_FLT (_TL("East"            ), asTIN()->Get_Extent().Get_XMax());
+	DESC_ADD_FLT (_TL("West-East"       ), asTIN()->Get_Extent().Get_XRange());
+	DESC_ADD_FLT (_TL("South"           ), asTIN()->Get_Extent().Get_YMin());
+	DESC_ADD_FLT (_TL("North"           ), asTIN()->Get_Extent().Get_YMax());
+	DESC_ADD_FLT (_TL("South-North"     ), asTIN()->Get_Extent().Get_YRange());
+	DESC_ADD_LONG(_TL("Number of Points"), asTIN()->Get_Node_Count());
 
 	s	+= "</table>";
 
@@ -424,7 +424,7 @@ void CWKSP_TIN::_Draw_Triangles(CWKSP_Map_DC &dc_Map)
 {
 	if(	m_Parameters("DISPLAY_TRIANGES")->asBool() && dc_Map.IMG_Draw_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.) )
 	{
-		for(int iTriangle=0; iTriangle<asTIN()->Get_Triangle_Count(); iTriangle++)
+		for(sLong iTriangle=0; iTriangle<asTIN()->Get_Triangle_Count(); iTriangle++)
 		{
 			CSG_TIN_Triangle	*pTriangle	= asTIN()->Get_Triangle(iTriangle);
 
