@@ -790,7 +790,6 @@ bool CSG_ODBC_Connection::Table_Drop(const CSG_String &Table_Name, bool bCommit)
 //---------------------------------------------------------
 bool CSG_ODBC_Connection::Table_Insert(const CSG_String &Table_Name, const CSG_Table &Table, bool bCommit)
 {
-	//-----------------------------------------------------
 	if( !is_Connected() )
 	{
 		_Error_Message(_TL("no database connection"));
@@ -813,40 +812,39 @@ bool CSG_ODBC_Connection::Table_Insert(const CSG_String &Table_Name, const CSG_T
 	//-----------------------------------------------------
 	try
 	{
-		bool	bLOB	= false;
+		bool bLOB = false;
 
-		int				iField, iRecord;
-		CSG_String		Insert;
-		otl_stream		Stream;
+		CSG_String Insert;
+		otl_stream Stream;
 
 		//-------------------------------------------------
-		Insert.Printf(SG_T("INSERT INTO %s VALUES("), Table_Name.c_str());
+		Insert.Printf("INSERT INTO %s VALUES(", Table_Name.c_str());
 
-		for(iField=0; iField<Table.Get_Field_Count(); iField++)
+		for(int iField=0; iField<Table.Get_Field_Count(); iField++)
 		{
 			if( iField > 0 )
 			{
-				Insert	+= SG_T(",");
+				Insert	+= ",";
 			}
 
-			Insert	+= CSG_String::Format(SG_T(":f%d"), 1 + iField);
+			Insert	+= CSG_String::Format(":f%d", 1 + iField);
 
 			switch( Table.Get_Field_Type(iField) )
 			{
 			default:
-			case SG_DATATYPE_String:	Insert	+= SG_T("<varchar>");	break;
-			case SG_DATATYPE_Date:		Insert	+= SG_T("<char[12]>");	break;
-			case SG_DATATYPE_Char:		Insert	+= SG_T("<char>");		break;
-			case SG_DATATYPE_Short:		Insert	+= SG_T("<short>");		break;
-			case SG_DATATYPE_Int:		Insert	+= SG_T("<int>");		break;
-			case SG_DATATYPE_Color:		Insert	+= SG_T("<long>");		break;
-			case SG_DATATYPE_Long:		Insert	+= SG_T("<long>");		break;
-			case SG_DATATYPE_Float:		Insert	+= SG_T("<float>");		break;
-			case SG_DATATYPE_Double:	Insert	+= SG_T("<double>");	break;
+			case SG_DATATYPE_String: Insert += "<varchar>" ; break;
+			case SG_DATATYPE_Date  : Insert += "<char[12]>"; break;
+			case SG_DATATYPE_Char  : Insert += "<char>"    ; break;
+			case SG_DATATYPE_Short : Insert += "<short>"   ; break;
+			case SG_DATATYPE_Int   : Insert += "<int>"     ; break;
+			case SG_DATATYPE_Color : Insert += "<long>"    ; break;
+			case SG_DATATYPE_Long  : Insert += "<long>"    ; break;
+			case SG_DATATYPE_Float : Insert += "<float>"   ; break;
+			case SG_DATATYPE_Double: Insert += "<double>"  ; break;
 			}
 		}
 
-		Insert	+= SG_T(")");
+		Insert	+= ")";
 
 		Stream.set_all_column_types(otl_all_date2str);
 		Stream.set_lob_stream_mode(bLOB);
@@ -855,11 +853,11 @@ bool CSG_ODBC_Connection::Table_Insert(const CSG_String &Table_Name, const CSG_T
 		std_string	valString;
 
 		//-------------------------------------------------
-		for(iRecord=0; iRecord<Table.Get_Count() && SG_UI_Process_Set_Progress(iRecord, Table.Get_Count()); iRecord++)
+		for(sLong iRecord=0; iRecord<Table.Get_Count() && SG_UI_Process_Set_Progress(iRecord, Table.Get_Count()); iRecord++)
 		{
-			CSG_Table_Record	*pRecord	= Table.Get_Record(iRecord);
+			CSG_Table_Record *pRecord = Table.Get_Record(iRecord);
 
-			for(iField=0; iField<Table.Get_Field_Count(); iField++)
+			for(int iField=0; iField<Table.Get_Field_Count(); iField++)
 			{
 				if( pRecord->is_NoData(iField) )
 				{
@@ -874,13 +872,13 @@ bool CSG_ODBC_Connection::Table_Insert(const CSG_String &Table_Name, const CSG_T
 					Stream << valString;
 					break;
 
-				case SG_DATATYPE_Char:		Stream << (char)pRecord->asChar  (iField);	break;
-				case SG_DATATYPE_Short:		Stream <<       pRecord->asShort (iField);	break;
-				case SG_DATATYPE_Int:		Stream <<       pRecord->asInt   (iField);	break;
-				case SG_DATATYPE_Color:
-				case SG_DATATYPE_Long:		Stream << (long)pRecord->asInt   (iField);	break;
-				case SG_DATATYPE_Float:		Stream <<       pRecord->asFloat (iField);	break;
-				case SG_DATATYPE_Double:	Stream <<       pRecord->asDouble(iField);	break;
+				case SG_DATATYPE_Char  : Stream << (char)pRecord->asChar  (iField);	break;
+				case SG_DATATYPE_Short : Stream <<       pRecord->asShort (iField);	break;
+				case SG_DATATYPE_Int   : Stream <<       pRecord->asInt   (iField);	break;
+				case SG_DATATYPE_Color :
+				case SG_DATATYPE_Long  : Stream << (long)pRecord->asInt   (iField);	break;
+				case SG_DATATYPE_Float : Stream <<       pRecord->asFloat (iField);	break;
+				case SG_DATATYPE_Double: Stream <<       pRecord->asDouble(iField);	break;
 				}
 			}
 		}
@@ -904,7 +902,6 @@ bool CSG_ODBC_Connection::Table_Insert(const CSG_String &Table_Name, const CSG_T
 //---------------------------------------------------------
 bool CSG_ODBC_Connection::Table_Save(const CSG_String &Table_Name, const CSG_Table &Table, const CSG_Buffer &Flags, bool bCommit)
 {
-	//-----------------------------------------------------
 	if( !is_Connected() )
 	{
 		_Error_Message(_TL("no database connection"));
@@ -939,7 +936,6 @@ bool CSG_ODBC_Connection::Table_Save(const CSG_String &Table_Name, const CSG_Tab
 //---------------------------------------------------------
 bool CSG_ODBC_Connection::_Table_Load(CSG_Table &Table, const CSG_String &Select, const CSG_String &Name, bool bLOB)
 {
-	//-----------------------------------------------------
 	if( !is_Connected() )
 	{
 		_Error_Message(_TL("no database connection"));
@@ -990,20 +986,20 @@ bool CSG_ODBC_Connection::_Table_Load(CSG_Table &Table, const CSG_String &Select
 		//-------------------------------------------------
 		while( !Stream.eof() && SG_UI_Process_Get_Okay() )	// while not end-of-data
 		{
-			CSG_Table_Record	*pRecord	= Table.Add_Record();
+			CSG_Table_Record *pRecord = Table.Add_Record();
 
 			for(iField=0; iField<nFields; iField++)
 			{
 				switch( Table.Get_Field_Type(iField) )
 				{
-				case SG_DATATYPE_String:	Stream >> valString; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, CSG_String(valString.c_str()));	break;
-				case SG_DATATYPE_Short:			
-				case SG_DATATYPE_Int:		Stream >> valInt;    if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valInt);		break;
-				case SG_DATATYPE_DWord:
-				case SG_DATATYPE_Long:		Stream >> valLong;   if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valLong);		break;
-				case SG_DATATYPE_Float:		Stream >> valFloat;  if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valFloat);		break;
-				case SG_DATATYPE_Double:	Stream >> valDouble; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valDouble);	break;
-				case SG_DATATYPE_Binary:	Stream >> valRaw;    if( Stream.is_null() ) pRecord->Set_NoData(iField); else
+				case SG_DATATYPE_String: Stream >> valString; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, CSG_String(valString.c_str()));	break;
+				case SG_DATATYPE_Short :			
+				case SG_DATATYPE_Int   : Stream >> valInt   ; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valInt);		break;
+				case SG_DATATYPE_DWord :
+				case SG_DATATYPE_Long  : Stream >> valLong  ; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valLong);		break;
+				case SG_DATATYPE_Float : Stream >> valFloat ; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valFloat);		break;
+				case SG_DATATYPE_Double: Stream >> valDouble; if( Stream.is_null() ) pRecord->Set_NoData(iField); else pRecord->Set_Value(iField, valDouble);	break;
+				case SG_DATATYPE_Binary: Stream >> valRaw   ; if( Stream.is_null() ) pRecord->Set_NoData(iField); else
 					{
 						BLOB.Clear();
 
@@ -1033,34 +1029,34 @@ bool CSG_ODBC_Connection::_Table_Load(CSG_Table &Table, const CSG_String &Select
 //---------------------------------------------------------
 bool CSG_ODBC_Connection::Table_Load(CSG_Table &Table, const CSG_String &Table_Name, bool bLOB)
 {
-	return( _Table_Load(Table, CSG_String::Format(SG_T("SELECT * FROM \"%s\""), Table_Name.c_str()), Table_Name, bLOB) );
+	return( _Table_Load(Table, CSG_String::Format("SELECT * FROM \"%s\"", Table_Name.c_str()), Table_Name, bLOB) );
 }
 
 //---------------------------------------------------------
 bool CSG_ODBC_Connection::Table_Load(CSG_Table &Table, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where, const CSG_String &Group, const CSG_String &Having, const CSG_String &Order, bool bDistinct, bool bLOB)
 {
-	CSG_String	Select;
+	CSG_String Select;
 
-	Select.Printf(SG_T("SELECT %s %s FROM %s"), bDistinct ? SG_T("DISTINCT") : SG_T("ALL"), Fields.c_str(), Tables.c_str());
+	Select.Printf("SELECT %s %s FROM %s", bDistinct ? SG_T("DISTINCT") : SG_T("ALL"), Fields.is_Empty() ? SG_T("*") : Fields.c_str(), Tables.c_str());
 
 	if( Where.Length() )
 	{
-		Select	+= SG_T(" WHERE ") + Where;
+		Select += " WHERE " + Where;
 	}
 
 	if( Group.Length() )
 	{
-		Select	+= SG_T(" GROUP BY ") + Group;
+		Select += " GROUP BY " + Group;
 
 		if( Having.Length() )
 		{
-			Select	+= SG_T(" HAVING ") + Having;
+			Select += " HAVING " + Having;
 		}
 	}
 
 	if( Order.Length() )
 	{
-		Select	+= SG_T(" ORDER BY ") + Order;
+		Select += " ORDER BY " + Order;
 	}
 
 	return( _Table_Load(Table, Select, Table.Get_Name(), bLOB) );
@@ -1074,7 +1070,6 @@ bool CSG_ODBC_Connection::Table_Load(CSG_Table &Table, const CSG_String &Tables,
 //---------------------------------------------------------
 bool CSG_ODBC_Connection::Table_Load_BLOBs(CSG_Bytes_Array &BLOBs, const CSG_String &Table_Name, const CSG_String &Field, const CSG_String &Where, const CSG_String &Order)
 {
-	//-----------------------------------------------------
 	if( !is_Connected() )
 	{
 		_Error_Message(_TL("no database connection"));
@@ -1350,31 +1345,29 @@ bool CSG_ODBC_Connections::Del_Connection(CSG_ODBC_Connection *pConnection, bool
 //---------------------------------------------------------
 CSG_Strings CSG_ODBC_Connections::Get_Servers(void)
 {
-	CSG_Strings	Servers;
+	CSG_Strings Servers;
 
-	SQLRETURN	r;
-	SQLSMALLINT	dsnlen, dsclen;
-	SQLTCHAR	dsn[SQL_MAX_DSN_LENGTH + 1], dsc[256];
+	SQLSMALLINT dsnlen, dsclen; SQLTCHAR dsn[SQL_MAX_DSN_LENGTH + 1], dsc[256];
 
-	r	= SQLDataSources(m_hEnv, SQL_FETCH_FIRST,
-			(SQLTCHAR *)dsn, SQL_MAX_DSN_LENGTH + 1, &dsnlen,
-			(SQLTCHAR *)dsc, 256,                    &dsclen
-		);
+	SQLRETURN r = SQLDataSources(m_hEnv, SQL_FETCH_FIRST,
+		(SQLTCHAR *)dsn, SQL_MAX_DSN_LENGTH + 1, &dsnlen,
+		(SQLTCHAR *)dsc, 256,                    &dsclen
+	);
 
 	if( r != SQL_SUCCESS && r != SQL_SUCCESS_WITH_INFO )
 	{
-		SG_UI_Msg_Add_Error(SG_T("Unable to retrieve data source names!"));
+		SG_UI_Msg_Add_Error("Unable to retrieve data source names!");
 	}
 	else
 	{
 		do
 		{
-			Servers	+= CSG_String((const SG_ODBC_CHAR *)dsn);
+			Servers += CSG_String((const SG_ODBC_CHAR *)dsn);
 
-			r	= SQLDataSources(m_hEnv, SQL_FETCH_NEXT,
-					(SQLTCHAR *)dsn, SQL_MAX_DSN_LENGTH + 1, &dsnlen,
-					(SQLTCHAR *)dsc, 256,                    &dsclen
-				);
+			r = SQLDataSources(m_hEnv, SQL_FETCH_NEXT,
+				(SQLTCHAR *)dsn, SQL_MAX_DSN_LENGTH + 1, &dsnlen,
+				(SQLTCHAR *)dsc, 256,                    &dsclen
+			);
 		}
 		while( r == SQL_SUCCESS || r == SQL_SUCCESS_WITH_INFO );
 	}
@@ -1385,7 +1378,7 @@ CSG_Strings CSG_ODBC_Connections::Get_Servers(void)
 //---------------------------------------------------------
 int CSG_ODBC_Connections::Get_Servers(CSG_Strings &Servers)
 {
-	Servers	= Get_Servers();
+	Servers = Get_Servers();
 
 	return( Servers.Get_Count() );
 }
@@ -1393,11 +1386,11 @@ int CSG_ODBC_Connections::Get_Servers(CSG_Strings &Servers)
 //---------------------------------------------------------
 int CSG_ODBC_Connections::Get_Servers(CSG_String &Servers)
 {
-	CSG_Strings		s	= Get_Servers();
+	CSG_Strings s = Get_Servers();
 
 	for(int i=0; i<s.Get_Count(); i++)
 	{
-		Servers	+= s[i] + SG_T("|");
+		Servers += s[i] + "|";
 	}
 
 	return( s.Get_Count() );
@@ -1411,7 +1404,7 @@ int CSG_ODBC_Connections::Get_Servers(CSG_String &Servers)
 //---------------------------------------------------------
 CSG_Strings CSG_ODBC_Connections::Get_Connections(void)
 {
-	CSG_Strings		Connections;
+	CSG_Strings Connections;
 
 	for(int i=0; i<m_nConnections; i++)
 	{
@@ -1424,13 +1417,13 @@ CSG_Strings CSG_ODBC_Connections::Get_Connections(void)
 //---------------------------------------------------------
 int CSG_ODBC_Connections::Get_Connections(CSG_String &Connections)
 {
-	CSG_Strings		s	= Get_Connections();
+	CSG_Strings s = Get_Connections();
 
 	Connections.Clear();
 
 	for(int i=0; i<s.Get_Count(); i++)
 	{
-		Connections	+= CSG_String::Format(SG_T("%s|"), s[i].c_str());
+		Connections += CSG_String::Format("%s|", s[i].c_str());
 	}
 
 	return( s.Get_Count() );
@@ -1446,23 +1439,28 @@ int CSG_ODBC_Connections::Get_Connections(CSG_String &Connections)
 //---------------------------------------------------------
 CSG_ODBC_Tool::CSG_ODBC_Tool(void)
 {
-	Parameters.Add_String(NULL, "ODBC_DSN"  , _TL("DSN"              ), _TL("Data Source Name" ), "")->Set_UseInGUI(false);
-	Parameters.Add_String(NULL, "ODBC_USR"  , _TL("User"             ), _TL("User Name"        ), "")->Set_UseInGUI(false);
-	Parameters.Add_String(NULL, "ODBC_PWD"  , _TL("Password"         ), _TL("Password"         ), "")->Set_UseInGUI(false);
+	if( has_CMD() )
+	{
+		Parameters.Add_String("", "ODBC_DSN"  , _TL("Data Source"), _TL(""), ""             )->Set_UseInGUI(false);
+		Parameters.Add_String("", "ODBC_USR"  , _TL("User"       ), _TL(""), ""             )->Set_UseInGUI(false);
+		Parameters.Add_String("", "ODBC_PWD"  , _TL("Password"   ), _TL(""), "", false, true)->Set_UseInGUI(false);
+	}
+	else
+	{
+		Parameters.Add_Choice("", "CONNECTION", _TL("Connection" ), _TL(""), "");
+	}
 
-	Parameters.Add_Choice(NULL, "CONNECTION", _TL("Server Connection"), _TL("Server Connection"), "")->Set_UseInCMD(false);
-
-	m_pConnection	= NULL;
+	m_pConnection = NULL;
 }
 
 //---------------------------------------------------------
 bool CSG_ODBC_Tool::On_Before_Execution(void)
 {
-	m_pConnection	= NULL;
+	m_pConnection = NULL;
 
-	if( !has_GUI() )
+	if( has_CMD() )
 	{
-		m_pConnection	= SG_ODBC_Get_Connection_Manager().Add_Connection(
+		m_pConnection = SG_ODBC_Get_Connection_Manager().Add_Connection(
 			Parameters("ODBC_DSN")->asString(),
 			Parameters("ODBC_USR")->asString(),
 			Parameters("ODBC_PWD")->asString()
@@ -1480,11 +1478,11 @@ bool CSG_ODBC_Tool::On_Before_Execution(void)
 	}
 	else
 	{
-		CSG_String	Connections;
+		CSG_String Connections;
 
-		int	nConnections	= SG_ODBC_Get_Connection_Manager().Get_Connections(Connections);
+		int nConnections = SG_ODBC_Get_Connection_Manager().Get_Connections(Connections);
 
-		if( nConnections <= 0 )
+		if( nConnections < 1 )
 		{
 			Message_Dlg(
 				_TL("No ODBC connection available!"),
@@ -1496,7 +1494,7 @@ bool CSG_ODBC_Tool::On_Before_Execution(void)
 
 		if( nConnections == 1 )
 		{
-			m_pConnection	= SG_ODBC_Get_Connection_Manager().Get_Connection(0);
+			m_pConnection = SG_ODBC_Get_Connection_Manager().Get_Connection(0);
 		}
 
 		Parameters("CONNECTION")->asChoice()->Set_Items(Connections);
@@ -1504,7 +1502,7 @@ bool CSG_ODBC_Tool::On_Before_Execution(void)
 
 		if( !(m_pConnection = SG_ODBC_Get_Connection_Manager().Get_Connection(Parameters("CONNECTION")->asString())) )
 		{
-			m_pConnection	= SG_ODBC_Get_Connection_Manager().Get_Connection(0);
+			m_pConnection = SG_ODBC_Get_Connection_Manager().Get_Connection(0);
 		}
 
 		On_Parameter_Changed(&Parameters, Parameters("CONNECTION"));
@@ -1516,7 +1514,7 @@ bool CSG_ODBC_Tool::On_Before_Execution(void)
 //---------------------------------------------------------
 bool CSG_ODBC_Tool::On_After_Execution(void)
 {
-	if( !has_GUI() )
+	if( has_CMD() )
 	{
 		SG_ODBC_Get_Connection_Manager().Del_Connection(m_pConnection, true);
 	}
@@ -1527,19 +1525,17 @@ bool CSG_ODBC_Tool::On_After_Execution(void)
 //---------------------------------------------------------
 int CSG_ODBC_Tool::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( has_GUI() && pParameter->Cmp_Identifier("CONNECTION") )
+	if( has_CMD() == false && pParameter->Cmp_Identifier("CONNECTION") )
 	{
-		m_pConnection	= SG_ODBC_Get_Connection_Manager().Get_Connection(pParameter->asString());
+		CSG_ODBC_Connection *pConnection = SG_ODBC_Get_Connection_Manager().Get_Connection(pParameter->asString());
 
-		if( m_pConnection )
-		{
-			On_Connection_Changed(pParameters);
-		}
+		m_pConnection = pConnection;
 
-		return( 1 );
+		On_Connection_Changed(pParameters);
 	}
 
-	return( 0 );
+	//-----------------------------------------------------
+	return( CSG_Tool::On_Parameter_Changed(pParameters, pParameter) );
 }
 
 
@@ -1559,15 +1555,15 @@ bool CSG_ODBC_Tool::Set_Constraints(CSG_Parameters *pParameters, CSG_Table *pTab
 
 	if( pTable )
 	{
-		CSG_Parameter	*pP	= pParameters->Add_Node(NULL, "P", _TL("Primary key)")	, _TL(""));
-		CSG_Parameter	*pN	= pParameters->Add_Node(NULL, "N", _TL("Not Null")		, _TL(""));
-		CSG_Parameter	*pU	= pParameters->Add_Node(NULL, "U", _TL("Unique")		, _TL(""));
+		pParameters->Add_Node("", "P", _TL("Primary key"), _TL(""));
+		pParameters->Add_Node("", "N", _TL("Not Null"   ), _TL(""));
+		pParameters->Add_Node("", "U", _TL("Unique"     ), _TL(""));
 
 		for(int i=0; i<pTable->Get_Field_Count(); i++)
 		{
-			pParameters->Add_Value(pP, CSG_String::Format(SG_T("P%d"), i), pTable->Get_Field_Name(i), _TL(""), PARAMETER_TYPE_Bool, false);
-			pParameters->Add_Value(pN, CSG_String::Format(SG_T("N%d"), i), pTable->Get_Field_Name(i), _TL(""), PARAMETER_TYPE_Bool, false);
-			pParameters->Add_Value(pU, CSG_String::Format(SG_T("U%d"), i), pTable->Get_Field_Name(i), _TL(""), PARAMETER_TYPE_Bool, false);
+			pParameters->Add_Bool("P", CSG_String::Format("P%d", i), pTable->Get_Field_Name(i), _TL(""), false);
+			pParameters->Add_Bool("N", CSG_String::Format("N%d", i), pTable->Get_Field_Name(i), _TL(""), false);
+			pParameters->Add_Bool("U", CSG_String::Format("U%d", i), pTable->Get_Field_Name(i), _TL(""), false);
 		}
 	}
 
@@ -1577,34 +1573,34 @@ bool CSG_ODBC_Tool::Set_Constraints(CSG_Parameters *pParameters, CSG_Table *pTab
 //---------------------------------------------------------
 CSG_Buffer CSG_ODBC_Tool::Get_Constraints(CSG_Parameters *pParameters, CSG_Table *pTable)
 {
-	CSG_Buffer	Flags;
+	CSG_Buffer Flags;
 
 	if( pParameters )
 	{
-		int		nFields	= pTable ? pTable->Get_Field_Count() : (pParameters->Get_Count() - 3) / 3;
+		int nFields = pTable ? pTable->Get_Field_Count() : (pParameters->Get_Count() - 3) / 3;
 
 		if( nFields * 3 + 3 == pParameters->Get_Count() )
 		{
 			for(int i=0; i<nFields; i++)
 			{
-				char	Flag	= 0;
+				char Flag = 0;
 
-				if( pParameters->Get_Parameter(CSG_String::Format(SG_T("P%d"), i))->asBool() )
+				if( pParameters->Get_Parameter(CSG_String::Format("P%d", i))->asBool() )
 				{
-					Flag	|= SG_ODBC_PRIMARY_KEY;
+					Flag |= SG_ODBC_PRIMARY_KEY;
 				}
 
-				if( pParameters->Get_Parameter(CSG_String::Format(SG_T("N%d"), i))->asBool() )
+				if( pParameters->Get_Parameter(CSG_String::Format("N%d", i))->asBool() )
 				{
-					Flag	|= SG_ODBC_NOT_NULL;
+					Flag |= SG_ODBC_NOT_NULL;
 				}
 
-				if( pParameters->Get_Parameter(CSG_String::Format(SG_T("U%d"), i))->asBool() )
+				if( pParameters->Get_Parameter(CSG_String::Format("U%d", i))->asBool() )
 				{
-					Flag	|= SG_ODBC_UNIQUE;
+					Flag |= SG_ODBC_UNIQUE;
 				}
 
-				Flags	+= Flag;
+				Flags += Flag;
 			}
 		}
 	}
