@@ -76,7 +76,7 @@ CGet_Connections::CGet_Connections(void)
 //---------------------------------------------------------
 bool CGet_Connections::On_Execute(void)
 {
-	CSG_Table	*pConnections	= Parameters("CONNECTIONS")->asTable();
+	CSG_Table *pConnections = Parameters("CONNECTIONS")->asTable();
 
 	pConnections->Destroy();
 	pConnections->Set_Name(_TL("PostgreSQL Connections"));
@@ -90,8 +90,8 @@ bool CGet_Connections::On_Execute(void)
 
 	for(int i=0; i<SG_PG_Get_Connection_Manager().Get_Count(); i++)
 	{
-		CSG_PG_Connection	*pConnection = SG_PG_Get_Connection_Manager().Get_Connection(i);
-		CSG_Table_Record	*pRecord     = pConnections->Add_Record();
+		CSG_PG_Connection *pConnection = SG_PG_Get_Connection_Manager().Get_Connection(i);
+		CSG_Table_Record      *pRecord = pConnections->Add_Record();
 
 		pRecord->Set_Value(0, pConnection->Get_Connection());
 		pRecord->Set_Value(1, pConnection->Get_Host      ());
@@ -122,35 +122,11 @@ CGet_Connection::CGet_Connection(void)
 		"Connect to PostgreSQL data source."
 	));
 
-	Parameters.Add_String("",
-		"PG_HOST"	, _TL("Host"),
-		_TL(""),
-		"localhost"
-	);
-
-	Parameters.Add_Int("",
-		"PG_PORT"	, _TL("Port"),
-		_TL(""),
-		5432, 0, true
-	);
-
-	Parameters.Add_String("",
-		"PG_USER"	, _TL("User"),
-		_TL(""),
-		"postgres"
-	);
-
-	Parameters.Add_String("",
-		"PG_PWD"	, _TL("Password"),
-		_TL(""),
-		"postgres", false, true
-	);
-
-	Parameters.Add_String("",
-		"PG_NAME"	, _TL("Database"),
-		_TL(""),
-		""
-	);
+	Parameters.Add_String("", "PG_HOST", _TL("Host"    ), _TL(""), "localhost");
+	Parameters.Add_Int   ("", "PG_PORT", _TL("Port"    ), _TL(""), 5432, 0, true);
+	Parameters.Add_String("", "PG_DB"  , _TL("Database"), _TL(""), "");
+	Parameters.Add_String("", "PG_USER", _TL("User"    ), _TL(""), "postgres");
+	Parameters.Add_String("", "PG_PWD" , _TL("Password"), _TL(""), "postgres", false, true);
 
 	Parameters.Add_Choice("",
 		"PG_LIST"	, _TL("Database"),
@@ -171,41 +147,41 @@ int CGet_Connection::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Param
 		||  pParameter->Cmp_Identifier("PG_USER")
 		||  pParameter->Cmp_Identifier("PG_PWD" ) )
 		{
-			CSG_Table	DBs;
+			CSG_Table DBs;
 
-			CSG_PG_Connection	Connection(
-				pParameters->Get_Parameter("PG_HOST")->asString(),
-				pParameters->Get_Parameter("PG_PORT")->asInt   (),
+			CSG_PG_Connection Connection(
+				(*pParameters)("PG_HOST")->asString(),
+				(*pParameters)("PG_PORT")->asInt   (),
 				"",
-				pParameters->Get_Parameter("PG_USER")->asString(),
-				pParameters->Get_Parameter("PG_PWD" )->asString()
+				(*pParameters)("PG_USER")->asString(),
+				(*pParameters)("PG_PWD" )->asString()
 			);
 
 			if( Connection.is_Connected() && Connection.Execute("SELECT datname FROM pg_database", &DBs) )
 			{
-				CSG_String	List;	DBs.Set_Index(0, TABLE_INDEX_Ascending);
+				CSG_String List; DBs.Set_Index(0, TABLE_INDEX_Ascending);
 
 				for(int i=0; i<DBs.Get_Count(); i++)
 				{
-					List	+= DBs[i].asString(0) + CSG_String("|");
+					List += DBs[i].asString(0) + CSG_String("|");
 				}
 
 				pParameters->Get_Parameter("PG_LIST")->asChoice()->Set_Items(List);
-				pParameters->Get_Parameter("PG_LIST")->Set_Value(pParameters->Get_Parameter("PG_NAME")->asString());
+				pParameters->Set_Parameter("PG_LIST", pParameters->Get_Parameter("PG_DB"  )->asString());
 				pParameters->Set_Enabled  ("PG_LIST",  true);
-				pParameters->Set_Enabled  ("PG_NAME", false);
-				pParameters->Get_Parameter("PG_NAME")->Set_Value(pParameters->Get_Parameter("PG_LIST")->asString());
+				pParameters->Set_Enabled  ("PG_DB"  , false);
+				pParameters->Set_Parameter("PG_DB"  , pParameters->Get_Parameter("PG_LIST")->asString());
 			}
 			else
 			{
 				pParameters->Set_Enabled  ("PG_LIST", false);
-				pParameters->Set_Enabled  ("PG_NAME",  true);
+				pParameters->Set_Enabled  ("PG_DB"  ,  true);
 			}
 		}
 
 		if( pParameter->Cmp_Identifier("PG_LIST") )
 		{
-			pParameters->Get_Parameter("PG_NAME")->Set_Value(pParameter->asString());
+			pParameters->Set_Parameter("PG_DB", pParameter->asString());
 		}
 	}
 
@@ -215,8 +191,8 @@ int CGet_Connection::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Param
 //---------------------------------------------------------
 bool CGet_Connection::On_Execute(void)
 {
-	CSG_String	Connection	= CSG_String::Format("%s [%s:%d]",
-		Parameters("PG_NAME")->asString(),
+	CSG_String Connection = CSG_String::Format("%s [%s:%d]",
+		Parameters("PG_DB"  )->asString(),
 		Parameters("PG_HOST")->asString(),
 		Parameters("PG_PORT")->asInt   ()
 	);
@@ -228,8 +204,8 @@ bool CGet_Connection::On_Execute(void)
 		return( false );
 	}
 
-	CSG_PG_Connection	*pConnection	= SG_PG_Get_Connection_Manager().Add_Connection(
-		Parameters("PG_NAME")->asString(),
+	CSG_PG_Connection *pConnection = SG_PG_Get_Connection_Manager().Add_Connection(
+		Parameters("PG_DB"  )->asString(),
 		Parameters("PG_USER")->asString(),
 		Parameters("PG_PWD" )->asString(),
 		Parameters("PG_HOST")->asString(),
@@ -238,6 +214,11 @@ bool CGet_Connection::On_Execute(void)
 
 	if( pConnection )
 	{
+		if( !has_GUI() )//&& !has_CMD() )
+		{
+			SG_UI_Console_Print_StdOut(CSG_String::Format("%s -> \"%s\"", _TL("PostgreSQL source connected"), Connection.c_str()));
+		}
+
 		Message_Add(Connection + ": " + _TL("PostgreSQL source connected"));
 
 		pConnection->GUI_Update();
@@ -281,7 +262,7 @@ CDel_Connection::CDel_Connection(void)
 //---------------------------------------------------------
 bool CDel_Connection::On_Execute(void)
 {
-	CSG_String	Connection	= Get_Connection()->Get_Connection();
+	CSG_String Connection = Get_Connection()->Get_Connection();
 
 	if( SG_PG_Get_Connection_Manager().Del_Connection(Get_Connection(), Parameters("TRANSACT")->asInt() == 1) )
 	{
@@ -344,9 +325,9 @@ bool CDel_Connections::On_Before_Execution(void)
 //---------------------------------------------------------
 bool CDel_Connections::On_Execute(void)
 {
-	bool	bCommit	= Parameters("TRANSACT")->asInt() == 1;
+	bool bCommit = Parameters("TRANSACT")->asInt() == 1;
 
-	CSG_PG_Connections	&Manager	= SG_PG_Get_Connection_Manager();
+	CSG_PG_Connections &Manager = SG_PG_Get_Connection_Manager();
 
 	for(int i=Manager.Get_Count()-1; i>=0; i--)
 	{
@@ -440,7 +421,7 @@ CTransaction_Stop::CTransaction_Stop(void)
 	Parameters.Add_Choice("",
 		"TRANSACT"	, _TL("Transactions"),
 		_TL(""),
-		CSG_String::Format("%s|%s|",
+		CSG_String::Format("%s|%s",
 			_TL("rollback"),
 			_TL("commit")
 		), 1
@@ -555,9 +536,9 @@ bool CExecute_SQL::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	int  nErrors = 0;
-	int  Output  = Parameters("OUTPUT")->asInt();
-	bool bStop   = Parameters("STOP"  )->asBool();
+	int nErrors = 0;
+	int  Output = Parameters("OUTPUT")->asInt();
+	bool  bStop = Parameters("STOP"  )->asBool();
 
 	CSG_Parameter_Table_List *pTables = Parameters("TABLES")->asTableList();
 
@@ -652,35 +633,11 @@ CDatabase_Create::CDatabase_Create(void)
 		"Creates a new PostgreSQL Database."
 	));
 
-	Parameters.Add_String("",
-		"PG_HOST"	, _TL("Host"),
-		_TL(""),
-		"localhost"
-	);
-
-	Parameters.Add_Int("",
-		"PG_PORT"	, _TL("Port"),
-		_TL(""),
-		5432, 0, true
-	);
-
-	Parameters.Add_String("",
-		"PG_NAME"	, _TL("Database"),
-		_TL(""),
-		"geo_test"
-	);
-
-	Parameters.Add_String("",
-		"PG_USER"	, _TL("User"),
-		_TL(""),
-		"postgres"
-	);
-
-	Parameters.Add_String("",
-		"PG_PWD"	, _TL("Password"),
-		_TL(""),
-		"postgres", false, true
-	);
+	Parameters.Add_String("", "PG_HOST", _TL("Host"    ), _TL(""), "localhost");
+	Parameters.Add_Int   ("", "PG_PORT", _TL("Port"    ), _TL(""), 5432, 0, true);
+	Parameters.Add_String("", "PG_DB"  , _TL("Database"), _TL(""), "dbname");
+	Parameters.Add_String("", "PG_USER", _TL("User"    ), _TL(""), "postgres");
+	Parameters.Add_String("", "PG_PWD" , _TL("Password"), _TL(""), "postgres", false, true);
 }
 
 //---------------------------------------------------------
@@ -688,7 +645,7 @@ bool CDatabase_Create::On_Execute(void)
 {
 	const SG_Char *Host     = Parameters("PG_HOST")->asString();
 	int            Port     = Parameters("PG_PORT")->asInt   ();
-	const SG_Char *Name     = Parameters("PG_NAME")->asString();
+	const SG_Char *Name     = Parameters("PG_DB"  )->asString();
 	const SG_Char *User     = Parameters("PG_USER")->asString();
 	const SG_Char *Password = Parameters("PG_PWD" )->asString();
 
@@ -748,35 +705,11 @@ CDatabase_Destroy::CDatabase_Destroy(void)
 		"Deletes a PostgreSQL Database."
 	));
 
-	Parameters.Add_String("",
-		"PG_HOST"	, _TL("Host"),
-		_TL(""),
-		"localhost"
-	);
-
-	Parameters.Add_Int("",
-		"PG_PORT"	, _TL("Port"),
-		_TL(""),
-		5432, 0, true
-	);
-
-	Parameters.Add_String("",
-		"PG_NAME"	, _TL("Database"),
-		_TL(""),
-		"geo_test"
-	);
-
-	Parameters.Add_String("",
-		"PG_USER"	, _TL("User"),
-		_TL(""),
-		"postgres"
-	);
-
-	Parameters.Add_String("",
-		"PG_PWD"	, _TL("Password"),
-		_TL(""),
-		"postgres", false, true
-	);
+	Parameters.Add_String("", "PG_HOST", _TL("Host"    ), _TL(""), "localhost");
+	Parameters.Add_Int   ("", "PG_PORT", _TL("Port"    ), _TL(""), 5432, 0, true);
+	Parameters.Add_String("", "PG_DB"  , _TL("Database"), _TL(""), "dbname");
+	Parameters.Add_String("", "PG_USER", _TL("User"    ), _TL(""), "postgres");
+	Parameters.Add_String("", "PG_PWD" , _TL("Password"), _TL(""), "postgres", false, true);
 }
 
 //---------------------------------------------------------
@@ -784,7 +717,7 @@ bool CDatabase_Destroy::On_Execute(void)
 {
 	const SG_Char *Host     = Parameters("PG_HOST")->asString();
 	int            Port     = Parameters("PG_PORT")->asInt   ();
-	const SG_Char *Name     = Parameters("PG_NAME")->asString();
+	const SG_Char *Name     = Parameters("PG_DB"  )->asString();
 	const SG_Char *User     = Parameters("PG_USER")->asString();
 	const SG_Char *Password = Parameters("PG_PWD" )->asString();
 
