@@ -68,17 +68,13 @@ CTable_List::CTable_List(void)
 		"Lists all tables of an PostgreSQL data source."
 	));
 
-	Parameters.Add_Table("",
-		"TABLES"	, _TL("Tables"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
+	Parameters.Add_Table("", "TABLES", _TL("Tables"), _TL(""), PARAMETER_OUTPUT);
 }
 
 //---------------------------------------------------------
 bool CTable_List::On_Execute(void)
 {
-	CSG_Table	*pTables	= Parameters("TABLES")->asTable();
+	CSG_Table *pTables = Parameters("TABLES")->asTable();
 
 	pTables->Destroy();
 	pTables->Set_Name(Get_Connection()->Get_Connection() + " [" + _TL("Tables") + "]");
@@ -86,30 +82,35 @@ bool CTable_List::On_Execute(void)
 	pTables->Add_Field(_TL("Table"), SG_DATATYPE_String);
 	pTables->Add_Field(_TL("Type" ), SG_DATATYPE_String);
 
-	CSG_Strings	Tables;
+	CSG_Strings Tables;
 
 	if( Get_Connection()->Get_Tables(Tables) )
 	{
-		CSG_Table	t;
+		bool bGeometry = false, bRaster = false;
+
+		for(int i=0; !(bGeometry && bRaster) && i<Tables.Get_Count(); i++)
+		{
+			if( !bGeometry && !Tables[i].Cmp("geometry_columns") ) { bGeometry = true; }
+			if( !bRaster   && !Tables[i].Cmp("raster_columns"  ) ) { bRaster   = true; }
+		}
 
 		for(int i=0; i<Tables.Get_Count(); i++)
 		{
-			CSG_Table_Record	*pTable	= pTables->Add_Record();
+			CSG_String Name(Tables[i]), Type("TABLE"); CSG_Table t;
 
-			pTable->Set_Value(0, Tables[i]);
+			if( bGeometry    && Get_Connection()->Table_Load(t, "geometry_columns", "type", CSG_String::Format("f_table_name='%s'", Name.c_str())) && t.Get_Count() == 1 )
+			{
+				Type = t[0][0].asString();
+			}
+			else if( bRaster && Get_Connection()->Table_Load(t, "raster_columns"  , "*"   , CSG_String::Format("r_table_name='%s'", Name.c_str())) && t.Get_Count() == 1 )
+			{
+				Type = "RASTER";
+			}
 
-			if( Get_Connection()->Table_Load(t, "geometry_columns", "type", CSG_String::Format("f_table_name='%s'", Tables[i].c_str())) && t.Get_Count() == 1 )
-			{
-				pTable->Set_Value(1, t[0][0].asString());
-			}
-			else if( Get_Connection()->Table_Load(t, "raster_columns", "*", CSG_String::Format("r_table_name='%s'", Tables[i].c_str())) && t.Get_Count() == 1 )
-			{
-				pTable->Set_Value(1, "RASTER");
-			}
-			else
-			{
-				pTable->Set_Value(1, "TABLE");
-			}
+			CSG_Table_Record &Record = *pTables->Add_Record();
+
+			Record.Set_Value(0, Name);
+			Record.Set_Value(1, Type);
 		}
 	}
 
@@ -134,42 +135,40 @@ CTable_Info::CTable_Info(void)
 		"Loads table information from PostgreSQL data source."
 	));
 
-	Parameters.Add_Table("",
-		"TABLE"		, _TL("Field Description"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
+	Parameters.Add_Table ("", "TABLE", _TL("Field Description"), _TL(""), PARAMETER_OUTPUT);
 
-	Parameters.Add_Choice("",
-		"TABLES"	, _TL("Table"),
-		_TL(""),
-		""
-	);
+	if( has_GUI() )
+	{
+		Parameters.Add_Choice("", "DB_TABLE", _TL("Table"), _TL(""), "");
+	}
+	else
+	{
+		Parameters.Add_String("", "DB_TABLE", _TL("Table"), _TL(""), "");
+	}
 
-	Parameters.Add_Bool("",
-		"VERBOSE"	, _TL("Verbose"),
-		_TL(""),
-		false
-	);
+	Parameters.Add_Bool  ("", "VERBOSE", _TL("Verbose"), _TL(""), false);
 }
 
 //---------------------------------------------------------
 void CTable_Info::On_Connection_Changed(CSG_Parameters *pParameters)
 {
-	CSG_Parameter	*pParameter	= pParameters->Get_Parameter("TABLES");
-
-	pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
-	pParameter->Set_Value(pParameter->asString());
+	if( has_GUI() )
+	{
+		CSG_Parameter *pParameter = pParameters->Get_Parameter("DB_TABLE");
+		pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
+		pParameter->Set_Value(pParameter->asString());
+	}
 }
 
 //---------------------------------------------------------
 bool CTable_Info::On_Execute(void)
 {
-	CSG_String	Table	= Parameters("TABLES")->asString();
-	CSG_Table	*pTable	= Parameters("TABLE" )->asTable();
+	CSG_String DB_Table(Parameters("DB_TABLE")->asString());
 
-	pTable->Create(Get_Connection()->Get_Field_Desc(Table, Parameters("VERBOSE")->asBool()));
-	pTable->Set_Name(Table + " [" + _TL("Field Description") + "]");
+	CSG_Table *pTable = Parameters("TABLE" )->asTable();
+
+	pTable->Create(Get_Connection()->Get_Field_Desc(DB_Table, Parameters("VERBOSE")->asBool()));
+	pTable->Set_Name(DB_Table + " [" + _TL("Field Description") + "]");
 
 	return( true );
 }
@@ -192,34 +191,37 @@ CTable_Load::CTable_Load(void)
 		"Imports a table from a PostgreSQL database."
 	));
 
-	Parameters.Add_Table("",
-		"TABLE"		, _TL("Table"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
+	Parameters.Add_Table("", "TABLE", _TL("Table"), _TL(""), PARAMETER_OUTPUT);
 
-	Parameters.Add_Choice("",
-		"TABLES"	, _TL("Tables"),
-		_TL(""),
-		""
-	);
+	if( has_GUI() )
+	{
+		Parameters.Add_Choice("", "DB_TABLE", _TL("Table"), _TL(""), "");
+	}
+	else
+	{
+		Parameters.Add_String("", "DB_TABLE", _TL("Table"), _TL(""), "");
+	}
 }
 
 //---------------------------------------------------------
 void CTable_Load::On_Connection_Changed(CSG_Parameters *pParameters)
 {
-	CSG_Parameter	*pParameter	= pParameters->Get_Parameter("TABLES");
-
-	pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
-	pParameter->Set_Value(pParameter->asString());
+	if( has_GUI() )
+	{
+		CSG_Parameter *pParameter = pParameters->Get_Parameter("DB_TABLE");
+		pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
+		pParameter->Set_Value(pParameter->asString());
+	}
 }
 
 //---------------------------------------------------------
 bool CTable_Load::On_Execute(void)
 {
-	CSG_Table	*pTable	= Parameters("TABLE")->asTable();
+	CSG_String DB_Table(Parameters("DB_TABLE")->asString());
 
-	return( Get_Connection()->Table_Load(*pTable, Parameters("TABLES")->asString()) );
+	CSG_Table *pTable = Parameters("TABLE")->asTable();
+
+	return( Get_Connection()->Table_Load(*pTable, DB_Table) );
 }
 
 
@@ -286,16 +288,16 @@ int CTable_Save::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 //---------------------------------------------------------
 bool CTable_Save::On_Execute(void)
 {
-	bool		bResult	= false;
-	CSG_Table	*pTable	= Parameters("TABLE")->asTable();
-	CSG_String	Name	= Parameters("NAME" )->asString();	if( Name.Length() == 0 )	Name	= pTable->Get_Name();
+	CSG_Table *pTable = Parameters("TABLE")->asTable();
+	CSG_String Name   = Parameters("NAME" )->asString(); if( Name.is_Empty() ) { Name = pTable->Get_Name(); }
 
 	//-----------------------------------------------------
-	CSG_String	SavePoint;
+	bool bResult = false;
 
-	Get_Connection()->Begin(SavePoint = Get_Connection()->is_Transaction() ? "SHAPES_SAVE" : "");
+	CSG_String SavePoint(Get_Connection()->is_Transaction() ? "SHAPES_SAVE" : "");
+
+	Get_Connection()->Begin(SavePoint);
 
-	//-----------------------------------------------------
 	if( Get_Connection()->Table_Exists(Name) )
 	{
 		Message_Fmt("\n%s: %s", _TL("table already exists"), Name.c_str());
@@ -366,26 +368,33 @@ CTable_Drop::CTable_Drop(void)
 		"Deletes a table from a PostgreSQL database."
 	));
 
-	Parameters.Add_Choice("",
-		"TABLES"	, _TL("Tables"),
-		_TL(""),
-		""
-	);
+	if( has_GUI() )
+	{
+		Parameters.Add_Choice("", "DB_TABLE", _TL("Table"), _TL(""), "");
+	}
+	else
+	{
+		Parameters.Add_String("", "DB_TABLE", _TL("Table"), _TL(""), "");
+	}
 }
 
 //---------------------------------------------------------
 void CTable_Drop::On_Connection_Changed(CSG_Parameters *pParameters)
 {
-	CSG_Parameter	*pParameter	= pParameters->Get_Parameter("TABLES");
-
-	pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
-	pParameter->Set_Value(pParameter->asString());
+	if( has_GUI() )
+	{
+		CSG_Parameter *pParameter = pParameters->Get_Parameter("DB_TABLE");
+		pParameter->asChoice()->Set_Items(Get_Connection()->Get_Tables());
+		pParameter->Set_Value(pParameter->asString());
+	}
 }
 
 //---------------------------------------------------------
 bool CTable_Drop::On_Execute(void)
 {
-	if( Get_Connection()->Table_Drop(Parameters("TABLES")->asChoice()->asString()) )
+	CSG_String DB_Table(Parameters("DB_TABLE")->asString());
+
+	if( Get_Connection()->Table_Drop(DB_Table) )
 	{
 		Get_Connection()->GUI_Update();
 
@@ -413,19 +422,15 @@ CTable_Query::CTable_Query(void)
 		"Import a SQL table from a PostgreSQL database."
 	));
 
-	Parameters.Add_Table("",
-		"TABLE"		, _TL("Query Result"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
+	Parameters.Add_Table ("", "TABLE"   , _TL("Query Result"), _TL(""), PARAMETER_OUTPUT);
 
-	Parameters.Add_String("", "TABLES"  , _TL("Tables"  ), _TL(""), "");
-	Parameters.Add_String("", "FIELDS"  , _TL("Fields"  ), _TL(""), "");
-	Parameters.Add_String("", "WHERE"   , _TL("Where"   ), _TL(""), "");
-	Parameters.Add_String("", "GROUP"   , _TL("Group by"), _TL(""), "");
-	Parameters.Add_String("", "HAVING"  , _TL("Having"  ), _TL(""), "");
-	Parameters.Add_String("", "ORDER"   , _TL("Order by"), _TL(""), "");
-	Parameters.Add_Bool  ("", "DISTINCT", _TL("Distinct"), _TL("")    );
+	Parameters.Add_String("", "TABLES"  , _TL("Tables"      ), _TL(""), "");
+	Parameters.Add_String("", "FIELDS"  , _TL("Fields"      ), _TL(""), "");
+	Parameters.Add_String("", "WHERE"   , _TL("Where"       ), _TL(""), "");
+	Parameters.Add_String("", "GROUP"   , _TL("Group by"    ), _TL(""), "");
+	Parameters.Add_String("", "HAVING"  , _TL("Having"      ), _TL(""), "");
+	Parameters.Add_String("", "ORDER"   , _TL("Order by"    ), _TL(""), "");
+	Parameters.Add_Bool  ("", "DISTINCT", _TL("Distinct"    ), _TL("")    );
 }
 
 //---------------------------------------------------------
@@ -461,11 +466,7 @@ CTable_Query_GUI::CTable_Query_GUI(void)
 		"Import a SQL table from a PostgreSQL database."
 	));
 
-	Parameters.Add_Table("",
-		"TABLE"		, _TL("Query Result"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
+	Parameters.Add_Table("", "TABLE", _TL("Query Result"), _TL(""), PARAMETER_OUTPUT);
 
 	Parameters.Add_Parameters("", "TABLES"  , _TL("Tables"  ), _TL("")    );
 	Parameters.Add_Parameters("", "FIELDS"  , _TL("Fields"  ), _TL("")    );
@@ -479,11 +480,11 @@ CTable_Query_GUI::CTable_Query_GUI(void)
 //---------------------------------------------------------
 void CTable_Query_GUI::On_Connection_Changed(CSG_Parameters *pParameters)
 {
-	CSG_Parameters	*pTables	= pParameters->Get_Parameter("TABLES")->asParameters();
+	CSG_Parameters *pTables = pParameters->Get_Parameter("TABLES")->asParameters();
 
 	pTables->Del_Parameters();
 
-	CSG_Strings	Tables;
+	CSG_Strings Tables;
 
 	if( Get_Connection()->Get_Tables(Tables) > 0 )
 	{
@@ -504,24 +505,24 @@ int CTable_Query_GUI::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Para
 {
 	if( pParameter->Cmp_Identifier("TABLES") )
 	{
-		CSG_Parameters	&Tables	= *pParameters->Get_Parameter("TABLES")->asParameters();
-		CSG_Parameters	&Fields	= *pParameters->Get_Parameter("FIELDS")->asParameters();
-		CSG_Parameters	&Group	= *pParameters->Get_Parameter("GROUP" )->asParameters();
+		CSG_Parameters &Tables = *pParameters->Get_Parameter("TABLES")->asParameters();
+		CSG_Parameters &Fields = *pParameters->Get_Parameter("FIELDS")->asParameters();
+		CSG_Parameters &Group  = *pParameters->Get_Parameter("GROUP" )->asParameters();
 
 		for(int i=0; i<Tables.Get_Count(); i++)
 		{
-			CSG_String	Table	= Tables[i].Get_Identifier();
+			CSG_String Table = Tables[i].Get_Identifier();
 
 			if( Tables[i].asBool() && !Fields(Table) )
 			{
-				CSG_Table	Desc	= Get_Connection()->Get_Field_Desc(Table);
+				CSG_Table Desc = Get_Connection()->Get_Field_Desc(Table);
 
-				CSG_Parameter	*pFields	= Fields.Add_Node("", Table, Table, "");
-				CSG_Parameter	*pGroup 	= Group .Add_Node("", Table, Table, "");
+				CSG_Parameter *pFields = Fields.Add_Node("", Table, Table, "");
+				CSG_Parameter *pGroup  = Group .Add_Node("", Table, Table, "");
 
 				for(int j=0; j<Desc.Get_Count(); j++)
 				{
-					CSG_String	ID	= Table + "." + Desc[j].asString(0);
+					CSG_String ID = Table + "." + Desc[j].asString(0);
 
 					Fields.Add_Bool(pFields, ID, Desc[j].asString(0), "");
 					Group .Add_Bool(pGroup , ID, Desc[j].asString(0), "");
@@ -562,11 +563,11 @@ bool CTable_Query_GUI::On_Execute(void)
 //---------------------------------------------------------
 CSG_String CTable_Query_GUI::Get_Selection(const CSG_String &Parameter)
 {
-	CSG_String	s;
+	CSG_String s;
 
 	if( Parameters(Parameter) && Parameters(Parameter)->asParameters() )
 	{
-		CSG_Parameters	&P	= *Parameters(Parameter)->asParameters();
+		CSG_Parameters &P = *Parameters(Parameter)->asParameters();
 
 		for(int i=0; i<P.Get_Count(); i++)
 		{
@@ -574,18 +575,18 @@ CSG_String CTable_Query_GUI::Get_Selection(const CSG_String &Parameter)
 			{
 				if( !s.is_Empty() )
 				{
-					s	+= ",";
+					s += ",";
 				}
 
-				CSG_String	ID	= P[i].Get_Identifier();
+				CSG_String ID = P[i].Get_Identifier();
 
 				if( ID.Find('.') < 0 )	// table
 				{
-					s	+= "\"" + ID + "\"";
+					s += "\"" + ID + "\"";
 				}
 				else					// field
 				{
-					s	+= "\"" + ID.BeforeFirst('.') + "\".\"" + ID.AfterFirst('.') + "\"";
+					s += "\"" + ID.BeforeFirst('.') + "\".\"" + ID.AfterFirst('.') + "\"";
 				}
 			}
 		}
