@@ -105,9 +105,9 @@ CClassify_Grid::CClassify_Grid(void)
 	);
 
 	Parameters.Add_Grid("",
-		"CLASSES"		, _TL("Classes"),
+		"CLASSES"		, _TL("Classification"),
 		_TL(""),
-		PARAMETER_OUTPUT, true, SG_DATATYPE_Short
+		PARAMETER_OUTPUT, true, SG_DATATYPE_Char
 	);
 
 	Parameters.Add_Table("CLASSES",
@@ -164,7 +164,7 @@ CClassify_Grid::CClassify_Grid(void)
 			_TL("none"),
 			SG_T("L1"),
 			SG_T("L2")
-		), 1
+		), 0
 	);
 
 	Parameters.Add_Double("YT_REGUL",
@@ -258,8 +258,6 @@ bool CClassify_Grid::On_Execute(void)
 	CSG_Grid	*pClasses	= Parameters("CLASSES")->asGrid();
 	CSG_Grid	*pProb		= Parameters("PROB"   )->asGrid();
 
-	pClasses->Set_NoData_Value(-1);
-
 	if( !pProb->Get_Range() )
 	{
 		DataObject_Set_Colors(pProb, 11, SG_COLORS_YELLOW_GREEN);
@@ -293,12 +291,16 @@ bool CClassify_Grid::On_Execute(void)
 		return( false );
 	}
 
+	pClasses->Set_NoData_Value(-1);
+	pClasses->Fmt_Name("%s [%s]", _TL("Classification"), _TL("Maximum Entropy"));
+	pProb->Fmt_Name("%s %s [%s]", _TL("Classification"), _TL("Probability"), _TL("Maximum Entropy"));
+
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("prediction"));
 
 	double	minProb	= Parameters("PROB_MIN")->asDouble();
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -515,7 +517,7 @@ bool CClassify_Grid::Get_Training(void)
 			pClass->Set_Value(4,         i );
 		}
 
-		pLUT->asTable()->Set_Record_Count(Classes.Get_Count());
+		pLUT->asTable()->Set_Count(Classes.Get_Count());
 
 		DataObject_Set_Parameter(pClasses, pLUT            );
 		DataObject_Set_Parameter(pClasses, "COLORS_TYPE", 1);	// Color Classification Type: Lookup Table
@@ -756,7 +758,7 @@ bool CClassify_Grid::Get_File(const CSG_String &File)
 			pClass->Set_Value(4, m_YT_Model.get_class_id(Label));
 		}
 
-		pLUT->asTable()->Set_Record_Count(m_YT_Model.num_classes());
+		pLUT->asTable()->Set_Count(m_YT_Model.num_classes());
 
 		DataObject_Set_Parameter(pClasses, pLUT            );
 		DataObject_Set_Parameter(pClasses, "COLORS_TYPE", 1);	// Color Classification Type: Lookup Table
