@@ -12,8 +12,8 @@
 //                                                       //
 //                   TLB_Interface.cpp                   //
 //                                                       //
-//                 Copyright (C) 2009 by                 //
-//                 SAGA User Group Assoc.                //
+//                 Copyright (C) 2023 by                 //
+//                      Olaf Conrad                      //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -21,7 +21,7 @@
 // Geoscientific Analyses'. SAGA is free software; you   //
 // can redistribute it and/or modify it under the terms  //
 // of the GNU General Public License as published by the //
-// Free Software Foundation, either version 2 of the     //
+// Free Software Foundation, either version 2 of the     //	
 // License, or (at your option) any later version.       //
 //                                                       //
 // SAGA is distributed in the hope that it will be       //
@@ -36,12 +36,12 @@
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
-//    e-mail:     author@email.de                        //
+//    e-mail:     oconrad@saga-gis.org                   //
 //                                                       //
-//    contact:    Author                                 //
-//                Sesame Street. 7                       //
-//                12345 Metropolis                       //
-//                Nirwana                                //
+//    contact:    Olaf Conrad                            //
+//                Institute of Geography                 //
+//                University of Hamburg                  //
+//                Germany                                //
 //                                                       //
 ///////////////////////////////////////////////////////////
 
@@ -71,7 +71,7 @@ CSG_String Get_Info(int i)
 		return( _TL("Image processing and analysis tools.") );
 
 	case TLB_INFO_Version:
-		return( SG_T("1.0") );
+		return( "1.0" );
 
 	case TLB_INFO_Menu_Path:
 		return( _TL("Imagery") );
@@ -100,6 +100,11 @@ CSG_String Get_Info(int i)
 #include "sentinel_2_scene_import.h"
 #include "sentinel_3_scene_import.h"
 
+#include "Spectral_Profile.h"
+
+#include "topographic_correction.h"
+#include "clouds_and_shadows.h"
+
 
 //---------------------------------------------------------
 // 4. Allow your tools to be created here...
@@ -108,31 +113,39 @@ CSG_Tool *		Create_Tool(int i)
 {
 	switch( i )
 	{
-	case  0:	return( new CImage_VI_Distance );
-	case  1:	return( new CImage_VI_Slope );
-	case  2:	return( new CEnhanced_VI );
-	case  3:	return( new CTasseled_Cap );
+	case  0: return( new CImage_VI_Distance );
+	case  1: return( new CImage_VI_Slope );
+	case  2: return( new CEnhanced_VI );
+	case  3: return( new CTasseled_Cap );
 
-	case  4:	return( new CPanSharp_IHS );
-	case  5:	return( new CPanSharp_Brovey );
-	case  6:	return( new CPanSharp_CN );
-	case  7:	return( new CPanSharp_PCA );
+	case  4: return( new CPanSharp_IHS );
+	case  5: return( new CPanSharp_Brovey );
+	case  6: return( new CPanSharp_CN );
+	case  7: return( new CPanSharp_PCA );
 
-	case  8:	return( new CLandsat_TOAR );
-	case  9:	return( new CLandsat_ACCA );
-	case 10:	return( new CLandsat_Import );
-	case 14:	return( new CLandsat_Scene_Import );
+	case  8: return( new CLandsat_TOAR );
+	case  9: return( new CLandsat_ACCA );
+	case 10: return( new CLandsat_Import );
+	case 14: return( new CLandsat_Scene_Import );
 
-	case 11:	return( new CTextural_Features );
-	case 12:	return( new CLocal_Statistical_Measures );
-	case 13:	return( new CImage_Quality_Index );
+	case 11: return( new CTextural_Features );
+	case 12: return( new CLocal_Statistical_Measures );
+	case 13: return( new CImage_Quality_Index );
 
-	case 15:	return( new CSentinel_2_Scene_Import );
-	case 16:	return( new CSentinel_3_Scene_Import );
+	case 15: return( new CSentinel_2_Scene_Import );
+	case 16: return( new CSentinel_3_Scene_Import );
+
+	case 17: return( new CSpectral_Profile );
+	case 18: return( new CSpectral_Profile_Interactive );
+
+	case 19: return( new CTopographic_Correction );
+
+	case 20: return( new CDetect_Clouds );
+	case 21: return( new CDetect_CloudShadows );
 
 	//-----------------------------------------------------
-	case 17:	return( NULL );
-	default:	return( TLB_INTERFACE_SKIP_TOOL );
+	case 22: return( NULL );
+	default: return( TLB_INTERFACE_SKIP_TOOL );
 	}
 }
 
