@@ -76,7 +76,6 @@ TSG_Grid_Resampling	Get_Resampling(int Resampling)
 //---------------------------------------------------------
 CPanSharp_IHS::CPanSharp_IHS(void)
 {
-	//-----------------------------------------------------
 	Set_Name		(_TL("IHS Sharpening"));
 
 	Set_Author		("O.Conrad (c) 2011");
@@ -106,14 +105,18 @@ CPanSharp_IHS::CPanSharp_IHS(void)
 		PARAMETER_INPUT, false
 	);
 
-	Parameters.Add_Grid("PAN_SYSTEM", "R_SHARP", _TL("Red"  ), _TL(""), PARAMETER_OUTPUT, false);
-	Parameters.Add_Grid("PAN_SYSTEM", "G_SHARP", _TL("Green"), _TL(""), PARAMETER_OUTPUT, false);
-	Parameters.Add_Grid("PAN_SYSTEM", "B_SHARP", _TL("Blue" ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grid ("PAN_SYSTEM", "R_SHARP", _TL("Red"      ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grid ("PAN_SYSTEM", "G_SHARP", _TL("Green"    ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grid ("PAN_SYSTEM", "B_SHARP", _TL("Blue"     ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grids("PAN_SYSTEM",   "SHARP", _TL("Sharpened"), _TL(""), PARAMETER_OUTPUT, false);
 
-	Parameters.Add_Grid_List("",
-		"SHARPEN"	, _TL("Sharpened Channels"),
+	Parameters.Add_Choice("",
+		"OUTPUT"	, _TL("Output"),
 		_TL(""),
-		PARAMETER_OUTPUT
+		CSG_String::Format("%s|%s",
+			_TL("single grids"),
+			_TL("grid collection")
+		), 1
 	);
 
 	Parameters.Add_Choice("",
@@ -137,6 +140,25 @@ CPanSharp_IHS::CPanSharp_IHS(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+int CPanSharp_IHS::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("OUTPUT") )
+	{
+		pParameters->Set_Enabled("R_SHARP", pParameter->asInt() == 0);
+		pParameters->Set_Enabled("G_SHARP", pParameter->asInt() == 0);
+		pParameters->Set_Enabled("B_SHARP", pParameter->asInt() == 0);
+		pParameters->Set_Enabled(  "SHARP", pParameter->asInt() == 1);
+	}
+
+	return( CSG_Tool_Grid::On_Parameters_Enable(pParameters, pParameter) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -144,43 +166,54 @@ CPanSharp_IHS::CPanSharp_IHS(void)
 //---------------------------------------------------------
 bool CPanSharp_IHS::On_Execute(void)
 {
-	//-----------------------------------------------------
 	TSG_Grid_Resampling	Resampling	= Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	//-----------------------------------------------------
-	int			y;
-
-	CSG_Grid	*pPan	= Parameters("PAN")->asGrid();
+	CSG_Grid *pR, *pG, *pB, *pPan = Parameters("PAN")->asGrid();
 
 	//-----------------------------------------------------
+	if( Parameters("OUTPUT")->asInt() == 0 ) // single grids
+	{
+		pR = Parameters("R_SHARP")->asGrid(); pR->Set_Name(Parameters("R")->asGrid()->Get_Name());
+		pG = Parameters("G_SHARP")->asGrid(); pG->Set_Name(Parameters("G")->asGrid()->Get_Name());
+		pB = Parameters("B_SHARP")->asGrid(); pB->Set_Name(Parameters("B")->asGrid()->Get_Name());
+	}
+	else // grid collection
+	{
+		CSG_Grids *pRGB = Parameters("SHARP")->asGrids();
+
+		pRGB->Create(pPan->Get_System(), 3); pRGB->Set_Name(_TL("IHS Sharpening"));
+		pRGB->Add_Attribute("ID"  , SG_DATATYPE_Int   );
+		pRGB->Add_Attribute("NAME", SG_DATATYPE_String);
+		pRGB->Set_Z_Attribute(1); pRGB->Set_Z_Name_Field(2); pRGB->Del_Attribute(0);
+
+		pR = pRGB->Get_Grid_Ptr(2); pRGB->Get_Attributes(2).Set_Value(0, 3); pRGB->Get_Attributes(2).Set_Value(1, Parameters("R")->asGrid()->Get_Name());
+		pG = pRGB->Get_Grid_Ptr(1); pRGB->Get_Attributes(1).Set_Value(0, 2); pRGB->Get_Attributes(1).Set_Value(1, Parameters("G")->asGrid()->Get_Name());
+		pB = pRGB->Get_Grid_Ptr(0); pRGB->Get_Attributes(0).Set_Value(0, 1); pRGB->Get_Attributes(0).Set_Value(1, Parameters("B")->asGrid()->Get_Name());
+	}
+
 	Process_Set_Text("%s: %s ...", _TL("Resampling"), Parameters("R")->asGrid()->Get_Name());
-	CSG_Grid	*pR	= Parameters("R_SHARP")->asGrid();
 	pR->Assign  (Parameters("R")->asGrid(), Resampling);
-	pR->Set_Name(Parameters("R")->asGrid()->Get_Name());
 
 	Process_Set_Text("%s: %s ...", _TL("Resampling"), Parameters("G")->asGrid()->Get_Name());
-	CSG_Grid	*pG	= Parameters("G_SHARP")->asGrid();
 	pG->Assign  (Parameters("G")->asGrid(), Resampling);
-	pG->Set_Name(Parameters("G")->asGrid()->Get_Name());
 
 	Process_Set_Text("%s: %s ...", _TL("Resampling"), Parameters("B")->asGrid()->Get_Name());
-	CSG_Grid	*pB	= Parameters("B_SHARP")->asGrid();
 	pB->Assign  (Parameters("B")->asGrid(), Resampling);
-	pB->Set_Name(Parameters("B")->asGrid()->Get_Name());
 
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("RGB to IHS"));
 
-	double	rMin	= pR->Get_Min(),	rRange	= pR->Get_Range();
-	double	gMin	= pG->Get_Min(),	gRange	= pG->Get_Range();
-	double	bMin	= pB->Get_Min(),	bRange	= pB->Get_Range();
+	double rMin = pR->Get_Min(), rRange = pR->Get_Range();
+	double gMin = pG->Get_Min(), gRange = pG->Get_Range();
+	double bMin = pB->Get_Min(), bRange = pB->Get_Range();
 
-	for(y=0; y<pPan->Get_NY() && Set_Progress(y, pPan->Get_NY()); y++)
+	for(int y=0; y<pPan->Get_NY() && Set_Progress(y, pPan->Get_NY()); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<pPan->Get_NX(); x++)
 		{
-			bool	bNoData	= true;
+			bool bNoData = true;
 
 			if( pPan->is_NoData(x, y) || pR->is_NoData(x, y) || pG->is_NoData(x, y) || pB->is_NoData(x, y) )
 			{
@@ -190,27 +223,27 @@ bool CPanSharp_IHS::On_Execute(void)
 			}
 			else
 			{
-				double	r	= (pR->asDouble(x, y) - rMin) / rRange;	if( r < 0.0 ) r = 0.0; else if( r > 1.0 ) r = 1.0;
-				double	g	= (pG->asDouble(x, y) - gMin) / gRange;	if( g < 0.0 ) g = 0.0; else if( g > 1.0 ) g = 1.0;
-				double	b	= (pB->asDouble(x, y) - bMin) / bRange;	if( b < 0.0 ) b = 0.0; else if( b > 1.0 ) b = 1.0;
+				double r = (pR->asDouble(x, y) - rMin) / rRange; if( r < 0. ) r = 0.; else if( r > 1. ) r = 1.;
+				double g = (pG->asDouble(x, y) - gMin) / gRange; if( g < 0. ) g = 0.; else if( g > 1. ) g = 1.;
+				double b = (pB->asDouble(x, y) - bMin) / bRange; if( b < 0. ) b = 0.; else if( b > 1. ) b = 1.;
 
-				double	h, s, i	= r + g + b;
+				double h, s, i = r + g + b;
 				
-				if( i <= 0.0 )
+				if( i <= 0. )
 				{
-					h	= 0.0;
-					s	= 0.0;
+					h = 0.;
+					s = 0.;
 				}
 				else
 				{
-					if( r == g && g == b )			{	h	= 0.0;	}
-					else if( b < r && b < g )		{	h	= (g - b) / (i - 3 * b)    ;	}
-					else if( r < g && r < b )		{	h	= (b - r) / (i - 3 * r) + 1;	}
-					else							{	h	= (r - g) / (i - 3 * g) + 2;	}
+					if( r == g && g == b )    { h = 0.; }
+					else if( b < r && b < g ) { h = (g - b) / (i - 3 * b)    ; }
+					else if( r < g && r < b ) { h = (b - r) / (i - 3 * r) + 1; }
+					else                      { h = (r - g) / (i - 3 * g) + 2; }
 
-					if     ( 0.0 <= h && h < 1.0 )	{	s	= (i - 3 * b) / i;	}
-					else if( 1.0 <= h && h < 2.0 )	{	s	= (i - 3 * r) / i;	}
-					else							{	s	= (i - 3 * g) / i;	}
+					if     ( 0. <= h && h < 1. ) { s = (i - 3 * b) / i; }
+					else if( 1. <= h && h < 2. ) { s = (i - 3 * r) / i; }
+					else                         { s = (i - 3 * g) / i; }
 				}
 
 				pR->Set_Value(x, y, i);
@@ -221,54 +254,54 @@ bool CPanSharp_IHS::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	double	Offset_Pan, Offset, Scale;
+	double Offset_Pan, Offset, Scale;
 
 	if( Parameters("PAN_MATCH")->asInt() == 0 )
 	{
-		Offset_Pan	= pPan->Get_Min();
-		Offset		= pR->Get_Min();
-		Scale		= pR->Get_Range() / pPan->Get_Range();
+		Offset_Pan = pPan->Get_Min();
+		Offset     = pR->Get_Min();
+		Scale      = pR->Get_Range() / pPan->Get_Range();
 	}
 	else
 	{
-		Offset_Pan	= pPan->Get_Mean();
-		Offset		= pR->Get_Mean();
-		Scale		= pR->Get_StdDev() / pPan->Get_StdDev();
+		Offset_Pan = pPan->Get_Mean();
+		Offset     = pR->Get_Mean();
+		Scale      = pR->Get_StdDev() / pPan->Get_StdDev();
 	}
 
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("IHS to RGB"));
 
-	for(y=0; y<pPan->Get_NY() && Set_Progress(y, pPan->Get_NY()); y++)
+	for(int y=0; y<pPan->Get_NY() && Set_Progress(y, pPan->Get_NY()); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<pPan->Get_NX(); x++)
 		{
 			if( !pR->is_NoData(x, y) )
 			{
-				double	i	= Offset + Scale * (pPan->asDouble(x, y) - Offset_Pan);
-				double	s	= pG  ->asDouble(x, y);
-				double	h	= pB  ->asDouble(x, y);
+				double i = Offset + Scale * (pPan->asDouble(x, y) - Offset_Pan);
+				double s = pG->asDouble(x, y);
+				double h = pB->asDouble(x, y);
 
-				double	r, g, b;
+				double r, g, b;
 
-				if     ( 0.0 <= h && h < 1.0 )
+				if     ( 0. <= h && h < 1. )
 				{
-					r	= i * (1 + 2 * s - 3 * s * h) / 3;
-					g	= i * (1 -     s + 3 * s * h) / 3;
-					b	= i * (1 -     s            ) / 3;
+					r = i * (1 + 2 * s - 3 * s * h) / 3;
+					g = i * (1 -     s + 3 * s * h) / 3;
+					b = i * (1 -     s            ) / 3;
 				}
-				else if( 1.0 <= h && h < 2.0 )
+				else if( 1. <= h && h < 2. )
 				{
-					r	= i * (1 -     s                  ) / 3;
-					g	= i * (1 + 2 * s - 3 * s * (h - 1)) / 3;
-					b	= i * (1 -     s + 3 * s * (h - 1)) / 3;
+					r = i * (1 -     s                  ) / 3;
+					g = i * (1 + 2 * s - 3 * s * (h - 1)) / 3;
+					b = i * (1 -     s + 3 * s * (h - 1)) / 3;
 				}
 				else
 				{
-					r	= i * (1 -     s + 3 * s * (h - 2)) / 3;
-					g	= i * (1 -     s                  ) / 3;
-					b	= i * (1 + 2 * s - 3 * s * (h - 2)) / 3;
+					r = i * (1 -     s + 3 * s * (h - 2)) / 3;
+					g = i * (1 -     s                  ) / 3;
+					b = i * (1 + 2 * s - 3 * s * (h - 2)) / 3;
 				}
 
 				pR->Set_Value(x, y, rMin + r * rRange);
@@ -292,7 +325,6 @@ bool CPanSharp_IHS::On_Execute(void)
 //---------------------------------------------------------
 CPanSharp_Brovey::CPanSharp_Brovey(void)
 {
-	//-----------------------------------------------------
 	Set_Name		(_TL("Colour Normalized Brovey Sharpening"));
 
 	Set_Author		("O.Conrad (c) 2011");
@@ -322,14 +354,18 @@ CPanSharp_Brovey::CPanSharp_Brovey(void)
 		PARAMETER_INPUT, false
 	);
 
-	Parameters.Add_Grid("PAN_SYSTEM", "R_SHARP", _TL("Red"  ), _TL(""), PARAMETER_OUTPUT, false);
-	Parameters.Add_Grid("PAN_SYSTEM", "G_SHARP", _TL("Green"), _TL(""), PARAMETER_OUTPUT, false);
-	Parameters.Add_Grid("PAN_SYSTEM", "B_SHARP", _TL("Blue" ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grid ("PAN_SYSTEM", "R_SHARP", _TL("Red"      ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grid ("PAN_SYSTEM", "G_SHARP", _TL("Green"    ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grid ("PAN_SYSTEM", "B_SHARP", _TL("Blue"     ), _TL(""), PARAMETER_OUTPUT, false);
+	Parameters.Add_Grids("PAN_SYSTEM",   "SHARP", _TL("Sharpened"), _TL(""), PARAMETER_OUTPUT, false);
 
-	Parameters.Add_Grid_List("",
-		"SHARPEN"	, _TL("Sharpened Channels"),
+	Parameters.Add_Choice("",
+		"OUTPUT"	, _TL("Output"),
 		_TL(""),
-		PARAMETER_OUTPUT
+		CSG_String::Format("%s|%s",
+			_TL("single grids"),
+			_TL("grid collection")
+		), 1
 	);
 
 	Parameters.Add_Choice("",
@@ -344,6 +380,25 @@ CPanSharp_Brovey::CPanSharp_Brovey(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+int CPanSharp_Brovey::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("OUTPUT") )
+	{
+		pParameters->Set_Enabled("R_SHARP", pParameter->asInt() == 0);
+		pParameters->Set_Enabled("G_SHARP", pParameter->asInt() == 0);
+		pParameters->Set_Enabled("B_SHARP", pParameter->asInt() == 0);
+		pParameters->Set_Enabled(  "SHARP", pParameter->asInt() == 1);
+	}
+
+	return( CSG_Tool_Grid::On_Parameters_Enable(pParameters, pParameter) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -351,27 +406,40 @@ CPanSharp_Brovey::CPanSharp_Brovey(void)
 //---------------------------------------------------------
 bool CPanSharp_Brovey::On_Execute(void)
 {
-	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling	= Get_Resampling(Parameters("RESAMPLING")->asInt());
+	TSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	//-----------------------------------------------------
-	CSG_Grid	*pPan	= Parameters("PAN")->asGrid();
+	CSG_Grid *pR, *pG, *pB, *pPan = Parameters("PAN")->asGrid();
 
 	//-----------------------------------------------------
+	if( Parameters("OUTPUT")->asInt() == 0 ) // single grids
+	{
+		pR = Parameters("R_SHARP")->asGrid(); pR->Set_Name(Parameters("R")->asGrid()->Get_Name());
+		pG = Parameters("G_SHARP")->asGrid(); pG->Set_Name(Parameters("G")->asGrid()->Get_Name());
+		pB = Parameters("B_SHARP")->asGrid(); pB->Set_Name(Parameters("B")->asGrid()->Get_Name());
+	}
+	else // grid collection
+	{
+		CSG_Grids *pRGB = Parameters("SHARP")->asGrids();
+
+		pRGB->Create(pPan->Get_System(), 3); pRGB->Set_Name(_TL("Brovey Sharpening"));
+		pRGB->Add_Attribute("ID"  , SG_DATATYPE_Int   );
+		pRGB->Add_Attribute("NAME", SG_DATATYPE_String);
+		pRGB->Set_Z_Attribute(1); pRGB->Set_Z_Name_Field(2); pRGB->Del_Attribute(0);
+
+		pR = pRGB->Get_Grid_Ptr(2); pRGB->Get_Attributes(2).Set_Value(0, 3); pRGB->Get_Attributes(2).Set_Value(1, Parameters("R")->asGrid()->Get_Name());
+		pG = pRGB->Get_Grid_Ptr(1); pRGB->Get_Attributes(1).Set_Value(0, 2); pRGB->Get_Attributes(1).Set_Value(1, Parameters("G")->asGrid()->Get_Name());
+		pB = pRGB->Get_Grid_Ptr(0); pRGB->Get_Attributes(0).Set_Value(0, 1); pRGB->Get_Attributes(0).Set_Value(1, Parameters("B")->asGrid()->Get_Name());
+	}
+
 	Process_Set_Text("%s: %s ...", _TL("Resampling"), Parameters("R")->asGrid()->Get_Name());
-	CSG_Grid	*pR	= Parameters("R_SHARP")->asGrid();
 	pR->Assign  (Parameters("R")->asGrid(), Resampling);
-	pR->Set_Name(Parameters("R")->asGrid()->Get_Name());
 
 	Process_Set_Text("%s: %s ...", _TL("Resampling"), Parameters("G")->asGrid()->Get_Name());
-	CSG_Grid	*pG	= Parameters("G_SHARP")->asGrid();
 	pG->Assign  (Parameters("G")->asGrid(), Resampling);
-	pG->Set_Name(Parameters("G")->asGrid()->Get_Name());
 
 	Process_Set_Text("%s: %s ...", _TL("Resampling"), Parameters("B")->asGrid()->Get_Name());
-	CSG_Grid	*pB	= Parameters("B_SHARP")->asGrid();
 	pB->Assign  (Parameters("B")->asGrid(), Resampling);
-	pB->Set_Name(Parameters("B")->asGrid()->Get_Name());
 
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("Sharpening"));
@@ -383,11 +451,11 @@ bool CPanSharp_Brovey::On_Execute(void)
 		{
 			if( !pPan->is_NoData(x, y) && !pR->is_NoData(x, y) && !pG->is_NoData(x, y) && !pB->is_NoData(x, y) )
 			{
-				double	k	= (pR->asDouble(x, y) + pG->asDouble(x, y) + pB->asDouble(x, y));
+				double k = (pR->asDouble(x, y) + pG->asDouble(x, y) + pB->asDouble(x, y));
 
-				if( k != 0.0 )
+				if( k != 0. )
 				{
-					k	= pPan->asDouble(x, y) / k;
+					k = pPan->asDouble(x, y) / k;
 				}
 
 				pR->Mul_Value(x, y, k);
@@ -417,7 +485,6 @@ bool CPanSharp_Brovey::On_Execute(void)
 //---------------------------------------------------------
 CPanSharp_CN::CPanSharp_CN(void)
 {
-	//-----------------------------------------------------
 	Set_Name		(_TL("Colour Normalized Spectral Sharpening"));
 
 	Set_Author		("O.Conrad (c) 2011");
@@ -455,15 +522,30 @@ CPanSharp_CN::CPanSharp_CN(void)
 	);
 
 	Parameters.Add_Grid_List("",
-		"SHARPEN"	, _TL("Sharpened Channels"),
+		"SINGLES"	, _TL("Sharpened Channels"),
+		_TL(""),
+		PARAMETER_OUTPUT
+	);
+
+	Parameters.Add_Grids("",
+		"COLLECTION", _TL("Sharpened Channels"),
 		_TL(""),
 		PARAMETER_OUTPUT
 	);
 
+	Parameters.Add_Choice("",
+		"OUTPUT"	, _TL("Output"),
+		_TL(""),
+		CSG_String::Format("%s|%s",
+			_TL("single grids"),
+			_TL("grid collection")
+		), 1
+	);
+
 	Parameters.Add_Choice("",
 		"RESAMPLING", _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s",
 			_TL("nearest neighbour"),
 			_TL("bilinear"),
 			_TL("cubic convolution")
@@ -472,6 +554,23 @@ CPanSharp_CN::CPanSharp_CN(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+int CPanSharp_CN::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("OUTPUT") )
+	{
+		pParameters->Set_Enabled("SINGLES"   , pParameter->asInt() == 0);
+		pParameters->Set_Enabled("COLLECTION", pParameter->asInt() == 1);
+	}
+
+	return( CSG_Tool_Grid::On_Parameters_Enable(pParameters, pParameter) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -479,51 +578,73 @@ CPanSharp_CN::CPanSharp_CN(void)
 //---------------------------------------------------------
 bool CPanSharp_CN::On_Execute(void)
 {
-	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling	= Get_Resampling(Parameters("RESAMPLING")->asInt());
+	TSG_Grid_Resampling Resampling = Get_Resampling(Parameters("RESAMPLING")->asInt());
 
 	//-----------------------------------------------------
-	int		i;
+	CSG_Grid *pPan = Parameters("PAN")->asGrid();
 
-	CSG_Grid	*pPan	= Parameters("PAN")->asGrid();
-
-	CSG_Parameter_Grid_List	*pGrids	= Parameters("GRIDS"  )->asGridList();
-	CSG_Parameter_Grid_List	*pSharp	= Parameters("SHARPEN")->asGridList();
+	CSG_Parameter_Grid_List *pGrids = Parameters("GRIDS"  )->asGridList();
+	CSG_Parameter_Grid_List *pSharp = Parameters("SINGLES")->asGridList();
 
 	//-----------------------------------------------------
 	pSharp->Del_Items();
 
-	for(i=0; i<pGrids->Get_Grid_Count(); i++)
+	if( Parameters("OUTPUT")->asInt() == 0 ) // single grids
 	{
-		Process_Set_Text("%s: %s ...", _TL("Resampling"), pGrids->Get_Grid(i)->Get_Name());
+		for(int i=0; i<pGrids->Get_Grid_Count(); i++)
+		{
+			Process_Set_Text("%s: %s ...", _TL("Resampling"), pGrids->Get_Grid(i)->Get_Name());
 
-		CSG_Grid	*pGrid	= SG_Create_Grid(Get_System());
+			CSG_Grid *pGrid = SG_Create_Grid(Get_System());
 
-		pGrid->Set_Name (pGrids->Get_Grid(i)->Get_Name());
-		pGrid->Assign   (pGrids->Get_Grid(i), Resampling);
+			pGrid->Set_Name(pGrids->Get_Grid(i)->Get_Name());
+			pGrid->Assign  (pGrids->Get_Grid(i), Resampling);
 
-		pSharp->Add_Item(pGrid);
+			pSharp->Add_Item(pGrid);
+		}
+	}
+	else // grid collection
+	{
+		CSG_Grids *pCollection = Parameters("COLLECTION")->asGrids();
+
+		pCollection->Create(Get_System(), pGrids->Get_Grid_Count()); pCollection->Set_Name(Get_Name());
+		pCollection->Add_Attribute("ID"  , SG_DATATYPE_Int   );
+		pCollection->Add_Attribute("NAME", SG_DATATYPE_String);
+		pCollection->Set_Z_Attribute(1); pCollection->Set_Z_Name_Field(2); pCollection->Del_Attribute(0);
+
+		for(int i=0; i<pGrids->Get_Grid_Count(); i++)
+		{
+			Process_Set_Text("%s: %s ...", _TL("Resampling"), pGrids->Get_Grid(i)->Get_Name());
+
+			CSG_Grid *pGrid = pCollection->Get_Grid_Ptr(i);
+
+			pCollection->Get_Attributes(i).Set_Value(0, i + 1); pCollection->Get_Attributes(i).Set_Value(1, pGrids->Get_Grid(i)->Get_Name());
+
+			pGrid->Assign(pGrids->Get_Grid(i), Resampling);
+
+			pSharp->Add_Item(pGrid);
+		}
 	}
 
 	//-----------------------------------------------------
 	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
-		#pragma omp parallel for private(i)
+		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
 		{
-			double	Sum	= 0.0;
+			double Sum = 0.;
 
 			if( !pPan->is_NoData(x, y) )
 			{
-				for(i=0; i<pSharp->Get_Grid_Count(); i++)
+				for(int i=0; i<pSharp->Get_Grid_Count(); i++)
 				{
 					if( !pSharp->Get_Grid(i)->is_NoData(x, y) )
 					{
-						Sum	+= pSharp->Get_Grid(i)->asDouble(x, y);
+						Sum += pSharp->Get_Grid(i)->asDouble(x, y);
 					}
 					else
 					{
-						Sum	 = 0.0;
+						Sum = 0.;
 
 						break;
 					}
@@ -532,16 +653,16 @@ bool CPanSharp_CN::On_Execute(void)
 
 			if( Sum )
 			{
-				Sum	= pPan->asDouble(x, y) * pSharp->Get_Grid_Count() / (Sum + pSharp->Get_Grid_Count());
+				Sum = pPan->asDouble(x, y) * pSharp->Get_Grid_Count() / (Sum + pSharp->Get_Grid_Count());
 
-				for(i=0; i<pSharp->Get_Grid_Count(); i++)
+				for(int i=0; i<pSharp->Get_Grid_Count(); i++)
 				{
 					pSharp->Get_Grid(i)->Mul_Value(x, y, Sum);
 				}
 			}
 			else
 			{
-				for(i=0; i<pSharp->Get_Grid_Count(); i++)
+				for(int i=0; i<pSharp->Get_Grid_Count(); i++)
 				{
 					pSharp->Get_Grid(i)->Set_NoData(x, y);
 				}
@@ -550,6 +671,11 @@ bool CPanSharp_CN::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
+	if( Parameters("OUTPUT")->asInt() == 1 ) // grid collection
+	{
+		pSharp->Del_Items();
+	}
+
 	return( true );
 }
 
@@ -563,7 +689,6 @@ bool CPanSharp_CN::On_Execute(void)
 //---------------------------------------------------------
 CPanSharp_PCA::CPanSharp_PCA(void)
 {
-	//-----------------------------------------------------
 	Set_Name		(_TL("Principal Component Based Image Sharpening"));
 
 	Set_Author		("O.Conrad (c) 2011");
@@ -591,11 +716,26 @@ CPanSharp_PCA::CPanSharp_PCA(void)
 	);
 
 	Parameters.Add_Grid_List("",
-		"SHARPEN"	, _TL("Sharpened Channels"),
+		"SINGLES"	, _TL("Sharpened Channels"),
 		_TL(""),
 		PARAMETER_OUTPUT
 	);
 
+	Parameters.Add_Grids("",
+		"COLLECTION", _TL("Sharpened Channels"),
+		_TL(""),
+		PARAMETER_OUTPUT
+	);
+
+	Parameters.Add_Choice("",
+		"OUTPUT"	, _TL("Output"),
+		_TL(""),
+		CSG_String::Format("%s|%s",
+			_TL("single grids"),
+			_TL("grid collection")
+		), 1
+	);
+
 	Parameters.Add_Choice("",
 		"METHOD"	, _TL("Method"),
 		_TL(""),
@@ -603,13 +743,13 @@ CPanSharp_PCA::CPanSharp_PCA(void)
 			_TL("correlation matrix"),
 			_TL("variance-covariance matrix"),
 			_TL("sums-of-squares-and-cross-products matrix")
-		), 1
+		), 2
 	);
 
 	Parameters.Add_Choice("",
 		"RESAMPLING", _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s",
 			_TL("nearest neighbour"),
 			_TL("bilinear"),
 			_TL("cubic convolution")
@@ -633,6 +773,24 @@ CPanSharp_PCA::CPanSharp_PCA(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+int CPanSharp_PCA::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("OUTPUT") )
+	{
+		pParameters->Set_Enabled("SINGLES"   , pParameter->asInt() == 0);
+		pParameters->Set_Enabled("OVERWRITE" , pParameter->asInt() == 0);
+		pParameters->Set_Enabled("COLLECTION", pParameter->asInt() == 1);
+	}
+
+	return( CSG_Tool_Grid::On_Parameters_Enable(pParameters, pParameter) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -732,7 +890,7 @@ bool CPanSharp_PCA::On_Execute(void)
 
 	SG_RUN_TOOL_KEEP_PARMS(bResult, "statistics_grid", 10, Tool_Parms,
 			SG_TOOL_PARAMETER_SET("PCA"  , pPCA)
-		&&	SG_TOOL_PARAMETER_SET("GRIDS", Parameters("SHARPEN"))
+		&&	SG_TOOL_PARAMETER_SET("GRIDS", Parameters("SINGLES"))
 		&&	SG_TOOL_PARAMETER_SET("EIGEN", &Eigen)
 	);
 
@@ -743,29 +901,52 @@ bool CPanSharp_PCA::On_Execute(void)
 		return( false );
 	}
 
-	CSG_Parameter_Grid_List	*pHiRes	= Parameters("SHARPEN")->asGridList();
-	CSG_Parameter_Grid_List	*pLoRes	= Parameters("GRIDS"  )->asGridList();
-	CSG_Parameter_Grid_List	*pGrids	= Tool_Parms("GRIDS"  )->asGridList();
+	//-----------------------------------------------------
+	// collect the results
 
-	if( !Parameters("OVERWRITE")->asBool() )
+	CSG_Parameter_Grid_List *pLoRes = Parameters("GRIDS")->asGridList();
+	CSG_Parameter_Grid_List *pGrids = Tool_Parms("GRIDS")->asGridList();
+
+	if( Parameters("OUTPUT")->asInt() == 0 ) // single grids
 	{
-		pHiRes->Del_Items();
+		CSG_Parameter_Grid_List *pHiRes = Parameters("SINGLES")->asGridList();
+
+		if( !Parameters("OVERWRITE")->asBool() )
+		{
+			pHiRes->Del_Items();
+		}
+
+		for(int i=0; i<pLoRes->Get_Grid_Count() && i<pGrids->Get_Grid_Count(); i++)
+		{
+			if( pHiRes->Get_Grid(i) )
+			{
+				pHiRes->Get_Grid(i)->Assign(pGrids->Get_Grid(i));
+
+				delete(pGrids->Get_Grid(i));
+			}
+			else
+			{
+				pHiRes->Add_Item(pGrids->Get_Grid(i));
+			}
+
+			pHiRes->Get_Grid(i)->Set_Name(pLoRes->Get_Grid(i)->Get_Name());
+		}
 	}
-
-	for(int i=0; i<pLoRes->Get_Grid_Count() && i<pGrids->Get_Grid_Count(); i++)
+	else // grid collection
 	{
-		if( pHiRes->Get_Grid(i) )
-		{
-			pHiRes->Get_Grid(i)->Assign(pGrids->Get_Grid(i));
+		CSG_Grids *pHiRes = Parameters("COLLECTION")->asGrids();
 
-			delete(pGrids->Get_Grid(i));
-		}
-		else
-		{
-			pHiRes->Add_Item(pGrids->Get_Grid(i));
-		}
+		pHiRes->Create(Get_System()); pHiRes->Set_Name(Get_Name());
+		pHiRes->Add_Attribute("ID"  , SG_DATATYPE_Int   );
+		pHiRes->Add_Attribute("NAME", SG_DATATYPE_String);
+		pHiRes->Set_Z_Attribute(1); pHiRes->Set_Z_Name_Field(2); pHiRes->Del_Attribute(0);
 
-		pHiRes->Get_Grid(i)->Set_Name(pLoRes->Get_Grid(i)->Get_Name());
+		for(int i=0; i<pLoRes->Get_Grid_Count() && i<pGrids->Get_Grid_Count(); i++)
+		{
+			pHiRes->Add_Grid(i, pGrids->Get_Grid(i), true);
+			pHiRes->Get_Attributes(i).Set_Value(0, i + 1);
+			pHiRes->Get_Attributes(i).Set_Value(1, pLoRes->Get_Grid(i)->Get_Name());
+		}
 	}
 
 	return( true );
