@@ -157,14 +157,11 @@ CSentinel_2_Scene_Import::CSentinel_2_Scene_Import(void)
 		)
 	);
 
-	Parameters.Add_Grid_List("",
-		"BANDS"			, _TL("Bands"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
+	Parameters.Add_Grid_List("", "BANDS"    , _TL("Spectral Bands" ), _TL(""), PARAMETER_OUTPUT);
+	Parameters.Add_Grid_List("", "BANDS_AUX", _TL("Auxiliary Bands"), _TL(""), PARAMETER_OUTPUT);
 
 	Parameters.Add_Bool("",
-		"MULTI2GRIDS"	, _TL("Multispectral Bands as Grid Collection"),
+		"MULTI2GRIDS"	, _TL("Spectral Bands as Grid Collection"),
 		_TL(""),
 		true
 	);
@@ -179,7 +176,7 @@ CSentinel_2_Scene_Import::CSentinel_2_Scene_Import(void)
 		"REFLECTANCE"	, _TL("Reflectance Values"),
 		_TL(""),
 		CSG_String::Format("%s|%s",
-			_TL("original"),
+			_TL("digital number"),
 			_TL("fraction")
 		), 1
 	);
@@ -195,12 +192,13 @@ CSentinel_2_Scene_Import::CSentinel_2_Scene_Import(void)
 	Parameters.Add_Choice("",
 		"PROJECTION"	, _TL("Coordinate System"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s",
+		CSG_String::Format("%s|%s|%s|%s|%s",
 			_TL("UTM North"),
 			_TL("UTM South"),
 			_TL("Geographic Coordinates"),
-			_TL("Different UTM Zone")
-		), 0
+			_TL("Different UTM Zone"),
+			_TL("original")
+		), 4
 	);
 
 	Parameters.Add_Choice("PROJECTION",
@@ -272,7 +270,7 @@ int CSentinel_2_Scene_Import::On_Parameters_Enable(CSG_Parameters *pParameters,
 	if( pParameter->Cmp_Identifier("METAFILE") )
 	{
 		bool bLevel2 = SG_File_Exists  (pParameter->asString())
-					&& SG_File_Get_Name(pParameter->asString(), false).Find("MTD_MSIL2") == 0;
+		            && SG_File_Get_Name(pParameter->asString(), false).Find("MTD_MSIL2") == 0;
 
 		pParameters->Set_Enabled("LOAD_AOT", bLevel2);
 		pParameters->Set_Enabled("LOAD_WVP", bLevel2);
@@ -281,10 +279,10 @@ int CSentinel_2_Scene_Import::On_Parameters_Enable(CSG_Parameters *pParameters,
 
 	if( pParameter->Cmp_Identifier("PROJECTION") )
 	{
-		pParameters->Set_Enabled("RESAMPLING", pParameter->asInt() >= 2);
+		pParameters->Set_Enabled("RESAMPLING", pParameter->asInt() == 2 || pParameter->asInt() == 3);
 		pParameters->Set_Enabled("UTM_ZONE"  , pParameter->asInt() == 3);
 		pParameters->Set_Enabled("UTM_SOUTH" , pParameter->asInt() == 3);
-		pParameters->Set_Enabled("RESOLUTION", pParameter->asInt() <= 1);
+		pParameters->Set_Enabled("RESOLUTION", pParameter->asInt() != 2 && pParameter->asInt() != 3);
 	}
 
 	if(	pParameter->Cmp_Identifier("EXTENT") )
@@ -323,7 +321,7 @@ bool CSentinel_2_Scene_Import::On_Execute(void)
 	//-----------------------------------------------------
 	CSG_String Path = SG_File_Get_Path(Parameters("METAFILE")->asString());
 
-	bool bLevel2  = SG_File_Get_Name(Path, false).Find("MTD_MSIL2") == 0;
+	bool bLevel2  = SG_File_Get_Name(Parameters("METAFILE")->asString(), false).Find("MTD_MSIL2") == 0;
 
 	bool bLoadTCI = Parameters("LOAD_TCI") && Parameters("LOAD_TCI")->asBool();
 	bool bLoadAOT = Parameters("LOAD_AOT") && Parameters("LOAD_AOT")->asBool() && bLevel2;
@@ -331,14 +329,15 @@ bool CSentinel_2_Scene_Import::On_Execute(void)
 	bool bLoadSCL = Parameters("LOAD_SCL") && Parameters("LOAD_SCL")->asBool() && bLevel2;
 	bool bLoad60m = Parameters("LOAD_60M") && Parameters("LOAD_60M")->asBool();
 
-	int Resolution = Parameters("PROJECTION")->asInt() <= 1 ? Parameters("RESOLUTION")->asInt() : 0;
+	int Resolution = Parameters("PROJECTION")->asInt() != 2 && Parameters("PROJECTION")->asInt() != 3 ? Parameters("RESOLUTION")->asInt() : 0;
 
 	bool bMultiGrids = Parameters("MULTI2GRIDS")->asBool();
 
 	CSG_Table Info_Bands(Get_Info_Bands());
 
 	//-----------------------------------------------------
-	Parameters("BANDS")->asGridList()->Del_Items();
+	Parameters("BANDS"    )->asGridList()->Del_Items();
+	Parameters("BANDS_AUX")->asGridList()->Del_Items();
 
 	CSG_Grids *pBands[2]; pBands[0] = pBands[1] = NULL; CSG_Grid *pSCL = NULL;
 
@@ -411,7 +410,14 @@ bool CSentinel_2_Scene_Import::On_Execute(void)
 				pSCL = pBand;
 			}
 
-			Parameters("BANDS")->asGridList()->Add_Item(pBand);
+			if( BAND_IS_10m(Band) || BAND_IS_20m(Band) )
+			{
+				Parameters("BANDS"    )->asGridList()->Add_Item(pBand);
+			}
+			else
+			{
+				Parameters("BANDS_AUX")->asGridList()->Add_Item(pBand);
+			}
 		}
 	}
 
@@ -424,12 +430,13 @@ bool CSentinel_2_Scene_Import::On_Execute(void)
 		{
 			pBands[i]->Fmt_Name("S2_%s_%dm", Date.c_str(), i == 0 ? 10 : 20);
 			pBands[i]->Get_MetaData().Add_Child(Info_General)->Set_Name("SENTINEL-2");
+			pBands[i]->Get_MetaData().Add_Child(Info_Image  )->Set_Name("BANDS");
 			pBands[i]->Set_Description(Info_General.asText());
 			pBands[i]->Set_Z_Attribute (INFO_FIELD_WAVE);
 			pBands[i]->Set_Z_Name_Field(INFO_FIELD_NAME);
 			pBands[i]->Set_Scaling(Scaling, Offset);
 
-			DataObject_Add(pBands[i], true);
+			DataObject_Add(pBands[i]);
 		}
 	}
 
@@ -502,6 +509,11 @@ bool CSentinel_2_Scene_Import::Get_Scaling(CSG_MetaData &Image, int Band, double
 		{
 			Scaling = 1. / Scaling;
 		}
+		else if( Image("QUANTIFICATION_VALUES_LIST") && Image["QUANTIFICATION_VALUES_LIST"]("BOA_QUANTIFICATION_VALUE")
+		&&       Image["QUANTIFICATION_VALUES_LIST"].Get_Content("BOA_QUANTIFICATION_VALUE", Scaling) && Scaling != 0. )
+		{
+			Scaling = 1. / Scaling;
+		}
 		else
 		{
 			Scaling = 1. / 10000.;
@@ -513,6 +525,11 @@ bool CSentinel_2_Scene_Import::Get_Scaling(CSG_MetaData &Image, int Band, double
 	{
 		Offset *= Scaling;
 	}
+	else if( Image("BOA_ADD_OFFSET_VALUES_LIST") && Image["BOA_ADD_OFFSET_VALUES_LIST"].Get_Children_Count() == 13
+	&&       Image["BOA_ADD_OFFSET_VALUES_LIST"][Band].Get_Content().asDouble(Offset) )
+	{
+		Offset *= Scaling;
+	}
 
 	return( true );
 }
@@ -577,6 +594,12 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 		// undefined coordinate system, nothing to do be further done...
 	}
 
+	//-----------------------------------------------------
+	else if( Parameters("PROJECTION")->asInt() >= 4 ) // keep as it is provided
+	{
+		// nothing to do be further done...
+	}
+
 	//-----------------------------------------------------
 	else if( Parameters("PROJECTION")->asInt() <= 1 ) // UTM North or South
 	{
@@ -625,7 +648,7 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 			if( pTool->Set_Parameter("CRS_PROJ4" , SG_T("+proj=longlat +ellps=WGS84 +datum=WGS84"))
 			&&  pTool->Set_Parameter("SOURCE"    , pBand)
 			&&  pTool->Set_Parameter("RESAMPLING", Parameters("RESAMPLING"))
-			&&  pTool->Set_Parameter("KEEP_TYPE" , true)
+		//	&&  pTool->Set_Parameter("DATA_TYPE" , 10) // "Preserve" => is already default!
 			&&  pTool->Execute() )
 			{
 				delete(pBand);
@@ -658,7 +681,7 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 				if( pTool->Set_Parameter("CRS_PROJ4"       , Projection.Get_Proj4())
 				&&  pTool->Set_Parameter("SOURCE"          , pBand)
 				&&  pTool->Set_Parameter("RESAMPLING"      , Parameters("RESAMPLING"))
-				&&  pTool->Set_Parameter("KEEP_TYPE"       , true)
+			//	&&  pTool->Set_Parameter("DATA_TYPE"       , 10) // "Preserve" => is already default!
 				&&  pTool->Set_Parameter("TARGET_USER_SIZE", pBand->Get_Cellsize())
 				&&  pTool->Execute() )
 				{
@@ -735,6 +758,22 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Grid(const CSG_String &File)
 //---------------------------------------------------------
 bool CSentinel_2_Scene_Import::Load_Classification(CSG_Grid *pGrid, const CSG_String &File)
 {
+	const int Colors[] = {
+		SG_GET_RGB(255, 255, 255), //  0 NODATA
+		SG_GET_RGB(255,   0,   0), //  1 SATURATED DEFECTIVE
+		SG_GET_RGB(128,   0,   0), //  2 DARK FEATURE SHADOW
+		SG_GET_RGB(162,   0, 162), //  3 CLOUD SHADOW
+		SG_GET_RGB(  0, 128,   0), //  4 VEGETATION
+		SG_GET_RGB(255, 255,   0), //  5 NOT VEGETATED
+		SG_GET_RGB(  0,   0, 255), //  6 WATER
+		SG_GET_RGB(222, 222, 222), //  7 UNCLASSIFIED
+		SG_GET_RGB(255,   0, 255), //  8 CLOUD MEDIUM PROBA
+		SG_GET_RGB(228,   0, 192), //  9 CLOUD HIGH PROBA
+		SG_GET_RGB(255, 192, 255), // 10 THIN CIRRUS
+		SG_GET_RGB(128, 255, 255)  // 11 SNOW ICE
+	};
+
+	//-----------------------------------------------------
 	CSG_MetaData Metadata;
 
 	if( !Metadata.Load(File)
@@ -766,7 +805,7 @@ bool CSentinel_2_Scene_Import::Load_Classification(CSG_Grid *pGrid, const CSG_St
 
 			CSG_Table_Record &Class = *LUT.Add_Record();
 
-			Class.Set_Value(0, SG_Color_Get_Random());
+			Class.Set_Value(0, Colors[i % 12]);
 			Class.Set_Value(1, Name);
 			Class.Set_Value(3, Index);
 			Class.Set_Value(4, Index);
