@@ -207,7 +207,7 @@ bool CSentinel_3_Scene_Import::On_Execute(void)
 
 	if( !pLon || !pLat )
 	{
-		m_Data.Delete_All();
+		m_Data.Delete();
 
 		return( false );
 	}
@@ -370,7 +370,7 @@ bool CSentinel_3_Scene_Import::Georeference(CSG_Grid *pLon, CSG_Grid *pLat, CSG_
 	||  !pTool->Set_Parameter("GRID_Y"           , pLat  )
 	||  !pTool->Set_Parameter("GRIDS"            , pBands)
 	||  !pTool->Set_Parameter("BYTEWISE"         , false )
-	||  !pTool->Set_Parameter("KEEP_TYPE"        , true  )
+//	||  !pTool->Set_Parameter("DATA_TYPE"        , 10    ) // "Preserve" => is already default!
 	||  !pTool->Set_Parameter("RESAMPLING"       , 3     ) // B-Spline Interpolation
 	||  !pTool->Set_Parameter("TARGET_DEFINITION", 0     ) // user defined
 	||  !pTool->Set_Parameter("TARGET_USER_XMIN" , pLon->Get_Min())
@@ -384,7 +384,7 @@ bool CSentinel_3_Scene_Import::Georeference(CSG_Grid *pLon, CSG_Grid *pLat, CSG_
 
 		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
-		m_Data.Delete_All();
+		m_Data.Delete();
 
 		SG_UI_Msg_Lock(false);
 
@@ -394,7 +394,7 @@ bool CSentinel_3_Scene_Import::Georeference(CSG_Grid *pLon, CSG_Grid *pLat, CSG_
 	//-----------------------------------------------------
 	CSG_Parameter_Grid_List *pOutput = pTool->Get_Parameter("OUTPUT")->asGridList();
 
-	pBands = Parameters("BANDS")->asGridList();
+	pBands = Parameters("BANDS")->asGridList(); pBands->Del_Items();
 
 	for(int i=0; i<pOutput->Get_Grid_Count(); i++)
 	{
@@ -408,7 +408,7 @@ bool CSentinel_3_Scene_Import::Georeference(CSG_Grid *pLon, CSG_Grid *pLat, CSG_
 	//-----------------------------------------------------
 	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
-	m_Data.Delete_All();
+	m_Data.Delete();
 
 	SG_UI_Msg_Lock(false);
 
