@@ -124,6 +124,13 @@ GDALDriverH CSG_GDAL_Drivers::Get_Driver(int Index) const
 }
 
 //---------------------------------------------------------
+CSG_String CSG_GDAL_Drivers::Get_Name(const CSG_String &Name) const
+{
+	const char	*s	= GDALGetMetadataItem(Get_Driver(Name), GDAL_DMD_LONGNAME, "");
+
+	return( s ? s : "" );
+}
+
 CSG_String CSG_GDAL_Drivers::Get_Name(int Index) const
 {
 	const char	*s	= GDALGetMetadataItem(Get_Driver(Index), GDAL_DMD_LONGNAME, "");
@@ -132,6 +139,13 @@ CSG_String CSG_GDAL_Drivers::Get_Name(int Index) const
 }
 
 //---------------------------------------------------------
+CSG_String CSG_GDAL_Drivers::Get_Description(const CSG_String &Name) const
+{
+	const char	*s	= GDALGetDescription(Get_Driver(Name));
+
+	return( s ? s : "" );
+}
+
 CSG_String CSG_GDAL_Drivers::Get_Description(int Index) const
 {
 	const char	*s	= GDALGetDescription(Get_Driver(Index));
@@ -140,6 +154,13 @@ CSG_String CSG_GDAL_Drivers::Get_Description(int Index) const
 }
 
 //---------------------------------------------------------
+CSG_String CSG_GDAL_Drivers::Get_Extension(const CSG_String &Name) const
+{
+	const char	*s	= GDALGetMetadataItem(Get_Driver(Name), GDAL_DMD_EXTENSION, "");
+
+	return( s ? s : "" );
+}
+
 CSG_String CSG_GDAL_Drivers::Get_Extension(int Index) const
 {
 	const char	*s	= GDALGetMetadataItem(Get_Driver(Index), GDAL_DMD_EXTENSION, "");
@@ -199,7 +220,7 @@ int CSG_GDAL_Drivers::Get_GDAL_Type(TSG_Data_Type Type)
 	{
 	case SG_DATATYPE_Bit   :	return( GDT_Byte    );	// Eight bit unsigned integer
 	case SG_DATATYPE_Byte  :	return( GDT_Byte    );	// Eight bit unsigned integer
-	case SG_DATATYPE_Char  :	return( GDT_Byte    );	// Eight bit unsigned integer
+	case SG_DATATYPE_Char  :	return( GDT_Int16   );	// Use sixteen bit signed integer as GDAL has no eight bit signed integer
 	case SG_DATATYPE_Word  :	return( GDT_UInt16  );	// Sixteen bit unsigned integer
 	case SG_DATATYPE_Short :	return( GDT_Int16   );	// Sixteen bit signed integer
 	case SG_DATATYPE_DWord :	return( GDT_UInt32  );	// Thirty two bit unsigned integer
@@ -1069,21 +1090,21 @@ bool CSG_GDAL_DataSet::Write(int i, CSG_Grid *pGrid, double noDataValue)
 		return( false );
 	}
 
-	GDALRasterBandH	pBand	= GDALGetRasterBand(m_pDataSet, i + 1);
+	GDALRasterBandH pBand = GDALGetRasterBand(m_pDataSet, i + 1);
 
 	//-----------------------------------------------------
-	CPLErr	Error	= CE_None;
+	CPLErr Error  = CE_None;
 
-	double	*zLine	= (double *)SG_Malloc(Get_NX() * sizeof(double));
+	double *zLine = (double *)SG_Malloc(Get_NX() * sizeof(double));
 
 	for(int y=0, yy=Get_NY()-1; Error==CE_None && y<Get_NY() && SG_UI_Process_Set_Progress(y, Get_NY()); y++, yy--)
 	{
 		for(int x=0; x<Get_NX(); x++)
 		{
-			zLine[x]	= pGrid->is_NoData(x, yy) ? noDataValue : pGrid->asDouble(x, yy);
+			zLine[x] = pGrid->is_NoData(x, yy) ? noDataValue : pGrid->asDouble(x, yy, false);
 		}
 
-		Error	= GDALRasterIO(pBand, GF_Write, 0, y, Get_NX(), 1, zLine, Get_NX(), 1, GDT_Float64, 0, 0);
+		Error = GDALRasterIO(pBand, GF_Write, 0, y, Get_NX(), 1, zLine, Get_NX(), 1, GDT_Float64, 0, 0);
 	}
 
 	SG_Free(zLine);
