@@ -983,10 +983,10 @@ bool CSG_OGR_DataSet::Write(CSG_Shapes *pShapes, const CSG_String &CreationOptio
 #endif
 
 	//-----------------------------------------------------
-	for(int iShape=0; iShape<pShapes->Get_Count() && SG_UI_Process_Set_Progress(iShape, pShapes->Get_Count()); iShape++)
+	for(sLong iShape=0; iShape<pShapes->Get_Count() && SG_UI_Process_Set_Progress(iShape, pShapes->Get_Count()); iShape++)
 	{
-		CSG_Shape	*pShape		= pShapes->Get_Shape(iShape);
-		OGRFeatureH pFeature	= OGR_F_Create(OGR_L_GetLayerDefn(pLayer));
+		CSG_Shape   *pShape  = pShapes->Get_Shape(iShape);
+		OGRFeatureH pFeature = OGR_F_Create(OGR_L_GetLayerDefn(pLayer));
 
 		if( _Write_Geometry(pShape, pFeature, pShapes->Get_Vertex_Type() != SG_VERTEX_TYPE_XY) )
 		{
@@ -1001,7 +1001,7 @@ bool CSG_OGR_DataSet::Write(CSG_Shapes *pShapes, const CSG_String &CreationOptio
 					break;
 
 				case SG_DATATYPE_String: default: {
-					CSG_Buffer	s(CSG_String(pShape->asString(iField)).to_UTF8());	s	+= '\0';
+					CSG_Buffer	s(CSG_String(pShape->asString(iField)).to_UTF8());
 
 					OGR_F_SetFieldString (pFeature, iField, s.Get_Data());
 				}	break;
@@ -1043,7 +1043,7 @@ bool CSG_OGR_DataSet::_Write_Geometry(CSG_Shape *pShape, OGRFeatureH pFeature, b
 	//-----------------------------------------------------
 	case SHAPE_TYPE_Point:
 		{
-			TSG_Point	p	= pShape->Get_Point(0);
+			TSG_Point	p	= pShape->Get_Point();
 
 			OGRGeometryH	Point	= OGR_G_CreateGeometry(wkbPoint);
 
