@@ -199,12 +199,6 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 
 			SG_Free(Line);
 		}
-		else
-		{
-			delete(pGrid);
-
-			pGrid	= NULL;
-		}
 	}
 
 	//-----------------------------------------------------
@@ -240,8 +234,6 @@ bool CESRI_ArcInfo_Import::On_Execute(void)
 
 		pGrid->Get_Projection().Load(SG_File_Make_Path("", Parameters("FILE")->asString(), "prj"));
 
-		Parameters("GRID")->Set_Value(pGrid);
-
 		return( true );
 	}
 
@@ -358,13 +350,17 @@ CSG_Grid * CESRI_ArcInfo_Import::Read_Header(CSG_File &Stream, TSG_Data_Type Dat
 	double	NoData; Read_Header_Value(Stream, HDR_NODATA, NoData = -9999.);
 
 	//-------------------------------------------------
-	CSG_Grid	*pGrid	= SG_Create_Grid(Datatype, NX, NY, Cellsize, xMin, yMin);
-
-	if( pGrid )
+	CSG_Grid *pGrid = Parameters("GRID")->asGrid();
+	
+	if( !pGrid )
 	{
-		pGrid->Set_NoData_Value(NoData);
+		Parameters("GRID")->Set_Value(pGrid = SG_Create_Grid());
 	}
 
+	pGrid->Create(Datatype, NX, NY, Cellsize, xMin, yMin);
+
+	pGrid->Set_NoData_Value(NoData);
+
 	return( pGrid );
 }
 
