@@ -87,7 +87,7 @@ CPointCloud_Get_Grid_SPCVF_Base::~CPointCloud_Get_Grid_SPCVF_Base(void)
 
 
 //---------------------------------------------------------
-void CPointCloud_Get_Grid_SPCVF_Base::Initialise(int iOutputs, CSG_Rect AOI, CSG_Shapes *pShapes, int iFieldName, bool bMultiple, bool bAddOverlap, double dOverlap,
+void CPointCloud_Get_Grid_SPCVF_Base::Initialise(sLong iOutputs, CSG_Rect AOI, CSG_Shapes *pShapes, int iFieldName, bool bMultiple, bool bAddOverlap, double dOverlap,
 												 CSG_String sFileName, CSG_Parameter_File_Name *pFilePath, CSG_Parameter_Grid_List *pGridList, double dCellsize,
 												 bool bFitToCells, int iMethod, bool bConstrain, int iField, double dMinAttrRange, double dMaxAttrRange)
 {
@@ -209,15 +209,15 @@ bool CPointCloud_Get_Grid_SPCVF_Base::Get_Subset(int iFieldToGrid)
 
 
 	//-----------------------------------------------------
-	int				iDatasets = 0;
+	sLong			iDatasets = 0;
 	CSG_Grid		*pGrid = NULL;
 	double			dPoints = 0.0;
 
-	for(int iAOI=0; iAOI<m_iOutputs; iAOI++)
+	for(sLong iAOI=0; iAOI<m_iOutputs; iAOI++)
 	{
 		if( m_iOutputs > 1 )
 		{
-			SG_UI_Process_Set_Text(CSG_String::Format("%s %d...", _TL("processing AOI"), iAOI + 1));
+			SG_UI_Process_Set_Text(CSG_String::Format("%s %lld...", _TL("processing AOI"), iAOI + 1));
 		}
 		else
 		{
@@ -326,7 +326,7 @@ bool CPointCloud_Get_Grid_SPCVF_Base::Get_Subset(int iFieldToGrid)
 
 			bool bFound = false;
 
-			for(int iPoint=0; iPoint<pPC->Get_Count(); iPoint++)
+			for(sLong iPoint=0; iPoint<pPC->Get_Count(); iPoint++)
 			{
 				if( m_AOI.Get_XMin() <= pPC->Get_X(iPoint) && pPC->Get_X(iPoint) < m_AOI.Get_XMax() &&
 					m_AOI.Get_YMin() <= pPC->Get_Y(iPoint) && pPC->Get_Y(iPoint) < m_AOI.Get_YMax() )
@@ -347,22 +347,23 @@ bool CPointCloud_Get_Grid_SPCVF_Base::Get_Subset(int iFieldToGrid)
 						}
 					}
 
-					if( System.Get_World_to_Grid(x, y, pPC->Get_X(iPoint), pPC->Get_Y(iPoint)) )
+					if( pGrid && System.Get_World_to_Grid(x, y, pPC->Get_X(iPoint), pPC->Get_Y(iPoint)) )
 					{
 						switch( m_iMethod )
 						{
 						default:
-						case 0:		if( pGrid->is_NoData(x, y) || pGrid->asDouble(x, y) > pPC->Get_Value(iPoint, iFieldToGrid) )
-									{
-										pGrid->Set_Value(x, y, pPC->Get_Value(iPoint, iFieldToGrid));
-									}
-									break;
+							if( pGrid->is_NoData(x, y) || pGrid->asDouble(x, y) > pPC->Get_Value(iPoint, iFieldToGrid) )
+							{
+								pGrid->Set_Value(x, y, pPC->Get_Value(iPoint, iFieldToGrid));
+							}
+							break;
 
-						case 1:		if( pGrid->is_NoData(x, y) || pGrid->asDouble(x, y) < pPC->Get_Value(iPoint, iFieldToGrid) )
-									{
-										pGrid->Set_Value(x, y, pPC->Get_Value(iPoint, iFieldToGrid));
-									}
-									break;
+						case 1:
+							if( pGrid->is_NoData(x, y) || pGrid->asDouble(x, y) < pPC->Get_Value(iPoint, iFieldToGrid) )
+							{
+								pGrid->Set_Value(x, y, pPC->Get_Value(iPoint, iFieldToGrid));
+							}
+							break;
 						}
 
 						bFound = true;
@@ -416,7 +417,7 @@ bool CPointCloud_Get_Grid_SPCVF_Base::Get_Subset(int iFieldToGrid)
 
 
 //---------------------------------------------------------
-void CPointCloud_Get_Grid_SPCVF_Base::Write_Subset(CSG_Grid *pGrid, int iAOI, int iDatasets, double dPoints)
+void CPointCloud_Get_Grid_SPCVF_Base::Write_Subset(CSG_Grid *pGrid, sLong iAOI, sLong iDatasets, double dPoints)
 {
 	CSG_String	sPath = SG_T("");
 
@@ -442,7 +443,7 @@ void CPointCloud_Get_Grid_SPCVF_Base::Write_Subset(CSG_Grid *pGrid, int iAOI, in
 		pGrid->Fmt_Name("%spc_subset_%s", sPath.c_str(), SG_File_Get_Name(m_sFileName, false).c_str());
 	}
 
-	SG_UI_Msg_Add(CSG_String::Format(_TL("%.0f points from %d dataset(s) written to output grid %s."), dPoints, iDatasets, pGrid->Get_Name()), true);
+	SG_UI_Msg_Add(CSG_String::Format(_TL("%.0f points from %lld dataset(s) written to output grid %s."), dPoints, iDatasets, pGrid->Get_Name()), true);
 
 	if( m_pFilePath == NULL )
 	{
@@ -640,7 +641,7 @@ bool CPointCloud_Get_Grid_SPCVF::On_Execute(void)
 	bool			bAddOverlap;
 	double			dOverlap;
 	bool			bMultiple;
-	int				iOutputs = 1;
+	sLong			iOutputs = 1;
 	CSG_Rect		AOI;
 
 
@@ -852,20 +853,18 @@ bool CPointCloud_Get_Grid_SPCVF_Interactive::On_Execute_Position(CSG_Point ptWor
 {
 	switch( Mode )
 	{
-  default:
-    break;
+	default:
+		break;
 
 	//-----------------------------------------------------
 	case TOOL_INTERACTIVE_LDOWN:
-
 		m_ptDown	= ptWorld;
-
-		return( true );
+		break;
 
 	//-----------------------------------------------------
 	case TOOL_INTERACTIVE_LUP:
 
-		CSG_Rect	AOI(m_ptDown.Get_X(), m_ptDown.Get_Y(), ptWorld.Get_X(), ptWorld.Get_Y());
+		CSG_Rect	AOI(m_ptDown.x, m_ptDown.y, ptWorld.x, ptWorld.y);
 
 		// as long as this tool only supports to drag a box, we initialize it with a fake overlap in order
 		// to use CSG_Rect instead of CSG_Shape for point in polygon check in Get_Subset():
@@ -881,7 +880,7 @@ bool CPointCloud_Get_Grid_SPCVF_Interactive::On_Execute_Position(CSG_Point ptWor
 		{
 			CSG_Grid *pGrid = Parameters("GRID_OUT")->asGridList()->Get_Grid(Parameters("GRID_OUT")->asGridList()->Get_Grid_Count()-1);
 
-			DataObject_Update(pGrid, SG_UI_DATAOBJECT_SHOW_LAST_MAP);
+			DataObject_Update(pGrid, SG_UI_DATAOBJECT_SHOW_MAP_ACTIVE);
 		}
 
 		m_Get_Grid_SPCVF.Finalise();
