@@ -75,9 +75,9 @@ CGPP_Model::CGPP_Model(void)
 	//-----------------------------------------------------
 	Set_Name		(_TL("Gravitational Process Path Model"));
 
-	Set_Author		(SG_T("V. Wichmann (c) 2016-2022"));
+	Set_Author		(SG_T("V. Wichmann (c) 2016-2023"));
 
-    Set_Version     ("1.1");
+    Set_Version     ("1.4");
 
 	Set_Description	(_TW("The Gravitational Process Path (GPP) model can be used to simulate the process path and "
                          "run-out area of gravitational processes based on a digital terrain model (DTM). The "
@@ -106,9 +106,25 @@ CGPP_Model::CGPP_Model(void)
                          "and reports from which process paths and release areas objects might be hit. In order to enable this "
                          "backtracking, the user must provide an 'Objects' grid as input. The grid can be used to store different types "
                          "or classes of objects, using one-hot categorical data encoding for each object class, i.e. powers "
-                         "of ten: 1, 10, 100, 1000, etc. (all other cells NoData). The 'Endangered Objects' output grid will "
-                         "contain combinations of these numbers if several different classes were hit from a grid cell, allowing "
-                         "to analyse which object classes might be hit from which location."
+                         "of ten: 1, 10, 100, 1000, etc. (all other cells NoData). The 'Hazard Paths' and 'Hazard Sources' output "
+						 "grid will store combinations of these numbers if several different classes were hit from a grid cell, allowing "
+                         "to analyse which object classes might be hit from which location.<br/><br/>"
+                         "<b>New in version 1.2:</b><br/>"
+                         "Since version 1.2 the model supports the optional output of a grid with the material flux. This requires "
+                         "a 'Material' grid as input. The grid shows the height of the material that has passed in total "
+                         "through each grid cell.<br/><br/>"
+                         "<b>Version 1.3:</b><br/>"
+                         "Version 1.3 includes a fix for material deposition along the process path (amounts and the update of "
+                         "available material for subsequent runs) and improves the output of material flux.<br/><br/>"
+                         "<b>Version 1.4:</b><br/>"
+                         "Since version 1.4 two separate 'Endangered Objects' output grids are created, one encoding the process "
+                         "path cells, the other only the source cells from which objects have been hit. These optional output "
+						 "parameters also have been renamed ('HAZARD_PATHS', 'HAZARD_SOURCES') to improve the legibility of the "
+						 "parameter interface. A third grid, showing the total amount of material in each source cell that has hit "
+						 "objects from that position, has also been added. This output requires a material grid as input in "
+						 "order to calculate material flux. To determine the total amount, the highest material flux observed "
+						 "to hit an object per path and iteration is summed up and converted back to a material height per cell "
+						 "(comparable to the amount specified in the material input grid.)"
     ));
 
 	Add_Reference("Wichmann, V.", "2017",
@@ -199,7 +215,15 @@ bool CGPP_Model::On_Execute(void)
     //---------------------------------------------------------
     if( m_pObjects != NULL )
     {
-        m_pEndangered->Assign_NoData();
+        if( m_pHazardPaths != NULL )
+        {
+            m_pHazardPaths->Assign_NoData();
+        }
+
+        if( m_pHazardSources != NULL )
+        {
+            m_pHazardSources->Assign_NoData();
+        }
 
         m_pObjectClasses = new CSG_Grid(m_pObjects, SG_DATATYPE_Int);
 
@@ -214,19 +238,7 @@ bool CGPP_Model::On_Execute(void)
                 }
                 else
                 {
-                    sLong n = m_pObjects->asLong(x, y);
-
-                    int decimal = 0, i = 0, remainder;
-
-                    while( n != 0 )
-                    {
-                        remainder = n%10;
-                        n /= 10;
-                        decimal += (int)(remainder * pow(2, i));
-                        ++i;
-                    }
-
-                    m_pObjectClasses->Set_Value(x, y, decimal);
+                    m_pObjectClasses->Set_Value(x, y, _Get_ObjectClass_Decimal(m_pObjects->asLong(x, y)));
                 }
             }
         }
@@ -299,12 +311,16 @@ int CGPP_Model::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter
 	{
 		pParameters->Get_Parameter("SINK_MIN_SLOPE"				)->Set_Enabled( pParameter->asGrid() != NULL );
 		pParameters->Get_Parameter("DEPOSITION"					)->Set_Enabled( pParameter->asGrid() != NULL );
+		pParameters->Get_Parameter("MATERIAL_FLUX"				)->Set_Enabled( pParameter->asGrid() != NULL );
+		pParameters->Get_Parameter("HAZARD_SOURCES_MATERIAL"	)->Set_Enabled( pParameter->asGrid() != NULL && pParameters->Get_Parameter("OBJECTS")->asGrid() != NULL );
 	}
 
     //-----------------------------------------------------
     if(	pParameter->Cmp_Identifier(SG_T("OBJECTS")) )
     {
-        pParameters->Get_Parameter("ENDANGERED" 		        )->Set_Enabled( pParameter->asGrid() != NULL );
+        pParameters->Get_Parameter("HAZARD_PATHS"				)->Set_Enabled( pParameter->asGrid() != NULL );
+        pParameters->Get_Parameter("HAZARD_SOURCES"				)->Set_Enabled( pParameter->asGrid() != NULL );
+		pParameters->Get_Parameter("HAZARD_SOURCES_MATERIAL"	)->Set_Enabled( pParameter->asGrid() != NULL && pParameters->Get_Parameter("MATERIAL")->asGrid() != NULL );
     }
 
 	//-----------------------------------------------------
