@@ -70,7 +70,9 @@ CGPP_Model_Particle::CGPP_Model_Particle(int iReleaseID, GRID_CELL gPosition, do
 	m_gPosition				= gPosition;
 	m_gPosition_start		= gPosition;
 	m_dPathLength			= 0.0;
+	m_dMaterialRelease		= dMaterial;
 	m_dMaterial				= dMaterial;
+	m_dMaterialFlux			= 0.0;
 	m_dTanFrictionAngle		= dTanFrictionAngle;
 	m_dFrictionMu			= dFrictionMu;
 	m_dFrictionMassToDrag	= dFrictionMassToDrag;
@@ -144,15 +146,16 @@ void CGPP_Model_Particle::Set_Position(GRID_CELL gPosition)
 }
 
 //---------------------------------------------------------
-void CGPP_Model_Particle::Set_Previous_Position(GRID_CELL gPosition, double dSlope, double dLength, int iExitDir)
+void CGPP_Model_Particle::Set_Previous_Position(GRID_CELL gPosition, double dSlope, double dLength, int iExitDir, double dMaterialFlux)
 {
 	PATH_CELL	cell;
 
-	cell.position	= gPosition;
-	cell.slope		= dSlope;
-	cell.length		= dLength;
-	cell.exitDir	= iExitDir;
-	cell.deposit	= 0.0;
+	cell.position		= gPosition;
+	cell.slope			= dSlope;
+	cell.length			= dLength;
+	cell.exitDir		= iExitDir;
+	cell.deposit		= 0.0;
+	cell.materialflux	= dMaterialFlux;
 
 	m_vPath.push_back(cell);
 }
@@ -217,6 +220,24 @@ void CGPP_Model_Particle::Set_Material(double dMaterial)
 	m_dMaterial = dMaterial;
 }
 
+//---------------------------------------------------------
+double CGPP_Model_Particle::Get_Material_Release(void)
+{
+	return( m_dMaterialRelease );
+}
+
+//---------------------------------------------------------
+double CGPP_Model_Particle::Get_Material_Flux(void)
+{
+	return( m_dMaterialFlux );
+}
+
+//---------------------------------------------------------
+void CGPP_Model_Particle::Set_Material_Flux(double dMaterialFlux)
+{
+	m_dMaterialFlux = dMaterialFlux;
+}
+
 //---------------------------------------------------------
 double CGPP_Model_Particle::Get_Speed(void)
 {
@@ -421,9 +442,10 @@ void CGPP_Model_Particle::Deposit_Material(CSG_Grid *pGrid, double dSlope)
 }
 
 //---------------------------------------------------------
-void CGPP_Model_Particle::Evaluate_Damage_Potential(CSG_Grid *pObjectClasses, CSG_Grid *pEndangered)
+void CGPP_Model_Particle::Evaluate_Damage_Potential(CSG_Grid *pObjectClasses, CSG_Grid *pHazardPaths, CSG_Grid *pHazardSources, CSG_Grid *pHazardSourceMatl)
 {
-    int iEndangered = 0;
+    int		iObjectClasses   = 0;
+	double	dMaxMaterialFlux = 0.0;
 
     for(std::vector<PATH_CELL>::reverse_iterator rit=m_vPath.rbegin(); rit!=m_vPath.rend(); ++rit)
     {
@@ -432,27 +454,64 @@ void CGPP_Model_Particle::Evaluate_Damage_Potential(CSG_Grid *pObjectClasses, CS
 
         if( !pObjectClasses->is_NoData(x, y) )
         {
-            int iObject = pObjectClasses->asInt(x, y);
+            int iClass = pObjectClasses->asInt(x, y);
 
-            iEndangered |= iObject;
+            iObjectClasses |= iClass;
+
+			if( pHazardSourceMatl != NULL && iObjectClasses > 0)
+			{
+				if( dMaxMaterialFlux < (*rit).materialflux )
+				{
+					dMaxMaterialFlux = (*rit).materialflux;
+				}
+			}
         }
 
-        if (iEndangered > 0)
+        if( pHazardPaths != NULL && iObjectClasses > 0 )
         {
-            if( pEndangered->is_NoData(x, y) )
+            if( pHazardPaths->is_NoData(x, y) )
             {
-                pEndangered->Set_Value(x, y, iEndangered);
+                pHazardPaths->Set_Value(x, y, iObjectClasses);
             }
             else
             {
-                pEndangered->Set_Value(x, y, pEndangered->asInt(x, y) | iEndangered);
+                pHazardPaths->Set_Value(x, y, pHazardPaths->asInt(x, y) | iObjectClasses);
             }
         }
     }
 
+	if( pHazardSources != NULL && iObjectClasses > 0 )
+	{
+		GRID_CELL s = Get_Position_Start();
+
+		if( pHazardSources->is_NoData(s.x, s.y) )
+        {
+            pHazardSources->Set_Value(s.x, s.y, iObjectClasses);
+        }
+        else
+        {
+            pHazardSources->Set_Value(s.x, s.y, pHazardSources->asInt(s.x, s.y) | iObjectClasses);
+        }
+	}
+
+	if( pHazardSourceMatl != NULL && dMaxMaterialFlux > 0.0 )
+	{
+		GRID_CELL s = Get_Position_Start();
+
+		if( pHazardSourceMatl->is_NoData(s.x, s.y) )
+        {
+            pHazardSourceMatl->Set_Value(s.x, s.y, dMaxMaterialFlux / pHazardSourceMatl->Get_Cellsize());
+        }
+        else
+        {
+            pHazardSourceMatl->Add_Value(s.x, s.y, dMaxMaterialFlux / pHazardSourceMatl->Get_Cellsize());
+        }
+	}
+
     return;
 }
 
+
 //---------------------------------------------------------
 void CGPP_Model_BASE::Add_Dataset_Parameters(CSG_Parameters *pParameters)
 {
@@ -512,7 +571,7 @@ void CGPP_Model_BASE::Add_Dataset_Parameters(CSG_Parameters *pParameters)
 
 	pParameters->Add_Grid(	
 		NULL, "DEPOSITION", _TL("Deposition"), 
-		_TL("Height of material deposited in each cell [m]. Optional output in case a grid with material amounts is provided as input."), 
+		_TL("Height of the material deposited in each cell [m]. Optional output in case a grid with material amounts is provided as input."), 
 		PARAMETER_OUTPUT_OPTIONAL
 	);
 
@@ -529,10 +588,28 @@ void CGPP_Model_BASE::Add_Dataset_Parameters(CSG_Parameters *pParameters)
 	);
 
     pParameters->Add_Grid(	
-        NULL, "ENDANGERED", _TL("Endangered Objects"), 
-        _TL("Endangered objects, showing cells from which objects were hit. Cell values indicate which object classes were hit [combination of object classes]. Optional output in case a grid with potentially endangered objects is provided as input."), 
+        NULL, "HAZARD_PATHS", _TL("Hazard Paths"), 
+        _TL("Process path cells from which objects were hit. Cell values indicate which object classes were hit [combination of object classes]. Optional output in case a grid with potentially endangered objects is provided as input."), 
         PARAMETER_OUTPUT_OPTIONAL, true, SG_DATATYPE_Long
     );
+
+	pParameters->Add_Grid(	
+        NULL, "HAZARD_SOURCES", _TL("Hazard Sources"), 
+        _TL("Source (release area) cells from which objects were hit. Cell values indicate which object classes were hit [combination of object classes]. Optional output in case a grid with potentially endangered objects is provided as input."), 
+        PARAMETER_OUTPUT_OPTIONAL, true, SG_DATATYPE_Long
+    );
+
+	pParameters->Add_Grid(	
+        NULL, "HAZARD_SOURCES_MATERIAL", _TL("Hazard Sources Material"), 
+        _TL("Source (release area) cells from which objects were hit. Cell values indicate the material amount [m/cell] that has hit objects from that source cell. Optional output in case grids with material amounts and potentially endangered objects are provided as input."), 
+        PARAMETER_OUTPUT_OPTIONAL
+    );
+
+	pParameters->Add_Grid(	
+		NULL, "MATERIAL_FLUX", _TL("Material Flux"), 
+		_TL("Amount of material that has passed through each cell [m]. Optional output in case a grid with material amounts is provided as input."), 
+		PARAMETER_OUTPUT_OPTIONAL
+	);
 }
 
 //---------------------------------------------------------
@@ -790,17 +867,20 @@ bool CGPP_Model_BASE::Initialize_Parameters(CSG_Parameters &Parameters)
 	else
 		m_dInitVelocity		= 0.0;
 	
-	m_pProcessArea			= Parameters("PROCESS_AREA")->asGrid();			m_pProcessArea->Assign(0.0);
+	m_pProcessArea			= Parameters("PROCESS_AREA")->asGrid();				m_pProcessArea->Assign(0.0);
 	m_pDeposition			= Parameters("DEPOSITION")->asGrid();
-	m_pMaxVelocity			= Parameters("MAX_VELOCITY")->asGrid();			if( m_pMaxVelocity != NULL )	m_pMaxVelocity->Assign_NoData();
-	m_pStopPositions		= Parameters("STOP_POSITIONS")->asGrid();		if( m_pStopPositions != NULL )	m_pStopPositions->Assign(0.0);
-    m_pEndangered           = Parameters("ENDANGERED")->asGrid();
+	m_pMaxVelocity			= Parameters("MAX_VELOCITY")->asGrid();				if( m_pMaxVelocity != NULL )		m_pMaxVelocity->Assign_NoData();
+	m_pStopPositions		= Parameters("STOP_POSITIONS")->asGrid();			if( m_pStopPositions != NULL )		m_pStopPositions->Assign(0.0);
+    m_pHazardPaths			= Parameters("HAZARD_PATHS")->asGrid();				if( m_pHazardPaths != NULL )		m_pHazardPaths->Assign_NoData();
+	m_pHazardSources		= Parameters("HAZARD_SOURCES")->asGrid();			if( m_pHazardSources != NULL )		m_pHazardSources->Assign_NoData();
+	m_pHazardSourcesMatl	= Parameters("HAZARD_SOURCES_MATERIAL")->asGrid();	if( m_pHazardSourcesMatl != NULL )	m_pHazardSourcesMatl->Assign_NoData();
+	m_pMaterialFlux			= Parameters("MATERIAL_FLUX")->asGrid();			if( m_pMaterialFlux != NULL )		m_pMaterialFlux->Assign(0.0);
 	
 	m_GPP_Deposition_Model	= Parameters("DEPOSITION_MODEL")->asInt();
 	m_PercentInitialDeposit	= Parameters("DEPOSITION_INITIAL")->asDouble() / 100.0;
 	m_dDepSlopeThres		= tan(Parameters("DEPOSITION_SLOPE_THRES")->asDouble() * M_DEG_TO_RAD);
 	m_dDepVelocityThres		= Parameters("DEPOSITION_VELOCITY_THRES")->asDouble();
-	m_PercentMaxDeposit		= Parameters("DEPOSITION_MAX")->asDouble();
+	m_PercentMaxDeposit		= Parameters("DEPOSITION_MAX")->asDouble() / 100.0;
 	m_MinPathLength			= Parameters("DEPOSITION_MIN_PATH")->asDouble();
 
 	m_SinkMinSlope			= tan(Parameters("SINK_MIN_SLOPE")->asDouble() * M_DEG_TO_RAD);
@@ -814,13 +894,32 @@ bool CGPP_Model_BASE::Initialize_Parameters(CSG_Parameters &Parameters)
 		return( false );
 	}
 
-    //---------------------------------------------------------
-    if( m_pObjects != NULL && m_pEndangered == NULL )
-    {
-        m_pEndangered = new CSG_Grid(m_pObjects, SG_DATATYPE_Long);
-        m_pEndangered->Set_Name(_TL("Endangered Objects"));
+	//---------------------------------------------------------
+	if( m_GPP_Deposition_Model > GPP_DEPOSITION_NONE && m_pMaterial == NULL )
+	{
+		SG_UI_Msg_Add_Error(_TL("Deposition modelling requires a material grid as input!"));
+		return( false );
+	}
 
-        Parameters("ENDANGERED")->Set_Value(m_pEndangered);
+	//---------------------------------------------------------
+    if( m_pMaterialFlux != NULL && m_pMaterial == NULL )
+    {
+		SG_UI_Msg_Add_Error(_TL("Material flux output requires a material grid as input!"));
+		return( false );
+    }
+
+	//---------------------------------------------------------
+    if( m_pHazardSourcesMatl != NULL && (m_pMaterial == NULL || m_pObjects == NULL) )
+    {
+		SG_UI_Msg_Add_Error(_TL("Hazard sources material output requires a material and an objects grid as input!"));
+		return( false );
+    }
+
+    //---------------------------------------------------------
+    if( m_pObjects != NULL && (m_pHazardPaths == NULL && m_pHazardSources == NULL && m_pHazardSourcesMatl == NULL ) )
+    {
+		SG_UI_Msg_Add_Error(_TL("An 'Objects' input grid is provided but none of the 'hazard' grids (paths, sources or material) is selected as output!"));
+		return( false );
     }
 
     //---------------------------------------------------------
@@ -868,6 +967,11 @@ void CGPP_Model_BASE::Finalize(CSG_Parameters *pParameters)
 
 	m_pProcessArea->Set_NoData_Value(0.0);
 
+	if( m_pMaterialFlux != NULL )
+	{
+		m_pMaterialFlux->Set_NoData_Value(0.0);
+	}
+
 	if( m_pStopPositions != NULL )
 	{
 		m_pStopPositions->Set_NoData_Value(0.0);
@@ -877,26 +981,18 @@ void CGPP_Model_BASE::Finalize(CSG_Parameters *pParameters)
     if( m_pObjects != NULL )
     {
         #pragma omp parallel for
-        for(int y=0; y<m_pEndangered->Get_NY(); y++)
+        for(int y=0; y<m_pObjects->Get_NY(); y++)
         {
-            for(int x=0; x<m_pEndangered->Get_NX(); x++)
+            for(int x=0; x<m_pObjects->Get_NX(); x++)
             {
-                if( !m_pEndangered->is_NoData(x, y) )
+                if( m_pHazardPaths != NULL && !m_pHazardPaths->is_NoData(x, y) )
                 {
-                    int n = m_pEndangered->asInt(x, y);
+                    m_pHazardPaths->Set_Value(x, y, _Get_ObjectClass_Binary(m_pHazardPaths->asInt(x, y)));
+                }
 
-                    sLong binary = 0;
-                    int remainder, i = 1;
-
-                    while( n != 0 )
-                    {
-                        remainder = n%2;
-                        n /= 2;
-                        binary += remainder * i;
-                        i *= 10;
-                    }
-
-                    m_pEndangered->Set_Value(x, y, (double)binary);
+                if( m_pHazardSources != NULL && !m_pHazardSources->is_NoData(x, y) )
+                {
+                    m_pHazardSources->Set_Value(x, y, _Get_ObjectClass_Binary(m_pHazardSources->asInt(x, y)));
                 }
             }
         }
@@ -1067,26 +1163,48 @@ void CGPP_Model_BASE::Run_GPP_Model(std::vector<class CGPP_Model_Particle> *pvPr
 					m_pMaxVelocity->Set_Value(Particle.Get_X(), Particle.Get_Y(), Particle.Get_Speed());
 			}
 
-			double	dMaterialRun = Particle.Get_Material() / (m_iIterations - iIter);
+			double	dTotalMaterialLeft	= Particle.Get_Material();
+			double	dMaterialRun		= dTotalMaterialLeft / (m_iIterations - iIter);
 
 			Particle.Set_Material(dMaterialRun);
 
-
 			while( true )
 			{
 				if( !Update_Path(&Particle, dMaterialRun, &pvProcessingList->at(iParticle)) )
 				{
 					break;
 				}
-					
-				if( !Update_Speed(&Particle, &pvProcessingList->at(iParticle)) )
+
+				bool bContinue = Update_Speed(&Particle, &pvProcessingList->at(iParticle));
+
+				if( bContinue )
 				{
-					break;
+					if( m_GPP_Deposition_Model > GPP_DEPOSITION_ON_STOP && Particle.Get_PathLength() > m_MinPathLength )
+					{
+						Calc_Path_Deposition(&Particle);
+					}
 				}
 
-				if( m_GPP_Deposition_Model > GPP_DEPOSITION_ON_STOP && Particle.Get_PathLength() > m_MinPathLength )
+				if( (m_pMaterialFlux != NULL || m_pHazardSourcesMatl != NULL) && Particle.Get_Material() > 0.0 )
 				{
-					Calc_Path_Deposition(&Particle);
+					double dMaterial = Particle.Get_Material_Release() / m_iIterations;
+
+					if( Particle.Get_Material() < dMaterial )
+					{
+						dMaterial = Particle.Get_Material();
+					}
+
+					Particle.Set_Material_Flux(dMaterial * m_pDEM->Get_Cellsize());
+
+					if( m_pMaterialFlux != NULL )
+					{
+						m_pMaterialFlux->Add_Value(Particle.Get_X(), Particle.Get_Y(), Particle.Get_Material_Flux());
+					}
+				}
+
+				if( !bContinue )
+				{
+					break;
 				}
 
 				if( (sLong)Particle.Get_Count_Path_Positions() > m_pDEM->Get_NCells() )
@@ -1095,12 +1213,18 @@ void CGPP_Model_BASE::Run_GPP_Model(std::vector<class CGPP_Model_Particle> *pvPr
 
                     if( m_pObjects != NULL )
                     {
-                        Particle.Evaluate_Damage_Potential(m_pObjectClasses, m_pEndangered);
+                        Particle.Evaluate_Damage_Potential(m_pObjectClasses, m_pHazardPaths, m_pHazardSources, m_pHazardSourcesMatl);
                     }
 
 					break;
 				}
 			} // while( true )
+
+			if( m_GPP_Deposition_Model > GPP_DEPOSITION_NONE && dMaterialRun > Particle.Get_Material() )
+			{
+				// update material in start cell (amount available for subsequent runs) 
+				pvProcessingList->at(iParticle).Set_Material(dTotalMaterialLeft - (dMaterialRun - Particle.Get_Material()));
+			}
 		} // for iParticle
 	} // for iIteration
 
@@ -1133,25 +1257,19 @@ bool CGPP_Model_BASE::Update_Path(CGPP_Model_Particle *pParticle, double dMateri
 		if( bSink )
 		{
 			Fill_Sink(pParticle);
-
-			Update_Material_Start_Cell(pParticleStartCell, pParticle, dMaterialRun);
 		}
 
 		if( !bEdge && !bSink )
 		{
-			if( m_GPP_Deposition_Model >= GPP_DEPOSITION_ON_STOP )
+			if( m_GPP_Deposition_Model > GPP_DEPOSITION_NONE )
 			{
-				double dMaterialDeposit = pParticle->Get_Material();
-
 				Deposit_Material_On_Stop(pParticle);
-
-				Update_Material_Start_Cell(pParticleStartCell, pParticle, dMaterialDeposit);
 			}
 		}
 
         if( m_pObjects != NULL )
         {
-            pParticle->Evaluate_Damage_Potential(m_pObjectClasses, m_pEndangered);
+            pParticle->Evaluate_Damage_Potential(m_pObjectClasses, m_pHazardPaths, m_pHazardSources, m_pHazardSourcesMatl);
         }
 	}
 
@@ -1268,7 +1386,7 @@ bool CGPP_Model_BASE::Update_Path_Maximum_Slope(CGPP_Model_Particle *pParticle,
 
 	//---------------------------------------------------------
 	// update previous position
-	pParticle->Set_Previous_Position(pParticle->Get_Position(), pParticle->Get_Slope(), m_pDEM->Get_System().Get_Length(iExitDir), iExitDir);
+	pParticle->Set_Previous_Position(pParticle->Get_Position(), pParticle->Get_Slope(), m_pDEM->Get_System().Get_Length(iExitDir), iExitDir, pParticle->Get_Material_Flux());
 
 	// update current position
 	GRID_CELL	neighbor;
@@ -1474,7 +1592,7 @@ bool CGPP_Model_BASE::Update_Path_Random_Walk(CGPP_Model_Particle *pParticle, bo
 
 	//---------------------------------------------------------
 	// update previous position
-	pParticle->Set_Previous_Position(pParticle->Get_Position(), pParticle->Get_Slope(), m_pDEM->Get_System().Get_Length(iExitDir), iExitDir);
+	pParticle->Set_Previous_Position(pParticle->Get_Position(), pParticle->Get_Slope(), m_pDEM->Get_System().Get_Length(iExitDir), iExitDir, pParticle->Get_Material_Flux());
 
 	// update current position
 	GRID_CELL neighbor;
@@ -1519,7 +1637,7 @@ void  CGPP_Model_BASE::Fill_Sink(CGPP_Model_Particle *pParticle)
 	//---------------------------------------------------------
 	// add sink cell to path
 
-	pParticle->Set_Previous_Position(pParticle->Get_Position(), 0.0, 0.0, -1);
+	pParticle->Set_Previous_Position(pParticle->Get_Position(), 0.0, 0.0, -1, 0.0);
 	
 	
 	//---------------------------------------------------------
@@ -1600,7 +1718,7 @@ void CGPP_Model_BASE::Deposit_Material_On_Stop(CGPP_Model_Particle *pParticle)
 
 	//---------------------------------------------------------
 	// add stop cell to path
-	pParticle->Set_Previous_Position(pParticle->Get_Position(), 0.0, 0.0, -1);
+	pParticle->Set_Previous_Position(pParticle->Get_Position(), 0.0, 0.0, -1, pParticle->Get_Material_Flux());
 	
 
 	//---------------------------------------------------------
@@ -1624,20 +1742,6 @@ void CGPP_Model_BASE::Deposit_Material_On_Stop(CGPP_Model_Particle *pParticle)
 }
 
 
-//---------------------------------------------------------
-void CGPP_Model_BASE::Update_Material_Start_Cell(CGPP_Model_Particle *pParticleStartCell, CGPP_Model_Particle *pParticle, double dMaterial)
-{
-	if( dMaterial > pParticle->Get_Material() )
-	{
-		double dStartCellMaterial = pParticleStartCell->Get_Material();
-
-		pParticleStartCell->Set_Material(dStartCellMaterial - (dMaterial - pParticle->Get_Material()));
-	}
-
-	return;
-}
-
-
 //---------------------------------------------------------
 void CGPP_Model_BASE::Calc_Path_Deposition(CGPP_Model_Particle *pParticle)
 {
@@ -1725,18 +1829,31 @@ bool CGPP_Model_BASE::Update_Speed(CGPP_Model_Particle *pParticle, CGPP_Model_Pa
 			m_pStopPositions->Add_Value(pParticle->Get_X(), pParticle->Get_Y(), 1);
 		}
 
-		if( m_GPP_Deposition_Model >= GPP_DEPOSITION_ON_STOP )
+		if( m_GPP_Deposition_Model > GPP_DEPOSITION_NONE )
 		{
-			double dMaterialDeposit = pParticle->Get_Material();
+			if( (m_pMaterialFlux != NULL || m_pHazardSourcesMatl != NULL) && pParticle->Get_Material() > 0.0 )
+			{
+				double dMaterial = pParticle->Get_Material_Release() / m_iIterations;
+
+				if( pParticle->Get_Material() < dMaterial )
+				{
+					dMaterial = pParticle->Get_Material();
+				}
+
+				pParticle->Set_Material_Flux(dMaterial * m_pDEM->Get_Cellsize());
+
+				if( m_pMaterialFlux != NULL )
+				{
+					m_pMaterialFlux->Add_Value(pParticle->Get_X(), pParticle->Get_Y(), pParticle->Get_Material_Flux());
+				}
+			}
 
 			Deposit_Material_On_Stop(pParticle);
-
-			Update_Material_Start_Cell(pParticleStartCell, pParticle, dMaterialDeposit);
 		}
 
         if( m_pObjects != NULL )
         {
-            pParticle->Evaluate_Damage_Potential(m_pObjectClasses, m_pEndangered);
+            pParticle->Evaluate_Damage_Potential(m_pObjectClasses, m_pHazardPaths, m_pHazardSources, m_pHazardSourcesMatl);
         }
 	}
 
@@ -2039,6 +2156,41 @@ bool CGPP_Model_BASE::Update_Friction_PCM_Model(CGPP_Model_Particle *pParticle)
 }
 
 
+//---------------------------------------------------------
+int CGPP_Model_BASE::_Get_ObjectClass_Decimal(sLong n)
+{
+    int decimal = 0, i = 0, remainder;
+
+    while( n != 0 )
+    {
+        remainder = n%10;
+        n /= 10;
+        decimal += (int)(remainder * pow(2, i));
+        ++i;
+    }
+
+    return( decimal );
+}
+
+
+//---------------------------------------------------------
+double CGPP_Model_BASE::_Get_ObjectClass_Binary(int n)
+{
+    sLong binary = 0;
+    int remainder, i = 1;
+
+    while( n != 0 )
+    {
+        remainder = n%2;
+        n /= 2;
+        binary += remainder * i;
+        i *= 10;
+    }
+
+    return( (double)binary );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
