@@ -60,12 +60,19 @@
 //---------------------------------------------------------
 CTWI::CTWI(void)
 {
-	Set_Name		(_TL("Topographic Wetness Index (TWI)"));
+	Set_Name		(_TL("Topographic Wetness Index"));
 
 	Set_Author		("O.Conrad (c) 2003");
 
 	Set_Description	(_TW(
-		"Calculation of the slope and specific catchment area (SCA) based Topographic Wetness Index (TWI)."
+		"Calculates the Topographic Wetness Index (TWI) using the supplied rasters for "
+		"slope (Beta), specific catchment area (SCA), and optional transmissivity (T) "
+		"when the soil profile is saturated:\n\n"
+		"TWI = ln(SCA / tan(Beta))\n"
+		"\n"
+		"or with transmissivity\n"
+		"\n"
+		"TWI = ln(SCA / (T * tan(Beta)))"
 	));
 
 	Add_Reference(
@@ -164,7 +171,7 @@ bool CTWI::On_Execute(void)
 		Mean_Kf		= 0.;
 		Area		= 0.;
 
-		for(y=0; y<Get_NY() && Set_Progress(y); y++)
+		for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
 			for(x=0; x<Get_NX(); x++)
 			{
@@ -212,7 +219,7 @@ bool CTWI::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	for(y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		for(x=0; x<Get_NX(); x++)
 		{
@@ -322,7 +329,7 @@ bool CStream_Power::On_Execute(void)
 	DataObject_Set_Colors(pSPI, 11, SG_COLORS_RED_GREY_GREEN, true);
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -383,7 +390,7 @@ CCIT::CCIT(void)
 
     Parameters.Add_Grid("",
         "AREA"	, _TL("Catchment Area"),
-        _TL("The catchment area grid [map units^2]."),
+        _TL("The catchment area grid [map unitsz^2]."),
         PARAMETER_INPUT
     );
 
@@ -420,7 +427,7 @@ bool CCIT::On_Execute(void)
     DataObject_Set_Colors(pCIT, 11, SG_COLORS_RED_GREY_GREEN, true);
 
     //-----------------------------------------------------
-    for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+    for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
     {
         #pragma omp parallel for
         for(int x=0; x<Get_NX(); x++)
@@ -580,7 +587,7 @@ bool CLS_Factor::On_Execute(void)
 	DataObject_Set_Colors(pLS, 11, SG_COLORS_RED_GREY_GREEN, true);
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -748,7 +755,7 @@ bool CTCI_Low::On_Execute(void)
 	double	wRange	= log(1. + pTWI->Get_Range());
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
