@@ -362,7 +362,7 @@ bool CMorphometry::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -765,7 +765,7 @@ void CMorphometry::Set_Tarboton(int x, int y)
 //      Proceedings of the IEEE, v. 69, no. 1, p 14-47.
 //
 // Beasley, D.B. and Huggins, L.F. 1982:
-//		ANSWERS: Users manual.
+//		ANSWERS: User’s manual.
 //		U.S. EPA-905/9-82-001, Chicago, IL. 54pp.
 //
 // Costa-Cabral, M., and Burges, S.J., 1994:
