@@ -159,7 +159,7 @@ bool CDistance_Gradient::On_Execute(void)
 		//-------------------------------------------------
 		m_Dir.Create(m_pDEM, SG_DATATYPE_Char);
 
-		for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+		for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
 			#pragma omp parallel for
 			for(int x=0; x<Get_NX(); x++)
@@ -169,7 +169,7 @@ bool CDistance_Gradient::On_Execute(void)
 		}
 
 		//-------------------------------------------------
-		for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+		for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
 			#pragma omp parallel for
 			for(int x=0; x<Get_NX(); x++)
