@@ -146,7 +146,7 @@ bool CMass_Balance_Index::On_Execute(void)
 	DataObject_Set_Colors(pMBI, 11, SG_COLORS_RED_GREY_BLUE, true);
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
