@@ -177,7 +177,7 @@ bool CRelative_Heights::Get_Heights_Catchment(CSG_Grid *pDEM, CSG_Grid *pH, doub
 	pH->Assign(0.);
 
 	//-----------------------------------------------------
-	for(sLong n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
+	for(sLong n=0; n<Get_NCells() && Set_Progress_Cells(n); n++)
 	{
 		int	x, y;
 
@@ -242,8 +242,8 @@ bool CRelative_Heights::Get_Heights_Catchment(CSG_Grid *pDEM, CSG_Grid *pH, doub
 
 //---------------------------------------------------------
 // in den folgenden drei Schritten werden Maxima der
-// relativen Hhe H in Abhngigkeit der Neigung gesaugt.
-// Der e-Parameter steuert die strke der Maximum-Streckung
+// relativen Höhe H in Abhängigkeit der Neigung gesaugt.
+// Der e-Parameter steuert die stärke der Maximum-Streckung
 
 //---------------------------------------------------------
 bool CRelative_Heights::Get_Heights_Modified(CSG_Grid *pDEM, CSG_Grid *pH, double t, double e)
@@ -252,7 +252,7 @@ bool CRelative_Heights::Get_Heights_Modified(CSG_Grid *pDEM, CSG_Grid *pH, doubl
 
 	CSG_Grid	H, H_Last, T(pH);
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -331,7 +331,7 @@ bool CRelative_Heights::Get_Heights_Modified(CSG_Grid *pDEM, CSG_Grid *pH, doubl
 	//-----------------------------------------------------
 	Process_Set_Text(_TL("Modify: post-processing..."));
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -416,17 +416,17 @@ double CRelative_Heights::Get_Local_Maximum(CSG_Grid *pGrid, int x, int y)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-// auf Grundlage von HO und HU wird die Normierte Hhe
-// (NH) mit Hhenwerten zwischen minimal 0 (=unten) und
+// auf Grundlage von HO und HU wird die Normierte Höhe
+// (NH) mit Höhenwerten zwischen minimal 0 (=unten) und
 // maximal 1 (= oben) wie beim NDVI bestimmt. Die
-// Standardisierte Hhe SH streckt das Relief auf ein
-// Hhenspektrum zwischen theoretisch 0 (=unten) und
+// Standardisierte Höhe SH streckt das Relief auf ein
+// Höhenspektrum zwischen theoretisch 0 (=unten) und
 // dem Maximum der jeweiligen Scheitelbereiche, so dass
-// die ursprngliche Reliefenergie erhalten bleibt.
-// Selbstverstndlich muss fr Anwendungen berprft
-// werden, ob und welche relativen Hhen (HU, HO, SH)
+// die ursprüngliche Reliefenergie erhalten bleibt.
+// Selbstverständlich muss für Anwendungen überprüft
+// werden, ob und welche relativen Höhen (HU, HO, SH)
 // logarithmiert dargestellt werden. Als Beispiel ist
-// die Standardisierte Hhe logarithmiert berechnet (SHL)
+// die Standardisierte Höhe logarithmiert berechnet (SHL)
 
 //---------------------------------------------------------
 bool CRelative_Heights::Get_Results(CSG_Grid *pDEM, CSG_Grid *pHO, CSG_Grid *pHU)
@@ -437,7 +437,7 @@ bool CRelative_Heights::Get_Results(CSG_Grid *pDEM, CSG_Grid *pHO, CSG_Grid *pHU
 	CSG_Grid	*pSH	= Parameters("SH")->asGrid();
 	CSG_Grid	*pMS	= Parameters("MS")->asGrid();
 
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -479,7 +479,7 @@ bool CRelative_Heights::Get_Results(CSG_Grid *pDEM, CSG_Grid *pHO, CSG_Grid *pHU
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-//        The original BSL script by J.Bhner
+//        The original BSL script by J.Böhner
 //---------------------------------------------------------
 
 /*
@@ -533,10 +533,10 @@ m = 0;
 n = 0;
 o = 0;
 
-// Das gesamte Verfahren besteht aus zwei identischen Schritten zur Bestimmung von Hhe ber Kulmination (HO) und Hhe unter Kulmination (HU). Fr HO wird das DGM zunchst umgedreht //
+// Das gesamte Verfahren besteht aus zwei identischen Schritten zur Bestimmung von Höhe über Kulmination (HO) und Höhe unter Kulmination (HU). Für HO wird das DGM zunächst umgedreht //
 foreach p in M do
 {M[p] = -1 * O[p];}
-// hier wird eine Hilfsmatrix X erzeugt, die in der folgenden Schleife fafr sorgt, dass noch nicht attributisierte Rasterzellen in Ihrer Position identifiziert werden knnen //
+// hier wird eine Hilfsmatrix X erzeugt, die in der folgenden Schleife fafür sorgt, dass noch nicht attributisierte Rasterzellen in Ihrer Position identifiziert werden können //
 foreach p in X do
 {	if (p.x == 0 || p.x == M.xanz - 1 || p.y == 0 || p.y == M.yanz - 1)
 	{X[p] = -10000;}
@@ -805,7 +805,7 @@ else
 	{Z[p] = wul + wll + wol + woo + wor + wrr + wur + wuu;}
 	}
 }}}}}}}}
-// hier werden Grids UL bis UU (im Uhrzeigersinn) erzeugt, die angeben, welchen Anteil des Inhalts einer benachbarten Rasterzelle in die Zielrasterzelle (zentrale Rasterzelle im 9er Feld) bergen wird //
+// hier werden Grids UL bis UU (im Uhrzeigersinn) erzeugt, die angeben, welchen Anteil des Inhalts einer benachbarten Rasterzelle in die Zielrasterzelle (zentrale Rasterzelle im 9er Feld) übergen wird //
 foreach p in UL do
 {	if (p.x == 0 || p.y == 0)
 	{UL[p] = 0;}
@@ -886,7 +886,7 @@ foreach p in UU do
 		{UU[p] = 0;}
 		}
 }
-// in den folgenden drei Schritten wird nach der "multiple flow methode" die Einzugsgebietsgre C ermittelt //
+// in den folgenden drei Schritten wird nach der "multiple flow methode" die Einzugsgebietsgröße C ermittelt //
 foreach p in Z do
 {Z[p] = 1;}
 foreach ploop in Loop do
@@ -903,7 +903,7 @@ foreach ploop in Loop do
 setRandN(Z);
 foreach p in C do
 {C[p] = Z[p] * M.dxy^2;}
-// in den folgenden zwei Schritten werden Gewichte umgekehrt-proportional zur Einzugsgebietsgre nach der multiple flow methode aufsummiert. Der w-parameter steuert die strke der Gewichtung //
+// in den folgenden zwei Schritten werden Gewichte umgekehrt-proportional zur Einzugsgebietsgröße nach der multiple flow methode aufsummiert. Der w-parameter steuert die stärke der Gewichtung //
 foreach p in W do
 {W[p] = (1/C[p])^w;}
 foreach ploop in Loop do
@@ -918,7 +918,7 @@ foreach ploop in Loop do
 	{ploop.x = 100000;}
 }
 setRandN(W);
-// in den folgenden zwei Schritten werden Hhenwerte und Gewichte nach der multiple flow methode in der Matrix H aufsummiert, wobei lokale Maxima im Einzugsgebiet am strksten in H eingehen. Der w-Parameter steuert die Strke der Maximumgewichtung //
+// in den folgenden zwei Schritten werden Höhenwerte und Gewichte nach der multiple flow methode in der Matrix H aufsummiert, wobei lokale Maxima im Einzugsgebiet am stärksten in H eingehen. Der w-Parameter steuert die Stärke der Maximumgewichtung //
 foreach p in H do
 {H[p] = M[p] * (1/C[p])^w;}
 foreach ploop in Loop do
@@ -933,13 +933,13 @@ foreach ploop in Loop do
 	{ploop.x = 100000;}
 }
 setRandN(H);
-// im folgenden Schritt wird eine relative Hhe H ber dem gewichteten arithmetischen Mittel der Einzugsgebietsgre bestimmt //
+// im folgenden Schritt wird eine relative Höhe H über dem gewichteten arithmetischen Mittel der Einzugsgebietsgröße bestimmt //
 foreach p in H do
 {	if (isRand(p, M) == 0)
 	{H[p] = -1 * (M[p] - H[p]/W[p]);}
 }
 setRandN(H);
-// in den folgenden drei Schritten werden Maxima der relativen Hhe H in Abhngigkeit der Neigung gesaugt. Der e-Parameter steuert die strke der Maximum-Streckung //
+// in den folgenden drei Schritten werden Maxima der relativen Höhe H in Abhängigkeit der Neigung gesaugt. Der e-Parameter steuert die stärke der Maximum-Streckung //
 foreach p in X do
 {X[p] = H[p]^e;}
 foreach ploop in Loop do
@@ -976,7 +976,7 @@ m = 0;
 // hier wird das DGM nicht umgedreht //
 foreach p in M do
 {M[p] = O[p];}
-// hier wird eine Hilfsmatrix X erzeugt, die in der folgenden Schleife fafr sorgt, dass noch nicht attributisierte Rasterzellen in Ihrer Position identifiziert werden knnen //
+// hier wird eine Hilfsmatrix X erzeugt, die in der folgenden Schleife fafür sorgt, dass noch nicht attributisierte Rasterzellen in Ihrer Position identifiziert werden können //
 foreach p in X do
 {	if (p.x == 0 || p.x == M.xanz - 1 || p.y == 0 || p.y == M.yanz - 1)
 	{X[p] = -10000;}
@@ -1245,7 +1245,7 @@ else
 	{Z[p] = wul + wll + wol + woo + wor + wrr + wur + wuu;}
 	}
 }}}}}}}}
-// hier werden Grids UL bis UU (im Uhrzeigersinn) erzeugt, die angeben, welchen Anteil des Inhalts einer benachbarten Rasterzelle in die Zielrasterzelle (zentrale Rasterzelle im 9er Feld) bergen wird //
+// hier werden Grids UL bis UU (im Uhrzeigersinn) erzeugt, die angeben, welchen Anteil des Inhalts einer benachbarten Rasterzelle in die Zielrasterzelle (zentrale Rasterzelle im 9er Feld) übergen wird //
 foreach p in UL do
 {	if (p.x == 0 || p.y == 0)
 	{UL[p] = 0;}
@@ -1326,7 +1326,7 @@ foreach p in UU do
 		{UU[p] = 0;}
 		}
 }
-// in den folgenden drei Schritten wird nach der "multiple flow methode" die Einzugsgebietsgre C ermittelt //
+// in den folgenden drei Schritten wird nach der "multiple flow methode" die Einzugsgebietsgröße C ermittelt //
 foreach p in Z do
 {Z[p] = 1;}
 foreach ploop in Loop do
@@ -1343,7 +1343,7 @@ foreach ploop in Loop do
 setRandN(Z);
 foreach p in C do
 {C[p] = Z[p] * M.dxy^2;}
-// in den folgenden zwei Schritten werden Gewichte umgekehrt-proportional zur Einzugsgebietsgre nach der multiple flow methode aufsummiert. Der w-parameter steuert die strke der Gewichtung //
+// in den folgenden zwei Schritten werden Gewichte umgekehrt-proportional zur Einzugsgebietsgröße nach der multiple flow methode aufsummiert. Der w-parameter steuert die stärke der Gewichtung //
 foreach p in W do
 {W[p] = (1/C[p])^w;}
 foreach ploop in Loop do
@@ -1358,7 +1358,7 @@ foreach ploop in Loop do
 	{ploop.x = 100000;}
 }
 setRandN(W);
-// in den folgenden zwei Schritten werden Hhenwerte und Gewichte nach der multiple flow methode in der Matrix H aufsummiert, wobei lokale Maxima im Einzugsgebiet am strksten in H eingehen. Der w-Parameter steuert die Strke der Maximumgewichtung //
+// in den folgenden zwei Schritten werden Höhenwerte und Gewichte nach der multiple flow methode in der Matrix H aufsummiert, wobei lokale Maxima im Einzugsgebiet am stärksten in H eingehen. Der w-Parameter steuert die Stärke der Maximumgewichtung //
 foreach p in H do
 {H[p] = M[p] * (1/C[p])^w;}
 foreach ploop in Loop do
@@ -1373,13 +1373,13 @@ foreach ploop in Loop do
 	{ploop.x = 100000;}
 }
 setRandN(H);
-// im folgenden Schritt wird eine relative Hhe H ber dem gewichteten arithmetischen Mittel der Einzugsgebietsgre bestimmt //
+// im folgenden Schritt wird eine relative Höhe H über dem gewichteten arithmetischen Mittel der Einzugsgebietsgröße bestimmt //
 foreach p in H do
 {	if (isRand(p, M) == 0)
 	{H[p] = -1 * (M[p] - H[p]/W[p]);}
 }
 setRandN(H);
-// in den folgenden drei Schritten werden Maxima der relativen Hhe H in Abhngigkeit der Neigung gesaugt. Der e-Parameter steuert die strke der Maximum-Streckung //
+// in den folgenden drei Schritten werden Maxima der relativen Höhe H in Abhängigkeit der Neigung gesaugt. Der e-Parameter steuert die stärke der Maximum-Streckung //
 foreach p in X do
 {X[p] = H[p]^e;}
 foreach ploop in Loop do
@@ -1406,7 +1406,7 @@ foreach p in HU do
 setRandN (HU);
 showMatrix(HO);
 showMatrix(HU);
-// auf Grundlage von HO und HU wird die Normierte Hhe (NH) mit Hhenwerten zwischen minimal 0 (=unten) und maximal 1 (= oben) wie beim NDVI bestimmt. Die Standardisierte Hhe SH streckt das Relief auf ein Hhenspektrum zwischen theoretisch 0 (=unten) und dem Maximum der jeweiligen Scheitelbereiche, so dass die ursprngliche Reliefenergie erhalten bleibt. Selbstverstndlich muss fr Anwendungen berprft werden, ob und welche relativen Hhen (HU, HO, SH) logarithmiert dargestellt werden. Als Beispiel ist die Standardisierte Hhe logarithmiert berechnet (SHL) //
+// auf Grundlage von HO und HU wird die Normierte Höhe (NH) mit Höhenwerten zwischen minimal 0 (=unten) und maximal 1 (= oben) wie beim NDVI bestimmt. Die Standardisierte Höhe SH streckt das Relief auf ein Höhenspektrum zwischen theoretisch 0 (=unten) und dem Maximum der jeweiligen Scheitelbereiche, so dass die ursprüngliche Reliefenergie erhalten bleibt. Selbstverständlich muss für Anwendungen überprüft werden, ob und welche relativen Höhen (HU, HO, SH) logarithmiert dargestellt werden. Als Beispiel ist die Standardisierte Höhe logarithmiert berechnet (SHL) //
 foreach p in NH do
 {NH[p] = 0.5 * (1 + ((HO[p] - HU[p])/(HO[p] + HU[p])));}
 showMatrix(NH);
