@@ -79,8 +79,8 @@ CWind_Effect::CWind_Effect(void)
 	);
 
 	Add_Reference(
-		"Gerlitz, L., Conrad, O., Bhner, J.", "2015",
-		"Large scale atmospheric forcing and topographic modification of precipitation rates over High Asia  a neural network based approach",
+		"Gerlitz, L., Conrad, O., Böhner, J.", "2015",
+		"Large scale atmospheric forcing and topographic modification of precipitation rates over High Asia – a neural network based approach",
 		"Earth System Dynamics, 6, 1-21.",
 		SG_T("https://doi.org/10.5194/esd-6-61-2015"), SG_T("doi:10.5194/esd-6-61-2015")
 	);
@@ -290,7 +290,7 @@ bool CWind_Effect::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -584,8 +584,8 @@ CWind_Exposition::CWind_Exposition(void)
 	);
 
 	Add_Reference(
-		"Gerlitz, L., Conrad, O., Bhner, J.", "2015",
-		"Large scale atmospheric forcing and topographic modification of precipitation rates over High Asia  a neural network based approach",
+		"Gerlitz, L., Conrad, O., Böhner, J.", "2015",
+		"Large scale atmospheric forcing and topographic modification of precipitation rates over High Asia – a neural network based approach",
 		"Earth System Dynamics, 6, 1-21.",
 		SG_T("https://www.earth-syst-dynam.net/6/61/2015/"), SG_T("doi:10.5194/esd-6-61-2015.")
 	);
