@@ -86,42 +86,50 @@ CGrid_Profile_From_Lines::CGrid_Profile_From_Lines(void)
 		"Create profiles from a grid based DEM for each line of a lines layer. "
 	));
 
-	Parameters.Add_Grid       (""     , "DEM"     , _TL("Elevation"),
+	Parameters.Add_Grid("",
+		"DEM"     , _TL("Elevation"),
 		_TL(""),
 		PARAMETER_INPUT
 	);
 
-	Parameters.Add_Grid_List  (""     , "VALUES"  , _TL("Values"),
+	Parameters.Add_Grid_List("",
+		"VALUES"  , _TL("Values"),
 		_TL("Additional values to be collected along profile."),
 		PARAMETER_INPUT_OPTIONAL
 	);
 
-	Parameters.Add_Shapes     (""     , "LINES"   , _TL("Lines"),
+	Parameters.Add_Shapes("",
+		"LINES"   , _TL("Lines"),
 		_TL(""),
 		PARAMETER_INPUT, SHAPE_TYPE_Line
 	);
 
-	Parameters.Add_Table_Field("LINES", "NAME"    , _TL("Name"),
-		_TL("Attribute to use for splitted line naming (=> each line as new profile)"),
+	Parameters.Add_Table_Field("LINES",
+		"NAME"    , _TL("Name"),
+		_TL("Attribute to use for split line naming (=> each line as new profile)"),
 		true
 	);
 
-	Parameters.Add_Shapes     (""     , "PROFILE" , _TL("Profiles"),
+	Parameters.Add_Shapes("",
+		"PROFILE" , _TL("Profiles"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL, SHAPE_TYPE_Point
 	);
 
-	Parameters.Add_Shapes_List(""     , "PROFILES", _TL("Profiles"),
+	Parameters.Add_Shapes_List("",
+		"PROFILES", _TL("Profiles"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL, SHAPE_TYPE_Point
 	);
 
-	Parameters.Add_Bool       (""     , "SPLIT"   , _TL("Each Line as new Profile"),
+	Parameters.Add_Bool("",
+		"SPLIT"   , _TL("Each Line as new Profile"),
 		_TL(""),
 		false
 	);
 
-	Parameters.Add_Bool       (""     , "DIAGRAM", _TL("Show Diagram"),
+	Parameters.Add_Bool("",
+		"DIAGRAM", _TL("Show Diagram"),
 		_TL(""),
 		false
 	)->Set_UseInCMD(false);
@@ -217,7 +225,7 @@ bool CGrid_Profile_From_Lines::Init_Profile(CSG_Shapes *pPoints, const CSG_Strin
 	{
 		pPoints->Create(SHAPE_TYPE_Point, Name);
 
-		pPoints->Add_Field("ID_LINE" , SG_DATATYPE_Int   ); // FIELD_ID_LINE
+		pPoints->Add_Field("ID_LINE" , SG_DATATYPE_Long  ); // FIELD_ID_LINE
 		pPoints->Add_Field("ID_POINT", SG_DATATYPE_Int   ); // FIELD_ID_POINT
 		pPoints->Add_Field("DISTANCE", SG_DATATYPE_Double); // FIELD_DISTANCE
 		pPoints->Add_Field("OVERLAND", SG_DATATYPE_Double); // FIELD_OVERLAND
@@ -269,7 +277,7 @@ bool CGrid_Profile_From_Lines::Show_Profile(CSG_Shapes *pPoints)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CGrid_Profile_From_Lines::Set_Profile(int ID_Line, CSG_Shape *pLine)
+bool CGrid_Profile_From_Lines::Set_Profile(sLong ID_Line, CSG_Shape *pLine)
 {
 	if( pLine && pLine->Get_Point_Count(0) < 2 )
 	{
@@ -292,7 +300,7 @@ bool CGrid_Profile_From_Lines::Set_Profile(int ID_Line, CSG_Shape *pLine)
 }
 
 //---------------------------------------------------------
-bool CGrid_Profile_From_Lines::Set_Profile(int ID_Line, bool bStart, const TSG_Point &A, const TSG_Point &B, bool bLastPoint)
+bool CGrid_Profile_From_Lines::Set_Profile(sLong ID_Line, bool bStart, const TSG_Point &A, const TSG_Point &B, bool bLastPoint)
 {
 	double dx = fabs(B.x - A.x);
 	double dy = fabs(B.y - A.y), n;
@@ -339,7 +347,7 @@ bool CGrid_Profile_From_Lines::Set_Profile(int ID_Line, bool bStart, const TSG_P
 }
 
 //---------------------------------------------------------
-bool CGrid_Profile_From_Lines::Add_Point(int ID_Line, bool bStart, const TSG_Point &Point)
+bool CGrid_Profile_From_Lines::Add_Point(sLong ID_Line, bool bStart, const TSG_Point &Point)
 {
 	int x, y; Get_System().Get_World_to_Grid(x, y, Point);
 
