@@ -60,7 +60,7 @@
 //---------------------------------------------------------
 enum
 {
-	PLANE_SIDE_X	= 0,
+	PLANE_SIDE_X = 0,
 	PLANE_SIDE_Y,
 	PLANE_SIDE_Z
 };
@@ -71,6 +71,8 @@ class C3D_Viewer_Grids_Panel : public CSG_3DView_Panel
 public:
 	C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGrids);
 
+	static CSG_String			Get_Usage				(void);
+
 
 protected:
 
@@ -79,7 +81,8 @@ protected:
 	virtual void				Update_Statistics		(void);
 	virtual void				Update_Parent			(void);
 
-	virtual void				On_Key_Down				(wxKeyEvent &event);
+	virtual void				On_Key_Down				(wxKeyEvent   &event);
+	virtual void				On_Mouse_Motion			(wxMouseEvent &event);
 
 	virtual bool				On_Draw					(void);
 
@@ -99,7 +102,7 @@ private:
 	CSG_Grids					*m_pGrids;
 	
 
-	bool						Set_ZScale				(bool bIncrease);
+	bool						Inc_ZScale				(double Scale);
 	bool						Set_ZLevel				(bool bIncrease);
 	bool						Set_Resolution			(bool bIncrease, bool bVertical);
 
@@ -126,7 +129,8 @@ private:
 
 //---------------------------------------------------------
 BEGIN_EVENT_TABLE(C3D_Viewer_Grids_Panel, CSG_3DView_Panel)
-	EVT_KEY_DOWN	(C3D_Viewer_Grids_Panel::On_Key_Down)
+	EVT_KEY_DOWN(C3D_Viewer_Grids_Panel::On_Key_Down)
+	EVT_MOTION  (C3D_Viewer_Grids_Panel::On_Mouse_Motion)
 END_EVENT_TABLE()
 
 
@@ -141,7 +145,7 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 	m_pGrids = pGrids;
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Double("NODE_GENERAL",
+	m_Parameters.Add_Double("GENERAL",
 		"RESOLUTION_XY"	, _TL("Horizontal Resolution"),
 		_TL("Horizontal resolution (x/y) in map units. Use [F7]/[F8] keys to de-/increase."),
 		m_pGrids->Get_Extent().Get_Diameter() / 200,
@@ -162,7 +166,7 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 		), 0
 	);
 
-	m_Parameters.Add_Int("NODE_GENERAL",
+	m_Parameters.Add_Int("GENERAL",
 		"RESOLUTION_Z"	, _TL("Vertical Resolution"),
 		_TL("Vertical resolution (z) in number of levels. Use [F9]/[F10] keys to de-/increase."),
 		M_GET_MIN(m_pGrids->Get_NZ() * 4, 200), 10, true
@@ -179,55 +183,21 @@ C3D_Viewer_Grids_Panel::C3D_Viewer_Grids_Panel(wxWindow *pParent, CSG_Grids *pGr
 	);
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Node("",
-		"NODE_VIEW"		, _TL("Grid View Settings"),
-		_TL("")
-	);
-
 	if( !SG_UI_DataObject_Colors_Get(m_pGrids, &m_Colors) )
 	{
 		m_Colors.Set_Palette(SG_COLORS_RAINBOW);
 	}
 
-	m_Parameters.Add_Colors("NODE_VIEW",
-		"COLORS"		, _TL("Colors"),
-		_TL(""),
-		&m_Colors
-	);
-
-	m_Parameters.Add_Range("COLORS",
-		"COLOR_STRETCH"	, _TL("Histogram Stretch"),
-		_TL(""),
+	m_Parameters.Add_Colors("GENERAL", "COLORS"       , _TL("Colors"           ), _TL(""), &m_Colors);
+	m_Parameters.Add_Bool  ("COLORS" , "COLORS_GRAD"  , _TL("Graduated"        ), _TL(""), true);
+	m_Parameters.Add_Range ("COLORS" , "COLOR_STRETCH", _TL("Histogram Stretch"), _TL(""),
 		m_pGrids->Get_Mean() - 2. * m_pGrids->Get_StdDev(),
 		m_pGrids->Get_Mean() + 2. * m_pGrids->Get_StdDev()
 	);
 
-	m_Parameters.Add_Bool("COLORS",
-		"COLORS_GRAD"	, _TL("Graduated"),
-		_TL(""),
-		true
-	);
-
-	m_Parameters.Add_Choice("NODE_VIEW",
-		"SHADING"		, _TL("Shading"),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("none"),
-			_TL("shading")
-		), 1
-	);
-
-	m_Parameters.Add_Double("SHADING",
-		"SHADE_DEC"		, _TL("Light Source Height"),
-		_TL(""),
-		 45., -90., true, 90., true
-	);
-
-	m_Parameters.Add_Double("SHADING",
-		"SHADE_AZI"		, _TL("Light Source Direction"),
-		_TL(""),
-		45., -90., true, 90., true
-	);
+	m_Parameters.Add_Choice("GENERAL", "SHADING"      , _TL("Light Source"     ), _TL(""), CSG_String::Format("%s|%s", _TL("no"), _TL("yes")), 1);
+	m_Parameters.Add_Double("SHADING", "SHADE_DEC"    , _TL("Height"           ), _TL(""), 45., -90., true, 90., true);
+	m_Parameters.Add_Double("SHADING", "SHADE_AZI"    , _TL("Direction"        ), _TL(""), 45., -90., true, 90., true);
 
 	//-----------------------------------------------------
 	m_Parameters("Z_SCALE")->Set_Value(0.2 * (m_pGrids->Get_XRange() + m_pGrids->Get_YRange()) / m_pGrids->Get_ZRange());
@@ -256,8 +226,7 @@ int C3D_Viewer_Grids_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CS
 {
 	if( pParameter->Cmp_Identifier("SHADING") )
 	{
-		pParameters->Set_Enabled("SHADE_DEC", pParameter->asBool());
-		pParameters->Set_Enabled("SHADE_AZI", pParameter->asBool());
+		pParameter->Set_Children_Enabled(pParameter->asInt() > 0);
 	}
 
 	return( CSG_3DView_Panel::On_Parameters_Enable(pParameters, pParameter) );
@@ -271,16 +240,16 @@ int C3D_Viewer_Grids_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CS
 //---------------------------------------------------------
 void C3D_Viewer_Grids_Panel::Update_Statistics(void)
 {
-	m_Data_Min.x	= m_pGrids->Get_XMin();
-	m_Data_Max.x	= m_pGrids->Get_XMax();
+	m_Data_Min.x = m_pGrids->Get_XMin();
+	m_Data_Max.x = m_pGrids->Get_XMax();
 
-	m_Data_Min.y	= m_pGrids->Get_YMin();
-	m_Data_Max.y	= m_pGrids->Get_YMax();
+	m_Data_Min.y = m_pGrids->Get_YMin();
+	m_Data_Max.y = m_pGrids->Get_YMax();
 
-	m_Data_Min.z	= m_pGrids->Get_ZMin();
-	m_Data_Max.z	= m_pGrids->Get_ZMax();
+	m_Data_Min.z = m_pGrids->Get_ZMin();
+	m_Data_Max.z = m_pGrids->Get_ZMax();
 
-	Set_Planes();	// Update_View();
+	Set_Planes(); // Update_View();
 }
 
 //---------------------------------------------------------
@@ -295,10 +264,12 @@ void C3D_Viewer_Grids_Panel::Update_Parent(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool C3D_Viewer_Grids_Panel::Set_ZScale(bool bIncrease)
+bool C3D_Viewer_Grids_Panel::Inc_ZScale(double Increase)
 {
-	double d = 0.1 * 0.25 * (m_pGrids->Get_XRange() + m_pGrids->Get_YRange()) / m_pGrids->Get_ZRange();
-	m_Parameters("Z_SCALE")->Set_Value(m_Parameters("Z_SCALE")->asDouble() + (bIncrease ? d : -d));
+	double d = (m_pGrids->Get_XRange() + m_pGrids->Get_YRange()) / m_pGrids->Get_ZRange();
+
+	m_Parameters("Z_SCALE")->Set_Value(m_Parameters("Z_SCALE")->asDouble() + d * Increase / 10.);
+
 	Update_View();
 
 	return( true );
@@ -309,10 +280,10 @@ bool C3D_Viewer_Grids_Panel::Set_ZLevel(bool bIncrease)
 {
 	for(int i=1; i<m_pGrids->Get_NZ(); i++)
 	{
-		double	z	= m_pGrids->Get_Z(bIncrease ? i : m_pGrids->Get_NZ() - 1 - i);
+		double z = m_pGrids->Get_Z(bIncrease ? i : m_pGrids->Get_NZ() - 1 - i);
 
-		z	= (z - m_pGrids->Get_ZMin()) / m_pGrids->Get_ZRange();
-		z	= (int)(z * 100.) / 100.;	// rounding
+		z = (z - m_pGrids->Get_ZMin()) / m_pGrids->Get_ZRange();
+		z = (int)(z * 100.) / 100.;	// rounding
 
 		if( (bIncrease ==  true && z > m_Position[PLANE_SIDE_Z])
 		||  (bIncrease == false && z < m_Position[PLANE_SIDE_Z]) )
@@ -331,7 +302,7 @@ bool C3D_Viewer_Grids_Panel::Set_Resolution(bool bIncrease, bool bVertical)
 {
 	if( bVertical )
 	{
-		double	d	= m_Parameters("RESOLUTION_Z")->asDouble();
+		double d = m_Parameters("RESOLUTION_Z")->asDouble();
 
 		m_Parameters("RESOLUTION_Z")->Set_Value(bIncrease
 			? d + 5
@@ -340,7 +311,7 @@ bool C3D_Viewer_Grids_Panel::Set_Resolution(bool bIncrease, bool bVertical)
 	}
 	else
 	{
-		double	d	= m_Parameters("RESOLUTION_XY")->asDouble();
+		double d = m_Parameters("RESOLUTION_XY")->asDouble();
 
 		m_Parameters("RESOLUTION_XY")->Set_Value(bIncrease
 			? d - m_pGrids->Get_Cellsize()
@@ -353,32 +324,76 @@ bool C3D_Viewer_Grids_Panel::Set_Resolution(bool bIncrease, bool bVertical)
 	return( true );
 }
 
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_String C3D_Viewer_Grids_Panel::Get_Usage(void)
+{
+	CSG_Table Shortcuts(CSG_3DView_Panel::Get_Shortcuts());
+
+	#define ADD_SHORTCUT(KEY, CMD) { CSG_Table_Record &r = *Shortcuts.Add_Record(); r.Set_Value(0, KEY); r.Set_Value(1, CMD); }
+
+	ADD_SHORTCUT("F3", _TL("Decrease Horizontal Resolution"));
+	ADD_SHORTCUT("F4", _TL("Increase Horizontal Resolution"));
+
+	ADD_SHORTCUT("F5", _TL("Decrease Vertical Resolution"  ));
+	ADD_SHORTCUT("F6", _TL("Increase Vertical Resolution"  ));
+
+	ADD_SHORTCUT("F7", _TL("Previous Level"                ));
+	ADD_SHORTCUT("F8", _TL("Next Level"                    ));
+
+	return( CSG_3DView_Panel::Get_Usage(Shortcuts) );
+}
+
 //---------------------------------------------------------
 void C3D_Viewer_Grids_Panel::On_Key_Down(wxKeyEvent &event)
 {
 	switch( event.GetKeyCode() )
 	{
-	default:
-		CSG_3DView_Panel::On_Key_Down(event);
-		return;
+	default: CSG_3DView_Panel::On_Key_Down(event); return;
 
-	//-----------------------------------------------------
-	case WXK_F1 : Set_ZScale(false); break;
-	case WXK_F2 : Set_ZScale( true); break;
+	case WXK_F1: Inc_ZScale(-0.5); break;
+	case WXK_F2: Inc_ZScale( 0.5); break;
 
-	case WXK_F7 : Set_Resolution(false, false); break;
-	case WXK_F8 : Set_Resolution( true, false); break;
+	case WXK_F3: Set_Resolution(false, false); break;
+	case WXK_F4: Set_Resolution( true, false); break;
 
-	case WXK_F9 : Set_Resolution(false,  true); break;
-	case WXK_F10: Set_Resolution( true,  true); break;
+	case WXK_F5: Set_Resolution(false,  true); break;
+	case WXK_F6: Set_Resolution( true,  true); break;
 
-	case WXK_F11: Set_ZLevel(false); break;
-	case WXK_F12: Set_ZLevel( true); break;
+	case WXK_F7: Set_ZLevel(false); break;
+	case WXK_F8: Set_ZLevel( true); break;
 	}
 
 	Update_Parent();
 }
 
+//---------------------------------------------------------
+#define GET_MOUSE_X_RELDIFF	((double)(m_Down_Screen.x - event.GetX()) / (double)GetClientSize().x)
+#define GET_MOUSE_Y_RELDIFF	((double)(m_Down_Screen.y - event.GetY()) / (double)GetClientSize().y)
+
+//---------------------------------------------------------
+void C3D_Viewer_Grids_Panel::On_Mouse_Motion(wxMouseEvent &event)
+{
+	if( HasCapture() && event.Dragging() && event.MiddleIsDown() )
+	{
+		m_Projector.Set_Central_Distance(m_Down_Value.x + GET_MOUSE_X_RELDIFF);
+
+		double d = (m_pGrids->Get_XRange() + m_pGrids->Get_YRange()) / m_pGrids->Get_ZRange();
+
+		m_Parameters("Z_SCALE")->Set_Value(m_Down_Value.y + d * GET_MOUSE_Y_RELDIFF);
+
+		Update_View(); Update_Parent();
+
+		return;
+	}
+
+	CSG_3DView_Panel::On_Mouse_Motion(event);
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -392,7 +407,7 @@ int C3D_Viewer_Grids_Panel::Get_Color(double Value)
 		return( (int)Value );
 	}
 
-	double	c	= m_Color_Scale * (Value - m_Color_Min);
+	double c = m_Color_Scale * (Value - m_Color_Min);
 
 	return( m_Color_bGrad ? m_Colors.Get_Interpolated(c) : m_Colors[(int)c] );
 }
@@ -405,12 +420,12 @@ int C3D_Viewer_Grids_Panel::Get_Color(double Value)
 //---------------------------------------------------------
 bool C3D_Viewer_Grids_Panel::On_Draw(void)
 {
-	m_Colors		=*m_Parameters("COLORS")->asColors();
-	m_Color_bGrad	= m_Parameters("COLORS_GRAD")->asBool();
+	m_Colors      =*m_Parameters("COLORS")->asColors();
+	m_Color_bGrad = m_Parameters("COLORS_GRAD")->asBool();
 
-	m_Color_Min		= m_Parameters("COLOR_STRETCH")->asRange()->Get_Min();
-	double	Range	= m_Parameters("COLOR_STRETCH")->asRange()->Get_Max() - m_Color_Min;
-	m_Color_Scale	= Range > 0. ? (m_Colors.Get_Count() - 1) / Range : 0.;
+	m_Color_Min   = m_Parameters("COLOR_STRETCH")->asRange()->Get_Min();
+	double  Range = m_Parameters("COLOR_STRETCH")->asRange()->Get_Max() - m_Color_Min;
+	m_Color_Scale = Range > 0. ? (m_Colors.Get_Count() - 1) / Range : 0.;
 
 	//-----------------------------------------------------
 	Draw_Plane(m_Plane[PLANE_SIDE_X], m_Position[PLANE_SIDE_X], PLANE_SIDE_X);
@@ -451,17 +466,17 @@ bool C3D_Viewer_Grids_Panel::Set_Plane(double Position, int Side)
 //---------------------------------------------------------
 bool C3D_Viewer_Grids_Panel::Set_Plane(CSG_Grid &Plane, double Position, int Side)
 {
-	double	Cellsize	= m_Parameters("RESOLUTION_XY")->asDouble();
+	double Cellsize = m_Parameters("RESOLUTION_XY")->asDouble();
 
 	if( Cellsize < m_pGrids->Get_Cellsize() )
 	{
 		Cellsize = m_pGrids->Get_Cellsize();
 	}
 
-	int	zLevels	= m_Parameters("RESOLUTION_Z")->asInt();
+	int zLevels = m_Parameters("RESOLUTION_Z")->asInt();
 
 	//-----------------------------------------------------
-	TSG_Grid_Resampling	zResampling, Resampling;
+	TSG_Grid_Resampling zResampling, Resampling;
 
 	switch( m_Parameters("RESAMPLING_Z")->asInt() )
 	{
@@ -490,22 +505,20 @@ bool C3D_Viewer_Grids_Panel::Set_Plane(CSG_Grid &Plane, double Position, int Sid
 				Plane.Create(CSG_Grid_System(Cellsize, 0., m_pGrids->Get_YMin(), Cellsize * zLevels, m_pGrids->Get_YMax()));
 			}
 
-			double	dz	= m_pGrids->Get_ZRange() / Plane.Get_NX();
+			double dz = m_pGrids->Get_ZRange() / Plane.Get_NX();
 
-			#ifndef _DEBUG
 			#pragma omp parallel for
-			#endif
 			for(int y=0; y<Plane.Get_NY(); y++)
 			{
-				TSG_Point_Z	p;
+				TSG_Point_3D p;
 
-				p.z	= m_pGrids->Get_ZMin();
-				p.y	= Plane.Get_YMin() + Plane.Get_Cellsize() * y;
-				p.x	= m_pGrids->Get_XMin() + Position * m_pGrids->Get_XRange();
+				p.z = m_pGrids->Get_ZMin();
+				p.y = Plane.Get_YMin() + Plane.Get_Cellsize() * y;
+				p.x = m_pGrids->Get_XMin() + Position * m_pGrids->Get_XRange();
 
 				for(int x=0; x<Plane.Get_NX(); x++, p.z+=dz)
 				{
-					double	Value;
+					double Value;
 
 					if( m_pGrids->Get_Value(p, Value, Resampling, zResampling) )
 					{
@@ -528,22 +541,20 @@ bool C3D_Viewer_Grids_Panel::Set_Plane(CSG_Grid &Plane, double Position, int Sid
 				Plane.Create(CSG_Grid_System(Cellsize, m_pGrids->Get_XMin(), 0., m_pGrids->Get_XMax(), Cellsize * zLevels));
 			}
 
-			double	dz	= m_pGrids->Get_ZRange() / Plane.Get_NY();
+			double dz = m_pGrids->Get_ZRange() / Plane.Get_NY();
 
-			#ifndef _DEBUG
 			#pragma omp parallel for
-			#endif
 			for(int x=0; x<Plane.Get_NX(); x++)
 			{
-				TSG_Point_Z	p;
+				TSG_Point_3D p;
 
-				p.z	= m_pGrids->Get_ZMin();
-				p.y	= m_pGrids->Get_YMin() + Position * m_pGrids->Get_YRange();
-				p.x	= Plane.Get_XMin() + Plane.Get_Cellsize() * x;
+				p.z = m_pGrids->Get_ZMin();
+				p.y = m_pGrids->Get_YMin() + Position * m_pGrids->Get_YRange();
+				p.x = Plane.Get_XMin() + Plane.Get_Cellsize() * x;
 
 				for(int y=0; y<Plane.Get_NY(); y++, p.z+=dz)
 				{
-					double	Value;
+					double Value;
 
 					if( m_pGrids->Get_Value(p, Value, Resampling, zResampling) )
 					{
@@ -566,20 +577,18 @@ bool C3D_Viewer_Grids_Panel::Set_Plane(CSG_Grid &Plane, double Position, int Sid
 				Plane.Create(CSG_Grid_System(Cellsize, m_pGrids->Get_System().Get_Extent()));
 			}
 
-			#ifndef _DEBUG
 			#pragma omp parallel for
-			#endif
 			for(int y=0; y<Plane.Get_NY(); y++)
 			{
-				TSG_Point_Z	p;
+				TSG_Point_3D p;
 
-				p.z	= m_pGrids->Get_ZMin() + Position * m_pGrids->Get_ZRange();
-				p.y	= Plane.Get_YMin() + Plane.Get_Cellsize() * y;
-				p.x	= Plane.Get_XMin();
+				p.z = m_pGrids->Get_ZMin() + Position * m_pGrids->Get_ZRange();
+				p.y = Plane.Get_YMin() + Plane.Get_Cellsize() * y;
+				p.x = Plane.Get_XMin();
 
 				for(int x=0; x<Plane.Get_NX(); x++, p.x+=Plane.Get_Cellsize())
 				{
-					double	Value;
+					double Value;
 
 					if( m_pGrids->Get_Value(p, Value, Resampling, zResampling) )
 					{
@@ -608,7 +617,7 @@ inline bool C3D_Viewer_Grids_Panel::Get_Node(CSG_Grid &Plane, double Position, i
 {
 	if( Plane.is_InGrid(x, y) )
 	{
-		TSG_Point_Z p;
+		TSG_Point_3D p;
 
 		switch( Side )
 		{
@@ -722,10 +731,10 @@ public:
 		: wxDialog(pParent, wxID_ANY, _TL("Histogram"), wxDefaultPosition, wxDefaultSize, wxCAPTION|wxCLOSE_BOX|wxSTAY_ON_TOP)
 	#endif
 	{
-		m_pPanel		= pPanel;
-		m_pGrids		= pGrids;
-		m_nClasses		= 100;
-		m_bCumulative	= false;
+		m_pPanel      = pPanel;
+		m_pGrids      = pGrids;
+		m_nClasses    = 100;
+		m_bCumulative = false;
 
 		Set_Histogram(false);
 	}
@@ -751,7 +760,7 @@ private:
 	{
 		if( event.ControlDown() )
 		{
-			if( m_nClasses >   10 ) { m_nClasses -= 10; Set_Histogram(false); }
+			if( m_nClasses > 10 ) { m_nClasses -= 10; Set_Histogram(false); }
 		}
 		else
 		{
@@ -857,8 +866,8 @@ private:
 	//---------------------------------------------------------
 	void					Set_Histogram	(bool bRefresh = true)
 	{
-		double	Minimum	= m_pPanel->m_Parameters("COLOR_STRETCH")->asRange()->Get_Min();
-		double	Maximum	= m_pPanel->m_Parameters("COLOR_STRETCH")->asRange()->Get_Max();
+		double Minimum = m_pPanel->m_Parameters("COLOR_STRETCH")->asRange()->Get_Min();
+		double Maximum = m_pPanel->m_Parameters("COLOR_STRETCH")->asRange()->Get_Max();
 
 		m_Histogram.Create(m_nClasses, Minimum, Maximum, m_pGrids, m_pGrids->Get_Max_Samples());
 
@@ -1050,19 +1059,19 @@ protected:
 		wxMenu *pMenu = Menu.FindChildItem(Menu.FindItem(_TL("Display")))->GetSubMenu();
 
 		pMenu->AppendSeparator();
-		pMenu->Append(MENU_SCALE_Z_DEC , _TL("Decrease Exaggeration [F1]"));
-		pMenu->Append(MENU_SCALE_Z_INC , _TL("Increase Exaggeration [F2]"));
+		pMenu->Append(MENU_SCALE_Z_DEC , wxString::Format("%s [F1]", _TL("Decrease Exaggeration"         )));
+		pMenu->Append(MENU_SCALE_Z_INC , wxString::Format("%s [F2]", _TL("Increase Exaggeration"         )));
 
 		pMenu->AppendSeparator();
-		pMenu->Append(MENU_LEVEL_Z_DEC , _TL("Previous Level [F11]"));
-		pMenu->Append(MENU_LEVEL_Z_INC , _TL("Next Level [F12]"));
+		pMenu->Append(MENU_RESLT_XY_DEC, wxString::Format("%s [F3]", _TL("Decrease Horizontal Resolution")));
+		pMenu->Append(MENU_RESLT_XY_INC, wxString::Format("%s [F4]", _TL("Increase Horizontal Resolution")));
+
+		pMenu->Append(MENU_RESLT_Z_DEC , wxString::Format("%s [F5]", _TL("Decrease Vertical Resolution"  )));
+		pMenu->Append(MENU_RESLT_Z_INC , wxString::Format("%s [F6]", _TL("Increase Vertical Resolution"  )));
 
 		pMenu->AppendSeparator();
-		pMenu->Append(MENU_RESLT_XY_DEC, _TL("Decrease Horizontal Resolution [F7]"));
-		pMenu->Append(MENU_RESLT_XY_INC, _TL("Increase Horizontal Resolution [F8]"));
-
-		pMenu->Append(MENU_RESLT_Z_DEC , _TL("Decrease Vertical Resolution [F9]"));
-		pMenu->Append(MENU_RESLT_Z_INC , _TL("Increase Vertical Resolution [F10]"));
+		pMenu->Append(MENU_LEVEL_Z_DEC , wxString::Format("%s [F7]", _TL("Previous Level"                )));
+		pMenu->Append(MENU_LEVEL_Z_INC , wxString::Format("%s [F8]", _TL("Next Level"                    )));
 
 		pMenu->AppendSeparator();
 		pMenu->AppendCheckItem(MENU_SHOW_SHADER, _TL("Toggle Light Source Controls"));
@@ -1077,8 +1086,10 @@ protected:
 		{
 		default: CSG_3DView_Dialog::On_Menu(event); return;
 
-		case MENU_SCALE_Z_DEC : pPanel->Set_ZScale(false); break;
-		case MENU_SCALE_Z_INC : pPanel->Set_ZScale( true); break;
+		case MENU_USAGE       : SG_UI_Dlg_Info(C3D_Viewer_Grids_Panel::Get_Usage(), _TL("Usage")); return;
+
+		case MENU_SCALE_Z_DEC : pPanel->Inc_ZScale(-0.5); break;
+		case MENU_SCALE_Z_INC : pPanel->Inc_ZScale( 0.5); break;
 
 		case MENU_LEVEL_Z_DEC : pPanel->Set_ZLevel(false); break;
 		case MENU_LEVEL_Z_INC : pPanel->Set_ZLevel( true); break;
@@ -1221,6 +1232,8 @@ C3D_Viewer_Grids::C3D_Viewer_Grids(void)
 		"or grids representing a time series, if these are managed in a grid collection. "
 	));
 
+	Set_Description(Get_Description() + C3D_Viewer_Grids_Panel::Get_Usage());
+
 	//-----------------------------------------------------
 	Parameters.Add_Grids(
 		""	, "GRIDS"	, _TL("Grids"),
@@ -1232,7 +1245,7 @@ C3D_Viewer_Grids::C3D_Viewer_Grids(void)
 //---------------------------------------------------------
 bool C3D_Viewer_Grids::On_Execute(void)
 {
-	CSG_Grids	*pGrids	= Parameters("GRIDS")->asGrids();
+	CSG_Grids *pGrids = Parameters("GRIDS")->asGrids();
 
 	if( pGrids->Get_Grid_Count() <= 0 )
 	{
@@ -1241,7 +1254,7 @@ bool C3D_Viewer_Grids::On_Execute(void)
 		return( false );
 	}
 
-	C3D_Viewer_Grids_Dialog	dlg(pGrids);
+	C3D_Viewer_Grids_Dialog dlg(pGrids);
 
 	dlg.ShowModal();
 
