@@ -63,11 +63,14 @@ class C3D_Viewer_PointCloud_Panel : public CSG_3DView_Panel
 public:
 	C3D_Viewer_PointCloud_Panel(wxWindow *pParent, CSG_PointCloud *pPoints, int Field_Color);
 
+	static CSG_String			Get_Usage				(void);
+
 	void						Set_Extent				(CSG_Rect Extent);
 
 
 protected:
 
+	virtual int					On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 	virtual int					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
 	virtual void				Update_Statistics		(void);
@@ -120,104 +123,39 @@ END_EVENT_TABLE()
 C3D_Viewer_PointCloud_Panel::C3D_Viewer_PointCloud_Panel(wxWindow *pParent, CSG_PointCloud *pPoints, int Field_Color)
 	: CSG_3DView_Panel(pParent)
 {
-	m_pPoints	= pPoints;
+	m_pPoints = pPoints;
 
 	//-----------------------------------------------------
-	CSG_String	Attributes;
+	CSG_String Attributes;
 
 	for(int i=0; i<m_pPoints->Get_Field_Count(); i++)
 	{
-		Attributes	+= m_pPoints->Get_Field_Name(i);
-		Attributes	+= "|";
+		Attributes += m_pPoints->Get_Field_Name(i); Attributes += "|";
 	}
 
-	//-----------------------------------------------------
-	m_Parameters.Add_Double("NODE_GENERAL",
-		"Z_SCALE"		, _TL("Exaggeration"),
-		_TL(""),
-		1.
-	);
+	//----------------------------------------------------
+	m_Parameters.Add_Double("GENERAL"    , "DETAIL"       , _TL("Level of Detail"   ), _TL(""), 100., 0., true, 100., true);
+
+	m_Parameters.Add_Choice("GENERAL"    , "COLORS_ATTR"  , _TL("Color Attribute"   ), _TL(""), Attributes, Field_Color);
+	m_Parameters.Add_Bool  ("COLORS_ATTR", "VAL_AS_RGB"   , _TL("RGB Values"        ), _TL(""), false);
+	m_Parameters.Add_Colors("COLORS_ATTR", "COLORS"       , _TL("Colors"            ), _TL(""));
+	m_Parameters.Add_Choice("COLORS_ATTR", "COLORS_GRAD"  , _TL("Color Classes"     ), _TL(""), CSG_String::Format("%s|%s", _TL("discrete"), _TL("graduated")), 1);
+	m_Parameters.Add_Choice("COLORS_ATTR", "COLORS_FIT"   , _TL("Color Fit"         ), _TL(""), CSG_String::Format("%s|%s", _TL("to extent when zoomed"), _TL("constant value range")), 0);
+	m_Parameters.Add_Range ("COLORS_FIT" , "COLORS_RANGE" , _TL("Value Range"       ), _TL(""));
+	m_Parameters.Add_Double("COLORS_FIT" , "COLORS_STDDEV", _TL("Standard Deviation"), _TL(""), 1.5, 0.1, true);
+
+	m_Parameters.Add_Bool  ("GENERAL"    , "DIM"          , _TL("Dim"               ), _TL(""), false);
+	m_Parameters.Add_Range ("DIM"        , "DIM_RANGE"    , _TL("Distance Range"    ), _TL(""), 0., 1., 0., true);
+
+	m_Parameters.Add_Int   ("GENERAL"    , "SIZE"         , _TL("Size"              ), _TL(""), 1, 1, true);
+	m_Parameters.Add_Double("GENERAL"    , "SIZE_SCALE"   , _TL("Size Scaling"      ), _TL(""), 0., 0., true);
+
+	m_Parameters.Add_Choice("GENERAL"    , "OVERVIEW_ATTR", _TL("Overview Content"  ), _TL(""), CSG_String::Format("%s|%s", _TL("average value"), _TL("number of points")), 0);
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Node("",
-		"NODE_VIEW"		, _TL("Point View Settings"),
-		_TL("")
-	);
+	m_Extent = pPoints->Get_Extent();
 
-	m_Parameters.Add_Double("NODE_VIEW",
-		"DETAIL"		, _TL("Level of Detail"),
-		_TL(""),
-		100., 0., true, 100., true
-	);
-
-	m_Parameters.Add_Choice("NODE_VIEW",
-		"COLORS_ATTR"	, _TL("Color Attribute"),
-		_TL(""),
-		Attributes, Field_Color
-	);
-
-	m_Parameters.Add_Bool("COLORS_ATTR",
-		"VAL_AS_RGB"	, _TL("RGB Values"),
-		_TL(""),
-		false
-	);
-
-	m_Parameters.Add_Colors("COLORS_ATTR",
-		"COLORS"		, _TL("Colors"),
-		_TL("")
-	);
-
-	m_Parameters.Add_Bool("COLORS_ATTR",
-		"COLORS_GRAD"	, _TL("Graduated"),
-		_TL(""),
-		true
-	);
-
-	m_Parameters.Add_Range("COLORS_ATTR",
-		"COLORS_RANGE"	, _TL("Value Range"),
-		_TL("")
-	);
-
-	//-----------------------------------------------------
-	m_Parameters.Add_Bool("NODE_VIEW",
-		"DIM"			, _TL("Dim"),
-		_TL(""),
-		false
-	);
-
-	m_Parameters.Add_Range("DIM",
-		"DIM_RANGE"		, _TL("Distance Range"),
-		_TL(""),
-		0., 1., 0., true
-	);
-
-	//-----------------------------------------------------
-	m_Parameters.Add_Int("NODE_VIEW",
-		"SIZE"			, _TL("Size"),
-		_TL(""),
-		2, 1, true
-	);
-
-	m_Parameters.Add_Double("NODE_VIEW",
-		"SIZE_SCALE"	, _TL("Size Scaling"),
-		_TL(""),
-		0., 0., true
-	);
-
-	//-----------------------------------------------------
-	m_Parameters.Add_Choice("NODE_VIEW",
-		"OVERVIEW_ATTR"	, _TL("Overview Content"),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("average value"),
-			_TL("number of points")
-		), 0
-	);
-
-	//-----------------------------------------------------
-	m_Extent	= pPoints->Get_Extent();
-
-	m_Selection.Create(sizeof(int), 0, SG_ARRAY_GROWTH_2);
+	m_Selection.Create(sizeof(sLong), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_2);
 
 	Update_Statistics();
 }
@@ -227,13 +165,33 @@ C3D_Viewer_PointCloud_Panel::C3D_Viewer_PointCloud_Panel(wxWindow *pParent, CSG_
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+int C3D_Viewer_PointCloud_Panel::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("COLORS_ATTR") )
+	{
+		double m = m_pPoints->Get_Mean(pParameter->asInt()), s = m_pPoints->Get_StdDev(pParameter->asInt()) * (*pParameters)("COLORS_STDDEV")->asDouble();
+
+		pParameters->Set_Parameter("COLORS_RANGE.MIN", m - s);
+		pParameters->Set_Parameter("COLORS_RANGE.MAX", m + s);
+	}
+
+	return( CSG_3DView_Panel::On_Parameter_Changed(pParameters, pParameter) );
+}
+
 //---------------------------------------------------------
 int C3D_Viewer_PointCloud_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
 	if( pParameter->Cmp_Identifier("VAL_AS_RGB") )
 	{
 		pParameters->Set_Enabled("COLORS"      , pParameter->asBool() == false);
-		pParameters->Set_Enabled("COLORS_RANGE", pParameter->asBool() == false);
+		pParameters->Set_Enabled("COLORS_GRAD" , pParameter->asBool() == false);
+		pParameters->Set_Enabled("COLORS_FIT"  , pParameter->asBool() == false);
+	}
+
+	if( pParameter->Cmp_Identifier("COLORS_FIT") )
+	{
+		pParameters->Set_Enabled("COLORS_RANGE", pParameter->asInt() == 1);
 	}
 
 	if( pParameter->Cmp_Identifier("DIM") )
@@ -280,41 +238,46 @@ void C3D_Viewer_PointCloud_Panel::Update_Statistics(void)
 
 	m_Selection.Set_Array(0);
 
+	int    cField = m_Parameters("COLORS_ATTR"  )->asInt   ();
+	double cSigma = m_Parameters("COLORS_STDDEV")->asDouble();
+
 	if( m_Extent.is_Equal(m_pPoints->Get_Extent()) )
 	{
-		int	cField = m_Parameters("COLORS_ATTR")->asInt();
-
-		m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
-			m_pPoints->Get_Mean(cField) - 1.5 * m_pPoints->Get_StdDev(cField),
-			m_pPoints->Get_Mean(cField) + 1.5 * m_pPoints->Get_StdDev(cField)
-		);
+		if( m_Parameters("COLORS_FIT")->asInt() == 0 )
+		{
+			m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
+				m_pPoints->Get_Mean(cField) - cSigma * m_pPoints->Get_StdDev(cField),
+				m_pPoints->Get_Mean(cField) + cSigma * m_pPoints->Get_StdDev(cField)
+			);
+		}
 
 		m_Data_Min.z = m_pPoints->Get_Minimum(2);	// Get_ZMin();	ToDo in CSG_PointCloud class!!!
 		m_Data_Max.z = m_pPoints->Get_Maximum(2);	// Get_ZMax();	ToDo in CSG_PointCloud class!!!
 	}
 	else
 	{
-		CSG_Simple_Statistics	cStats, zStats;
+		CSG_Simple_Statistics zStats, cStats;
 
-		int	cField = m_Parameters("COLORS_ATTR")->asInt();
-
-		for(int i=0; i<m_pPoints->Get_Count(); i++)
+		for(sLong i=0; i<m_pPoints->Get_Count(); i++)
 		{
 			m_pPoints->Set_Cursor(i);
 
 			if( m_Extent.Contains(m_pPoints->Get_X(), m_pPoints->Get_Y()) && m_Selection.Inc_Array() )
 			{
-				*((int *)m_Selection.Get_Entry(m_Selection.Get_Size() - 1))	= i;
+				*((sLong *)m_Selection.Get_Entry(m_Selection.Get_Size() - 1))	= i;
 
 				cStats += m_pPoints->Get_Value(cField);
 				zStats += m_pPoints->Get_Z();
 			}
 		}
 
-		m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
-			cStats.Get_Mean() - 1.5 * cStats.Get_StdDev(),
-			cStats.Get_Mean() + 1.5 * cStats.Get_StdDev()
-		);
+		if( m_Parameters("COLORS_FIT")->asInt() == 0 )
+		{
+			m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
+				cStats.Get_Mean() - cSigma * cStats.Get_StdDev(),
+				cStats.Get_Mean() + cSigma * cStats.Get_StdDev()
+			);
+		}
 
 		m_Data_Min.z = zStats.Get_Minimum();
 		m_Data_Max.z = zStats.Get_Maximum();
@@ -332,6 +295,22 @@ void C3D_Viewer_PointCloud_Panel::Update_Parent(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+CSG_String C3D_Viewer_PointCloud_Panel::Get_Usage(void)
+{
+	CSG_Table Shortcuts(CSG_3DView_Panel::Get_Shortcuts());
+
+	#define ADD_SHORTCUT(KEY, CMD) { CSG_Table_Record &r = *Shortcuts.Add_Record(); r.Set_Value(0, KEY); r.Set_Value(1, CMD); }
+
+	ADD_SHORTCUT("F3", _TL("Decrease Size"        ));
+	ADD_SHORTCUT("F4", _TL("Increase Size"        ));
+
+	ADD_SHORTCUT("F5", _TL("Decrease Size Scaling"));
+	ADD_SHORTCUT("F6", _TL("Increase Size Scaling"));
+
+	return( CSG_3DView_Panel::Get_Usage(Shortcuts) );
+}
+
 //---------------------------------------------------------
 void C3D_Viewer_PointCloud_Panel::On_Key_Down(wxKeyEvent &event)
 {
@@ -339,18 +318,12 @@ void C3D_Viewer_PointCloud_Panel::On_Key_Down(wxKeyEvent &event)
 	{
 	default    : CSG_3DView_Panel::On_Key_Down(event); return;
 
-	case WXK_F1: m_Parameters("Z_SCALE"   )->Set_Value(m_Parameters("Z_SCALE"   )->asDouble() - 0.5); break;
-	case WXK_F2: m_Parameters("Z_SCALE"   )->Set_Value(m_Parameters("Z_SCALE"   )->asDouble() + 0.5); break;
+	case WXK_F3: Parameter_Value_Add("SIZE"      ,  -1.); break;
+	case WXK_F4: Parameter_Value_Add("SIZE"      ,   1.); break;
 
-	case WXK_F5: m_Parameters("SIZE"      )->Set_Value(m_Parameters("SIZE"      )->asDouble() - 1.0); break;
-	case WXK_F6: m_Parameters("SIZE"      )->Set_Value(m_Parameters("SIZE"      )->asDouble() + 1.0); break;
-
-	case WXK_F7: m_Parameters("SIZE_SCALE")->Set_Value(m_Parameters("SIZE_SCALE")->asDouble() - 1.0); break;
-	case WXK_F8: m_Parameters("SIZE_SCALE")->Set_Value(m_Parameters("SIZE_SCALE")->asDouble() + 1.0); break;
+	case WXK_F5: Parameter_Value_Add("SIZE_SCALE", -10.); break;
+	case WXK_F6: Parameter_Value_Add("SIZE_SCALE",  10.); break;
 	}
-
-	//-----------------------------------------------------
-	Update_View(); Update_Parent();
 }
 
 
@@ -414,17 +387,17 @@ bool C3D_Viewer_PointCloud_Panel::On_Draw(void)
 {
 	int cField = m_Parameters("COLORS_ATTR")->asInt();
 
-	if( m_Parameters("COLORS_RANGE")->asRange()->Get_Min()
-	>=  m_Parameters("COLORS_RANGE")->asRange()->Get_Max() )
+	if( m_Parameters("COLORS_RANGE.MIN")->asDouble()
+	>=  m_Parameters("COLORS_RANGE.MAX")->asDouble() )
 	{
-		m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
-			m_pPoints->Get_Mean(cField) - 1.5 * m_pPoints->Get_StdDev(cField),
-			m_pPoints->Get_Mean(cField) + 1.5 * m_pPoints->Get_StdDev(cField)
-		);
+		double cSigma = m_Parameters("COLORS_STDDEV")->asDouble();
+
+		m_Parameters("COLORS_RANGE.MIN")->Set_Value(m_pPoints->Get_Mean(cField) - cSigma * m_pPoints->Get_StdDev(cField));
+		m_Parameters("COLORS_RANGE.MAX")->Set_Value(m_pPoints->Get_Mean(cField) + cSigma * m_pPoints->Get_StdDev(cField));
 	}
 
 	m_Colors      = *m_Parameters("COLORS")->asColors();
-	m_Color_bGrad = m_Parameters("COLORS_GRAD")->asBool();
+	m_Color_bGrad = m_Parameters("COLORS_GRAD")->asInt() == 1;
 	m_Color_Min   = m_Parameters("COLORS_RANGE.MIN")->asDouble();
 	m_Color_Scale = m_Parameters("COLORS_RANGE.MAX")->asDouble() - m_Color_Min;
 	m_Color_Scale = m_Parameters("VAL_AS_RGB")->asBool() || m_Color_Scale <= 0. ? 0. : m_Colors.Get_Count() / m_Color_Scale;
@@ -444,14 +417,14 @@ bool C3D_Viewer_PointCloud_Panel::On_Draw(void)
 	
 	int nSkip   = 1 + (int)(0.001 * m_pPoints->Get_Count() * SG_Get_Square(1. - 0.01 * m_Parameters("DETAIL")->asDouble()));
 
-	int	nPoints	= m_Selection.Get_Size() > 0 ? (int)m_Selection.Get_Size() : m_pPoints->Get_Count();
+	sLong	nPoints	= m_Selection.Get_Size() > 0 ? m_Selection.Get_Size() : m_pPoints->Get_Count();
 
 	#pragma omp parallel for
-	for(int iPoint=0; iPoint<nPoints; iPoint+=nSkip)
+	for(sLong iPoint=0; iPoint<nPoints; iPoint+=nSkip)
 	{
-		int jPoint = m_Selection.Get_Size() > 0 ? *((int *)m_Selection.Get_Entry(iPoint)) : iPoint;
+		sLong jPoint = m_Selection.Get_Size() > 0 ? *((sLong *)m_Selection.Get_Entry(iPoint)) : iPoint;
 
-		TSG_Point_Z p = m_pPoints->Get_Point(jPoint); m_Projector.Get_Projection(p);
+		TSG_Point_3D p = m_pPoints->Get_Point(jPoint); m_Projector.Get_Projection(p);
 
 		double Size = minSize; if( dSize > 0. ) { Size += (int)(50. * exp(-p.z / dSize)); }
 
@@ -489,6 +462,8 @@ public:
 	{
 		m_pPanel = pPanel;
 
+		m_bCount = m_pPanel->m_Parameters("OVERVIEW_ATTR")->asInt() == 1;
+
 		double Ratio = pPoints->Get_Extent().Get_XRange() / pPoints->Get_Extent().Get_YRange();
 
 		int Size = GetClientSize().GetWidth(); CSG_Rect r(pPoints->Get_Extent()); CSG_Grid_System System;
@@ -515,8 +490,10 @@ public:
 		m_Count.Create(System, SG_DATATYPE_Int   );
 		m_Value.Create(System, SG_DATATYPE_Double);
 
-		for(int i=0, x, y; i<pPoints->Get_Count(); i++)
+		for(sLong i=0; i<pPoints->Get_Count(); i++)
 		{
+			int x, y;
+
 			if( m_Count.Get_System().Get_World_to_Grid(x, y, pPoints->Get_X(i), pPoints->Get_Y(i)) ) // && m_Count.is_InGrid(x, y, false) )
 			{
 				m_Count.Add_Value(x, y, 1);
@@ -541,6 +518,18 @@ public:
 	#endif
 	}
 
+	void						Set_Mode		(void)
+	{
+		bool bCount = m_pPanel->m_Parameters("OVERVIEW_ATTR")->asInt() == 1;
+
+		if( m_bCount != bCount )
+		{
+			m_bCount  = bCount;
+
+			Set_Image(true);
+		}
+	}
+
 
 private:
 
@@ -604,8 +593,8 @@ private:
 	//---------------------------------------------------------
 	void						On_Mouse_MDown	(wxMouseEvent &event)
 	{
-		m_pPanel->m_Parameters("OVERVIEW_ATTR")->Set_Value(m_pPanel->m_Parameters("OVERVIEW_ATTR")->asInt() ? 0 : 1);
-		Set_Image(true);
+		m_pPanel->Parameter_Value_Toggle("OVERVIEW_ATTR");
+		Set_Mode();
 	}
 
 	//---------------------------------------------------------
@@ -627,7 +616,7 @@ private:
 		case WXK_PAGEDOWN: Set_Size(GetClientSize().GetWidth() / 1.25, GetClientSize().GetHeight() / 1.25, true); break;
 
 		case WXK_SPACE:
-			m_pPanel->m_Parameters("OVERVIEW_ATTR")->Set_Value(m_pPanel->m_Parameters("OVERVIEW_ATTR")->asInt() ? 0 : 1);
+			m_pPanel->Parameter_Value_Toggle("OVERVIEW_ATTR");
 			Set_Image(true);
 			break;
 		}
@@ -705,13 +694,11 @@ private:
 	{
 		if( m_Image.IsOk() && m_Count.is_Valid() )
 		{
-			bool bCount = m_pPanel->m_Parameters("OVERVIEW_ATTR")->asInt() == 1;
-
 			CSG_Colors Colors(11, SG_COLORS_RAINBOW); Colors.Set_Color(0, m_pPanel->m_Parameters("BGCOLOR")->asColor());
 
 			double dx = m_Count.Get_XRange() / (double)m_Image.GetWidth ();
 			double dy = m_Count.Get_YRange() / (double)m_Image.GetHeight();
-			double dz = (Colors.Get_Count() - 2.) / (bCount ? log(1. + m_Count.Get_Max()) : 4. * m_Value.Get_StdDev());
+			double dz = (Colors.Get_Count() - 2.) / (m_bCount ? log(1. + m_Count.Get_Max()) : 4. * m_Value.Get_StdDev());
 
 			#pragma omp parallel for
 			for(int y=0; y<m_Image.GetHeight(); y++)
@@ -720,7 +707,7 @@ private:
 
 				for(int x=0; x<m_Image.GetWidth(); x++, ix+=dx)
 				{
-					if( bCount )
+					if( m_bCount )
 					{
 						iz = dz * (m_Count.Get_Value(ix, iy, iz) && iz > 0. ? log(1. + iz) : 0.);
 					}
@@ -905,6 +892,8 @@ void C3D_Viewer_PointCloud_Dialog::Update_Controls(void)
 	m_pOverview_Check->SetValue(m_pOverview->IsShown());
 #endif
 
+	m_pOverview->Set_Mode();
+
 	CSG_3DView_Dialog::Update_Controls();
 }
 
@@ -935,9 +924,9 @@ void C3D_Viewer_PointCloud_Dialog::On_Menu(wxCommandEvent &event)
 {
 	switch( event.GetId() )
 	{
-	default:
-		CSG_3DView_Dialog::On_Menu(event);
-		break;
+	default: CSG_3DView_Dialog::On_Menu(event); break;
+
+	case MENU_USAGE         : SG_UI_Dlg_Info(C3D_Viewer_PointCloud_Panel::Get_Usage(), _TL("Usage")); return;
 
 	case MENU_SCALE_Z_DEC   : m_pPanel->Parameter_Value_Add("Z_SCALE"   , -0.5); break;
 	case MENU_SCALE_Z_INC   : m_pPanel->Parameter_Value_Add("Z_SCALE"   ,  0.5); break;
@@ -948,8 +937,8 @@ void C3D_Viewer_PointCloud_Dialog::On_Menu(wxCommandEvent &event)
 	case MENU_SIZE_SCALE_DEC: m_pPanel->Parameter_Value_Add("SIZE_SCALE", -1.0); break;
 	case MENU_SIZE_SCALE_INC: m_pPanel->Parameter_Value_Add("SIZE_SCALE",  1.0); break;
 
-	case MENU_VAL_AS_RGB    : m_pPanel->Parameter_Value_Toggle("VAL_AS_RGB" ); break;
-	case MENU_COLORS_GRAD   : m_pPanel->Parameter_Value_Toggle("COLORS_GRAD"); break;
+	case MENU_VAL_AS_RGB    : m_pPanel->Parameter_Value_Toggle("VAL_AS_RGB"   ); break;
+	case MENU_COLORS_GRAD   : m_pPanel->Parameter_Value_Toggle("COLORS_GRAD"  ); break;
 	}
 }
 
@@ -962,8 +951,8 @@ void C3D_Viewer_PointCloud_Dialog::On_Menu_UI(wxUpdateUIEvent &event)
 		CSG_3DView_Dialog::On_Menu_UI(event);
 		break;
 
-	case MENU_VAL_AS_RGB : event.Check(m_pPanel->m_Parameters("VAL_AS_RGB" )->asBool()); break;
-	case MENU_COLORS_GRAD: event.Check(m_pPanel->m_Parameters("COLORS_GRAD")->asBool()); break;
+	case MENU_VAL_AS_RGB : event.Check(m_pPanel->m_Parameters("VAL_AS_RGB" )->asBool()    ); break;
+	case MENU_COLORS_GRAD: event.Check(m_pPanel->m_Parameters("COLORS_GRAD")->asInt() == 1); break;
 	}
 }
 
@@ -985,6 +974,8 @@ C3D_Viewer_PointCloud::C3D_Viewer_PointCloud(void)
 		"3D viewer for point clouds."
 	));
 
+	Set_Description(Get_Description() + C3D_Viewer_PointCloud_Panel::Get_Usage());
+
 	//-----------------------------------------------------
 	Parameters.Add_PointCloud("",
 		"POINTS"	, _TL("Point Cloud"),
