@@ -63,6 +63,8 @@ class C3D_Viewer_TIN_Panel : public CSG_3DView_Panel
 public:
 	C3D_Viewer_TIN_Panel(wxWindow *pParent, CSG_TIN *pTIN, int Field_Z, int Field_Color, CSG_Grid *pDrape);
 
+	static CSG_String			Get_Usage				(void);
+
 
 protected:
 
@@ -122,111 +124,27 @@ C3D_Viewer_TIN_Panel::C3D_Viewer_TIN_Panel(wxWindow *pParent, CSG_TIN *pTIN, int
 		Attributes += pTIN->Get_Field_Name(i); Attributes += "|";
 	}
 
-	//-----------------------------------------------------
-	m_Parameters.Add_Choice("NODE_GENERAL",
-		"Z_ATTR"		, _TL("Z Attribute"),
-		_TL(""),
-		Attributes, zField
-	);
+	m_Parameters.Add_Choice("GENERAL"       , "Z_ATTR"        , _TL("Z Attribute"     ), _TL(""), Attributes, zField);
 
-	//-----------------------------------------------------
-	m_Parameters.Add_Node("",
-		"NODE_VIEW"		, _TL("TIN View Settings"),
-		_TL("")
-	);
+	m_Parameters.Add_Bool  ("GENERAL"       , "DRAW_FACES"    , _TL("Draw Faces"      ), _TL(""), true);
 
-	m_Parameters.Add_Bool("NODE_VIEW",
-		"DRAW_FACES"	, _TL("Draw Faces"),
-		_TL(""),
-		true
-	);
+	m_Parameters.Add_Choice("DRAW_FACES"    , "COLORS_ATTR"   , _TL("Colour Attribute"), _TL(""), Attributes, cField);
+	m_Parameters.Add_Colors("COLORS_ATTR"   , "COLORS"        , _TL("Colours"         ), _TL(""));
+	m_Parameters.Add_Bool  ("COLORS_ATTR"   , "COLORS_GRAD"   , _TL("Graduated"       ), _TL(""), true);
+	m_Parameters.Add_Range ("COLORS_ATTR"   , "COLORS_RANGE"  , _TL("Value Range"     ), _TL(""));
 
-	m_Parameters.Add_Choice("DRAW_FACES",
-		"COLORS_ATTR"	, _TL("Colour Attribute"),
-		_TL(""),
-		Attributes, cField
-	);
+	m_Parameters.Add_Choice("DRAW_FACES"    , "SHADING"       , _TL("Light Source"    ), _TL(""), CSG_String::Format("%s|%s", _TL("no"), _TL("yes")), 1);
+	m_Parameters.Add_Double("SHADING"       , "SHADE_DEC"     , _TL("Height"          ), _TL(""), 45., -180., true, 180., true);
+	m_Parameters.Add_Double("SHADING"       , "SHADE_AZI"     , _TL("Direction"       ), _TL(""), 90., -180., true, 180., true);
 
-	m_Parameters.Add_Colors("COLORS_ATTR",
-		"COLORS"		, _TL("Colours"),
-		_TL("")
-	);
+	m_Parameters.Add_Bool  ("GENERAL"       , "DRAW_EDGES"    , _TL("Draw Wire"       ), _TL(""), false);
+	m_Parameters.Add_Bool  ("DRAW_EDGES"    , "EDGE_COLOR_UNI", _TL("Single Color"    ), _TL(""), false);
+	m_Parameters.Add_Color ("EDGE_COLOR_UNI", "EDGE_COLOR"    , _TL("Color"           ), _TL(""), SG_GET_RGB(150, 150, 150));
 
-	m_Parameters.Add_Bool("COLORS_ATTR",
-		"COLORS_GRAD"	, _TL("Graduated"),
-		_TL(""),
-		true
-	);
-
-	m_Parameters.Add_Range("COLORS_ATTR",
-		"COLORS_RANGE"	, _TL("Value Range"),
-		_TL("")
-	);
-
-	m_Parameters.Add_Choice("DRAW_FACES",
-		"SHADING"		, _TL("Shading"),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("none"),
-			_TL("shading")
-		), 1
-	);
-
-	m_Parameters.Add_Double("SHADING",
-		"SHADE_DEC"		, _TL("Light Source Height"),
-		_TL(""),
-		45., -180., true, 180., true
-	);
-
-	m_Parameters.Add_Double("SHADING",
-		"SHADE_AZI"		, _TL("Light Source Direction"),
-		_TL(""),
-		90., -180., true, 180., true
-	);
-
-	//-----------------------------------------------------
-	m_Parameters.Add_Bool("NODE_VIEW",
-		"DRAW_EDGES"	, _TL("Draw Wire"),
-		_TL(""),
-		false
-	);
-
-	m_Parameters.Add_Bool("DRAW_EDGES",
-		"EDGE_COLOR_UNI", _TL("Single Colour"),
-		_TL(""),
-		false
-	);
-
-	m_Parameters.Add_Color("EDGE_COLOR_UNI",
-		"EDGE_COLOR"	, _TL("Colour"),
-		_TL(""),
-		SG_GET_RGB(150, 150, 150)
-	);
-
-	//-----------------------------------------------------
-	m_Parameters.Add_Bool("",
-		"DRAW_NODES"	, _TL("Draw Nodes"),
-		_TL(""),
-		false
-	);
-
-	m_Parameters.Add_Color("DRAW_NODES",
-		"NODE_COLOR"	, _TL("Colour"),
-		_TL(""),
-		SG_COLOR_BLACK
-	);
-
-	m_Parameters.Add_Int("DRAW_NODES",
-		"NODE_SIZE"		, _TL("Size"),
-		_TL(""),
-		2, 1, true
-	);
-
-	m_Parameters.Add_Double("DRAW_NODES",
-		"NODE_SCALE"	, _TL("Size Scaling"),
-		_TL(""),
-		250., 1., true
-	);
+	m_Parameters.Add_Bool  ("GENERAL"       , "DRAW_NODES"    , _TL("Draw Nodes"      ), _TL(""), false);
+	m_Parameters.Add_Color ("DRAW_NODES"    , "NODE_COLOR"    , _TL("Color"           ), _TL(""), SG_COLOR_BLACK);
+	m_Parameters.Add_Int   ("DRAW_NODES"    , "NODE_SIZE"     , _TL("Size"            ), _TL(""), 2, 1, true);
+	m_Parameters.Add_Double("DRAW_NODES"    , "NODE_SCALE"    , _TL("Size Scaling"    ), _TL(""), 250., 1., true);
 
 	//-----------------------------------------------------
 	Update_Statistics();
@@ -242,13 +160,13 @@ int C3D_Viewer_TIN_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_
 {
 	if( pParameter->Cmp_Identifier("DRAW_FACES") )
 	{
-		CSG_Parameter *pDrape = pParameters->Get_Parameter("DO_DRAPE");
+		CSG_Parameter *pDrape = pParameters->Get_Parameter("MAP_DRAPE");
 
 		pParameters->Set_Enabled("COLORS_ATTR"   , pParameter->asBool() && (!pDrape || !pDrape->asBool()));
 		pParameters->Set_Enabled("SHADING"       , pParameter->asBool());
 	}
 
-	if( pParameter->Cmp_Identifier("DO_DRAPE") )
+	if( pParameter->Cmp_Identifier("MAP_DRAPE") )
 	{
 		CSG_Parameter *pFaces = pParameters->Get_Parameter("DRAW_FACES");
 
@@ -257,8 +175,7 @@ int C3D_Viewer_TIN_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_
 
 	if( pParameter->Cmp_Identifier("SHADING") )
 	{
-		pParameters->Set_Enabled("SHADE_DEC"     , pParameter->asBool());
-		pParameters->Set_Enabled("SHADE_AZI"     , pParameter->asBool());
+		pParameter->Set_Children_Enabled(pParameter->asInt() > 0);
 	}
 
 	if( pParameter->Cmp_Identifier("DRAW_EDGES") )
@@ -289,23 +206,22 @@ int C3D_Viewer_TIN_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_
 //---------------------------------------------------------
 void C3D_Viewer_TIN_Panel::Update_Statistics(void)
 {
-	int	Field	= m_Parameters("COLORS_ATTR")->asInt();
+	int Field = m_Parameters("COLORS_ATTR")->asInt();
 
 	m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
 		m_pTIN->Get_Mean(Field) - 1.5 * m_pTIN->Get_StdDev(Field),
 		m_pTIN->Get_Mean(Field) + 1.5 * m_pTIN->Get_StdDev(Field)
 	);
 
-	m_Data_Min.x	= m_pTIN->Get_Extent().Get_XMin();
-	m_Data_Max.x	= m_pTIN->Get_Extent().Get_XMax();
+	m_Data_Min.x = m_pTIN->Get_Extent().Get_XMin();
+	m_Data_Max.x = m_pTIN->Get_Extent().Get_XMax();
 
-	m_Data_Min.y	= m_pTIN->Get_Extent().Get_YMin();
-	m_Data_Max.y	= m_pTIN->Get_Extent().Get_YMax();
+	m_Data_Min.y = m_pTIN->Get_Extent().Get_YMin();
+	m_Data_Max.y = m_pTIN->Get_Extent().Get_YMax();
 
-	m_Data_Min.z	= m_pTIN->Get_Minimum(m_Parameters("Z_ATTR")->asInt());
-	m_Data_Max.z	= m_pTIN->Get_Maximum(m_Parameters("Z_ATTR")->asInt());
+	m_Data_Min.z = m_pTIN->Get_Minimum(m_Parameters("Z_ATTR")->asInt());
+	m_Data_Max.z = m_pTIN->Get_Maximum(m_Parameters("Z_ATTR")->asInt());
 
-	//-----------------------------------------------------
 	Update_View();
 }
 
@@ -314,24 +230,35 @@ void C3D_Viewer_TIN_Panel::Update_Statistics(void)
 //														 //
 ///////////////////////////////////////////////////////////
 
+//---------------------------------------------------------
+CSG_String C3D_Viewer_TIN_Panel::Get_Usage(void)
+{
+	CSG_Table Shortcuts(CSG_3DView_Panel::Get_Shortcuts());
+
+	#define ADD_SHORTCUT(KEY, CMD) { CSG_Table_Record &r = *Shortcuts.Add_Record(); r.Set_Value(0, KEY); r.Set_Value(1, CMD); }
+
+	ADD_SHORTCUT("F3", _TL("Decrease Size"        ));
+	ADD_SHORTCUT("F4", _TL("Increase Size"        ));
+
+	ADD_SHORTCUT("F5", _TL("Decrease Size Scaling"));
+	ADD_SHORTCUT("F6", _TL("Increase Size Scaling"));
+
+	return( CSG_3DView_Panel::Get_Usage(Shortcuts) );
+}
+
 //---------------------------------------------------------
 void C3D_Viewer_TIN_Panel::On_Key_Down(wxKeyEvent &event)
 {
 	switch( event.GetKeyCode() )
 	{
-	default:
-		CSG_3DView_Panel::On_Key_Down(event);
-		return;
+	default: CSG_3DView_Panel::On_Key_Down(event); return;
 
-	case WXK_F5: m_Parameters("NODE_SIZE" )->Set_Value(m_Parameters("NODE_SIZE" )->asDouble() -  1.0); break;
-	case WXK_F6: m_Parameters("NODE_SIZE" )->Set_Value(m_Parameters("NODE_SIZE" )->asDouble() +  1.0); break;
+	case WXK_F3: Parameter_Value_Add("NODE_SIZE" ,  -1.); break;
+	case WXK_F4: Parameter_Value_Add("NODE_SIZE" ,   1.); break;
 
-	case WXK_F7: m_Parameters("NODE_SCALE")->Set_Value(m_Parameters("NODE_SCALE")->asDouble() - 10.0); break;
-	case WXK_F8: m_Parameters("NODE_SCALE")->Set_Value(m_Parameters("NODE_SCALE")->asDouble() + 10.0); break;
+	case WXK_F5: Parameter_Value_Add("NODE_SCALE", -10.); break;
+	case WXK_F6: Parameter_Value_Add("NODE_SCALE",  10.); break;
 	}
-
-	//-----------------------------------------------------
-	Update_View(); Update_Parent();
 }
 
 
@@ -380,7 +307,7 @@ bool C3D_Viewer_TIN_Panel::On_Draw(void)
 	//-----------------------------------------------------
 	if( m_Parameters("DRAW_FACES")->asBool() )	// Face
 	{
-		bool bDrape = m_Parameters("DO_DRAPE") && m_Parameters("DO_DRAPE")->asBool();
+		bool bDrape = m_Parameters("MAP_DRAPE") && m_Parameters("MAP_DRAPE")->asBool();
 
 		CSG_Vector LightSource;
 
@@ -395,7 +322,7 @@ bool C3D_Viewer_TIN_Panel::On_Draw(void)
 		}
 
 		#pragma omp parallel for
-		for(int iTriangle=0; iTriangle<m_pTIN->Get_Triangle_Count(); iTriangle++)
+		for(sLong iTriangle=0; iTriangle<m_pTIN->Get_Triangle_Count(); iTriangle++)
 		{
 			CSG_TIN_Triangle *pTriangle = m_pTIN->Get_Triangle(iTriangle); TSG_Triangle_Node p[3];
 
@@ -435,7 +362,7 @@ bool C3D_Viewer_TIN_Panel::On_Draw(void)
 		int  Color  = m_Parameters("EDGE_COLOR"    )->asColor();
 
 		#pragma omp parallel for
-		for(int iEdge=0; iEdge<m_pTIN->Get_Edge_Count(); iEdge++)
+		for(sLong iEdge=0; iEdge<m_pTIN->Get_Edge_Count(); iEdge++)
 		{
 			CSG_TIN_Edge *pEdge = m_pTIN->Get_Edge(iEdge); TSG_Triangle_Node p[2];
 
@@ -470,9 +397,9 @@ bool C3D_Viewer_TIN_Panel::On_Draw(void)
 		int Size  = m_Parameters("NODE_SIZE" )->asInt   ();
 
 		#pragma omp parallel for
-		for(int iNode=0; iNode<m_pTIN->Get_Node_Count(); iNode++)
+		for(sLong iNode=0; iNode<m_pTIN->Get_Node_Count(); iNode++)
 		{
-			CSG_TIN_Node *pNode = m_pTIN->Get_Node(iNode); TSG_Point_Z p;
+			CSG_TIN_Node *pNode = m_pTIN->Get_Node(iNode); TSG_Point_3D p;
 
 			p.x = pNode->Get_Point().x;
 			p.y = pNode->Get_Point().y;
@@ -643,12 +570,12 @@ void C3D_Viewer_TIN_Dialog::On_Menu(wxCommandEvent &event)
 {
 	switch( event.GetId() )
 	{
-	default: 
-		CSG_3DView_Dialog::On_Menu(event);
-		break;
+	default: CSG_3DView_Dialog::On_Menu(event); break;
 
-	case MENU_SCALE_Z_DEC: m_pPanel->Parameter_Value_Add("Z_SCALE", -0.5); break;
-	case MENU_SCALE_Z_INC: m_pPanel->Parameter_Value_Add("Z_SCALE",  0.5); break;
+	case MENU_USAGE      : SG_UI_Dlg_Info(C3D_Viewer_TIN_Panel::Get_Usage(), _TL("Usage")); return;
+
+	case MENU_SCALE_Z_DEC: m_pPanel->Parameter_Value_Add("Z_SCALE",  -0.5); break;
+	case MENU_SCALE_Z_INC: m_pPanel->Parameter_Value_Add("Z_SCALE",   0.5); break;
 
 	case MENU_COLORS_GRAD: m_pPanel->Parameter_Value_Toggle("COLORS_GRAD"); break;
 
@@ -697,6 +624,8 @@ C3D_Viewer_TIN::C3D_Viewer_TIN(void)
 		"3D viewer for TIN."
 	));
 
+	Set_Description(Get_Description() + C3D_Viewer_TIN_Panel::Get_Usage());
+
 	//-----------------------------------------------------
 	Parameters.Add_TIN("",
 		"TIN"		, _TL("TIN"),
